diff --git a/books/bookvol10.pamphlet b/books/bookvol10.pamphlet
index 04e0405..f6e93c6 100644
--- a/books/bookvol10.pamphlet
+++ b/books/bookvol10.pamphlet
@@ -3,6 +3,19158 @@
 \input{bookheader.tex}
 \mainmatter
 \setcounter{chapter}{0} % Chapter 1
+\chapter{The Algebra Makefile}
+\section{Adding new algebra}
+This is a complex process by its very nature. Developers and Maintainers
+who undertake the process need to understand quite a lot of detail. The
+ultimate steps to add algebra are tedious but simple. Note that only
+algebra code that gets shipped with the system needs to undergo this
+process. User code can be compiled once the distributed algebra exists
+and does not need either this Makefile or this installation process.
+
+Since understanding is the key to making correct changes to this file
+I'll work on explaining the details of why things need to exist. 
+
+The first idea that you need to understand is the overall process
+of adding algebra code. Lets assume that you have a brand new spad
+file, called bsd.spad containing a simple domain BSD. The
+steps in the process of adding this file are:
+\begin{enumerate}
+\item Find out where the algebra code lives in the lattice.
+\begin{enumerate}
+\item Start a new interpsys session. This will give you a clean build.
+\item )set mes auto on -- This will allow us to see what algebra files
+get loaded during compile
+\item )co BAR.spad       
+\item We collect all the names of the algebra files BSD loaded. Look for
+lines that say a file is loaded. Collect all of the names of those files.
+\item For each of the loaded files determine which layer contains the 
+loaded file by searching this file. For instance, if BAR.spad required
+FSAGG then look for /FSAGG.o, which resides in layer 13. 
+\item Determine the highest layer (e.g. 13) that contains the required files
+and add the new algebra file (e.g. BSD.o) in the next layer (e.g. 14).
+\item Next we need to create the graph structure information. This involves
+creating a two part stanza of information. For instance,
+\begin{verbatim}
+"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
+        shape=ellipse]
+/*"BSD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "INT"}*/
+/*"BSD" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"BSD" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "OM"; "PATMAB"}*/
+"BSD" -> "FSAGG" 
+\end{verbatim}
+\item The first part determines the color, shape of the graph node,
+and a link to the book containing the source code. The color and name
+of the book are related:
+\begin{enumerate}
+\item \#4488FF == bookvol10.2
+\item \#88FF44 == bookvol10.3
+\item \#FF4488 == bookvol10.4
+\item \#444488 == bookvol10.5
+\end{enumerate}
+\item The second part is the graph structure. All of the loaded algebra
+files are listed (currently as comments due to the size of the complete
+graph). In particular, the node that ``supports'' BSD is FSAGG so we
+make sure that the graph edge \verb|"BSD" -> "FSAGG"| is uncommented.
+\end{enumerate}
+\item Insert the documentation after the layer (e.g after layer 14).
+This documentation is used to reconstruct the full and partial graphs.
+\item Insert the \verb|${OUT}/BSD.o| file into the layer's file list. This
+will cause the algebra to build after all of the algebra it depends on is
+built.
+\item Add the algebra to the books
+\end{enumerate}
+
+\section{Adding the algebra to the proper book}
+The algebra sources are in 4 books:
+\begin{itemize}
+\item bookvol10.2 == Category
+\item bookvol10.3 == Domain
+\item bookvol10.4 == Package
+\item bookvol10.5 == Numeric
+\end{itemize}
+The algebra in these files is structured slightly differently for each
+one. Follow the directions for the kind of algebra you are adding.
+\subsection{Adding a Category}
+\subsection{Adding a Domain}
+In the Domains book we see that each domain is in alphabetic order by
+the {\bf full domain name}, not by the abbreviation. So for BSD we see
+several parts. 
+\subsubsection{The section separator}
+This gives a visual and logical separation for each domain. 
+\begin{verbatim}
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\section{domain BSD BasicStochasticDifferential}
+\end{verbatim}
+
+\subsubsection{The input section}
+This is a standard input file format. It will be extracted from the book
+during the testing process so we can keep the test cases with the domain.
+The --R lines are the commented output of actually running the functions.
+Note that ``--'' is the comment character in Axiom. The ``regress'' function
+will run the code and then compare the actual output with the lines marked
+``--R'' and report any differences. 
+
+You can create this file by:
+\begin{itemize}
+\item Start Axiom
+\item make a bsd.input file with all of your algebra tests
+\item )co BSD -- compile your algebra to make sure it is up to date
+\item )spool BSD.output -- this will put all output into a file
+\item )read bsd -- this will read the tests and the output will be
+stored in BSD.output
+\item Modify the BSD.output file to have the same format using 
+``--S n of N'' to start the test, ``--R'' to prefix the actual output, 
+and ``--E n'' to end the test.
+\item save the test as bsdtest.input
+\item Validate the newly formatted test file (bsdtest.input):
+\begin{itemize}
+\item start a new Axiom
+\item )co BSD -- compile your new algebra
+\item )read bsdtest.input -- BE SURE to use the new test file format.
+If you did it right it will create a new file called
+BasicStochasticDifferential.output
+\item )lisp (regress "BasicStochasticDifferential.output") -- this will
+run the regress function which compares the actual output with the
+expected output and reports success or failure.
+\item fix up failures and repeat until none remain
+\item add the contents of bsdtest.input to the algebra file
+\end{itemize}
+\end{itemize}
+
+\subsubsection{The input section}
+Here we use BasicStochasticDifferential.output to create a set of test
+cases. These are automatically extracted as part of the build process
+by the function ``makeInputFiles''. This function is in the tangle.lisp file.
+\begin{verbatim}
+
+)set break resume
+)sys rm -f BasicStochasticDifferential.output
+)spool BasicStochasticDifferential.output
+)set message test on
+)set message auto off
+)clear all
+--S 1 of 2
+q := D(p, x)
+--R 
+--R
+--R                 __
+--R   (6)  0.1x + 0.10
+--R                                             Type: Polynomial BinaryExpansion
+--E 1
+
+--S 2 of 2
+g := gcd(p, q)
+--R 
+--R
+--R              __
+--R   (7)  x + 1.01
+--R                                             Type: Polynomial BinaryExpansion
+--E 2
+
+)spool
+)lisp (bye)
+
+\end{verbatim}
+
+\subsubsection{The help section}
+This section becomes a help file in the distributed Axiom system.
+This section is automatically extracted as part of the build process
+by the function ``makeHelpFiles''. This function is in the tangle.lisp file.
+The help section gets typed out when the user types:
+\begin{verbatim}
+)help BasicStochasticDifferential
+\end{verbatim}
+\begin{verbatim}
+begin{chunk}{BasicStochasticDifferential.help}
+====================================================================
+BasicStochasticDifferential examples
+====================================================================
+All rational numbers have repeating binary expansions.  Operations to
+access the individual bits of a binary expansion can be obtained by
+converting the value to RadixExpansion(2).  More examples of
+expansions are available with
+
+The expansion (of type BinaryExpansion) of a rational number is
+returned by the binary operation.
+
+  r := binary(22/7)
+      ___
+   11.001
+                      Type: BinaryExpansion
+
+Arithmetic is exact.
+
+  r + binary(6/7)
+   100 
+                      Type: BinaryExpansion
+
+See Also:
+o )help BasicStochasticDifferential
+o )help HexadecimalExpansion
+o )show BasicStochasticDifferential
+
+end{chunk}
+\end{verbatim}
+
+\subsubsection{The pagehead section}
+Next we create the format information for the book itself. This will
+control the display of the new algebra in the book. The ``pagehead''
+macro formats a new section for this algebra and adds it to the proper
+indexing and other housekeeping sections.
+
+The ``pagepic'' creates a graph image inline showing the subgraph
+containing this algebra from the full graph. This information is kept
+in this file (see the graph subsection below). The ``1.00'' is a 
+scaling factor for the graph.
+
+The ``pageto'' macro inserts HTML anchors into the PDF file so there
+is a way to navigate to algebra that is ``above'' this domain in the
+graph. There can be multiple pageto macros.
+
+The ``pagefrom'' macro inserts HTML anchors into the PDF file so there
+is a way to navigate to algebra that is ``below'' this domain in the
+graph. There can be multiple pagefrom macros.
+
+Together these two macros, pageto and pagefrom, allow the user to 
+follow the thread of domains in the PDF documentation.
+\begin{verbatim}
+\pagehead{BasicStochasticDifferential}{BSD}
+\pagepic{ps/v103basicstochasticdifferential.ps}{BSD}{1.00}
+{\bf See}\\
+\pageto{HexadecimalExpansion}{HEXADEC}
+\end{verbatim}
+
+\subsubsection{The Exports section}
+This shows the same information as the ``)show'' function in a running
+Axiom. The ``cross'' macro adds information to the index to cross reference
+the domain and the functions.
+\begin{verbatim}
+{\bf Exports:}\\
+\begin{tabular}{lll}
+\cross{BSD}{0} &
+\cross{BSD}{1} &
+\cross{BSD}{abs} \\
+\cross{BSD}{associates?} &
+\cross{BSD}{binary} &
+\cross{BSD}{ceiling} \\
+\cross{BSD}{characteristic} 
+\end{tabular}
+\end{verbatim}
+
+\subsubsection{The Code section}
+This is the actual algebra. Note that the ``++'' comments from the 
+description section are available at runtime using the ``)describe''
+command. They have certain format limitations so be sure to check
+this in the final system. 
+
+The signatures have comments. If the comments are broken into two
+parts and the lines of the second part of the comment start with
+``++X'' then these will be typed out as part of the output of the
+command ``)d op''. For instance, in the code below for the ``introduce!''
+function the comments read:
+\begin{verbatim}
+  introduce!: (Symbol,Symbol) -> Union(%, "failed")
+   ++ introduce!(X,dX) returns \axiom{dX} as \axiom{BSD} if it
+   ++ isn't already in \axiom{BSD}
+   ++
+   ++X introduce!(t,dt)
+\end{verbatim}
+When we type ``)d op introduce!'' in a running Axiom we will see the
+example text:
+\begin{verbatim}
+   introduce!(t,dt)
+\end{verbatim}
+\begin{verbatim}
+<domain BSD BasicStochasticDifferential>>=
+)abbrev domain BSD BasicStochasticDifferential
+++ Basic Operations: introduce!, copyBSD, copyIto, getSmgl
+++ Related Domains: StochasticDifferential(R)
+++ Also See:
+++ AMS Classifications:
+++ Keywords: stochastic differential, semimartingale.
+++ Examples:
+++ References:
+++ Ito (1975), Kendall (1991a,b; 1993a,b; 1999a,b).
+++ Description:
+++ Based on Symbol: a domain of symbols
+++ representing basic stochastic differentials, used
+++ in StochasticDifferential(R) in the underlying
+++ sparse multivariate polynomial representation.
+++
+++ We create new BSD only by coercion from Symbol
+++ using a special function introduce! first of all to 
+++ add to a private set SDset. We allow a separate 
+++ function convertIfCan which will check whether the
+++ argument has previously been declared as a BSD.
+BasicStochasticDifferential(): Category == Implementation where
+ INT ==> Integer
+ OF  ==> OutputForm
+ Category ==> OrderedSet with
+  ConvertibleTo(Symbol)
+
+  convertIfCan: Symbol -> Union(%, "failed")
+   ++ convertIfCan(ds) transforms \axiom{dX} into a \axiom{BSD}
+   ++ if possible (if \axiom{introduce(X,dX)} has
+   ++ been invoked previously).
+
+  convert: Symbol -> %
+   ++ convert(dX) transforms \axiom{dX} into a \axiom{BSD}
+   ++ if possible and otherwise produces an error.
+
+  introduce!: (Symbol,Symbol) -> Union(%, "failed")
+   ++ introduce!(X,dX) returns \axiom{dX} as \axiom{BSD} if it
+   ++ isn't already in \axiom{BSD}
+
+  d: Symbol -> Union(%,INT)
+   ++ d(X) returns \axiom{dX} if \axiom{tableIto(X)=dX}
+   ++ and otherwise returns \axiom{0}
+
+  copyBSD:() -> List %
+   ++ copyBSD() returns \axiom{setBSD} as a list of \axiom{BSD}.
+  copyIto:() -> Table(Symbol,%)
+   ++ copyIto() returns the table relating semimartingales
+   ++ to basic stochastic differentials.
+  getSmgl: % -> Union(Symbol,"failed")
+   ++ getSmgl(bsd) returns the semimartingale \axiom{S} related
+   ++ to the basic stochastic differential \axiom{bsd} by
+   ++ \axiom{introduce!}
+
+ Implementation ==> Symbol add 
+
+  Rep := Symbol
+
+  setBSD := empty()$Set(Symbol)
+  tableIto:Table(Symbol,%) := table()
+  tableBSD:Table(%,Symbol) := table()
+
+  convertIfCan(ds:Symbol):Union(%,"failed") ==
+   not(member?(ds,setBSD)) => "failed"
+   ds::%
+
+  convert(ds:Symbol):% ==
+   (du:=convertIfCan(ds)) 
+    case "failed" =>
+     print(hconcat(ds::Symbol::OF,
+       message(" is not a stochastic differential")$OF))
+     error "above causes failure in convert$BSD"
+   du
+
+  introduce!(X,dX) == 
+   member?(dX,setBSD) => "failed"
+   insert!(dX,setBSD)
+   tableBSD(dX::%) := X
+   tableIto(X) := dX::%
+
+  d(X) ==
+   search(X,tableIto) case "failed" => 0::INT
+   tableIto(X)
+
+  copyBSD() == [ds::% for ds in members(setBSD)]
+  copyIto() == tableIto
+  getSmgl(ds:%):Union(Symbol,"failed") == tableBSD(ds)
+\end{verbatim}
+
+\subsubsection{The dotabb section}
+This section is used to create the ``ps/v103basicstochasticdifferential.ps''
+graph image used above. The actual code used is kept here so we can modify
+or reproduce the result. The first line is the current domain. The second
+line is the domain, category, or package that ``supports'' this domain 
+in the previous layer. These three lines are create the subgraph of the
+main algebra graph.
+\begin{verbatim}
+<BINARY.dotabb>>=
+"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
+        shape=ellipse]
+"FSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FSAGG"]
+"BSD" -> "FSAGG"
+
+\end{chunk}
+\end{verbatim}
+In order to actually create the graph this code gets wrapped with the
+graphviz information. So you pick up the above lines and insert them
+into a file surrounded by the graphviz commands as in:
+\begin{verbatim}
+digraph pic {
+ fontsize=10;
+ bgcolor="#ECEA81";
+ node [shape=box, color=white, style=filled];
+
+"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
+        shape=ellipse]
+"FSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FSAGG"]
+"BSD" -> "FSAGG"
+
+}
+\end{verbatim}
+Save this in a file, say bsd.dot.
+To create the correct postscript file use the command:
+\begin{verbatim}
+   dot -Teps bsd.dot >ps/v103basicstochasticdifferential.eps
+\end{verbatim}
+Notice that the output goes into a ps subdirectory. It is named
+with the v103 prefix, meaning it is intended for volume 10.3.
+
+The REGRESS table contains the names of all of the regression
+files. These are the test case files we constructed for the
+algebra. Putting a chunk name in this table will extract the test
+case, run it, and run regression testing on it looking for
+failures. The naming convention is the same as the .input file but
+uses .regress so the Makefile regression stanza is invoked. So, for
+our example, we need to add
+\begin{verbatim}
+    BasicStochasticDifferential.regress
+\end{verbatim}
+
+We must also add the domain to the \verb|$globalExposureGroupAlist|
+in the interpreter (book volume 5). This is a lisp cons structure
+where the CAR is the domain name and the CDR is the domain abbreviation.
+So we add the line:
+\begin{verbatim}
+   (|BasicStochasticDifferential| . BSD)
+\end{verbatim}
+
+\subsection{Adding a Package}
+\subsection{Adding Numerics}
+
+\section{Rebuilding the algebra from scratch}
+Compile order is important. Here we try to define the ordered lattice
+of spad file dependencies. However this is, in reality, a graph rather
+than a lattice. In order to break cycles in this graph we explicitly
+cache a few of the intermediate generated lisp code for certain files.
+These are marked throughout (both here and in the various pamphlet
+files) with the word {\bf BOOTSTRAP}.
+
+If we take a cycle such as {\bf RING} we discover that in order to
+compile the spad code we must load the compiled definition of {\bf RING}.
+In this case we must compile the cached lisp code before we try to 
+compile the spad file.
+
+The cycle for {\bf SETCAT} is longer consisting of: {\bf SETCAT} needs
+{\bf SINT} needs {\bf UFD} needs {\bf GCDDOM} needs {\bf COMRING} needs
+{\bf RING} needs {\bf RNG} needs {\bf ABELGRP} needs {\bf CABMON} needs
+{\bf ABELMON} needs {\bf ABELSG} needs {\bf SETCAT}.
+
+It is highly recommended that you try to become a developer of Axiom
+and read the archived mailing lists before you decide to change a
+cached file. In the fullness of time we will rewrite the whole algebra
+structure into a proper lattice if possible. Alternatively we'll
+reimplement the compiler to handle graphs. Or deeply adopt the
+extensible domains. Whatever we do will be much discussed (and cause
+much disgust) around the campfire. If you come up with a brilliant
+plan that gets adopted we'll even inscribe your name on a log and add
+it to the fire.
+
+In the code that follows we find the categories, packages and domains
+that compile with no dependencies and call this set ``layer 0''. Next
+we find the categories, packages and domains that will compile using
+only ``layer 0'' code and call this ``layer 1''. We walk up the
+lattice in this fashion adding layers. Note that at layer 3 this
+process runs into cycles and we create the ``layer 3 bootstrap''
+stanzas before continuing upward.
+
+\section{The Algebra Lattice Layers}
+\subsection{Layer 0 Bootstrap}
+The easiest way to find out where a spad file lives in the hierarchy
+is to create the following script (called 'show'):
+\begin{verbatim}
+  echo ")co $1" | AXIOMsys >out
+  fgrep abbreviates out
+  fgrep "Loading" out | grep -v autoload
+\end{verbatim}
+and then run it with ``./show FOO'' where the algebra source file
+is FOO.spad.
+
+Each layer is followed by a layerpic chunk which gives the graphviz
+graph information. The graphviz header information is here:
+\begin{chunk}{layerpic}
+digraph pic {
+ fontsize=10;
+ bgcolor="\#ECEA81";
+ node [shape=box, color=white, style=filled];
+ ranksep=3.0;
+ /* nodsep=inches */
+ /* size="x,y", size="7.5,10" fits 8.5x11 page */
+ /* ratio=auto */ /* page="x,y" */ /* generates multipage layout */
+ /* margin=0 */
+
+"Category" [color="\#4488FF"]
+"Category" -> "."
+
+"Domain" [color="\#88FF44"]
+"Domain" -> "."
+
+"Package" [color="\#FF4488"]
+"Package" -> "."
+
+\end{chunk}
+
+\subsubsection{Completed spad files}
+Note well that none of the algebra stanzas should include these
+files in the preconditions otherwise we have an infinite compile
+loop. These files are originally bootstrapped from lisp code
+when we build the system for the first time but they are
+forcibly recompiled at the end of the build so they reflect
+current code (just in case someone changes the spad code but
+does not re-cache the generated lisp). If you add these files
+as preconditions (note that they are all in the {\bf MID} 
+directory rather than the {\bf OUT} directory like everything
+else) then the final recompile will invalidate all of the
+rest of the algebra targets which will get rebuilt again causing
+these targets to be out of date. The rest of the loop is left
+up to the student.
+
+The bootstrap process works because first we ask for the compiled
+lisp code stanzas (the \verb|\${MID}/BAR.o| files), THEN we ask for
+the final algebra code stanzas (the \verb|\${OUT}/BAR.o| files). This
+is a very subtle point so think it through carefully. Notice that
+this is the only layer calling for \verb|\${MID}| files. All other 
+layers call for \verb|\${OUT}| files. If you break this the world
+will no longer compile so don't change it if you don't understand it.
+
+\begin{verbatim}
+LAYER0BOOTSTRAP=${OUT}/XPR.o 
+\end{verbatim}
+
+\begin{chunk}{layer0 bootstrap}
+
+LAYER0BOOTSTRAP=\
+  ${MID}/ABELGRP.o  ${MID}/ABELGRP-.o ${MID}/ABELMON.o  ${MID}/ABELMON-.o \
+  ${MID}/ABELSG.o   ${MID}/ABELSG-.o  ${MID}/ALAGG.o    ${MID}/BOOLEAN.o  \
+  ${MID}/CABMON.o   ${MID}/CHAR.o     ${MID}/CLAGG.o    ${MID}/CLAGG-.o   \
+  ${MID}/COMRING.o  ${MID}/DFLOAT.o   ${MID}/DIFRING.o  ${MID}/DIFRING-.o \
+  ${MID}/DIVRING.o  ${MID}/DIVRING-.o ${MID}/ENTIRER.o  ${MID}/ES.o       \
+  ${MID}/ES-.o      ${MID}/EUCDOM.o   ${MID}/EUCDOM-.o  ${MID}/FFIELDC.o  \
+  ${MID}/FFIELDC-.o ${MID}/FPS.o      ${MID}/FPS-.o     ${MID}/GCDDOM.o   \
+  ${MID}/GCDDOM-.o  ${MID}/HOAGG.o    ${MID}/HOAGG-.o   ${MID}/ILIST.o    \
+  ${MID}/INS.o      ${MID}/INS-.o     ${MID}/INT.o      ${MID}/INTDOM.o   \
+  ${MID}/INTDOM-.o  ${MID}/ISTRING.o  ${MID}/LIST.o     ${MID}/LNAGG.o    \
+  ${MID}/LNAGG-.o   ${MID}/LSAGG.o    ${MID}/LSAGG-.o   ${MID}/MONOID.o   \
+  ${MID}/MONOID-.o  ${MID}/MTSCAT.o   ${MID}/NNI.o      ${MID}/OINTDOM.o  \
+  ${MID}/ORDRING.o  ${MID}/ORDRING-.o ${MID}/OUTFORM.o  ${MID}/PI.o       \
+  ${MID}/PRIMARR.o  ${MID}/POLYCAT.o  ${MID}/POLYCAT-.o ${MID}/PSETCAT.o  \
+  ${MID}/PSETCAT-.o ${MID}/QFCAT.o    ${MID}/QFCAT-.o   ${MID}/RCAGG.o    \
+  ${MID}/RCAGG-.o   ${MID}/REF.o      ${MID}/RING.o     ${MID}/RING-.o    \
+  ${MID}/RNG.o      ${MID}/RNS.o      ${MID}/RNS-.o     ${MID}/SETAGG.o   \
+  ${MID}/SETAGG-.o  ${MID}/SETCAT.o   ${MID}/SETCAT-.o  ${MID}/SINT.o     \
+  ${MID}/STAGG.o    ${MID}/STAGG-.o   ${MID}/SYMBOL.o   ${MID}/TSETCAT.o  \
+  ${MID}/TSETCAT-.o ${MID}/UFD.o      ${MID}/UFD-.o     ${MID}/ULSCAT.o   \
+  ${MID}/UPOLYC.o   ${MID}/UPOLYC-.o  ${MID}/URAGG.o    ${MID}/URAGG-.o   \
+  ${MID}/VECTOR.o \
+  layer0bootstrap
+
+\end{chunk}
+\begin{chunk}{layer0 copy}
+
+LAYER0COPY=\
+  ${OUT}/ABELGRP.o  ${OUT}/ABELGRP-.o ${OUT}/ABELMON.o  ${OUT}/ABELMON-.o \
+  ${OUT}/ABELSG.o   ${OUT}/ABELSG-.o  ${OUT}/ALAGG.o    ${OUT}/BOOLEAN.o  \
+  ${OUT}/CABMON.o   ${OUT}/CHAR.o     ${OUT}/CLAGG.o    ${OUT}/CLAGG-.o   \
+  ${OUT}/COMRING.o  ${OUT}/DFLOAT.o   ${OUT}/DIFRING.o  ${OUT}/DIFRING-.o \
+  ${OUT}/DIVRING.o  ${OUT}/DIVRING-.o ${OUT}/ENTIRER.o  ${OUT}/ES.o       \
+  ${OUT}/ES-.o      ${OUT}/EUCDOM.o   ${OUT}/EUCDOM-.o  ${OUT}/FFIELDC.o  \
+  ${OUT}/FFIELDC-.o ${OUT}/FPS.o      ${OUT}/FPS-.o     ${OUT}/GCDDOM.o   \
+  ${OUT}/GCDDOM-.o  ${OUT}/HOAGG.o    ${OUT}/HOAGG-.o   ${OUT}/ILIST.o    \
+  ${OUT}/INS.o      ${OUT}/INS-.o     ${OUT}/INT.o      ${OUT}/INTDOM.o   \
+  ${OUT}/INTDOM-.o  ${OUT}/ISTRING.o  ${OUT}/LIST.o     ${OUT}/LNAGG.o    \
+  ${OUT}/LNAGG-.o   ${OUT}/LSAGG.o    ${OUT}/LSAGG-.o   ${OUT}/MONOID.o   \
+  ${OUT}/MONOID-.o  ${OUT}/MTSCAT.o   ${OUT}/NNI.o      ${OUT}/OINTDOM.o  \
+  ${OUT}/ORDRING.o  ${OUT}/ORDRING-.o ${OUT}/OUTFORM.o  ${OUT}/PI.o       \
+  ${OUT}/PRIMARR.o  ${OUT}/POLYCAT.o  ${OUT}/POLYCAT-.o ${OUT}/PSETCAT.o  \
+  ${OUT}/PSETCAT-.o ${OUT}/QFCAT.o    ${OUT}/QFCAT-.o   ${OUT}/RCAGG.o    \
+  ${OUT}/RCAGG-.o   ${OUT}/REF.o      ${OUT}/RING.o     ${OUT}/RING-.o    \
+  ${OUT}/RNG.o      ${OUT}/RNS.o      ${OUT}/RNS-.o     ${OUT}/SETAGG.o   \
+  ${OUT}/SETAGG-.o  ${OUT}/SETCAT.o   ${OUT}/SETCAT-.o  ${OUT}/SINT.o     \
+  ${OUT}/STAGG.o    ${OUT}/STAGG-.o   ${OUT}/SYMBOL.o   ${OUT}/TSETCAT.o  \
+  ${OUT}/TSETCAT-.o ${OUT}/UFD.o      ${OUT}/UFD-.o     ${OUT}/ULSCAT.o   \
+  ${OUT}/UPOLYC.o   ${OUT}/UPOLYC-.o  ${OUT}/URAGG.o    ${OUT}/URAGG-.o   \
+  ${OUT}/VECTOR.o \
+  layer0copy
+
+\end{chunk}
+\subsection{Layer 0}
+Depends on: Category Domain Package Bootstrap\\
+Used by next layer: BASTYPE CFCAT KOERCE KONVERT TYPE
+\begin{chunk}{layer0}
+
+LAYER0=\
+  ${OUT}/AHYP.o     ${OUT}/ATADDVA.o  ${OUT}/ATCENRL.o  ${OUT}/ATCS.o \
+  ${OUT}/ATAPPRO.o  ${OUT}/ATARBEX.o \
+  ${OUT}/ATARBPR.o  ${OUT}/ATCANCL.o  ${OUT}/ATCANON.o  ${OUT}/ATCUNOR.o \
+  ${OUT}/ATFINAG.o  ${OUT}/ATJACID.o  ${OUT}/ATLR.o     ${OUT}/ATLUNIT.o \
+  ${OUT}/ATMULVA.o  ${OUT}/ATNOTHR.o  ${OUT}/ATNULSQ.o \
+  ${OUT}/ATNZDIV.o  ${OUT}/ATPOSET.o \
+  ${OUT}/ATSHMUT.o \
+  ${OUT}/ATTREG.o   ${OUT}/ATUNIKN.o \
+  ${OUT}/BASTYPE.o  ${OUT}/BASTYPE-.o \
+  ${OUT}/CFCAT.o    ${OUT}/ELTAB.o    ${OUT}/ESCONT1.o ${OUT}/GRDEF.o \
+  ${OUT}/INTBIT.o   ${OUT}/KOERCE.o   ${OUT}/KONVERT.o \
+  ${OUT}/MAGCDOC.o  ${OUT}/MSYSCMD.o \
+  ${OUT}/ODEIFTBL.o ${OUT}/OM.o       ${OUT}/OMCONN.o  ${OUT}/OMDEV.o  \
+  ${OUT}/OUT.o      ${OUT}/PRIMCAT.o  ${OUT}/PRINT.o   ${OUT}/PTRANFN.o \
+  ${OUT}/RFDIST.o   ${OUT}/RIDIST.o   ${OUT}/SPFCAT.o  ${OUT}/TYPE.o \
+  layer0done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 0 */
+/* depends on: Category Domain Package Bootstrap */
+/* provides: BASTYPE CFCAT KOERCE KONVERT TYPE */
+
+"AHYP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=AHYP"]
+"AHYP" -> "Category"
+
+"ATADDVA"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATADDVA"];
+"ATADDVA" -> "Category"
+
+"ATCENRL"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCENRL"];
+"ATCENRL" -> "Category"
+
+"ATCS"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCS"];
+"ATCS" -> "Category"
+
+"ATAPPRO"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATAPPRO"];
+"ATAPPRO" -> "Category"
+
+"ATARBEX"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATARBEX"];
+"ATARBEX" -> "Category"
+
+"ATARBPR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATARBPR"];
+"ATARBPR" -> "Category"
+
+"ATCANCL"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCANCL"];
+"ATCANCL" -> "Category"
+
+"ATCANON"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCANON"];
+"ATCANON" -> "Category"
+
+"ATCUNOR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCUNOR"];
+"ATCUNOR" -> "Category"
+
+"ATFINAG"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATFINAG"];
+"ATFINAG" -> "Category"
+
+"ATJACID"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATJACID"];
+"ATJACID" -> "Category"
+
+"ATLR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATLR"];
+"ATLR" -> "Category"
+
+"ATLUNIT"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATLUNIT"];
+"ATLUNIT" -> "Category"
+
+"ATMULVA"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATMULVA"];
+"ATMULVA" -> "Category"
+
+"ATNOTHR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATNOTHR"];
+"ATNOTHR" -> "Category"
+
+"ATNULSQ"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATNULSQ"];
+"ATNULSQ" -> "Category"
+
+"ATNZDIV"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATNZDIV"];
+"ATNZDIV" -> "Category"
+
+"ATSHMUT"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATSHMUT"];
+"ATSHMUT" -> "Category"
+
+"ATTREG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ATTREG"]
+"ATTREG"  -> "Category"
+
+"ATUNIKN"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATUNIKN"];
+"ATUNIKN" -> "Category"
+
+/* nobody seems to go to bastype by itself */
+/* we combine these two to minimize edges in the graph */
+/* note that koerce is duplicated */
+"BASTYPE/KOERCE" [color="blue",href="bookvol10.2.pdf#nameddest=BASTYPE"]
+"BASTYPE/KOERCE" -> "Category"
+/*"BASTYPE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BASTYPE"]*/
+/*"BASTYPE" -> "Category"*/
+/*"BASTYPE" -> "BOOLEAN"*/
+"KOERCE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=KOERCE"]
+"KOERCE"  -> "Category"
+
+"BASTYPE-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BASTYPE"]
+"BASTYPE-" -> "Domain"
+/*"BASTYPE-" -> "BOOLEAN"*/
+
+"CFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CFCAT"]
+"CFCAT"  -> "Category"
+
+"ELTAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELTAB"]
+"ELTAB"  -> "Category"
+
+"ESCONT1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESCONT1"]
+"ESCONT1" -> "Package"
+/*"ESCONT1" -> "DFLOAT"*/
+/*"ESCONT1" -> "BOOLEAN"*/
+
+"GRDEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GRDEF"]
+"GRDEF" -> "Package"
+/*"GRDEF" -> "BOOLEAN"*/
+
+"INTBIT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTBIT"]
+"INTBIT" -> "Package"
+/*"INTBIT" -> "INT"*/
+
+"KONVERT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=KONVERT"]
+"KONVERT"  -> "Category"
+
+"MAGCDOC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MAGCDOC"]
+"MAGCDOC" -> "Category"
+
+"MSYSCMD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MSYSCMD"]
+"MSYSCMD" -> "Package"
+
+"ODEIFTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODEIFTBL"]
+"ODEIFTBL" -> "Domain"
+
+"OM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OM"]
+"OM"  -> "Category"
+
+"OMCONN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMCONN"]
+"OMCONN" -> "Domain"
+
+"OMDEV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMDEV"]
+"OMDEV" -> "Domain"
+
+"OUT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OUT"]
+"OUT" -> "Package"
+/* "OUT" -> {"STRING", "CHAR", "SINT", "OUTFORM", "LIST", "INT"}*/
+/* "OUT" -> {"PRIMARR", "A1AGG-", "ISTRING"} */
+
+"PRIMCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PRIMCAT"]
+"PRIMCAT"  -> "Category"
+
+"PRINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRINT"]
+"PRINT" -> "Package"
+
+"PTRANFN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PTRANFN"]
+"PTRANFN"  -> "Category"
+
+"RFDIST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFDIST"]
+"RFDIST" -> "Package"
+/*"RFDIST" -> {"INT"; "PI"; "NNI"; "BOOLEAN"; "SINT"}*/
+
+"RIDIST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RIDIST"]
+"RIDIST" -> "Package"
+/*"RIDIST" -> {"SINT"; "NNI"; "INT"}*/
+
+"SPFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SPFCAT"]
+"SPFCAT"  -> "Category"
+
+"TYPE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TYPE"]
+"TYPE"  -> "Category"
+
+\end{chunk}
+\subsection{Layer 1}
+Depends on: BASTYPE CFCAT KOERCE KONVERT TYPE\\
+Used by next layer: AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE 
+MONAD ORDSET PATMAB RETRACT RMODULE SGROUP 
+
+\begin{chunk}{layer1}
+
+LAYER1=\
+  ${OUT}/AGG.o      ${OUT}/AGG-.o     ${OUT}/ANON.o     ${OUT}/ANY1.o     \
+  ${OUT}/BLMETCT.o  \
+  ${OUT}/COLOR.o    ${OUT}/COMBOPC.o  ${OUT}/COMM.o     ${OUT}/COMPAR.o   \
+  ${OUT}/COMPPROP.o \
+  ${OUT}/DROPT1.o   ${OUT}/ELTAGG.o   ${OUT}/ELTAGG-.o  ${OUT}/EQ2.o      \
+  ${OUT}/EXIT.o     ${OUT}/FILECAT.o  ${OUT}/FINITE.o   ${OUT}/FINITE-.o  \
+  ${OUT}/FNCAT.o    \
+  ${OUT}/FORMULA1.o ${OUT}/FORTCAT.o  ${OUT}/IDPC.o     ${OUT}/IEVALAB.o  \
+  ${OUT}/IEVALAB-.o ${OUT}/ITFUN2.o   ${OUT}/ITFUN3.o   ${OUT}/ITUPLE.o   \
+  ${OUT}/LIST3.o    ${OUT}/LMODULE.o  ${OUT}/LOGIC.o    ${OUT}/LOGIC-.o   \
+  ${OUT}/MAPHACK1.o ${OUT}/MAPHACK2.o ${OUT}/MAPHACK3.o ${OUT}/MAPPKG1.o  \
+  ${OUT}/MAPPKG2.o  ${OUT}/MAPPKG3.o  ${OUT}/MKBCFUNC.o ${OUT}/MKFUNC.o   \
+  ${OUT}/MKRECORD.o ${OUT}/MKUCFUNC.o ${OUT}/MONAD.o    ${OUT}/MONAD-.o   \
+  ${OUT}/NIPROB.o   ${OUT}/NONE.o     ${OUT}/NONE1.o    ${OUT}/NUMINT.o   \
+  ${OUT}/ODECAT.o   ${OUT}/ODEPROB.o  ${OUT}/OMENC.o    ${OUT}/ONECOMP2.o \
+  ${OUT}/OPTCAT.o   ${OUT}/OPTPROB.o  ${OUT}/ORDCOMP2.o ${OUT}/ORDSET.o   \
+  ${OUT}/ORDSET-.o  ${OUT}/PALETTE.o  ${OUT}/PARPCURV.o ${OUT}/PARPC2.o   \
+  ${OUT}/PARSCURV.o ${OUT}/PARSC2.o   ${OUT}/PARSURF.o  ${OUT}/PARSU2.o   \
+  ${OUT}/PATAB.o    ${OUT}/PATMAB.o   ${OUT}/PATRES2.o  ${OUT}/PATTERN1.o \
+  ${OUT}/PDECAT.o   ${OUT}/PDEPROB.o  ${OUT}/PLOT1.o    ${OUT}/PPCURVE.o  \
+  ${OUT}/PSCURVE.o  ${OUT}/REAL.o     ${OUT}/REPDB.o    ${OUT}/REPSQ.o    \
+  ${OUT}/RESLATC.o  ${OUT}/RETRACT.o  ${OUT}/RETRACT-.o ${OUT}/RMODULE.o  \
+  ${OUT}/SEGBIND2.o ${OUT}/SEGCAT.o   ${OUT}/SETCATD.o  \
+  ${OUT}/SEXCAT.o   ${OUT}/SGROUP.o   \
+  ${OUT}/SGROUP-.o  ${OUT}/SPACEC.o   ${OUT}/SPLNODE.o  ${OUT}/STEP.o     \
+  ${OUT}/STNSR.o    \
+  ${OUT}/STREAM1.o  ${OUT}/STREAM2.o  ${OUT}/STREAM3.o  ${OUT}/SUCH.o     \
+  ${OUT}/TEX1.o     ${OUT}/UDVO.o     ${OUT}/YSTREAM.o \
+  layer1done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 1 */
+/* depends on: BASTYPE CFCAT KOERCE KONVERT TYPE */
+/* provides: FORTCAT RETRACT SEGCAT */
+
+"AGG"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=AGG"]
+"AGG" -> "TYPE"
+/*"AGG" -> "NNI"*/
+/*"AGG" -> "INT"*/
+
+"AGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AGG"]
+"AGG-" -> "TYPE"
+/*"AGG-" -> "NNI"*/
+/*"AGG-" -> "INT"*/
+
+"ANON" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ANON"]
+/*"ANON" -> "SETCAT"*/
+"ANON" -> "BASTYPE/KOERCE"
+/*"ANON" -> "KOERCE"*/
+
+"ANY1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ANY1"]
+"ANY1" -> "TYPE"
+
+"BLMETCT"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=BLMETCT"]
+"BLMETCT" -> {"SETCAT", "BASTYPE/KOERCE"}
+
+"CABMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CABMON",
+           shape=ellipse]
+/*"CABMON" -> {"ABELMON"; "ABELSG"; "SETCAT"}*/
+"CABMON" -> "BASTYPE/KOERCE"
+/*"CABMON" -> "KOERCE"*/
+
+"COLOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COLOR"]
+/*"COLOR" -> "ABELSG"*/
+/*"COLOR" -> "SETCAT"*/
+"COLOR" -> "BASTYPE/KOERCE"
+/*"COLOR" -> {"KOERCE"; "DFLOAT"; "INT"; "FPS-"; "RNS-"; "NNI"; "PI"}*/
+/*"COLOR" -> "BOOLEAN"*/
+
+"COMBOPC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMBOPC"]
+"COMBOPC" -> "CFCAT"
+
+"COMM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMM"]
+/*"COMM" -> "SETCAT"*/
+"COMM" -> "BASTYPE/KOERCE"
+/*"COMM" -> {"KOERCE"; "BOOLEAN"}*/
+
+"COMPAR" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMPAR"]
+/*"COMPAR" -> "SETCAT"*/
+"COMPAR" -> "BASTYPE/KOERCE"
+
+"COMPPROP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMPPROP"]
+/*"COMPPROP" -> "SETCAT"*/
+"COMPPROP" -> "BASTYPE/KOERCE"
+/*"COMPPROP" -> {"KOERCE"; "BOOLEAN"}*/
+
+"DROPT1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DROPT1"]
+"DROPT1" -> "TYPE"
+
+"ELTAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELTAGG"]
+/*"ELTAGG" -> "ELTAB"*/
+/*"ELTAGG" -> "SETCAT"*/
+"ELTAGG" -> "BASTYPE/KOERCE"
+/*"ELTAGG" -> "KOERCE"*/
+"ELTAGG" -> "TYPE"
+
+"ELTAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ELTAGG"]
+/*"ELTAGG-" -> {"ELTAB"; "SETCAT"}*/
+"ELTAGG-" -> "BASTYPE/KOERCE"
+/*"ELTAGG-" -> "KOERCE"*/
+"ELTAGG-" -> "TYPE"
+
+"EQ2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EQ2"]
+"EQ2" -> "TYPE"
+
+"EXIT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXIT"]
+/*"EXIT" -> "SETCAT"*/
+"EXIT" -> "BASTYPE/KOERCE"
+/*"EXIT" -> "KOERCE"*/
+
+"FILECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FILECAT"]
+/*"FILECAT" -> "SETCAT"*/
+"FILECAT" -> "BASTYPE/KOERCE"
+/*"FILECAT" -> "KOERCE"*/
+
+"FINITE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FINITE"]
+/*"FINITE" -> "SETCAT"*/
+"FINITE" -> "BASTYPE/KOERCE"
+/*"FINITE" -> "KOERCE"*/
+
+"FNCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FNCAT"]
+/*"FNCAT" -> "SETCAT"*/
+"FNCAT" -> "BASTYPE/KOERCE"
+/*"FNCAT" -> "KOERCE"*/
+
+"FORMULA1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FORMULA1"]
+/*"FORMULA1" -> "SETCAT"*/
+"FORMULA1" -> "BASTYPE/KOERCE"
+/*"FORMULA1" -> "KOERCE"*/
+
+"FORTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FORTCAT"]
+"FORTCAT" -> "TYPE"
+/*"FORTCAT" -> "KOERCE"*/
+
+"IDPC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=IDPC"]
+/*"IDPC" -> "SETCAT"*/
+"IDPC" -> "BASTYPE/KOERCE"
+/*"IDPC" -> "KOERCE"*/
+
+"IEVALAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=IEVALAB"]
+/*"IEVALAB" -> "SETCAT"*/
+"IEVALAB" -> "BASTYPE/KOERCE"
+/*"IEVALAB" -> "KOERCE"*/
+"IEVALAB" -> "TYPE"
+
+"IEVALAB-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IEVALAB"]
+/*"IEVALAB-" -> "SETCAT"*/
+"IEVALAB-" -> "BASTYPE/KOERCE"
+/*"IEVALAB-" -> "KOERCE"*/
+"IEVALAB-" -> "TYPE"
+
+"ITFUN2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ITFUN2"]
+"ITFUN2" -> "TYPE"
+
+"ITFUN3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ITFUN3"]
+"ITFUN3" -> "TYPE"
+
+"ITUPLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ITUPLE"]
+/*"ITUPLE" -> "KOERCE"*/
+"ITUPLE" -> "TYPE"
+
+"LIST3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIST3"]
+"LIST3" -> "TYPE"
+/*"LIST3" -> {"INT"; "LIST"; "ILIST"}*/
+
+"LOGIC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LOGIC"]
+"LOGIC" -> "BASTYPE/KOERCE"
+
+"LOGIC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LOGIC"]
+"LOGIC-" -> "BASTYPE/KOERCE"
+
+"MAPHACK1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPHACK1"]
+/*"MAPHACK1" -> "SETCAT"*/
+"MAPHACK1" -> "BASTYPE/KOERCE"
+/*"MAPHACK1" -> {"KOERCE"; "SINT"; "NNI"; "INT"}*/
+
+"MAPHACK2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPHACK2"]
+/*"MAPHACK2" -> "SETCAT"*/
+"MAPHACK2" -> "BASTYPE/KOERCE"
+/*"MAPHACK2" -> "KOERCE"*/
+
+"MAPHACK3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPHACK3"]
+/*"MAPHACK3" -> "SETCAT"*/
+"MAPHACK3" -> "BASTYPE/KOERCE"
+/*"MAPHACK3" -> "KOERCE"*/
+
+"MAPPKG1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG1"]
+/*"MAPPKG1" -> "SETCAT"*/
+"MAPPKG1" -> "BASTYPE/KOERCE"
+/*"MAPPKG1" -> {"KOERCE"; "SINT"; "NNI"; "INT"; "BOOLEAN"}*/
+
+"MAPPKG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG2"]
+/*"MAPPKG2" -> "SETCAT"*/
+"MAPPKG2" -> "BASTYPE/KOERCE"
+/*"MAPPKG2" -> "KOERCE"*/
+
+"MAPPKG3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG3"]
+/*"MAPPKG3" -> "SETCAT"*/
+"MAPPKG3" -> "BASTYPE/KOERCE"
+/*"MAPPKG3" -> "KOERCE"*/
+
+"MKBCFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKBCFUNC"]
+"MKBCFUNC" -> "KONVERT"
+"MKBCFUNC" -> "TYPE"
+
+"MKFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKFUNC"]
+"MKFUNC" -> "KONVERT"
+/*"MKFUNC" -> {"INT"; "LIST"}*/
+
+"MKRECORD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKRECORD"]
+"MKRECORD" -> "TYPE"
+
+"MKUCFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKUCFUNC"]
+"MKUCFUNC" -> "KONVERT"
+"MKUCFUNC" -> "TYPE"
+
+"MONAD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONAD"]
+/*"MONAD" -> "SETCAT"*/
+"MONAD" -> "BASTYPE/KOERCE"
+/*"MONAD" -> {"KOERCE"; "PI"; "NNI"; "INT"; "SINT"}*/
+
+"MONAD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONAD"]
+/*"MONAD-" -> "SETCAT"*/
+"MONAD-" -> "BASTYPE/KOERCE"
+/*"MONAD-" -> {"KOERCE"; "PI"; "NNI"; "INT"; "SINT"}*/
+
+"NIPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NIPROB"]
+/*"NIPROB" -> "SETCAT"*/
+"NIPROB" -> "BASTYPE/KOERCE"
+/*"NIPROB" -> "KOERCE"*/
+
+"NONE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NONE"]
+/*"NONE" -> "SETCAT"*/
+"NONE" -> "BASTYPE/KOERCE"
+/*"NONE" -> "KOERCE"*/
+
+"NONE1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NONE1"]
+"NONE1" -> "TYPE"
+
+"NUMINT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NUMINT"]
+/*"NUMINT" -> "SETCAT"*/
+"NUMINT" -> "BASTYPE/KOERCE"
+/*"NUMINT" -> "KOERCE"*/
+
+"ODECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ODECAT"]
+/*"ODECAT" -> "SETCAT"*/
+"ODECAT" -> "BASTYPE/KOERCE"
+/*"ODECAT" -> "KOERCE"*/
+
+"ODEPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODEPROB"]
+/*"ODEPROB" -> "SETCAT"*/
+"ODEPROB" -> "BASTYPE/KOERCE"
+/*"ODEPROB" -> "KOERCE"*/
+
+"OMENC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMENC"]
+/*"OMENC" -> "SETCAT"*/
+"OMENC" -> "BASTYPE/KOERCE"
+/*"OMENC" -> {"KOERCE"; "SINT"}*/
+
+"ONECOMP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ONECOMP2"]
+/*"ONECOMP2" -> "SETCAT"*/
+"ONECOMP2" -> "BASTYPE/KOERCE"
+/*"ONECOMP2" -> "KOERCE"*/
+
+"OPTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OPTCAT"]
+/*"OPTCAT" -> "SETCAT"*/
+"OPTCAT" -> "BASTYPE/KOERCE"
+/*"OPTCAT" -> "KOERCE"*/
+
+"OPTPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OPTPROB"]
+/*"OPTPROB" -> "SETCAT"*/
+"OPTPROB" -> "BASTYPE/KOERCE"
+/*"OPTPROB" -> "KOERCE"*/
+
+"ORDCOMP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ORDCOMP2"]
+/*"ORDCOMP2" -> "SETCAT"*/
+"ORDCOMP2" -> "BASTYPE/KOERCE"
+/*"ORDCOMP2" -> {"KOERCE"; "SINT"}*/
+
+"ORDSET" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDSET"]
+/*"ORDSET" -> "SETCAT"*/
+"ORDSET" -> "BASTYPE/KOERCE"
+/*"ORDSET" -> {"KOERCE"; "BOOLEAN"}*/
+
+"ORDSET-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ORDSET"]
+/*"ORDSET-" -> "SETCAT"*/
+"ORDSET-" -> "BASTYPE/KOERCE"
+/*"ORDSET-" -> {"KOERCE"; "BOOLEAN"}*/
+
+"PALETTE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PALETTE"]
+/*"PALETTE" -> "SETCAT"*/
+"PALETTE" -> "BASTYPE/KOERCE"
+/*"PALETTE" -> {"KOERCE"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+
+"PARPCURV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PARPCURV"]
+"PARPCURV" -> "TYPE"
+/*"PARPCURV" -> "NNI"*/
+/*"PARPCURV" -> "INT"*/
+
+"PARPC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARPC2"]
+"PARPC2" -> "TYPE"
+/*"PARPC2" -> "NNI"*/
+/*"PARPC2" -> "INT"*/
+
+"PARSCURV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PARSCURV"]
+"PARSCURV" -> "TYPE"
+/*"PARSCURV" -> "NNI"*/
+/*"PARSCURV" -> "INT"*/
+
+"PARSC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARSC2"]
+"PARSC2" -> "TYPE"
+/*"PARSC2" -> "NNI"*/
+/*"PARSC2" -> "INT"*/
+
+"PARSURF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PARSURF"]
+"PARSURF" -> "TYPE"
+/*"PARSURF" -> "NNI"*/
+/*"PARSURF" -> "INT"*/
+
+"PARSU2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARSU2"]
+"PARSU2" -> "TYPE"
+/*"PARSU2" -> "NNI"*/
+/*"PARSU2" -> "INT"*/
+
+"PATAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PATAB"]
+"PATAB" -> "KONVERT"
+
+"PATMAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PATMAB"]
+/*"PATMAB" -> "SETCAT"*/
+"PATMAB" -> "BASTYPE/KOERCE"
+/*"PATMAB" -> "KOERCE"*/
+
+"PATRES2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATRES2"]
+/*"PATRES2" -> "SETCAT"*/
+"PATRES2" -> "BASTYPE/KOERCE"
+/*"PATRES2" -> "KOERCE" */
+
+"PATTERN1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATTERN1"]
+/*"PATTERN1" -> "SETCAT"*/
+"PATTERN1" -> "BASTYPE/KOERCE"
+/*"PATTERN1" -> "KOERCE"*/
+"PATTERN1" -> "TYPE"
+/*"PATTERN1" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "BOOLEAN"}*/
+
+"PDECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PDECAT"]
+/*"PDECAT" -> "SETCAT"*/
+"PDECAT" -> "BASTYPE/KOERCE"
+/*"PDECAT" -> "KOERCE"*/
+
+"PDEPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PDEPROB"]
+/*"PDEPROB" -> "SETCAT"*/
+"PDEPROB" -> "BASTYPE/KOERCE"
+/*"PDEPROB" -> "KOERCE"*/
+
+"PLOT1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PLOT1"]
+"PLOT1" -> "KONVERT"
+
+"PPCURVE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PPCURVE"]
+"PPCURVE" -> "KOERCE"
+
+"REAL" [color="#4488FF",href="bookvol10.2.pdf#nameddest=REAL"]
+"REAL" -> "KONVERT"
+
+"REF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=REF",
+          shape=ellipse]
+"REF" -> "TYPE"
+/*"REF" -> "SETCAT"*/
+"REF" -> "BASTYPE/KOERCE"
+/*"REF" -> "KOERCE"*/
+
+"REPDB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REPDB"]
+/*"REPDB" -> "SETCAT"*/
+"REPDB" -> "BASTYPE/KOERCE"
+/*"REPDB" -> {"KOERCE"; "PI"; "NNI"; "INT"}*/
+
+"REPSQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REPSQ"]
+/*"REPSQ" -> "SETCAT"*/
+"REPSQ" -> "BASTYPE/KOERCE"
+/*"REPSQ" -> {"KOERCE"; "PI"; "NNI"; "INT"}*/
+
+"RESLATC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RESLATC"]
+"RESLATC" -> "TYPE"
+
+"RETRACT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RETRACT"]
+"RETRACT" -> "TYPE"
+
+"RETRACT-" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RETRACT"]
+"RETRACT-" -> "TYPE"
+
+"RMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RMODULE"]
+/*"RMODULE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+"RMODULE" -> "BASTYPE/KOERCE"
+/*"RMODULE" -> "KOERCE"*/
+
+"SEGBIND2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SEGBIND2"]
+"SEGBIND2" -> "TYPE"
+
+"SEGCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SEGCAT"]
+"SEGCAT" -> "TYPE"
+
+"SETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SETCAT",
+          shape=ellipse]
+"SETCAT" -> "BASTYPE/KOERCE"
+/*"SETCAT" -> "KOERCE"*/
+/*"SETCAT" -> "SINT"*/
+
+"SETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SETCAT",
+          shape=ellipse]
+"SETCAT-" -> "BASTYPE/KOERCE"
+/*"SETCAT-" -> {"KOERCE"; "SINT"}*/
+
+"SETCATD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SETCATD"]
+/*"SETCATD" -> "SETCAT"*/
+"SETCATD" -> "BASTYPE/KOERCE"
+
+"SEXCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SEXCAT"]
+/*"SEXCAT" -> "SETCAT"*/
+"SEXCAT" -> "BASTYPE/KOERCE"
+/*"SEXCAT" -> "KOERCE"*/
+
+/* We combine LMODULE and SGROUP to minimize edges */
+"LMODULE/SGROUP" [color="blue",href="bookvol10.2.pdf#nameddest=LMODULE"]
+"LMODULE/SGROUP" -> "BASTYPE/KOERCE"
+/*"LMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LMODULE"]*/
+/*"LMODULE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"LMODULE" -> {"BASTYPE/KOERCE"; "KOERCE"}*/
+
+"SGROUP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SGROUP"]
+/*"SGROUP" -> "SETCAT"*/
+"SGROUP" -> "BASTYPE/KOERCE"
+/*"SGROUP" -> "KOERCE"*/
+
+"SGROUP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SGROUP"]
+/*"SGROUP" -> "SETCAT"*/
+"SGROUP-" -> "BASTYPE/KOERCE"
+/*"SGROUP-" -> "KOERCE"*/
+
+"SPACEC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SPACEC"]
+/*"SPACEC" -> "SETCAT"*/
+"SPACEC" -> "BASTYPE/KOERCE"
+/*"SPACEC" -> "KOERCE"*/
+
+"SPLNODE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SPLNODE"]
+/*"SPLNODE" -> "SETCAT"*/
+"SPLNODE" -> "BASTYPE/KOERCE"
+/*"SPLNODE" -> {"KOERCE"; "AGG"}*/
+"SPLNODE" -> "TYPE"
+/*"SPLNODE" -> "BOOLEAN"*/
+
+"STEP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=STEP"]
+/*"STEP" -> "SETCAT"*/
+"STEP" -> "BASTYPE/KOERCE"
+/*"STEP" -> "KOERCE"*/
+
+"STNSR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STNSR"]
+"STNSR" -> "TYPE"
+
+"STREAM1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STREAM1"]
+"STREAM1" -> "TYPE"
+
+"STREAM2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STREAM2"]
+"STREAM2" -> "TYPE"
+
+"STREAM3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STREAM3"]
+"STREAM3" -> "TYPE"
+
+"SUCH" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUCH"]
+/*"SUCH" -> "SETCAT"*/
+"SUCH" -> "BASTYPE/KOERCE"
+/*"SUCH" -> "KOERCE"*/
+
+"TEX1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TEX1"]
+/*"TEX1" -> "SETCAT"*/
+"TEX1" -> "BASTYPE/KOERCE"
+/*"TEX1" -> "KOERCE"*/
+
+"UDVO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UDVO"]
+/*"UDVO" -> {"INT"; "LIST"; "ILIST"; "ORDSET"; "SETCAT"}*/
+"UDVO" -> "BASTYPE/KOERCE"
+/*"UDVO" -> "KOERCE"*/
+
+"YSTREAM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=YSTREAM"]
+"YSTREAM" -> "TYPE"
+/*"YSTREAM" -> {"INT"; "SINT"; "NNI"}*/
+
+\end{chunk}
+\subsection{Layer 2}
+Depends on: AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE MONAD ORDSET 
+PATMAB RETRACT RMODULE SGROUP SETCATD \\
+Used by next layer: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG 
+OASGP PDRING 
+\begin{chunk}{layer2}
+
+LAYER2=\
+  ${OUT}/AFSPCAT.o  \
+  ${OUT}/API.o      ${OUT}/ASP29.o    ${OUT}/ATRIG.o    ${OUT}/ATRIG-.o   \
+  ${OUT}/BEZIER.o   ${OUT}/BLHN.o     \
+  ${OUT}/BLQT.o     ${OUT}/BMODULE.o  ${OUT}/CACHSET.o  \
+  ${OUT}/CHARNZ.o   ${OUT}/CHARZ.o    ${OUT}/DVARCAT.o  ${OUT}/DVARCAT-.o \
+  ${OUT}/ELEMFUN.o  ${OUT}/ELEMFUN-.o ${OUT}/ESTOOLS2.o ${OUT}/EVALAB.o   \
+  ${OUT}/EVALAB-.o  ${OUT}/FAMONC.o   ${OUT}/FCOMP.o    ${OUT}/FEVALAB.o  \
+  ${OUT}/FEVALAB-.o ${OUT}/FMC.o      ${OUT}/FMFUN.o    ${OUT}/FORTFN.o   \
+  ${OUT}/FPATMAB.o  ${OUT}/FVC.o      ${OUT}/FVFUN.o    ${OUT}/GROUP.o    \
+  ${OUT}/GROUP-.o   ${OUT}/IDPAG.o    ${OUT}/IDPAM.o    ${OUT}/IDPO.o     \
+  ${OUT}/INCRMAPS.o ${OUT}/INTRET.o   ${OUT}/IXAGG.o    ${OUT}/IXAGG-.o   \
+  ${OUT}/KERNEL2.o  ${OUT}/LALG.o     ${OUT}/LALG-.o    ${OUT}/LINEXP.o   \
+  ${OUT}/MODMONOM.o ${OUT}/MONADWU.o  ${OUT}/MONADWU-.o ${OUT}/MRF2.o     \
+  ${OUT}/NARNG.o    ${OUT}/NARNG-.o   ${OUT}/NSUP2.o    ${OUT}/OASGP.o    \
+  ${OUT}/ODVAR.o    ${OUT}/OPQUERY.o  ${OUT}/ORDFIN.o   ${OUT}/ORDMON.o   \
+  ${OUT}/PATMATCH.o ${OUT}/PERMCAT.o  ${OUT}/PDRING.o   ${OUT}/PDRING-.o  \
+  ${OUT}/PLACESC.o  ${OUT}/PRSPCAT.o  \
+  ${OUT}/SDVAR.o    ${OUT}/SEGXCAT.o  ${OUT}/SUP2.o     ${OUT}/TRIGCAT.o  \
+  ${OUT}/TRIGCAT-.o ${OUT}/ULS2.o     ${OUT}/UP2.o \
+  layer2done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 2 */
+/* AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE MONAD ORDSET */
+/* PATMAB RETRACT RMODULE SEGCAT SGROUP SETCATD */
+
+"AFSPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=AFSPCAT",
+          shape=ellipse]
+"AFSPCAT" -> "SETCATD"
+/*"AFSPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"ABELGRP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ABELGRP",
+           shape=ellipse]
+/*"ABELGRP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"ABELGRP" -> {"KOERCE"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+"ABELGRP" -> "LMODULE/SGROUP"
+/*"ABELGRP" -> "INT"*/
+
+"ABELGRP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ABELGRP",
+           shape=ellipse]
+/*"ABELGRP-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"ABELGRP-" -> {"KOERCE"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+"ABELGRP-" -> "LMODULE/SGROUP"
+/*"ABELGRP-" -> "INT"*/
+
+"ABELMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ABELMON",
+           shape=ellipse]
+/*"ABELMON" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
+/*"ABELMON" -> {"ABELGRP"; "CABMON"; "SGROUP"; "MONOID"}*/
+"ABELMON" -> "LMODULE/SGROUP"
+/*"ABELMON" -> {"NNI"; "INT"}*/
+
+"ABELMON-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ABELMON",
+           shape=ellipse]
+/*"ABELMON-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
+/*"ABELMON-" -> {"ABELGRP"; "CABMON"; "SGROUP"; "MONOID"}*/
+"ABELMON-" -> "LMODULE/SGROUP"
+/*"ABELMON-" -> {"NNI"; "INT"}*/
+
+"ABELSG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ABELSG",
+           shape=ellipse]
+/*"ABELSG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ABELSG" -> {"CABMON"; "ABELMON"; "SGROUP"; "MONOID"}*/
+"ABELSG" -> "LMODULE/SGROUP"
+
+"ABELSG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ABELSG",
+           shape=ellipse]
+/*"ABELSG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ABELSG-" -> {"CABMON"; "ABELMON"; "SGROUP"; "MONOID"}*/
+"ABELSG-" -> "LMODULE/SGROUP"
+
+"API"  [color="#FF4488",href="bookvol10.4.pdf#nameddest=API"]
+/*"API" -> {"INT"; "LIST"; "ILIST"}*/
+"API" -> "ORDSET"
+/*"API" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"ATRIG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ATRIG"]
+/*"ATRIG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ATRIG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"ATRIG" -> "LMODULE/SGROUP"
+
+"ATRIG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ATRIG"]
+/*"ATRIG-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ATRIG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"ATRIG-" -> "LMODULE/SGROUP"
+
+"BEZIER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BEZIER"]
+/*"BEZIER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"BEZIER" -> {"SETCAT"; "BASTYPE"; "KOERCE" "SGROUP"; "MONOID"; "LMODULE"} */
+"BEZIER" -> "LMODULE/SGROUP"
+
+"BLQT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BLQT"]
+"BLQT" -> "BLMETCT"
+/*"BLQT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"BLQT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BLQT"]
+"BLQT" -> "BLMETCT"
+/*"BLQT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"BLQT" -> {"STAGG-"; "PI"; "NNI"}*/
+
+"BMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BMODULE"]
+/*"BMODULE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"BMODULE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"BMODULE" -> "LMODULE/SGROUP"
+"BMODULE" -> "RMODULE"
+
+"CACHSET" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CACHSET"]
+"CACHSET" -> "ORDSET"
+/*"CACHSET" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"CHARNZ" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CHARNZ"]
+/*"CHARNZ" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"CHARNZ" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"CHARNZ" -> "LMODULE/SGROUP"
+
+"CHARZ" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CHARZ"]
+/*"CHARZ" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"CHARZ" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"CHARZ" -> "LMODULE/SGROUP"
+
+"DIFRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIFRING",
+           shape=ellipse]
+/*"DIFRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DIFRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"DIFRING" -> "LMODULE/SGROUP"
+/*"DIFRING" -> {"SINT"; "NNI"; "INT"}*/
+
+"DIFRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIFRING",
+           shape=ellipse]
+/*"DIFRING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DIFRING-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"DIFRING-" -> "LMODULE/SGROUP"
+/*"DIFRING-" -> {"SINT"; "NNI"; "INT"}*/
+
+"DVARCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DVARCAT"]
+"DVARCAT" -> "ORDSET"
+/*"DVARCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"DVARCAT" -> "RETRACT"
+/*"DVARCAT" -> {"NNI"; "INT"; "BOOLEAN"}*/
+
+"DVARCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DVARCAT"]
+"DVARCAT-" -> "ORDSET"
+/*"DVARCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"DVARCAT-" -> "RETRACT"
+/*"DVARCAT-" -> {"NNI"; "INT"; "BOOLEAN"}*/
+
+"ELEMFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELEMFUN"]
+/*"ELEMFUN" -> "MONOID"*/
+"ELEMFUN" -> "SGROUP"
+/*"ELEMFUN" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"ELEMFUN-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ELEMFUN"]
+/*"ELEMFUN-" -> "MONOID"*/
+"ELEMFUN-" -> "SGROUP"
+/*"ELEMFUN-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"ESTOOLS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESTOOLS2"]
+/*"ESTOOLS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ESTOOLS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"ESTOOLS2" -> "LMODULE/SGROUP"
+
+"EVALAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=EVALAB"]
+"EVALAB" -> "IEVALAB"
+/*"EVALAB" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"EVALAB-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EVALAB"]
+"EVALAB-" -> "IEVALAB"
+/*"EVALAB-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"FAMONC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FAMONC"]
+/*"FAMONC" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"FAMONC" -> "RETRACT"
+
+"FCOMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FCOMP"]
+"FCOMP" -> "ORDSET"
+/*"FCOMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"}*/
+
+"FEVALAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FEVALAB"]
+/*"FEVALAB" -> {"ELTAB"; "EVALAB"}*/
+"FEVALAB" -> "IEVALAB"
+/*"FEVALAB" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"FEVALAB-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FEVALAB"]
+/*"FEVALAB-" -> {"ELTAB"; "EVALAB"}*/
+"FEVALAB-" -> "IEVALAB"
+/*"FEVALAB-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"FMC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMC"]
+"FMC" -> "FORTCAT"
+/*"FMC" -> {"TYPE"; "KOERCE"}*/
+
+"FMFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMFUN"]
+"FMFUN" -> "FORTCAT"
+/*"FMFUN" -> {"TYPE"; "KOERCE"}*/
+
+"FORTFN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FORTFN"]
+"FORTFN" -> "FORTCAT"
+/*"FORTFN" -> {"TYPE"; "KOERCE"}*/
+
+"FPATMAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FPATMAB"]
+/*"FPATMAB" -> "TYPE"*/
+"FPATMAB" -> "PATMAB"
+/*"FPATMAB" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"FVC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FVC"]
+"FVC" -> "FORTCAT"
+/*"FVC" -> {"TYPE"; "KOERCE"}*/
+
+"FVFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FVFUN"]
+"FVFUN" -> "FORTCAT"
+/*"FVFUN" -> {"TYPE"; "KOERCE"}*/
+
+"GROUP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GROUP"]
+/*"GROUP" -> "MONOID"*/
+"GROUP" -> "SGROUP"
+/*"GROUP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"}*/
+
+"GROUP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GROUP"]
+/*"GROUP-" -> "MONOID"*/
+"GROUP-" -> "SGROUP"
+/*"GROUP-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"}*/
+
+"IDPAG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPAG"]
+/*"IDPAG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"IDPAG" -> {"BASTYPE"; "KOERCE"}*/ 
+"IDPAG" -> "IDPC"
+"IDPAG" -> "ORDSET"
+/*"IDPAG" -> {"INT"; "BOOLEAN"; "LIST"; "ILIST"}*/
+
+"IDPAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPAM"]
+/*"IDPAM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"IDPAM" -> "IDPC"
+"IDPAM" -> "ORDSET"
+/*"IDPAM" -> {"INT"; "LIST"; "ILIST"; "BOOLEAN"; "NNI"}*/
+
+"IDPO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPO"]
+"IDPO" -> "IDPC"
+/*"IDPO" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"IDPO" -> "ORDSET"
+/*"IDPO" -> {"INT"; "LIST"; "BOOLEAN"; "ILIST"}*/
+
+"INCRMAPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INCRMAPS"]
+/*"INCRMAPS" -> "MONOID"*/
+"INCRMAPS" -> "SGROUP"
+/*"INCRMAPS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELSG"}*/
+
+"INTRET" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTRET"]
+"INTRET" -> "RETRACT"
+
+"IXAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=IXAGG"]
+/*"IXAGG" -> "HOAGG"*/
+"IXAGG" -> "AGG"
+/*"IXAGG" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+"IXAGG" -> "ELTAGG"
+/*"IXAGG" -> "ELTAB"*/
+"IXAGG" -> "ORDSET"
+
+"IXAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IXAGG"]
+/*"IXAGG-" -> "HOAGG"*/
+"IXAGG-" -> "AGG"
+/*"IXAGG-" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+"IXAGG-" -> "ELTAGG"
+/*"IXAGG-" -> "ELTAB"*/
+"IXAGG-" -> "ORDSET"
+
+"KERNEL2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=KERNEL2"]
+"KERNEL2" -> "ORDSET"
+/*"KERNEL2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "NNI"}*/
+
+"LALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LALG"]
+/*"LALG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"LALG" -> "LMODULE/SGROUP"
+
+"LALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LALG"]
+/*"LALG-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LALG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"LALG-" -> "LMODULE/SGROUP"
+
+"LINEXP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LINEXP"]
+/*"LINEXP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LINEXP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"LINEXP" -> "LMODULE/SGROUP"
+
+"MODMONOM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODMONOM"]
+"MODMONOM" -> "ORDSET"
+/*"MODMONOM" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"MONADWU" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONADWU"]
+"MONADWU" -> "MONAD"
+/*"MONADWU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "SINT"}*/
+
+"MONADWU-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONADWU"]
+"MONADWU-" -> "MONAD"
+/*"MONADWU-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "SINT"}*/
+
+"MONOID" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONOID",
+          shape=ellipse]
+"MONOID" -> "SGROUP"
+/*"MONOID" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+
+"MONOID-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONOID",
+          shape=ellipse]
+"MONOID-" -> "SGROUP"
+/*"MONOID-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+
+"MRF2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MRF2"]
+/*"MRF2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"MRF2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"MRF2" -> "LMODULE/SGROUP"
+
+"NARNG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NARNG"]
+/*"NARNG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NARNG" -> {"BASTYPE"; "KOERCE"}*/
+"NARNG" -> "MONAD"
+
+"NARNG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NARNG"]
+/*"NARNG-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NARNG-" -> {"BASTYPE"; "KOERCE"}*/
+"NARNG-" -> "MONAD"
+
+"NSUP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NSUP2"]
+/*"NSUP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"NSUP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"NSUP2" -> "LMODULE/SGROUP"
+
+"OASGP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OASGP"]
+"OASGP" -> "ORDSET"
+/*"OASGP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
+
+"ODVAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODVAR"]
+/*"ODVAR" -> "DVARCAT"*/
+"ODVAR" -> "ORDSET"
+/*"ODVAR" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"ODVAR" -> "RETRACT"
+
+"OPQUERY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OPQUERY"]
+"OPQUERY" -> "ORDSET"
+/*"OPQUERY" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"ORDFIN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDFIN"]
+"ORDFIN" -> "ORDSET"
+/*"ORDFIN" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"ORDFIN" -> "FINITE"
+
+"ORDMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDMON"]
+"ORDMON" -> "ORDSET"
+/*"ORDMON" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONOID"}*/
+"ORDMON" -> "SGROUP"
+
+"PATMATCH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATMATCH"]
+/*"PATMATCH" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"PATMATCH" -> "PATMAB"
+/*"PATMATCH" -> {"KONVERT"; "BOOLEAN"}*/
+"PATMATCH" -> "RETRACT"
+/*"PATMATCH" -> {"INT"; "LIST"; "ILIST"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PATMATCH" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+"PATMATCH" -> "LMODULE/SGROUP"
+
+"PDRING"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=PDRING"]
+/*"PDRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PDRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"PDRING" -> "LMODULE/SGROUP"
+/*"PDRING" -> {"SINT"; "NNI"; "INT"}*/
+
+"PDRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PDRING"]
+/*"PDRING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PDRING-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"PDRING-" -> "LMODULE/SGROUP"
+/*"PDRING-" -> {"SINT"; "NNI"; "INT"}*/
+
+"PERMCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PERMCAT"]
+/*"PERMCAT" -> {"GROUP"; "MONOID"}*/
+"PERMCAT" -> "SGROUP"
+/*"PERMCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"PERMCAT" -> "ORDSET"
+"PERMCAT" -> "FINITE"
+
+"PI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PI",
+          shape=ellipse]
+/*"PI" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"PI" -> "ORDSET"
+/*"PI" -> "MONOID"*/
+"PI" -> "SGROUP"
+/*"PI" -> {"NNI"; "INT"}*/
+
+"RING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RING",
+          shape=ellipse]
+/*"RING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"RING" -> "LMODULE/SGROUP"
+
+"RING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RING",
+          shape=ellipse]
+/*"RING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RING-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"RING-" -> "LMODULE/SGROUP"
+
+"RNG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RNG",
+          shape=ellipse]
+/*"RNG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RNG" -> "KOERCE"*/
+"RNG" -> "SGROUP"
+
+"PLACESC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PLACESC",
+          shape=ellipse]
+"PLACESC" -> "SETCATD"
+/*"PLACESC" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"PRSPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PRSPCAT",
+          shape=ellipse]
+"PRSPCAT" -> "SETCATD"
+/*"PRSPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+
+"SDVAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SDVAR"]
+/*"SDVAR" -> "DVARCAT"*/
+"SDVAR" -> "ORDSET"
+/*"SDVAR" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"SDVAR" -> "RETRACT"
+/*"SDVAR" -> {"NNI"; "INT"}*/
+
+"SEGXCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SEGXCAT"]
+"SEGXCAT" -> "SEGCAT"
+/*"SEGXCAT" -> "TYPE"*/
+
+"SUP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUP2"]
+/*"SUP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SUP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"SUP2" -> "LMODULE/SGROUP"
+
+"TRIGCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TRIGCAT"]
+/*"TRIGCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"TRIGCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"TRIGCAT" -> "LMODULE/SGROUP"
+
+"TRIGCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TRIGCAT"]
+/*"TRIGCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"TRIGCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"TRIGCAT-" -> "LMODULE/SGROUP"
+
+"ULS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ULS2"]
+/*"ULS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ULS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"ULS2" -> "LMODULE/SGROUP"
+
+"UP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UP2"]
+/*"UP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+"UP2" -> "LMODULE/SGROUP"
+
+\end{chunk}
+\subsection{Layer 3}
+Depends on: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG 
+OASGP PDRING\\
+Used by next layer: BGAGG BRAGG ELAGG- GRMOD MODULE OAMON 
+\begin{chunk}{layer3}
+
+LAYER3=\
+  ${OUT}/AUTOMOR.o  ${OUT}/BGAGG.o   ${OUT}/BGAGG-.o   ${OUT}/BRAGG.o    \
+  ${OUT}/BRAGG-.o   ${OUT}/CARTEN2.o ${OUT}/CHARPOL.o  ${OUT}/COMPLEX2.o \
+  ${OUT}/DIFEXT.o   ${OUT}/DIFEXT-.o ${OUT}/DLAGG.o    ${OUT}/DSTRCAT.o  \
+  ${OUT}/ELAGG.o    \
+  ${OUT}/ELAGG-.o   ${OUT}/ES1.o     ${OUT}/ES2.o      ${OUT}/GRMOD.o    \
+  ${OUT}/GRMOD-.o   ${OUT}/HYPCAT.o  ${OUT}/HYPCAT-.o  ${OUT}/LORER.o    \
+  ${OUT}/MKCHSET.o  \
+  ${OUT}/MODRING.o  ${OUT}/MODULE.o  ${OUT}/MODULE-.o  ${OUT}/NASRING.o  \
+  ${OUT}/NASRING-.o ${OUT}/OAMON.o   ${OUT}/SORTPAK.o  ${OUT}/ZMOD.o \
+  layer3done
+
+\end{chunk}
+
+\begin{chunk}{layerpic}
+/* layer 3 */
+/* depends on: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG */
+/* OASGP PDRING */
+
+"AUTOMOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AUTOMOR"]
+"AUTOMOR" -> "GROUP"
+/*"AUTOMOR" -> {"MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"AUTOMOR" -> {"ELTAB"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"AUTOMOR" -> {"ABELSG"; "LMODULE"; "INT"; "SINT"; "NNI"}*/
+
+"BGAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BGAGG"]
+/*"BGAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"BGAGG" -> "EVALAB"
+/*"BGAGG" -> "IEVALAB"*/
+
+"BGAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BGAGG"]
+/*"BGAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"BGAGG-" -> "EVALAB"
+/*"BGAGG-" -> "IEVALAB"*/
+
+"BRAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BRAGG"]
+/*"BRAGG" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"BRAGG" -> "KOERCE"*/
+"BRAGG" -> "EVALAB"
+/*"BRAGG" -> {"IEVALAB"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"BRAGG" -> {"STAGG-"; "SETAGG"; "CLAGG"; "KONVERT"; "NNI"}*/
+
+"BRAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BRAGG"]
+/*"BRAGG-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"BRAGG-" -> "KOERCE"*/
+"BRAGG-" -> "EVALAB"
+/*"BRAGG-" -> {"IEVALAB"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"BRAGG-" -> {"STAGG-"; "SETAGG"; "CLAGG"; "KONVERT"; "NNI"}*/
+
+"CARTEN2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CARTEN2"]
+/*"CARTEN2" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"CARTEN2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"CARTEN2" -> {"MONOID"; "LMODULE"}*/
+"CARTEN2" -> "BMODULE"
+/*"CARTEN2" -> "RMODULE"*/
+
+"CHARPOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CHARPOL"]
+/*"CHARPOL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"CHARPOL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"CHARPOL" -> {"MONOID"; "LMODULE"}*/
+"CHARPOL" -> "BMODULE"
+/*"CHARPOL" -> {"RMODULE"; "NNI"; "INT"; "SINT"; "PI"}*/
+
+"COMPLEX2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMPLEX2"]
+/*"COMPLEX2" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"COMPLEX2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"COMPLEX2" -> {"MONOID"; "LMODULE"}*/
+"COMPLEX2" -> "BMODULE"
+/*"COMPLEX2" -> "RMODULE"*/
+
+"COMRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMRING",
+           shape=ellipse]
+/*"COMRING" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"COMRING" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"COMRING" -> {"MONOID"; "LMODULE"}*/
+"COMRING" -> "BMODULE"
+/*"COMRING" -> "RMODULE"*/
+
+"DIFEXT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIFEXT"]
+/*"DIFEXT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DIFEXT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"*}/ 
+/*"DIFEXT" -> "DIFRING"*/
+"DIFEXT" -> "PDRING"
+/*"DIFEXT" -> {"SINT"; "NNI"; "INT"}*/
+
+"DIFEXT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIFEXT"]
+/*"DIFEXT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DIFEXT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"DIFEXT-" -> {"LMODULE"; "DIFRING"}*/
+"DIFEXT-" -> "PDRING"
+/*"DIFEXT-" -> {"SINT"; "NNI"; "INT"}*/
+
+"DLAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DLAGG"]
+/*"DLAGG" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"DLAGG" -> "EVALAB"
+/*"DLAGG" -> "IEVALAB"*/
+
+"DSTRCAT"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=DSTRCAT"]
+/*"DSTRCAT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+"DSTRCAT" -> "EVALAB"
+/*"DSTRCAT" -> {"KOERCE"; "IEVALAB"}*/
+
+"ELAGG"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELAGG"]
+/*"ELAGG" -> "LNAGG"*/
+"ELAGG" -> "IXAGG"
+/*"ELAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"ELAGG" -> "EVALAB"
+/*"ELAGG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "NNI"}*/
+/*"ELAGG" -> {"INT"; "ORDSET"}*/
+
+"ELAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ELAGG"]
+/*"ELAGG-" -> "LNAGG"*/
+"ELAGG-" -> "IXAGG"
+/*"ELAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"ELAGG-" -> "EVALAB"
+/*"ELAGG-" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "NNI"}*/
+/*"ELAGG-" -> {"INT"; "ORDSET"}*/
+
+/* Note that ENTIRER has a circular self reference */
+"ENTIRER" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ENTIRER",
+           shape=ellipse]
+/*"ENTIRER" -> {"ENTIRER"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ENTIRER" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ENTIRER" -> {"MONOID"; "LMODULE"}*/
+"ENTIRER" -> "BMODULE"
+/*"ENTIRER" -> "RMODULE"*/
+
+"ES1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ES1"]
+/*"ES1" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"ES1" -> "IEVALAB"*/
+"ES1" -> "EVALAB"
+/*"ES1" -> "TYPE"*/
+
+"ES2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ES2"]
+/*"ES2" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"ES2" -> "IEVALAB"*/
+"ES2" -> "EVALAB"
+
+"GRMOD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GRMOD"]
+/*"GRMOD" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "COMRING"; "RING"; "RNG"}*/
+/*"GRMOD" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"GRMOD" -> {"MONOID"; "LMODULE"}*/
+"GRMOD" -> "BMODULE"
+/*"GRMOD" -> "RMODULE"*/
+
+"GRMOD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GRMOD"]
+/*"GRMOD-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "COMRING"; "RING"; "RNG"}*/
+/*"GRMOD-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"GRMOD-" -> {"MONOID"; "LMODULE"}*/
+"GRMOD-" -> "BMODULE"
+/*"GRMOD-" -> "RMODULE"*/
+
+"HYPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=HYPCAT"]
+/*"HYPCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"HYPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"HYPCAT" -> "LMODULE"*/
+"HYPCAT" -> "ELEMFUN"
+
+"HYPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HYPCAT"]
+/*"HYPCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"HYPCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"HYPCAT-" -> "LMODULE"*/
+"HYPCAT-" -> "ELEMFUN"
+
+"LORER" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LORER"]
+/*"LORER" -> {"ENTIRER"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LORER" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"LORER" -> {"MONOID"; "LMODULE"; "RMODULE"}*/
+"LORER" -> "BMODULE"
+
+"MKCHSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MKCHSET"]
+"MKCHSET" -> "CACHSET"
+/*"MKCHSET" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+
+"MODRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODRING"]
+/*"MODRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"MODRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"MODRING" -> {"LMODULE"; "COMRING"}*/
+"MODRING" -> "BMODULE"
+/*"MODRING" -> {"RMODULE"; "BOOLEAN"}*/
+
+"MODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MODULE"]
+/*"MODULE" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"MODULE" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"MODULE" -> {"MONOID"; "LMODULE"}*/
+"MODULE" -> "BMODULE"
+/*"MODULE" -> "RMODULE"*/
+
+"MODULE-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODULE"]
+/*"MODULE-" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"MODULE-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"MODULE-" -> {"MONOID"; "LMODULE"}*/
+"MODULE-" -> "BMODULE"
+/*"MODULE-" -> "RMODULE"*/
+
+"NASRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NASRING"]
+"NASRING" -> "NARNG"
+/*"NASRING" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NASRING" -> {"BASTYPE"; "KOERCE"; "MONAD"}*/
+"NASRING" -> "MONADWU"
+
+"NASRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NASRING"]
+"NASRING-" -> "NARNG"
+/*"NASRING-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NASRING-" -> {"BASTYPE"; "KOERCE"; "MONAD"}*/
+"NASRING-" -> "MONADWU"
+
+"OAMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OAMON"]
+"OAMON" -> "OASGP"
+/*"OAMON" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
+
+"SETAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SETAGG",
+          shape=ellipse]
+/*"SETAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"; "HOAGG"; "AGG"*/
+/*"SETAGG" -> "TYPE"*/
+"SETAGG" -> "EVALAB"
+/*"SETAGG" -> {"IEVALAB"; "KONVERT"}*/
+
+"SETAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SETAGG",
+          shape=ellipse]
+/*"SETAGG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"; "HOAGG"; "AGG"}*/
+/*"SETAGG-" -> "TYPE"*/
+"SETAGG-" -> "EVALAB"
+/*"SETAGG-" -> {"IEVALAB"; "KONVERT"}*/
+
+"SORTPAK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SORTPAK"]
+/*"SORTPAK" -> "TYPE"*/
+"SORTPAK" -> "IXAGG"
+/*"SORTPAK" -> {"HOAGG"; "AGG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"SORTPAK" -> "EVALAB"
+/*"SORTPAK" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "SINT"; "NNI"; "INT"}*/
+/*"SORTPAK" -> {"BOOLEAN"; "PI"; "ORDSET"; "URAGG"; "RCAGG"}*/
+
+"ZMOD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ZMOD"]
+/*"ZMOD" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ZMOD" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ZMOD" -> "LMODULE"*/
+"ZMOD" -> "BMODULE"
+/*"ZMOD" -> {"RMODULE"; "FINITE"; "KONVERT"; "STEP"; "SINT"; "INT"}*/
+/*"ZMOD" -> {"PI"; "NNI"; "INS-"; "EUCDOM-"}*/
+
+\end{chunk}
+\subsection{Layer 4}
+Depends on: BGAGG BRAGG ELAGG- GRMOD MODULE OAMON \\
+Used by next layer: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG
+\begin{chunk}{layer4}
+
+LAYER4=\
+  ${OUT}/ALGEBRA.o ${OUT}/ALGEBRA-.o ${OUT}/BTCAT.o  ${OUT}/BTCAT-.o \
+  ${OUT}/FMCAT.o   ${OUT}/IDPOAM.o   ${OUT}/IFAMON.o ${OUT}/GRALG.o  \
+  ${OUT}/GRALG-.o  ${OUT}/NAALG.o    ${OUT}/NAALG-.o ${OUT}/OCAMON.o \
+  ${OUT}/PRQAGG.o  ${OUT}/QUAGG.o    ${OUT}/SKAGG.o  \
+  layer4done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 4 */
+/* dpends on: BGAGG BRAGG GRMOD MODULE OAMON */
+
+"ALGEBRA" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ALGEBRA"]
+/*"ALGEBRA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ALGEBRA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ALGEBRA" -> "LMODULE"*/
+"ALGEBRA" -> "MODULE"
+/*"ALGEBRA" -> {"BMODULE"; "RMODULE"; "COMRING"}*/
+
+"ALGEBRA-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALGEBRA"]
+/*"ALGEBRA-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ALGEBRA-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ALGEBRA-" -> "LMODULE"*/
+"ALGEBRA-" -> "MODULE"
+/*"ALGEBRA-" -> {"BMODULE"; "RMODULE"; "COMRING"}*/
+
+"BTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BTCAT"]
+"BTCAT" -> "BRAGG"
+/*"BTCAT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"BTCAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "NNI"; "INT"}*/
+
+"BTCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTCAT"]
+"BTCAT-" -> "BRAGG"
+/*"BTCAT-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"BTCAT-" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "NNI"; "INT"}*/
+
+"FMCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMCAT"]
+/*"FMCAT" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FMCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "RETRACT"}*/
+"FMCAT" -> "MODULE"
+
+"IDPOAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPOAM"]
+"IDPOAM" -> "OAMON"
+/*"IDPOAM" -> {"OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"}*/
+/*"IDPOAM" -> {"ABELSG"; "IDPC"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
+
+"IFAMON" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IFAMON"]
+/*"IFAMON" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"IFAMON" -> {"FAMONC"; "RETRACT"; "INT"; "LIST"; "ILIST"}*/
+"IFAMON" -> "OAMON"
+/*"IFAMON" -> {"OASGP"; "ORDSET"}*/
+
+"GRALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GRALG"]
+"GRALG" -> "GRMOD"
+/*"GRALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "COMRING"; "RING"}*/
+/*"GRALG" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"GRALG" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+
+"GRALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GRALG"]
+"GRALG-" -> "GRMOD"
+/*"GRALG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "COMRING"; "RING"}*/
+/*"GRALG-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"GRALG-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+
+"NAALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NAALG"]
+/*"NAALG" -> {"NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NAALG" -> {"BASTYPE"; "KOERCE"; "MONAD"}*/
+"NAALG" -> "MODULE"
+/*"NAALG" -> {"BMODULE"; "LMODULE"; "RMODULE"; "COMRING"; "RING"; "RNG"}*/
+/*"NAALG" -> {"SGROUP"; "MONOID"; "PI"; "NNI"; "INT"}*/
+
+"NAALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NAALG"]
+/*"NAALG-" -> {"NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"NAALG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
+"NAALG-" -> "MODULE"
+/*"NAALG-" -> {"BMODULE"; "LMODULE"; "RMODULE"; "COMRING"; "RING"; "RNG"}*/
+/*"NAALG-" -> {"SGROUP"; "MONOID"; "PI"; "NNI"; "INT"}*/
+
+"OCAMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OCAMON"]
+"OCAMON" -> "OAMON"
+/*"OCAMON" -> {"OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"OCAMON" -> {"ABELMON"; "ABELSG"; "CABMON"}*/
+
+"PRQAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PRQAGG"]
+"PRQAGG" -> "BGAGG"
+/*"PRQAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PRQAGG" -> {"EVALAB"; "IEVALAB"}*/
+
+"QUAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=QUAGG"]
+"QUAGG" -> "BGAGG"
+/*"QUAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"QUAGG" -> {"EVALAB"; "IEVALAB"}*/
+
+"SKAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SKAGG"]
+"SKAGG" -> "BGAGG"
+/*"SKAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SKAGG" -> {"EVALAB"; "IEVALAB"}*/
+
+\end{chunk}
+\subsection{Layer 5}
+Depends on: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG\\
+Used by next layer: MLO OAGROUP OAMONS PID XALG
+
+\begin{chunk}{layer5}
+
+LAYER5=\
+  ${OUT}/BSTREE.o  ${OUT}/BTOURN.o   ${OUT}/CARD.o     ${OUT}/DRAWHACK.o \
+  ${OUT}/DQAGG.o   ${OUT}/FACTFUNC.o ${OUT}/FMTC.o     ${OUT}/FR2.o      \
+  ${OUT}/FRAC2.o   ${OUT}/FRUTIL.o   ${OUT}/ITAYLOR.o  ${OUT}/MLO.o      \
+  ${OUT}/NEWTON.o  ${OUT}/OAGROUP.o  ${OUT}/OAMONS.o   ${OUT}/OP.o       \
+  ${OUT}/PID.o     ${OUT}/RANDSRC.o  ${OUT}/UNISEG2.o  ${OUT}/XALG.o     \
+  layer5done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 5 */
+/* depends on: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG */
+
+"BSTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSTREE"]
+"BSTREE" -> "BTCAT"
+/*"BSTREE" -> {"BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"BSTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ORDSET"}*/
+/*"BSTREE" -> {"INT"; "LIST"; "ILIST"}*/
+
+"BTOURN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTOURN"]
+"BTOURN" -> "BTCAT"
+/*"BTOURN" -> {"BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"BTOURN" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ORDSET"}*/
+/*"BTOURN" -> {"INT"; "LIST"; "ILIST"}*/
+
+"CARD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CARD"]
+/*"CARD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
+/*"CARD" -> {"MONOID"; "SGROUP"; "RETRACT"; "BOOLEAN"; "INT"; "NNI"; "INS-"}*/
+/*"CARD" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+"CARD" -> "ALGEBRA-"
+/*"CARD" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+
+"DRAWHACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWHACK"]
+/*"DRAWHACK" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"DRAWHACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"DRAWHACK" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"DRAWHACK" -> "RMODULE"*/
+"DRAWHACK" -> "ALGEBRA"
+/*"DRAWHACK" -> {"MODULE"; "ENTIRER"; "KONVERT"}*/
+
+"DQAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DQAGG"]
+"DQAGG" -> "SKAGG"
+/*"DQAGG" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"DQAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"}*/
+"DQAGG" -> "QUAGG"
+
+"FACTFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACTFUNC"]
+/*"FACTFUNC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FACTFUNC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FACTFUNC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"FACTFUNC" -> "ALGEBRA"
+/*"FACTFUNC" -> {"MODULE"; "ENTIRER"; "INT"; "LIST"; "ILIST"; "INS-"}*/
+/*"FACTFUNC" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "NNI"; "LSAGG-"; "STAGG-"}*/
+/*"FACTFUNC" -> "ELAGG-"*/
+
+"FMTC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMTC"]
+/*"FMTC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FMTC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FMTC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"FMTC" -> "ALGEBRA"
+/*"FMTC" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
+
+"FR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FR2"]
+/*"FR2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FR2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FR2" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"FR2" -> "ALGEBRA"
+/*"FR2" -> {"MODULE"; "ENTIRER"}*/
+
+"FRAC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRAC2"]
+/*"FRAC2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FRAC2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FRAC2" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"FRAC2" -> "ALGEBRA"
+/*"FRAC2" -> {"MODULE"; "ENTIRER"}*/
+
+"FRUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRUTIL"]
+/*"FRUTIL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FRUTIL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FRUTIL" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"FRUTIL" -> "ALGEBRA"
+/*"FRUTIL" -> {"MODULE"; "ENTIRER"; "INT"; "LIST"; "ILIST"; "PI"; "NNI"}*/
+/*"FRUTIL" -> {"LSAGG-"; "STAGG-"}*/
+
+"ITAYLOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ITAYLOR"]
+/*"ITAYLOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ITAYLOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ITAYLOR" -> {"LMODULE"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
+"ITAYLOR" -> "ALGEBRA"
+/*"ITAYLOR" -> {"MODULE"; "ENTIRER"; "SINT"; "NNI"; "INT"; "BOOLEAN"}*/
+
+"MLO" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MLO"]
+/*"MLO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"MLO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MLO" -> {"BMODULE"; "RMODULE"}*/
+"MLO" -> "ALGEBRA"
+/*"MLO" -> "MODULE"*/
+
+"NEWTON" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NEWTON"]
+/*"NEWTON" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"NEWTON" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"NEWTON" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"NEWTON" -> "ALGEBRA"
+/*"NEWTON" -> {"MODULE"; "ENTIRER"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+/*"NEWTON" -> {"LSAGG-"; "STAGG-"}*/
+
+/* The PID/OAGROUP node is added to the graph to simplify the layout*/
+/* Note that PID and OAGROUP also exist */
+"PID/OAGROUP" [color="blue",href="bookvol10.2.pdf#nameddest=OAGROUP"]
+"PID/OAGROUP" -> "OCAMON"
+"PID/OAGROUP" -> "ALGEBRA"
+
+"OAGROUP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OAGROUP"]
+"OAGROUP" -> "OCAMON"
+/*"OAGROUP" -> {"OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"OAGROUP" -> {"ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
+
+"PID" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PID"]
+/*"PID" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PID" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PID" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"PID" -> "ALGEBRA"
+/*"PID" -> {"MODULE"; "ENTIRER"}*/
+
+"OAMONS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OAMONS"]
+"OAMONS" -> "OCAMON"
+/*"OAMONS" -> {"OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"OAMONS" -> {"ABELMON"; "ABELSG"; "CABMON"}*/
+
+"OP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OP"]
+/*"OP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"OP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "RETRACT"}*/
+/*"OP" -> {"ELTAB"; "CHARZ"; "CHARNZ"}*/
+"OP" -> "ALGEBRA"
+/*"OP" -> {"MODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ORDSET"}*/
+
+"RANDSRC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RANDSRC"]
+/*"RANDSRC" -> {"INT"; "PI"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"RANDSRC" -> "INTDOM-"*/
+"RANDSRC" -> "ALGEBRA-"
+/*"RANDSRC" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"RANDSRC" -> "ABELMON-"*/
+
+"UNISEG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UNISEG2"]
+/*"UNISEG2" -> {"TYPE"; "ORDRING"; "OAGROUP"*/
+"UNISEG2" -> "OCAMON"
+/*"UNISEG2" -> {"OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"UNISEG2" -> {"ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"; "RING"; "RNG"}*/
+/*"UNISEG2" -> {"SGROUP"; "MONOID"; "LMODULE"}*/
+
+"XALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XALG"]
+/*"XALG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"XALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"XALG" -> {"BMODULE"; "RMODULE"}*/
+"XALG" -> "ALGEBRA"
+/*"XALG" -> "MODULE"*/
+
+\end{chunk}
+\subsection{Layer6}
+Depends on: MLO OAGROUP OAMONS PID XALG\\
+Used by next layer: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT 
+XFALG
+\begin{chunk}{layer6}
+
+LAYER6=\
+  ${OUT}/AMR.o      ${OUT}/AMR-.o     ${OUT}/DEGRED.o  ${OUT}/DIVCAT.o   \
+  ${OUT}/DLP.o      \
+  ${OUT}/EAB.o      ${OUT}/ESTOOLS1.o ${OUT}/FAGROUP.o ${OUT}/FAMONOID.o \
+  ${OUT}/FIELD.o    ${OUT}/FIELD-.o   ${OUT}/FLAGG.o   ${OUT}/FLAGG-.o   \
+  ${OUT}/FLINEXP.o  ${OUT}/FLINEXP-.o ${OUT}/FRETRCT.o ${OUT}/FRETRCT-.o \
+  ${OUT}/FSERIES.o  ${OUT}/FT.o       ${OUT}/IDPOAMS.o ${OUT}/INFINITY.o \
+  ${OUT}/LA.o       ${OUT}/MAPPKG4.o  ${OUT}/OMLO.o    ${OUT}/ORTHPOL.o  \
+  ${OUT}/PRODUCT.o  ${OUT}/PADICCT.o  ${OUT}/PMPRED.o  ${OUT}/PMASS.o   \
+  ${OUT}/PTFUNC2.o  ${OUT}/RADCAT.o   ${OUT}/RADCAT-.o ${OUT}/RATRET.o  \
+  ${OUT}/RADUTIL.o  ${OUT}/UPXS2.o    ${OUT}/XFALG.o   ${OUT}/ZLINDEP.o \
+  layer6done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 6 */
+/* MLO OAGROUP OAMONS PID XALG */
+
+"AMR" [color="#4488FF",href="bookvol10.2.pdf#nameddest=AMR"]
+/*"AMR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"AMR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"AMR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"AMR" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"AMR" -> {"INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
+"AMR" -> "PID/OAGROUP"
+/*"AMR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"}*/
+/*"AMR" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"AMR" -> "STEP"*/
+
+"AMR-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AMR"]
+/*"AMR-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"AMR-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"AMR-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"AMR-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"AMR-" -> {"INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
+"AMR-" -> "PID/OAGROUP"
+/*"AMR-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"}*/
+/*"AMR-" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"AMR-" -> "STEP"*/
+
+"DEGRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DEGRED"]
+/*"DEGRED" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DEGRED" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DEGRED" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"DEGRED" -> {"MODULE"; "ENTIRER"; "ORDSET"; "BOOLEAN"; "INT"; "LIST"}*/
+/*"DEGRED" -> {"ILIST"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+/*"DEGRED" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"DEGRED" -> {"ABELGRP-"; "ABELMON-"; "PI"; "NNI"; "INS"; "UFD"; "GCDDOM"}*/
+/*"DEGRED" -> "EUCDOM"*/
+"DEGRED" -> "PID/OAGROUP"
+/*"DEGRED" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"DEGRED" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"DEGRED" -> {"REAL"; "CHARZ"; "STEP"; "SINT"}*/
+
+"DIVCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DIVCAT"]
+/*"DIVCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"DIVCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"DIVCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DIVCAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "OINTDOM"}*/
+/*"DIVCAT" -> {"ORDRING"}*/
+"DIVCAT" -> "PID"
+"DIVCAT" -> "OAGROUP"
+/*"DIVCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"DIVCAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"DIVCAT" -> {"STEP"; "FAMONC"}*/
+
+"DLP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DLP"]
+/*"DLP" -> {"MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
+/*"DLP" -> {"INT"; "NNI"; "BOOLEAN"; "SINT"; "PI"; "ABELSG"}*/
+"DLP" -> "OAMONS"
+/*"DLP" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "ABELMON"; "CABMON"}*/
+
+"EAB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EAB"]
+/*"EAB" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"}*/
+/*"EAB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"EAB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"EAB" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"EAB" -> "PID/OAGROUP"
+/*"EAB" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"EAB" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"EAB" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "LIST"; "ILIST"}*/
+/*"EAB" -> {"BOOLEAN"; "NNI"; "SINT"}*/
+
+"ESTOOLS1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESTOOLS1"]
+/*"ESTOOLS1" -> "ORDRING"*/
+"ESTOOLS1" -> "OAGROUP"
+/*"ESTOOLS1" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+/*"ESTOOLS1" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
+/*"ESTOOLS1" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+
+"FAGROUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAGROUP"]
+/*"FAGROUP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FAGROUP" -> {"BASTYPE"; "KOERCE"; "MODULE"; "BMODULE"; "LMODULE"}*/
+/*"FAGROUP" -> {"RMODULE"; "FAMONC"; "RETRACT"; "ORDSET"; "INS"; "UFD"}*/
+/*"FAGROUP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"}*/
+/*"FAGROUP" -> {"MONOID"; "ALGEBRA"; "ENTIRER"; "EUCDOM"}*/
+"FAGROUP" -> "PID/OAGROUP"
+/*"FAGROUP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FAGROUP" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"FAGROUP" -> {"CHARZ"; "STEP"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "OM"}*/
+
+"FAMONOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAMONOID"]
+/*"FAMONOID" -> {"FAMONC"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FAMONOID" -> {"BASTYPE"; "KOERCE"; "RETRACT"}*/
+"FAMONOID" -> "OAMONS"
+/*"FAMONOID" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "NNI"; "INT"}*/
+/*"FAMONOID" -> {"MONOID"; "SGROUP"}*/
+
+"FIELD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FIELD"]
+/*"FIELD" -> "EUCDOM"*/
+"FIELD" -> "PID"
+/*"FIELD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FIELD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FIELD" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FIELD" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"FIELD" -> {"BOOLEAN"; "INT"; "NNI"}*/
+
+"FIELD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FIELD"]
+/*"FIELD-" -> "EUCDOM"*/
+"FIELD-" -> "PID"
+/*"FIELD-" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FIELD-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FIELD-" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FIELD-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "BOOLEAN"}*/
+/*"FIELD-" -> {"INT"; "NNI"}*/
+
+"FLAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FLAGG"]
+/*"FLAGG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"FLAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"FLAGG" -> {"KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"FLAGG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FLAGG" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FLAGG" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"FLAGG" -> "PID/OAGROUP"
+/*"FLAGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FLAGG" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"FLAGG" -> {"CHARZ"; "STEP"; "OM"}*/
+
+"FLAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FLAGG"]
+/*"FLAGG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"FLAGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"FLAGG-" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"}*/
+/*"FLAGG-" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FLAGG-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"FLAGG-" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FLAGG-" -> {"ENTIRER"; "EUCDOM"}*/
+"FLAGG-" -> "PID/OAGROUP"
+/*"FLAGG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FLAGG-" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"FLAGG-" -> {"CHARZ"; "STEP"; "OM"}*/
+
+"FLINEXP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FLINEXP"]
+/*"FLINEXP" -> {"LINEXP"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FLINEXP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FLINEXP" -> {"LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FLINEXP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FLINEXP" -> "EUCDOM"*/
+"FLINEXP" -> "PID/OAGROUP"
+/*"FLINEXP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FLINEXP" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "PATMAB"}*/
+/*"FLINEXP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"FLINEXP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FLINEXP"]
+/*"FLINEXP-" -> {"LINEXP"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FLINEXP-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FLINEXP-" -> {"MONOID"; "LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"FLINEXP-" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FLINEXP-" -> {"ENTIRER"; "EUCDOM"}*/
+"FLINEXP-" -> "PID/OAGROUP"
+/*"FLINEXP-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FLINEXP-" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"FLINEXP-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"FRETRCT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FRETRCT"]
+/*"FRETRCT" -> {"RETRACT"; "TYPE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"FRETRCT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FRETRCT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FRETRCT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FRETRCT" -> {"ENTIRER"; "EUCDOM"}*/
+"FRETRCT" -> "PID/OAGROUP"
+/*"FRETRCT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FRETRCT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"FRETRCT" -> {"REAL"; "CHARZ"; "STEP"}*/
+
+"FRETRCT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRETRCT"]
+/*"FRETRCT-" -> {"RETRACT"; "TYPE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"FRETRCT-" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FRETRCT-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FRETRCT-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FRETRCT-" -> {"MODULE"; "ENTIRER"; "EUCDOM"}*/
+"FRETRCT-" -> "PID/OAGROUP"
+/*"FRETRCT-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FRETRCT-" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"}*/
+/*"FRETRCT-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"FSERIES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FSERIES"]
+/*"FSERIES" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FSERIES" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FSERIES" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"FSERIES" -> {"ORDSET"; "PI"; "NNI"; "INT"; "INS"; "UFD"; "GCDDOM"}*/
+/*"FSERIES" -> {"INTDOM"; "ENTIRER"; "EUCDOM"}*/
+"FSERIES" -> "PID/OAGROUP"
+/*"FSERIES" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FSERIES" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"FSERIES" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LIST"}*/
+
+"FT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FT"]
+/*"FT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
+/*"FT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"FT" -> "PID/OAGROUP"
+/*"FT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"FT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"; "LIST"; "ILIST"}*/
+/*"FT" -> "BOOLEAN"*/
+
+"IDPOAMS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPOAMS"]
+"IDPOAMS" -> "OAMONS"
+/*"IDPOAMS" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+/*"IDPOAMS" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "IDPC"; "INT"}*/
+/*"IDPOAMS" -> {"LIST"; "ILIST"}*/
+
+"INFINITY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFINITY"]
+/*"INFINITY" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"INFINITY" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"INFINITY" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INFINITY" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"INFINITY" -> "EUCDOM"*/
+"INFINITY" -> "PID/OAGROUP"
+/*"INFINITY" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"INFINITY" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"INFINITY" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+/* Note that INS has a circular self reference */
+"INS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INS",
+          shape=ellipse]
+/*"INS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"INS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"INS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"INS" -> "PID/OAGROUP"
+/*"INS" -> "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"INS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"INS" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"; "INT"}*/
+/*"INS" -> {"BOOLEAN"; "DFLOAT"}*/
+
+"INS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INS",
+          shape=ellipse]
+/*"INS-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"INS-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"INS-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"INS-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"INS-" -> "PID/OAGROUP"
+/*"INS-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"INS-" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"INS-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"; "INT"}*/
+/*"INS-" -> {"BOOLEAN"; "DFLOAT"}*/
+
+"LA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LA"]
+/*"LA" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LA" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"LA" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "ORDRING"}*/
+"LA" -> "OAGROUP"
+/*"LA" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "COMRING"}*/
+
+"LNAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LNAGG",
+          shape=ellipse]
+/*"LNAGG" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"LNAGG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"LNAGG" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"LNAGG" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"LNAGG" -> "PID/OAGROUP"
+/*"LNAGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"LNAGG" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"LNAGG" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "IXAGG"; "HOAGG"}*/
+/*"LNAGG" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"LNAGG" -> {"CLAGG"; "OM"; "INT"; "BOOLEAN"; "NNI"}*/
+
+"LNAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LNAGG",
+          shape=ellipse]
+/*"LNAGG-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"LNAGG-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"LNAGG-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"LNAGG-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"LNAGG-" -> "PID/OAGROUP"
+/*"LNAGG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"LNAGG-" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"LNAGG-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"LNAGG-" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"LNAGG-" -> {"OM"; "INT"; "BOOLEAN"; "NNI"}*/
+
+"MAPPKG4" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG4"]
+/*"MAPPKG4" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MAPPKG4" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MAPPKG4" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"MAPPKG4" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"MAPPKG4" -> "PID/OAGROUP"
+/*"MAPPKG4" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"MAPPKG4" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"MAPPKG4" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"NNI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NNI",
+          shape=ellipse]
+"NNI" -> "OAMONS"
+/*"NNI" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+/*"NNI" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "MONOID"; "SGROUP"}*/
+/*"NNI" -> {"NNI"; "INT"; "BOOLEAN"}*/
+
+"OINTDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OINTDOM",
+          shape=ellipse]
+/*"OINTDOM" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"OINTDOM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"OINTDOM" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"OINTDOM" -> {"MODULE"; "ENTIRER"; "ORDRING"}*/
+"OINTDOM" -> "OAGROUP"
+/*"OINTDOM" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+
+"OMLO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMLO"]
+"OMLO" -> "MLO"
+/*"OMLO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"OMLO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"OMLO" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "DIFRING"; "COMRING"}*/
+
+"ORDRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDRING",
+          shape=ellipse]
+"ORDRING" -> "OAGROUP"
+/*"ORDRING" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+/*"ORDRING" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
+/*"ORDRING" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"; "INT"}*/
+
+"ORDRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ORDRING",
+          shape=ellipse]
+"ORDRING-" -> "OAGROUP"
+/*"ORDRING-" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+/*"ORDRING-" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"; "RING"}*/
+/*"ORDRING-" -> {"RNG"; "SGROUP"; "MONOID"; "LMODULE"; "INT"}*/
+
+"ORTHPOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ORTHPOL"]
+/*"ORTHPOL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ORTHPOL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ORTHPOL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "NNI"; "INT"; "SINT"}*/
+/*"ORTHPOL" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "PI"; "INS-"}*/
+/*"ORTHPOL" -> {"ALGEBRA"; "MODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"ORTHPOL" -> {"ENTIRER"; "EUCDOM"}*/
+"ORTHPOL" -> "PID/OAGROUP"
+/*"ORTHPOL" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ORTHPOL" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"ORTHPOL" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"ORTHPOL" -> "STEP"*/
+
+"PRODUCT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PRODUCT"]
+/*"PRODUCT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"; "MONOID"}*/
+/*"PRODUCT" -> {"SGROUP"; "ABELMON"; "ABELSG"; "CABMON"; "GROUP"; {"ABELGRP"}*/
+"PRODUCT" -> "OAMONS"
+/*"PRODUCT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "BOOLEAN"; "NNI"}*/
+/*"PRODUCT" -> "INT"*/
+
+"PADICCT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PADICCT"]
+/*"PADICCT" -> "EUCDOM"*/
+"PADICCT" -> "PID"
+/*"PADICCT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PADICCT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PADICCT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PADICCT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
+
+"PMPRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPRED"]
+/*"PMPRED" -> {"TYPE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PMPRED" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PMPRED" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PMPRED" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"PMPRED" -> "PID/OAGROUP"
+/*"PMPRED" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PMPRED" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"PMPRED" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"PMASS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMASS"]
+/*"PMASS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PMASS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PMASS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PMASS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"PMASS" -> "PID/OAGROUP"
+/*"PMASS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PMASS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"PMASS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"PTFUNC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PTFUNC2"]
+/*"PTFUNC2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PTFUNC2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PTFUNC2" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"PTFUNC2" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"PTFUNC2" -> "PID/OAGROUP"
+/*"PTFUNC2" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PTFUNC2" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"PTFUNC2" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"RADCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RADCAT"]
+/*"RADCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"RADCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RADCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"RADCAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"RADCAT" -> "PID/OAGROUP"
+/*"RADCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"RADCAT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"RADCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"RADCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RADCAT"]
+/*"RADCAT-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"RADCAT-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"RADCAT-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RADCAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"RADCAT-" -> "EUCDOM"*/
+"RADCAT-" -> "PID/OAGROUP"
+/*"RADCAT-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"RADCAT-" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"RADCAT-" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"RATRET" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RATRET"]
+/*"RATRET" -> {"RETRACT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"RATRET" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RATRET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RATRET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"RATRET" -> "EUCDOM"*/
+"RATRET" -> "PID/OAGROUP"
+/*"RATRET" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"RATRET" -> {"ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"RATRET" -> {"REAL"; "CHARZ"; "STEP"}*/
+
+"RADUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RADUTIL"]
+/*"RADUTIL" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"RADUTIL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"RADUTIL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RADUTIL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"RADUTIL" -> "EUCDOM"*/
+"RADUTIL" -> "PID/OAGROUP"
+/*"RADUTIL" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"RADUTIL" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"RADUTIL" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+/* Note that SINT references itself! */
+"SINT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SINT",
+          shape=ellipse]
+/*"SINT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"SINT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SINT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SINT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"SINT" -> "PID/OAGROUP"
+/*"SINT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SINT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"SINT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LOGIC"; "OM"; "SINT"; "INT"}*/
+
+"STAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=STAGG",
+          shape=ellipse]
+/*"STAGG" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"STAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"STAGG" -> {"ELTAB"; "CLAGG"; "KONVERT"; "BOOLEAN"; "SINT"; "NNI"; "INT"}*/
+/*"STAGG" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"STAGG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"STAGG" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"STAGG" -> {"ENTIRER"; "EUCDOM"}*/
+"STAGG" -> "PID/OAGROUP"
+/*"STAGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"STAGG" -> {"ORDSET"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"STAGG" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "LIST"; "ILIST"}*/
+
+"STAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STAGG",
+          shape=ellipse]
+/*"STAGG-" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"STAGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"STAGG-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "BOOLEAN"; "SINT"}*/
+/*"STAGG-" -> {"NNI"; "INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"STAGG-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"STAGG-" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"STAGG-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"STAGG-" -> "PID/OAGROUP"
+/*"STAGG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"STAGG-" -> {"ORDSET"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"STAGG-" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "LIST"; "ILIST"}*/
+
+"UPXS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPXS2"]
+/*"UPXS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UPXS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UPXS2" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"UPXS2" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+"UPXS2" -> "PID/OAGROUP"
+/*"UPXS2" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"UPXS2" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"UPXS2" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"XFALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XFALG"]
+/*"XFALG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"XFALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+"XFALG" -> "XALG"
+/*"XFALG" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "RETRACT"}*/
+
+"ZLINDEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ZLINDEP"]
+/*"ZLINDEP" -> {"LINEXP"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ZLINDEP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ZLINDEP" -> {"MONOID"; "LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"ZLINDEP" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ZLINDEP" -> {"ENTIRER"; "EUCDOM"}*/
+"ZLINDEP" -> "PID/OAGROUP"
+/*"ZLINDEP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ZLINDEP" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"ZLINDEP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+\end{chunk}
+\subsection{Layer7}
+Depends on: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT XFALG \\
+Used by next layer: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT 
+TRANFUN VSPACE XPOLYC
+\begin{chunk}{layer7}
+
+LAYER7=\
+  ${OUT}/A1AGG.o    ${OUT}/A1AGG-.o   ${OUT}/ARR2CAT.o  ${OUT}/ARR2CAT-.o \
+  ${OUT}/ASP34.o    ${OUT}/BBTREE.o   ${OUT}/BFUNCT.o   ${OUT}/BLAS1.o    \
+  ${OUT}/BPADIC.o   \
+  ${OUT}/BTREE.o    ${OUT}/CRAPACK.o  ${OUT}/DEQUEUE.o  ${OUT}/DIRRING.o  \
+  ${OUT}/DIV.o      ${OUT}/DLIST.o    \
+  ${OUT}/DRAWCX.o   ${OUT}/DRAWPT.o   ${OUT}/D01GBFA.o  ${OUT}/D02EJFA.o  \
+  ${OUT}/D03FAFA.o  ${OUT}/FAMR.o     ${OUT}/FAMR-.o    ${OUT}/FIELD.o    \
+  ${OUT}/FLASORT.o  \
+  ${OUT}/FLAGG2.o   ${OUT}/FGROUP.o   ${OUT}/FM.o       ${OUT}/FM1.o      \
+  ${OUT}/FPC.o      ${OUT}/FPC-.o     ${OUT}/FMONOID.o  ${OUT}/INDE.o     \
+  ${OUT}/IPADIC.o   ${OUT}/IROOT.o    ${OUT}/IR2.o      ${OUT}/LEXP.o     \
+  ${OUT}/LIECAT.o   ${OUT}/LIECAT-.o  ${OUT}/LIST2.o    ${OUT}/LIST2MAP.o \
+  ${OUT}/LMOPS.o    ${OUT}/LZSTAGG.o  ${OUT}/LZSTAGG-.o ${OUT}/MAGMA.o    \
+  ${OUT}/MESH.o     ${OUT}/MOEBIUS.o  ${OUT}/MODFIELD.o ${OUT}/MODOP.o    \
+  ${OUT}/MRING.o    ${OUT}/MTHING.o   ${OUT}/NCNTFRAC.o ${OUT}/NCODIV.o   \
+  ${OUT}/NUMTUBE.o  ${OUT}/ODR.o      ${OUT}/OFMONOID.o ${OUT}/ONECOMP.o  \
+  ${OUT}/ORDCOMP.o  ${OUT}/OREPCAT.o  ${OUT}/OREPCAT-.o ${OUT}/OWP.o      \
+  ${OUT}/PACPERC.o  \
+  ${OUT}/PADIC.o    ${OUT}/PATTERN2.o ${OUT}/PATLRES.o  ${OUT}/PARTPERM.o \
+  ${OUT}/PBWLB.o    ${OUT}/PENDTREE.o ${OUT}/PGE.o      ${OUT}/PGROEB.o   \
+  ${OUT}/PINTERP.o  ${OUT}/PLOTTOOL.o ${OUT}/PFR.o      ${OUT}/PMDOWN.o   \
+  ${OUT}/PMINS.o    ${OUT}/PMLSAGG.o  ${OUT}/PMTOOLS.o  ${OUT}/PRTITION.o \
+  ${OUT}/PSCAT.o    ${OUT}/PSCAT-.o   ${OUT}/QFORM.o    ${OUT}/QUEUE.o    \
+  ${OUT}/SCACHE.o   ${OUT}/SEG.o      ${OUT}/SEG2.o     ${OUT}/SEXOF.o    \
+  ${OUT}/STACK.o    ${OUT}/STTAYLOR.o ${OUT}/TABLBUMP.o ${OUT}/TABLEAU.o  \
+  ${OUT}/TOPSP.o    ${OUT}/TRANFUN.o  ${OUT}/TRANFUN-.o ${OUT}/TUBE.o     \
+  ${OUT}/UDPO.o     ${OUT}/UNISEG.o   ${OUT}/VIEW.o     ${OUT}/VSPACE.o   \
+  ${OUT}/VSPACE-.o  ${OUT}/XPOLYC.o   ${OUT}/XPR.o \
+  layer7done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 7 */
+/* depends on: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT XFALG */
+
+"A1AGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=A1AGG"]
+"A1AGG" -> "FLAGG"
+/*"A1AGG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"A1AGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"A1AGG" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"}*/
+/*"A1AGG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"A1AGG" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"A1AGG" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"A1AGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"A1AGG" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"A1AGG" -> {"CHARZ"; "STEP"; "OM"; "BOOLEAN"; "SINT"; "INT"}*/
+/*"A1AGG" -> {"NNI"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"A1AGG" -> {"RCAGG"; "ELAGG"}*/
+
+"A1AGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=A1AGG"]
+"A1AGG-" -> "FLAGG"
+/*"A1AGG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"A1AGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"A1AGG-" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"}*/
+/*"A1AGG-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"A1AGG-" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"A1AGG-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"A1AGG-" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"A1AGG-" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"A1AGG-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+/*"A1AGG-" -> {"BOOLEAN"; "SINT"; "INT"; "NNI"; "LIST"; "ILIST"}*/
+/*"A1AGG-" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+
+"ARR2CAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ARR2CAT"]
+/*"ARR2CAT" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ARR2CAT" -> {"EVALAB"; "IEVALAB"}*/
+"ARR2CAT" -> "FLAGG"
+/*"ARR2CAT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"ARR2CAT" -> {"ORDSET"; "BOOLEAN"; "NNI"; "INT"; "SINT"; "LIST"}*/
+/*"ARR2CAT" -> {"ILIST"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ARR2CAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ARR2CAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ARR2CAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"ARR2CAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"ARR2CAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"ARR2CAT" -> {"CHARZ"; "STEP"; "OM"}*/
+
+"ARR2CAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ARR2CAT"]
+/*"ARR2CAT-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ARR2CAT-" -> {"EVALAB"; "IEVALAB"}*/
+"ARR2CAT-" -> "FLAGG"
+/*"ARR2CAT-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"ARR2CAT-" -> {"ORDSET"; "BOOLEAN"; "NNI"; "INT"; "SINT"; "LIST"; "ILIST"}*/
+/*"ARR2CAT-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"ARR2CAT-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"ARR2CAT-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ARR2CAT-" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"ARR2CAT-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ARR2CAT-" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"ARR2CAT-" -> {"REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"ASP34" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP34"]
+/*"ASP34" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "INS"; "UFD"}*/
+/*"ASP34" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ASP34" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"}*/
+/*"ASP34" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ASP34" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"ASP34" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"ASP34" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"ASP34" -> {"STEP"; "FPS"; "RNS"}*/
+"ASP34" -> "FIELD"
+/*"ASP34" -> "DIVRING"*/
+"ASP34" -> "RADCAT"
+/*"ASP34" -> {"NNI"; "INT"; "OM"}*/
+
+"BBTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BBTREE"]
+/*"BBTREE" -> {"BTCAT"; "BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"BBTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "BOOLEAN"}*/
+/*"BBTREE" -> {"LSAGG"; "STAGG"; "URAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"BBTREE" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"BBTREE" -> "FLAGG"
+/*"BBTREE" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+/*"BBTREE" -> {"SINT"; "PI"; "LSAGG-"; "STAGG-"}*/
+
+"BFUNCT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BFUNCT"]
+/*"BFUNCT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "DFLOAT"; "FPS-"}*/
+/*"BFUNCT" -> "RNS-"*/
+"BFUNCT" -> "FIELD-"
+/*"BFUNCT" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
+/*"BFUNCT" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "INT"}*/
+
+"BLAS1" [color="#444488",href="bookvol10.5.pdf#nameddest=BLAS1"]
+/*"BLAS1" -> {"FPS" "RNS"}*/ 
+"BLAS1" -> "FIELD"
+/*"BLAS1" -> {"EUCDOM" "PID" "GCDDOM" "INTDOM" "COMRING" "RING" "RNG"}*/
+/*"BLAS1" -> {"ABELGRP" "CABMON" "ABELMON" "ABELSG" "SETCAT" "BASTYPE"}*/ 
+/*"BLAS1" -> {"KOERCE" "SGROUP" "MONOID" "LMODULE" "BMODULE" "RMODULE"}*/
+/*"BLAS1" -> {"ALGEBRA" "MODULE" "ENTIRER" "UFD" "DIVRING" "ORDRING"}*/ 
+/*"BLAS1" -> {"OAGROUP" "OCAMON" "OAMON" "OASGP" "ORDSET" "REAL"}*/
+/*"BLAS1" -> {"KONVERT" "RETRACT"}*/ 
+"BLAS1" -> "RADCAT"
+/*"BLAS1" -> {"PATMAB" "CHARZ"}*/
+
+"BPADIC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BPADIC"]
+/*"BPADIC" -> "BOOLEAN"*/
+"BPADIC" -> "PADICCT"
+/*"BPADIC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"BPADIC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"BPADIC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"BPADIC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "INS"}*/
+/*"BPADIC" -> {"UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"BPADIC" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"BPADIC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+
+"BTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTREE"]
+/*"BTREE" -> {"BTCAT"; "BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"BTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"}*/
+/*"BTREE" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
+/*"BTREE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"BTREE" -> "FLAGG"
+/*"BTREE" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"CLAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CLAGG",
+         shape=ellipse]
+/*"CLAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"CLAGG" -> {"EVALAB"; "IEVALAB"; "KONVERT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"CLAGG" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+"CLAGG" -> "FLAGG" 
+/*"CLAGG" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+/*"CLAGG" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+
+"CLAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CLAGG",
+          shape=ellipse]
+/*"CLAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"CLAGG-" -> {"EVALAB"; "IEVALAB"; "KONVERT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"CLAGG-" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+"CLAGG-" -> "FLAGG"
+/*"CLAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+/*"CLAGG-" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "ELAGG"}*/
+
+"CRAPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CRAPACK"]
+/*"CRAPACK" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"CRAPACK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"CRAPACK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CRAPACK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"CRAPACK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"CRAPACK" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"CRAPACK" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"CRAPACK" -> "FLAGG"
+/*"CRAPACK" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+
+"DEQUEUE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DEQUEUE"]
+/*"DEQUEUE" -> {"DQAGG"; "SKAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"DEQUEUE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "QUAGG"; "INT"}*/
+/*"DEQUEUE" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"DEQUEUE" -> "FLAGG-"
+/*"DEQUEUE" -> {"URAGG-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"DEQUEUE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DEQUEUE" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DEQUEUE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"DEQUEUE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"DEQUEUE" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"DEQUEUE" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "LNAGG-"; "LSAGG"; "STAGG"}*/
+/*"DEQUEUE" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"DEQUEUE" -> "CLAGG"*/
+"DEQUEUE" -> "FLAGG"
+/*"DEQUEUE" -> "ELAGG"*/
+
+"DIRRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIRRING"]
+"DIRRING" -> "FLAGG"
+/*"DIRRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DIRRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DIRRING" -> {"ELTAB"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
+/*"DIRRING" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "INT"; "INS"; "UFD"}*/
+/*"DIRRING" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"DIRRING" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"DIRRING" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"DIRRING" -> {"STEP"; "PI"; "NNI"; "BOOLEAN"; "LIST"; "ILIST"; "INS-"}*/
+/*"DIRRING" -> {"MONOID-"; "ABELSG-"; "SGROUP-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"DIRRING" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; IEVALAB"}*/
+/*"DIRRING" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "ELAGG"; "OM"; "LSAGG-"}*/
+
+"DIV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIV"]
+"DIV" -> "DIVCAT"
+"DIV" -> "FLAGG"
+/*"DIV" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"DIV" -> {"KOERCE"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "FAMONC"}*/
+/*"DIV" -> {"RETRACT"; "SETCATD"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"DIV" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "ALGEBRA"}*/
+/*"DIV" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"DIV" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"DIV" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+/*"DIV" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"DIV" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"DIV" -> {"CLAGG"; "ELAGG"; "LIST"; "ILIST"; "LSAGG-"; "BOOLEAN"; "NNI"}*/
+/*"DIV" -> {"STAGG-"; "ELAGG-"; "PI"}*/
+
+"DLIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DLIST"]
+/*"DLIST" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"DLIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"DLIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"DLIST" -> "FLAGG"
+/*"DLIST" -> {"ORDSET"; "ELAGG"; "INT"; "LIST"; "ILIST"; "INS"; "UFD"}*/
+/*"DLIST" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"DLIST" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DLIST" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"DLIST" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"DLIST" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"DLIST" -> {"REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"DRAWCX" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWCX"]
+/*"DRAWCX" -> {"DFLOAT"; "PI"; "NNI"; "INT"; "FPS"; "RNS"}*/
+"DRAWCX" -> "FIELD"
+/*"DRAWCX" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DRAWCX" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"DRAWCX" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"DRAWCX" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"DRAWCX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"DRAWCX" -> {"REAL"; "KONVERT"; "RETRACT"}*/
+"DRAWCX" -> "RADCAT"
+/*"DRAWCX" -> {"PATMAB"; "CHARZ"; "SINT"; "LIST"; "ILIST"}*/
+
+"D01GBFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01GBFA"]
+/*"D01GBFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "DFLOAT"; "PI"}*/
+/*"D01GBFA" -> {"NNI"; "INT"; "FPS"; "RNS"}*/
+"D01GBFA" -> "FIELD"
+/*"D01GBFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"D01GBFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"D01GBFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"D01GBFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"D01GBFA" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"D01GBFA" -> "RETRACT"*/
+"D01GBFA" -> "RADCAT"
+/*"D01GBFA" -> {"PATMAB"; "CHARZ"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"D01GBFA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"D01GBFA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"D01GBFA" -> "FLAGG"
+/*"D01GBFA" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"D01GBFA" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"D01GBFA" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"D01GBFA" -> "ABELMON-"*/
+
+"D02EJFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02EJFA"]
+/*"D02EJFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+/*"D02EJFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"D02EJFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"D02EJFA" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"D02EJFA" -> "FLAGG"
+/*"D02EJFA" -> {"ORDSET"; "ELAGG"; "OM"; "LIST"; "ILIST"; "DFLOAT"}*/
+/*"D02EJFA" -> {"FPS-"; "RNS-"}*/
+"D02EJFA" -> "FIELD-"
+/*"D02EJFA" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
+/*"D02EJFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "FPS"; "RNS"}*/
+"D02EJFA" -> "FIELD"
+/*"D02EJFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"D02EJFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"D02EJFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"D02EJFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"D02EJFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
+"D02EJFA" -> "RADCAT"
+/*"D02EJFA" -> {"PATMAB"; "CHARZ"; "PI"}*/
+
+"D03FAFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D03FAFA"]
+/*"D03FAFA" -> {"PDECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"}*/
+/*"D03FAFA" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"D03FAFA" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"D03FAFA" -> "KONVERT"*/
+"D03FAFA" -> "FLAGG"
+/*"D03FAFA" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+
+"DRAWPT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWPT"]
+/*"DRAWPT" -> {"FPS"; "RNS"}*/
+"DRAWPT" -> "FIELD"
+/*"DRAWPT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DRAWPT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"DRAWPT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"DRAWPT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"DRAWPT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"DRAWPT" -> {"REAL"; "KONVERT"; "RETRACT"}*/
+"DRAWPT" -> "RADCAT"
+/*"DRAWPT" -> {"PATMAB"; "CHARZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"DRAWPT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"DRAWPT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"DRAWPT" -> "FLAGG"
+/*"DRAWPT" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "INS-"; "EUCDOM-"}*/
+/*"DRAWPT" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"DRAWPT" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+/*"DRAWPT" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"; "SETCAT-"}*/
+/*"DRAWPT" -> {"RETRACT-"; "BASTYPE-"; "DFLOAT"; "PI"; "NNI"; "SINT"}*/
+/*"DRAWPT" -> {"LSAGG-"; "STAGG-"}*/
+
+"EUCDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=EUCDOM",
+          shape=ellipse]
+/*"EUCDOM" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"EUCDOM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"EUCDOM" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"EUCDOM" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"EUCDOM" -> {"BOOLEAN"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"EUCDOM" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
+/*"EUCDOM" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"EUCDOM" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"EUCDOM" -> "KONVERT"*/
+"EUCDOM" -> "FLAGG"
+/*"EUCDOM" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"EUCDOM-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EUCDOM",
+          shape=ellipse]
+/*"EUCDOM-" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"EUCDOM-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"EUCDOM-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"EUCDOM-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"EUCDOM-" -> {"BOOLEAN"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"EUCDOM-" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
+/*"EUCDOM-" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"EUCDOM-" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"EUCDOM-" -> "KONVERT"*/
+"EUCDOM-" -> "FLAGG"
+/*"EUCDOM-" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"FAMR" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FAMR"]
+"FAMR" -> "AMR"
+/*"FAMR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FAMR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FAMR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"FAMR" -> {"CHARNZ"; "INTDOM"; "ENTIRER"}*/
+"FAMR" -> "FRETRCT"
+/*"FAMR" -> {"RETRACT"; "OAMON"; "OASGP"; "ORDSET"; "NNI"; "INT"; "LIST"}*/
+/*"FAMR" -> {"ILIST"; "PI"; "BOOLEAN"}*/
+"FAMR" -> "FIELD"
+/*"FAMR" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+
+"FAMR-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAMR"]
+"FAMR-" -> "AMR"
+/*"FAMR-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FAMR-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FAMR-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"FAMR-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"}*/
+"FAMR-" -> "FRETRCT"
+/*"FAMR-" -> {"RETRACT"; "OAMON"; "OASGP"; "ORDSET"; "NNI"; "INT"; "LIST"}*/
+/*"FAMR-" -> {"ILIST"; "PI"; "BOOLEAN"}*/
+"FAMR-" -> "FIELD"
+/*"FAMR-" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+
+"FLASORT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLASORT"]
+/*"FLASORT" -> "TYPE"*/
+"FLASORT" -> "FLAGG"
+/*"FLASORT" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"; "BASTYPE"}*/
+/*"FLASORT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"FLASORT" -> {"KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"FLASORT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FLASORT" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FLASORT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"FLASORT" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FLASORT" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"FLASORT" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "INS-"; "EUCDOM-"}*/
+/*"FLASORT" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"FLASORT" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+/*"FLASORT" -> {"PI"; "NNI"; "SINT"; "BOOLEAN"}*/
+
+"FLAGG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLAGG2"]
+/*"FLAGG2" -> "TYPE"*/
+"FLAGG2" -> "FLAGG"
+/*"FLAGG2" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"; "BASTYPE"}*/
+/*"FLAGG2" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"FLAGG2" -> {"KONVERT"; "ORDSET"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"FLAGG2" -> {"ELAGG"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FLAGG2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FLAGG2" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FLAGG2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"FLAGG2" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"FLAGG2" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"FLAGG2" -> {"STEP"; "OM"; "INT"}*/
+
+"FGROUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FGROUP"]
+/*"FGROUP" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FGROUP" -> {"RETRACT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FGROUP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FGROUP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FGROUP" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"FGROUP" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"FGROUP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"}*/
+/*"FGROUP" -> {"LIST"; "ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"FGROUP" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"FGROUP" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"FGROUP" -> "FLAGG"
+/*"FGROUP" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"FGROUP" -> "FLAGG-"
+/*"FGROUP" -> "URAGG-"*/
+
+"FM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FM"]
+/*"FM" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "IDPC"; "MODULE"}*/
+/*"FM" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "ORDSET"; "ENTIRER"; "INT"}*/
+/*"FM" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"FM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"FM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"FM" -> "FLAGG"
+/*"FM" -> {"ELAGG"; "OM"; "LSAGG-"}*/
+
+"FMONOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FMONOID"]
+/*"FMONOID" -> {"MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"FMONOID" -> {"ORDSET"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ABELMON"}*/
+/*"FMONOID" -> {"ABELSG"; "CABMON"; "NNI"; "INT"; "LIST"; "ILIST"}*/
+/*"FMONOID" -> {"LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"FMONOID" -> "FLAGG-"
+/*"FMONOID" -> {"URAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"FMONOID" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"FMONOID" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"FMONOID" -> "FLAGG"
+/*"FMONOID" -> {"ELAGG"; "OM"; "BOOLEAN"}*/
+
+"FM1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FM1"]
+/*"FM1" -> {"FMCAT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FM1" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "RETRACT"}*/
+/*"FM1" -> {"MODULE"; "ORDSET"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"FM1" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"FM1" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"FM1" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"FM1" -> "FLAGG"
+/*"FM1" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"}*/
+/*"FM1" -> "LSAGG-"*/
+
+"FPC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FPC"]
+"FPC" -> "FIELD"
+/*"FPC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FPC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FPC" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FPC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
+/*"FPC" -> {"INT"; "INS-"; "NNI"}*/
+
+"FPC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FPC"]
+"FPC-" -> "FIELD"
+/*"FPC-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FPC-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FPC-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FPC-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
+/*"FPC-" -> {"INT"; "INS-"; "NNI"}*/
+
+"FPS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FPS",
+          shape=ellipse]
+/*"FPS" -> "RNS"*/
+"FPS" -> "FIELD"
+/*"FPS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FPS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FPS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"FPS" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"FPS" -> {"KONVERT"; "RETRACT"}*/
+"FPS" -> "RADCAT"
+/*"FPS" -> {"PATMAB"; "CHARZ"; "PI"; "NNI"; "INT"; "INS-"; "EUCDOM-"}*/
+/*"FPS" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"FPS" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"FPS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FPS",
+          shape=ellipse]
+/*"FPS-" -> "RNS"*/
+"FPS-" -> "FIELD"
+/*"FPS-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"FPS-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FPS-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FPS-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"FPS-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"FPS-" -> {"REAL"; "KONVERT"; "RETRACT"}*/
+"FPS-" -> "RADCAT"
+/*"FPS-" -> {"PATMAB"; "CHARZ"; "PI"; "NNI"; "INT"; "INS-"; "EUCDOM-"}*/
+/*"FPS-" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"FPS-" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"GCDDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GCDDOM",
+          shape=ellipse]
+/*"GCDDOM" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"GCDDOM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GCDDOM" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"GCDDOM" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"GCDDOM" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"GCDDOM" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"GCDDOM" -> "FLAGG" 
+/*"GCDDOM" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"GCDDOM" -> "NNI"*/
+
+"GCDDOM-" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GCDDOM",
+          shape=ellipse]
+/*"GCDDOM-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"GCDDOM-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GCDDOM-" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"GCDDOM-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"GCDDOM-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"GCDDOM-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"GCDDOM-" -> "FLAGG"
+/*"GCDDOM-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"GCDDOM-" -> "NNI"*/
+
+"HOAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=HOAGG",
+          shape=ellipse]
+/*"HOAGG" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"HOAGG" -> {"IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"HOAGG" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"HOAGG" -> "FLAGG"
+/*"HOAGG" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
+/*"HOAGG" -> "NNI"*/
+
+"HOAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HOAGG",
+          shape=ellipse]
+/*"HOAGG-" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"HOAGG-" -> {"IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"HOAGG-" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"HOAGG-" -> "FLAGG"
+/*"HOAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
+/*"HOAGG-" -> "NNI"*/
+
+"INDE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INDE"]
+/*"INDE" -> {"OAMONS"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"INDE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"INDE" -> {"IDPC"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"}*/
+/*"INDE" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"INDE" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"INDE" -> "KONVERT"*/
+"INDE" -> "FLAGG"
+/*"INDE" -> {"ELAGG"; "OM"; "LSAGG-"}*/
+
+"INTDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INTDOM",
+          shape=ellipse]
+/*"INTDOM" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"INTDOM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"INTDOM" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"INTDOM" -> {"MODULE"; "ENTIRER"}*/
+"INTDOM" -> "FIELD"
+/*"INTDOM" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "BOOLEAN"}*/
+
+"INTDOM-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTDOM",
+          shape=ellipse]
+/*"INTDOM-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"INTDOM-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"INTDOM-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"INTDOM-" -> {"MODULE"; "ENTIRER"}*/
+"INTDOM-" -> "FIELD"
+/*"INTDOM-" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "BOOLEAN"}*/
+
+"IPADIC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IPADIC"]
+"IPADIC" -> "PADICCT"
+/*"IPADIC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"IPADIC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"IPADIC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"IPADIC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "INT"}*/
+/*"IPADIC" -> {"NNI"; "INS-"; "SINT"; "BOOLEAN"; "PI"; "INS"; "UFD"}*/
+/*"IPADIC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"IPADIC" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"IPADIC" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"; "LIST"; "ILIST"}*/
+/*"IPADIC" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"IPADIC" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"IPADIC" -> {"ELTAB"; "CLAGG"}*/
+"IPADIC" -> "FLAGG"
+/*"IPADIC" -> {"ELAGG"; "OM"; "LSAGG-"}*/
+
+"IROOT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IROOT"]
+/*"IROOT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"IROOT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"IROOT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"IROOT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"IROOT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"IROOT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"IROOT" -> {"REAL"; "CHARZ"; "STEP"; "PI"; "NNI"; "INT"; "BOOLEAN"; "SINT"}*/
+/*"IROOT" -> {"MONOID-"; "ABELMON-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"IROOT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"IROOT" -> {"ELTAGG"; "ELTAB"; "CLAGG"}*/
+"IROOT" -> "FLAGG"
+/*"IROOT" -> {"ELAGG"; "OM"; "LIST"; "ILIST"}*/
+
+"IR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IR2"]
+"IR2" -> "FIELD"
+/*"IR2" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"IR2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"IR2" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"IR2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"LEXP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LEXP"]
+/*"LEXP" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"LEXP" -> {"ORDSET"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"LEXP" -> {"ABELMON"; "ABELSG"; "LMODULE"; "BMODULE"; "RMODULE"; "MODULE"}*/
+/*"LEXP" -> {"INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"LEXP" -> "FLAGG-"
+/*"LEXP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"LEXP" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"LEXP" -> {"CLAGG"; "KONVERT"}*/
+"LEXP" -> "FLAGG"
+/*"LEXP" -> {"ELAGG"; "OM"; "PI"}*/
+
+"LIECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LIECAT"]
+/*"LIECAT" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
+/*"LIECAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"LIECAT" -> {"RMODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+"LIECAT" -> "FIELD"
+/*"LIECAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"}*/
+/*"LIECAT" -> {"UFD"; "DIVRING"}*/
+
+"LIECAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIECAT"]
+/*"LIECAT-" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
+/*"LIECAT-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"LIECAT-" -> {"RMODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+"LIECAT-" -> "FIELD"
+/*"LIECAT-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"}*/
+/*"LIECAT-" -> {"UFD"; "DIVRING"}*/
+
+"LIST2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIST2"]
+/*"LIST2" -> {"TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"LIST2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"LIST2" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"LIST2" -> "FLAGG"
+/*"LIST2" -> {"ORDSET"; "ELAGG"}*/
+
+"LIST2MAP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIST2MAP"]
+/*"LIST2MAP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "TYPE"; "INT"; "LIST"}*/
+/*"LIST2MAP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"LIST2MAP" -> "FLAGG-"
+/*"LIST2MAP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"LIST2MAP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"LIST2MAP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"LIST2MAP" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"LIST2MAP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"LIST2MAP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"LIST2MAP" -> {"CHARZ"; "STEP"; "OM"}*/
+
+"LMOPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LMOPS"]
+/*"LMOPS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"LMOPS" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"LMOPS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"LMOPS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"LMOPS" -> "FLAGG"
+/*"LMOPS" -> {"ORDSET"; "ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"LMOPS" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "SGROUP"}*/
+/*"LMOPS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"LMOPS" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"LMOPS" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "PATMAB"}*/
+/*"LMOPS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LSAGG-"; "STAGG-"}*/
+/*"LMOPS" -> "ELAGG-"*/
+"LMOPS" -> "FLAGG-"
+/*"LMOPS" -> {"URAGG-"; "NNI"; "BOOLEAN"}*/
+
+"LSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LSAGG",
+          shape=ellipse]
+/*"LSAGG" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"LSAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"LSAGG" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"LSAGG" -> "FLAGG"
+/*"LSAGG" -> {"ORDSET"; "ELAGG"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"LSAGG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LSAGG" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"LSAGG" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"LSAGG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"LSAGG" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"LSAGG" -> {"STEP"; "OM"; "INT"; "NNI"; "SINT"}*/
+
+"LSAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LSAGG",
+          shape=ellipse]
+/*{"LSAGG-" -> "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"LSAGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"LSAGG-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"LSAGG-" -> "FLAGG"
+/*"LSAGG-" -> {"ORDSET"; "ELAGG"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"}*/
+/*"LSAGG-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"LSAGG-" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LSAGG-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LSAGG-" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"LSAGG-" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"LSAGG-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "NNI"; "SINT"}*/
+
+"LZSTAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LZSTAGG"]
+/*"LZSTAGG" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"LZSTAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"LZSTAGG" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "BOOLEAN"; "INT"}*/
+/*"LZSTAGG" -> {"LIST"; "ILIST"; "NNI"; "SINT"; "LSAGG"}*/
+"LZSTAGG" -> "FLAGG"
+/*"LZSTAGG" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"LZSTAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LZSTAGG"]
+/*"LZSTAGG-" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"LZSTAGG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"LZSTAGG-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"LZSTAGG-" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "NNI"; "SINT"; "LSAGG"}*/
+"LZSTAGG-" -> "FLAGG"
+/*"LZSTAGG-" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"MAGMA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MAGMA"]
+/*"MAGMA" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"MAGMA" -> {"BOOLEAN"; "INT"; "LIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"MAGMA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"MAGMA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"MAGMA" -> "FLAGG"
+/*"MAGMA" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"MAGMA" -> "FLAGG-"
+/*"MAGMA" -> {"PI"; "NNI"}*/
+
+"MESH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MESH"]
+/*"MESH" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"MESH" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"MESH" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"MESH" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"MESH" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"MESH" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"MESH" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "FPS"; "RNS"}*/
+"MESH" -> "FIELD"
+/*"MESH" -> "DIVRING"*/
+"MESH" -> "RADCAT"
+/*"MESH" -> {"INT"; "LIST"; "DFLOAT"; "PI"; "NNI"; "SINT"; "ILIST"}*/
+/*"MESH" -> "BOOLEAN"*/
+
+"MOEBIUS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MOEBIUS"]
+/*"MOEBIUS" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"MOEBIUS" -> "FIELD"
+/*"MOEBIUS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"MOEBIUS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "LMODULE"}*/
+/*"MOEBIUS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"MOEBIUS" -> {"DIVRING"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "LSAGG-"}*/
+/*"MOEBIUS" -> {"STAGG-"; "ELAGG-"}*/
+"MOEBIUS" -> "FLAGG-"
+/*"MOEBIUS" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+
+"MODFIELD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODFIELD"]
+"MODFIELD" -> "FIELD"
+/*"MODFIELD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"MODFIELD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"MODFIELD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MODFIELD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"MODFIELD" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"MODFIELD" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"MODFIELD" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"MODFIELD" -> "STEP"*/
+
+"MODOP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODOP"]
+/*"MODOP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"MODOP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"MODOP" -> {"LMODULE"; "RETRACT"; "ELTAB"; "CHARZ"; "CHARNZ"; "ALGEBRA"}*/
+/*"MODOP" -> {"MODULE"; "BMODULE"; "RMODULE"; "COMRING"; "LSAGG"; "STAGG"}*/
+/*"MODOP" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"MODOP" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
+"MODOP" -> "FLAGG"
+/*"MODOP" -> {"ORDSET"; "ELAGG"; "INT"; "LIST"; "ILIST"; "OM"; "LSAGG-"}*/
+/*"MODOP" -> {"STAGG-"; "ELAGG-"}*/
+"MODOP" -> "FLAGG-"
+/*"MODOP" -> {"URAGG-"; "ES"; "SINT"; "NNI"}*/
+
+"MRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MRING"]
+/*"MRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"MRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MRING" -> {"RETRACT"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
+/*"MRING" -> {"RMODULE"; "FINITE"; "COMRING"; "INT"; "LIST"; "ILIST"}*/
+/*"MRING" -> {"NNI"; "SINT"; "PI"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"MRING" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"MRING" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"MRING" -> "FLAGG"
+/*"MRING" -> {"ORDSET"; "ELAGG"; "OM"; "GROUP"; "LSAGG-"; "STAGG-"}*/
+/*"MRING" -> {"ELAGG-"; "ORDMON"}*/
+"MRING" -> "FLAGG-"
+
+"MTHING" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MTHING"]
+/*"MTHING" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
+/*"MTHING" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"MTHING" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"MTHING" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"MTHING" -> "FLAGG"
+/*"MTHING" -> {"ELAGG"; "OM"}*/
+
+"NCNTFRAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NCNTFRAC"]
+/*"NCNTFRAC" -> {"FPS"; "RNS"}*/
+"NCNTFRAC" -> "FIELD"
+/*"NCNTFRAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"NCNTFRAC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NCNTFRAC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"NCNTFRAC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"NCNTFRAC" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NCNTFRAC" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+"NCNTFRAC" -> "RADCAT"
+/*"NCNTFRAC" -> {"PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"NCNTFRAC" -> {"CFCAT"; "STEP"; "INT"}*/
+
+"NCODIV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NCODIV"]
+/*"NCODIV" -> {"MLO"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NCODIV" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NCODIV" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+"NCODIV" -> "FIELD"
+/*"NCODIV" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
+/*"NCODIV" -> {"UFD"; "DIVRING"; "NNI"; "INT"; "BOOLEAN"}*/
+
+"NUMTUBE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMTUBE"]
+/*"NUMTUBE" -> {"PSCURVE"; "KOERCE"; "DFLOAT"; "FPS"; "RNS"}*/
+"NUMTUBE" -> "FIELD"
+/*"NUMTUBE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"NUMTUBE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NUMTUBE" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"NUMTUBE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"NUMTUBE" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"NUMTUBE" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+"NUMTUBE" -> "RADCAT"
+/*"NUMTUBE" -> {"PATMAB"; "CHARZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"NUMTUBE" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"NUMTUBE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"NUMTUBE" -> "FLAGG"
+/*"NUMTUBE" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
+/*"NUMTUBE" -> {"STAGG-"; "ELAGG-"}*/
+"NUMTUBE" -> "FLAGG-"
+/*"NUMTUBE" -> {"URAGG-"; "PI"; "BOOLEAN"}*/
+
+"ODR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODR"]
+/*"ODR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BMODULE"; "LMODULE"}*/
+/*"ODR" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "RMODULE"}*/
+/*"ODR" -> {"DIFRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+"ODR" -> "FIELD"
+/*"ODR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ALGEBRA"}*/
+/*"ODR" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "PDRING"; "INS"}*/
+/*"ODR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ODR" -> {"ORDSET"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"ODR" -> {"REAL"; "CHARZ"; "STEP"}*/
+
+"OFMONOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OFMONOID"]
+/*"OFMONOID" -> {"ORDMON"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"OFMONOID" -> {"MONOID"; "SGROUP"; "RETRACT"; "OAMONS"; "OCAMON"}*/
+/*"OFMONOID" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "NNI"}*/
+/*"OFMONOID" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"OFMONOID" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"OFMONOID" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"OFMONOID" -> "FLAGG"
+/*"OFMONOID" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"OFMONOID" -> "FLAGG-"
+/*"OFMONOID" -> "BOOLEAN"*/
+
+"ONECOMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ONECOMP"]
+/*"ONECOMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"ONECOMP" -> "FRETRCT"
+/*"ONECOMP" -> {"RETRACT"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ONECOMP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ONECOMP" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"; "BOOLEAN"}*/
+/*"ONECOMP" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ONECOMP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ONECOMP" -> {"EUCDOM"; "PID"; "OINTDOM"; "DIFRING"; "KONVERT"; "LINEXP"}*/
+/*"ONECOMP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"ORDCOMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ORDCOMP"]
+/*"ORDCOMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"ORDCOMP" -> "FRETRCT"
+/*"ORDCOMP" -> {"RETRACT"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ORDCOMP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ORDCOMP" -> {"ORDSET"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ORDCOMP" -> {"BOOLEAN"; "SINT"; "INT"; "INS"; "UFD"; "GCDDOM"}*/
+/*"ORDCOMP" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ORDCOMP" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "DIFRING"}*/
+/*"ORDCOMP" -> {"KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"ORDCOMP" -> "STEP"*/
+
+"OREPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OREPCAT"]
+/*"OREPCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"OREPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"OREPCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"}*/
+"OREPCAT" -> "FRETRCT"
+/*"OREPCAT" -> {"RETRACT"; "ALGEBRA"; "MODULE"; "NNI"; "INT"; "LIST"}*/
+/*"OREPCAT" -> {"ILIST"; "BOOLEAN"; "INTDOM"; "COMRING"; "ENTIRER"; "GCDDOM"}*/
+"OREPCAT" -> "FIELD"
+/*"OREPCAT" -> {"EUCDOM"; "PID"; "UFD"; "DIVRING"; "INS"; "OINTDOM"}*/
+/*"OREPCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"OREPCAT" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"OREPCAT" -> {"CHARZ"; "STEP"}*/
+
+"OREPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OREPCAT"]
+/*"OREPCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"OREPCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"OREPCAT-" -> {"LMODULE"; "BMODULE"; "RMODULE"}*/
+"OREPCAT-" -> "FRETRCT"
+/*"OREPCAT-" -> {"RETRACT"; "ALGEBRA"; "MODULE"; "NNI"; "INT"; "LIST"}*/
+/*"OREPCAT-" -> {"ILIST"; "BOOLEAN"; "INTDOM"; "COMRING"; "ENTIRER"}*/
+/*"OREPCAT-" -> "GCDDOM"*/
+"OREPCAT-" -> "FIELD"
+/*"OREPCAT-" -> {"EUCDOM"; "PID"; "UFD"; "DIVRING"; "INS"; "OINTDOM"}*/
+/*"OREPCAT-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"OREPCAT-" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"OREPCAT-" -> {"CHARZ"; "STEP"}*/
+
+"OUTFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OUTFORM",
+          shape=ellipse]
+/*"OUTFORM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "STRING"; "CHAR"; "SINT"}*/
+/*"OUTFORM" -> {"OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"OUTFORM" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "ILIST"; "LSAGG-"}*/
+/*"OUTFORM" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"OUTFORM" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"OUTFORM" -> {"BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"OUTFORM" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"OUTFORM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"OUTFORM" -> "FLAGG"
+/*"OUTFORM" -> {"ORDSET"; "ELAGG"; "OM"; "BOOLEAN"}*/
+
+"OWP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OWP"]
+/*"OWP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"OWP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"OWP" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
+"OWP" -> "FIELD"
+/*"OWP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"PACPERC" [color="#88FF44",href="bookvol10.2.pdf#nameddest=PACPERC"]
+"PACPERC" -> "FIELD"
+/*"PACPERC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PACPERC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PACPERC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PACPERC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE" }*/
+/*"PACPERC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"PADIC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PADIC"]
+/*"PADIC" -> "BOOLEAN"*/
+"PADIC" -> "PADICCT"
+/*"PADIC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PADIC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PADIC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PADIC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "INS"}*/
+/*"PADIC" -> {"UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PADIC" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"PADIC" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+
+"PATTERN2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATTERN2"]
+/*"PATTERN2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PATTERN2" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PATTERN2" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"PATTERN2" -> "FLAGG"
+/*"PATTERN2" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+
+"PATLRES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PATLRES"]
+/*"PATLRES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PATLRES" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PATLRES" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"PATLRES" -> "FLAGG"
+/*"PATLRES" -> {"ORDSET"; "ELAGG"; "BOOLEAN"}*/
+
+"PARTPERM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARTPERM"]
+/*"PARTPERM" -> {"INT"; "LIST"; "ILIST"; "SINT"; "NNI"; "BOOLEAN"; "LSAGG"}*/
+/*"PARTPERM" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PARTPERM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"PARTPERM" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"PARTPERM" -> "FLAGG"
+/*"PARTPERM" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"PBWLB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PBWLB"]
+/*"PBWLB" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "INT"}*/
+/*"PBWLB" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"PBWLB" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"PBWLB" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"PBWLB" -> "FLAGG"
+/*"PBWLB" -> {"ELAGG"; "OM"; "LSAGG-"; "BOOLEAN"; "NNI"}*/
+
+"PENDTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PENDTREE"]
+/*"PENDTREE" -> {"BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"PENDTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"}*/
+/*"PENDTREE" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"PENDTREE" -> "FLAGG-"
+/*"PENDTREE" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"PENDTREE" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+
+"PGE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PGE"]
+/*"PGE" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PGE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PGE" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PGE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"PGE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"PGE" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"PGE" -> {"REAL"; "CHARZ"; "STEP"; "SINT"; "NNI"; "INT"}*/
+/*"PGE" -> {"LIST"; "ILIST"; "LSAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PGE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PGE" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"PGE" -> "FLAGG"
+/*"PGE" -> {"ELAGG"; "OM"; "STAGG-"; "ELAGG-"; "PI"}*/
+
+"PGROEB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PGROEB"]
+/*"PGROEB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PGROEB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PGROEB" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PGROEB" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PGROEB" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PGROEB" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"PGROEB" -> "FLAGG"
+/*"PGROEB" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+
+"PINTERP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PINTERP"]
+"PINTERP" -> "FIELD"
+/*"PINTERP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PINTERP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PINTERP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PINTERP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PINTERP" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+
+"PLOTTOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PLOTTOOL"]
+/*"PLOTTOOL" -> {"DFLOAT"; "INT"; "LIST"; "ILIST"; "FPS"; "RNS"}*/
+"PLOTTOOL" -> "FIELD"
+/*"PLOTTOOL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PLOTTOOL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PLOTTOOL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PLOTTOOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PLOTTOOL" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"PLOTTOOL" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+"PLOTTOOL" -> "RADCAT"
+/*"PLOTTOOL" -> {"PATMAB"; "CHARZ"}*/
+
+"PFR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PFR"]
+"PFR" -> "FIELD"
+/*"PFR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PFR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PFR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PFR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"PFR" -> {"INT"; "LIST"; "ILIST"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"PFR" -> "FLAGG-"
+/*"PFR" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PFR" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"PFR" -> {"CLAGG"; "KONVERT"}*/
+"PFR" -> "FLAGG"
+/*"PFR" -> {"ORDSET"; "ELAGG"; "OM"; "PI"; "NNI"; "INS"; "OINTDOM"}*/
+/*"PFR" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"PFR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"PMDOWN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMDOWN"]
+/*"PMDOWN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PATMAB"; "RETRACT"}*/
+/*"PMDOWN" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PMDOWN" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PMDOWN" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"PMDOWN" -> "FLAGG"
+/*"PMDOWN" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"PRTITION" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PRTITION"]
+/*"PRTITION" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"PRTITION" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"PRTITION" -> {"KONVERT"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"PRTITION" -> "ELAGG-"*/
+"PRTITION" -> "FLAGG-"
+/*"PRTITION" -> {"BOOLEAN"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"PRTITION" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"PRTITION" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"PRTITION" -> "FLAGG"
+/*"PRTITION" -> {"ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"PRTITION" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
+/*"PRTITION" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PRTITION" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PRTITION" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"PRTITION" -> {"CHARZ"; "STEP"; "URAGG-"; "INS-"}*/
+
+"PMINS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMINS"]
+/*"PMINS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PMINS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PMINS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PMINS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"PMINS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PMINS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"PMINS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PMINS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PMINS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"PMINS" -> "FLAGG"
+/*"PMINS" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
+/*"PMINS" -> {"STAGG-"; "ELAGG-"}*/
+"PMINS" -> "FLAGG-"
+/*"PMINS" -> "URAGG-"*/
+
+"PMLSAGG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMLSAGG"]
+/*"PMLSAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PATMAB"; "LSAGG"; "STAGG"}*/
+/*"PMLSAGG" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"PMLSAGG" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"PMLSAGG" -> "KONVERT"*/
+"PMLSAGG" -> "FLAGG"
+/*"PMLSAGG" -> {"ORDSET"; "ELAGG"; "BOOLEAN"; "INT"; "LIST"; "ILIST"}*/
+
+"PMTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMTOOLS"]
+/*"PMTOOLS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PMTOOLS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PMTOOLS" -> {"ORDSET"; "KONVERT"; "RETRACT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PMTOOLS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PMTOOLS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"PMTOOLS" -> "FLAGG"
+/*"PMTOOLS" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"PMTOOLS" -> {"ELAGG-"; "NNI"}*/
+
+"PSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PSCAT"]
+"PSCAT" -> "AMR"
+/*"PSCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PSCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PSCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
+/*"PSCAT" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"}*/
+/*"PSCAT" -> {"OASGP"; "ORDSET"; "INT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
+/*"PSCAT" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"}*/
+/*"PSCAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"PSCAT" -> "STEP"*/
+"PSCAT" -> "FIELD"
+/*"PSCAT" -> "DIVRING"*/
+
+"PSCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PSCAT"]
+"PSCAT-" -> "AMR"
+/*"PSCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PSCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PSCAT-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"PSCAT-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"PSCAT-" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"PSCAT-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"; "KONVERT"}*/
+/*"PSCAT-" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+"PSCAT-" -> "FIELD"
+/*"PSCAT-" -> "DIVRING"*/
+
+"QFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QFORM"]
+/*"QFORM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"QFORM" -> {"BASTYPE"; "KOERCE"}*/
+"QFORM" -> "FIELD"
+/*"QFORM" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"QFORM" -> {"RNG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"QFORM" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"QUEUE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QUEUE"]
+/*"QUEUE" -> {"QUAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"QUEUE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"}*/
+/*"QUEUE" -> {"ILIST"; "LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"QUEUE" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"QUEUE" -> "FLAGG"
+/*"QUEUE" -> {"ORDSET"; "ELAGG"; "OM"; "STAGG-"; "ELAGG-"}*/
+"QUEUE" -> "FLAGG-"
+/*"QUEUE" -> "URAGG-"*/
+
+"RCAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RCAGG",
+          shape=ellipse]
+/*"RCAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RCAGG" -> {"EVALAB"; "IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
+/*"RCAGG" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"RCAGG" -> "FLAGG"
+/*"RCAGG" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+
+"RCAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RCAGG",
+          shape=ellipse]
+/*"RCAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RCAGG-" -> {"EVALAB"; "IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
+/*"RCAGG-" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"RCAGG-" -> "FLAGG"
+/*"RCAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+
+"RNS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RNS",
+          shape=ellipse]
+/*"RNS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"RNS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RNS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RNS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"RNS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"RNS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"RNS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
+"RNS" -> "FIELD"
+/*"RNS" -> "DIVRING"*/
+"RNS" -> "RADCAT"
+/*"RNS" -> {"NNI"; "INT"; "PI"}*/
+
+"RNS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RNS",
+          shape=ellipse]
+/*"RNS-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"RNS-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RNS-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"RNS-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"RNS-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"RNS-" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"RNS-" -> {"REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
+"RNS-" -> "FIELD"
+/*"RNS-" -> "DIVRING"*/
+"RNS-" -> "RADCAT"
+/*"RNS-" -> {"NNI"; "INT"; "PI"}*/
+
+"SCACHE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SCACHE"]
+/*"SCACHE" -> {"CACHSET"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"}*/
+/*"SCACHE" -> {"LIST"; "NNI"; "BOOLEAN"; "ILIST"; "LSAGG"; "STAGG"}*/
+/*"SCACHE" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"SCACHE" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"SCACHE" -> "KONVERT"*/
+"SCACHE" -> "FLAGG"
+/*"SCACHE" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "SINT"}*/
+
+"SEG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEG"]
+/*"SEG" -> {"SEGCAT"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "SEGXCAT"}*/
+/*"SEG" -> {"INT"; "BOOLEAN"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"SEG" -> {"OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
+/*"SEG" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"; "LIST"}*/
+/*"SEG" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"SEG" -> {"AGG"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"SEG" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"SEG" -> "FLAGG"
+/*"SEG" -> {"ELAGG"; "OM"}*/
+
+"SEG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SEG2"]
+/*"SEG2" -> {"TYPE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SEG2" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
+/*"SEG2" -> {"CABMON"; "ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"SEG2" -> {"LMODULE"; "INT"; "LIST"; "BOOLEAN"; "ILIST"; "LSAGG"}*/
+/*"SEG2" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "EVALAB"}*/
+/*"SEG2" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"SEG2" -> "KONVERT"*/
+"SEG2" -> "FLAGG"
+/*"SEG2" -> {"ELAGG"; "OM"}*/
+
+"SEXOF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEXOF"]
+/*"SEXOF" -> {"SEXCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"}*/
+/*"SEXOF" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"SEXOF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"SEXOF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"SEXOF" -> "FLAGG"
+/*"SEXOF" -> {"ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"SEXOF" -> "FLAGG-"
+/*"SEXOF" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"SEXOF" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "NNI"}*/
+
+"STACK" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STACK"]
+/*"STACK" -> {"SKAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"STACK" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"; "ILIST"}*/
+/*"STACK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
+/*"STACK" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"STACK" -> "FLAGG"
+/*"STACK" -> {"ORDSET"; "ELAGG"; "OM"}*/
+
+"STTAYLOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STTAYLOR"]
+/*"STTAYLOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"STTAYLOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"STTAYLOR" -> {"LMODULE"; "SINT"; "NNI"; "INT"; "LIST"; "ILIST"}*/
+/*"STTAYLOR" -> {"LSAGG-"; "STAGG-"; "PI"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
+/*"STTAYLOR" -> {"RMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"STTAYLOR" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"STTAYLOR" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"STTAYLOR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"STTAYLOR" -> "STEP"*/
+"STTAYLOR" -> "FIELD"
+/*"STTAYLOR" -> "DIVRING"*/
+
+"TABLBUMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TABLBUMP"]
+/*"TABLBUMP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
+/*"TABLBUMP" -> {"BOOLEAN"; "ILIST"; "LSAGG-"; "STAGG-"; "PI"; "NNI"}*/
+/*"TABLBUMP" -> "ELAGG-"*/
+"TABLBUMP" -> "FLAGG-"
+/*"TABLBUMP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"TABLBUMP" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"TABLBUMP" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"TABLBUMP" -> "FLAGG"
+/*"TABLBUMP" -> "ELAGG"*/
+
+"TABLEAU" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TABLEAU"]
+/*"TABLEAU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"}*/
+/*"TABLEAU" -> {"LSAGG-"; "SINT"; "NNI"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"TABLEAU" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"TABLEAU" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"TABLEAU" -> "FLAGG"
+/*"TABLEAU" -> {"ORDSET"; "ELAGG"; "OM"; "STAGG-"}*/
+
+"TOPSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TOPSP"]
+/*"TOPSP" -> {"FPS"; "RNS"}*/
+"TOPSP" -> "FIELD"
+/*"TOPSP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"TOPSP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"TOPSP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"TOPSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"TOPSP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"TOPSP" -> {"REAL"; "KONVERT"; "RETRACT"}*/
+"TOPSP" -> "RADCAT"
+/*"TOPSP" -> {"PATMAB"; "CHARZ"}*/
+
+"TRANFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TRANFUN"]
+/*"TRANFUN" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RING"}*/
+/*"TRANFUN" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"TRANFUN" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"TRANFUN" -> {"PI"; "NNI"; "INT"}*/
+"TRANFUN" -> "FIELD"
+/*"TRANFUN" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"TRANFUN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"TRANFUN-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TRANFUN"]
+/*"TRANFUN-" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RING"}*/
+/*"TRANFUN-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"TRANFUN-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "PI"}*/
+/*"TRANFUN-" -> {"NNI"; "INT"}*/
+"TRANFUN-" -> "FIELD"
+/*"TRANFUN-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"TRANFUN-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"TUBE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TUBE"]
+/*"TUBE" -> {"PSCURVE"; "KOERCE"; "FPS"; "RNS"}*/
+"TUBE" -> "FIELD"
+/*"TUBE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"TUBE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"TUBE" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"TUBE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"TUBE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"TUBE" -> {"REAL"; "KONVERT"; "RETRACT"}*/
+"TUBE" -> "RADCAT"
+/*"TUBE" -> {"PATMAB"; "CHARZ"; "BOOLEAN"}*/
+
+"UDPO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UDPO"]
+/*"UDPO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"}*/
+/*"UDPO" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"UDPO" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"UDPO" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"UDPO" -> "FLAGG"
+/*"UDPO" -> {"ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+
+"UFD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UFD",
+          shape=ellipse]
+/*"UFD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"UFD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"UFD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"UFD" -> {"MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"UFD" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"UFD" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+"UFD" -> "FLAGG"
+/*"UFD" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+
+"UFD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UFD",
+          shape=ellipse]
+/*"UFD-" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"UFD-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"UFD-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"UFD-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"}*/
+/*"UFD-" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"UFD-" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"UFD-" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"UFD-" -> "FLAGG"
+/*"UFD-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+
+"UNISEG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UNISEG"]
+/*"UNISEG" -> {"SEGCAT"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "SEGXCAT"}*/
+/*"UNISEG" -> {"INT"; "BOOLEAN"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"UNISEG" -> {"OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"UNISEG" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UNISEG" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"UNISEG" -> "FLAGG-"
+/*"UNISEG" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"UNISEG" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+
+"URAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=URAGG",
+          shape=ellipse]
+/*"URAGG" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"URAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "BOOLEAN"; "INT"; "LIST"}*/
+/*"URAGG" -> {"ILIST"; "LSAGG"; "STAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"URAGG" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"URAGG" -> "FLAGG"
+/*"URAGG" -> {"ORDSET"; "ELAGG"; "OM"; "NNI"; "SINT"}*/
+
+"URAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=URAGG",
+          shape=ellipse]
+/*"URAGG-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"URAGG-" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "BOOLEAN"; "INT"; "LIST"}*/
+/*"URAGG-" -> {"ILIST"; "LSAGG"; "STAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"URAGG-" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
+"URAGG-" -> "FLAGG"
+/*"URAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "NNI"; "SINT"}*/
+
+"VIEW" [color="#FF4488",href="bookvol10.4.pdf#nameddest=VIEW"]
+/*"VIEW" -> {"INT"; "LIST"; "FPS"; "RNS"}*/
+"VIEW" -> "FIELD"
+/*"VIEW" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"VIEW" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"VIEW" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"VIEW" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"VIEW" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"VIEW" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+"VIEW" -> "RADCAT"
+/*"VIEW" -> {"PATMAB"; "CHARZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"VIEW" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"VIEW" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+"VIEW" -> "FLAGG"
+/*"VIEW" -> {"ELAGG"; "OM"; "ILIST"; "SINT"; "PI"; "NNI"}*/
+
+"VSPACE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=VSPACE"]
+"VSPACE" -> "FIELD"
+/*"VSPACE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"VSPACE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"VSPACE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"VSPACE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"VSPACE" -> {"UFD"; "DIVRING"}*/
+
+"VSPACE-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VSPACE"]
+"VSPACE-" -> "FIELD"
+/*"VSPACE-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"VSPACE-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"VSPACE-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"VSPACE-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"VSPACE-" -> {"UFD"; "DIVRING"}*/
+
+"XPOLYC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XPOLYC"]
+"XPOLYC" -> "XFALG"
+/*"XPOLYC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"XPOLYC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"XPOLYC" -> {"LMODULE"; "XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"XPOLYC" -> {"MODULE"; "RETRACT"}*/
+
+"XPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XPR"]
+/*"XPR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"XPR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"XPR" -> {"XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "FMCAT"}*/
+/*"XPR" -> {"RETRACT"; "COMRING"; "ORDMON"; "ORDSET"; "LSAGG"; "STAGG"}*/
+/*"XPR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"XPR" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"XPR" -> "KONVERT"*/
+"XPR" -> "FLAGG"
+/*"XPR" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"XPR" -> "ELAGG-"*/
+"XPR" -> "FLAGG-"
+/*"XPR" -> {"URAGG-"; "BOOLEAN"; "NNI"}*/
+"XPR" -> "FIELD"
+/*"XPR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"}*/
+/*"XPR" -> "DIVRING"*/
+
+\end{chunk}
+\subsection{Layer8}
+Depends on: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT 
+TRANFUN VSPACE XPOLYC PACPERC\\
+Used by next layer: BTAGG FLALG MATCAT SRAGG VECTCAT 
+\begin{chunk}{layer8}
+
+LAYER8=\
+  ${OUT}/AFFSP.o    \
+  ${OUT}/APPLYORE.o ${OUT}/ARRAY1.o   ${OUT}/ARRAY12.o  ${OUT}/ARRAY2.o   \
+  ${OUT}/ASTACK.o   ${OUT}/BTAGG.o    ${OUT}/BTAGG-.o   ${OUT}/COMBINAT.o \
+  ${OUT}/CSTTOOLS.o ${OUT}/D01FCFA.o  ${OUT}/E04MBFA.o  ${OUT}/FAMR2.o    \
+  ${OUT}/FARRAY.o   ${OUT}/FLALG.o    ${OUT}/GALUTIL.o  ${OUT}/HEAP.o     \
+  ${OUT}/IARRAY1.o  ${OUT}/IARRAY2.o  ${OUT}/IFARRAY.o  ${OUT}/INTCAT.o   \
+  ${OUT}/INTHEORY.o ${OUT}/IRREDFFX.o ${OUT}/LFCAT.o    ${OUT}/LODOCAT.o  \
+  ${OUT}/LODOCAT-.o ${OUT}/LWORD.o    ${OUT}/MATCAT.o   ${OUT}/MATCAT-.o  \
+  ${OUT}/MATSTOR.o  ${OUT}/ORESUP.o   ${OUT}/OREPCTO.o  ${OUT}/OREUP.o    \
+  ${OUT}/PACFFC.o   \
+  ${OUT}/PLOT3D.o   ${OUT}/POLYVEC.o \
+  ${OUT}/PR.o       ${OUT}/PREASSOC.o ${OUT}/PRIMARR2.o \
+  ${OUT}/PROJSP.o   \
+  ${OUT}/REDORDER.o ${OUT}/SRAGG.o    ${OUT}/SRAGG-.o   ${OUT}/STREAM.o   \
+  ${OUT}/SYMPOLY.o  ${OUT}/TS.o       ${OUT}/TUPLE.o    ${OUT}/UPSCAT.o   \
+  ${OUT}/UPSCAT-.o  ${OUT}/U8VEC.o    ${OUT}/U16VEC.o   ${OUT}/U32VEC.o   \
+  ${OUT}/VECTCAT.o  ${OUT}/VECTCAT-.o ${OUT}/XDPOLY.o   \
+  ${OUT}/XEXPPKG.o  ${OUT}/XF.o       ${OUT}/XF-.o      ${OUT}/XPBWPOLY.o \
+  ${OUT}/XPOLY.o    ${OUT}/XRPOLY.o \
+  layer8done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 8 */
+/* depends on: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT */
+/* TRANFUN VSPACE XPOLYC PACPREC */
+
+"AFFSP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AFFSP"]
+/*"AFFSP" -> {"AFSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
+/*"AFFSP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"AFFSP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"AFFSP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"AFFSP" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"AFFSP" -> {"PI"; "NNI"; "FFIELDC"}*/
+"AFFSP" -> "FPC"
+"AFFSP" -> "PACPERC"
+/*"AFFSP" -> {"CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "STAGG-"; "ELAGG-"}*/
+/*"AFFSP" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"AFFSP" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"AFFSP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"AFFSP" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"AFFSP" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
+/*"AFFSP" -> {"BOOLEAN"}*/
+
+"APPLYORE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=APPLYORE"]
+/*"APPLYORE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"APPLYORE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"APPLYORE" -> "LMODULE"*/
+"APPLYORE" -> "OREPCAT"
+/*"APPLYORE" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
+/*"APPLYORE" -> {"MODULE"; "SINT"; "NNI"; "INT"}*/
+
+"ARRAY1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ARRAY1"]
+"ARRAY1" -> "A1AGG"
+/*"ARRAY1" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"ARRAY1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"ARRAY1" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"; "LSAGG"}*/
+/*"ARRAY1" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
+/*"ARRAY1" -> {"NNI"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ARRAY1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ARRAY1" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ARRAY1" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"ARRAY1" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ARRAY1" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"ARRAY1" -> {"REAL"; "CHARZ"; "STEP"}*/
+
+"ARRAY12" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ARRAY12"]
+/*"ARRAY12" -> "TYPE"*/
+"ARRAY12" -> "A1AGG"
+/*"ARRAY12" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"}*/
+/*"ARRAY12" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"ARRAY12" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+
+"ARRAY2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ARRAY2"]
+"ARRAY2" -> "ARR2CAT"
+/*"ARRAY2" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ARRAY2" -> {"EVALAB"; "IEVALAB"}*/
+"ARRAY2" -> "A1AGG"
+/*"ARRAY2" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"ARRAY2" -> {"KONVERT"; "ORDSET"; "INT"}*/
+
+"ASTACK" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASTACK"]
+/*"ASTACK" -> {"SKAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"ASTACK" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"}*/
+"ASTACK" -> "A1AGG"
+/*"ASTACK" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"ASTACK" -> {"KONVERT"; "ORDSET"; "ELAGG"; "LIST"; "ILIST"; "SINT"}*/
+/*"ASTACK" -> {"NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"ASTACK" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"ASTACK" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"ASTACK" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"ASTACK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"ASTACK" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ASTACK" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"ASTACK" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"ASTACK" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"ASTACK" -> {"STEP"; "OM"}*/
+
+"BTAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BTAGG"]
+/*"BTAGG" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"}*/
+"BTAGG" -> "A1AGG"
+/*"BTAGG" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"BTAGG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+
+"BTAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTAGG"]
+/*"BTAGG-" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"}*/
+"BTAGG-" -> "A1AGG"
+/*"BTAGG-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"BTAGG-" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+
+"COMBINAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMBINAT"]
+/*"COMBINAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"COMBINAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"COMBINAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"COMBINAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"COMBINAT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"COMBINAT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"COMBINAT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"COMBINAT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"; "INT"; "OM"}*/
+"COMBINAT" -> "A1AGG"
+/*"COMBINAT" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"COMBINAT" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"COMBINAT" -> {"ELAGG"; "SINT"; "MONOID-"; "ABELMON-"; "PI"}*/
+
+"CSTTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CSTTOOLS"]
+/*"CSTTOOLS" -> "TYPE"*/
+"CSTTOOLS" -> "LZSTAGG"
+/*"CSTTOOLS" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "SETCAT"}*/
+/*"CSTTOOLS" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"CSTTOOLS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "SINT"}*/
+/*"CSTTOOLS" -> {"NNI"; "INT"}*/
+
+"D01FCFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01FCFA"]
+/*"D01FCFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"D01FCFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"D01FCFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"D01FCFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"D01FCFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"D01FCFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"D01FCFA" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
+/*"D01FCFA" -> {"PATMAB"; "CHARZ"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"D01FCFA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"D01FCFA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"D01FCFA" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
+/*"D01FCFA" -> {"STAGG-"; "DIFRING"}*/
+"D01FCFA" -> "TRANFUN"
+/*"D01FCFA" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+/*"D01FCFA" -> {"PI"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
+/*"D01FCFA" -> {"DFLOAT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+/*"D01FCFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"D01FCFA" -> "ABELGRP-"*/
+
+"E04MBFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04MBFA"]
+/*"E04MBFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"E04MBFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"E04MBFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"E04MBFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"E04MBFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"E04MBFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"E04MBFA" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
+/*"E04MBFA" -> {"PATMAB"; "CHARZ"; "DIFRING"; "OM"}*/
+"E04MBFA" -> "TRANFUN"
+/*"E04MBFA" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+/*"E04MBFA" -> {"INT"; "NNI"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"E04MBFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"E04MBFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"E04MBFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "ELAGG-"; "DFLOAT"}*/
+/*"E04MBFA" -> {"PI"; "INS-"; "MONOID-"; "ABELMON-"; "BOOLEAN"}*/
+
+"FAMR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FAMR2"]
+/*"FAMR2" -> "{OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FAMR2" -> {"ABELMON"; "ABELSG"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FAMR2" -> {"SGROUP"; "MONOID"; "LMODULE"}*/
+"FAMR2" -> "FAMR"
+/*"FAMR2" -> {"AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
+/*"FAMR2" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"FAMR2" -> {"FRETRCT"; "RETRACT"}*/
+
+"FARRAY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FARRAY"]
+/*"FARRAY" -> "INT"*/
+"FARRAY" -> "A1AGG"
+/*"FARRAY" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"FARRAY" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"FARRAY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "ELAGG"; "INS"}*/
+/*"FARRAY" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FARRAY" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"FARRAY" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FARRAY" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"FARRAY" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"FARRAY" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"FARRAY" -> {"STEP"; "OM"}*/
+
+"FLALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FLALG"]
+"FLALG" -> "LIECAT"
+/*"FLALG" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FLALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"}*/
+
+"GALUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALUTIL"]
+/*"GALUTIL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"GALUTIL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"GALUTIL" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"GALUTIL" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"GALUTIL" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"GALUTIL" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"GALUTIL" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INT"; "NNI"; "PI"}*/
+"GALUTIL" -> "A1AGG"
+/*"GALUTIL" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"GALUTIL" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "ELAGG"}*/
+
+"HEAP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HEAP"]
+/*"HEAP" -> {"PRQAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"HEAP" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ORDSET"}*/
+/*"HEAP" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
+/*"HEAP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
+/*"HEAP" -> {"OM"; "LIST"; "ILIST"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"HEAP" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"HEAP" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "PI"}*/
+"HEAP" -> "A1AGG"
+/*"HEAP" -> "SINT"*/
+
+"IARRAY1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IARRAY1"]
+"IARRAY1" -> "A1AGG"
+/*"IARRAY1" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"IARRAY1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"IARRAY1" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "SINT"; "NNI"}*/
+/*"IARRAY1" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"IARRAY1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IARRAY1" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"IARRAY1" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"IARRAY1" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"IARRAY1" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"IARRAY1" -> {"CHARZ"; "STEP"; "OM"}*/
+
+"IARRAY2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IARRAY2"]
+"IARRAY2" -> "ARR2CAT"
+/*"IARRAY2" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"IARRAY2" -> {"EVALAB"; "IEVALAB"}*/
+"IARRAY2" -> "A1AGG"
+/*"IARRAY2" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"IARRAY2" -> {"KONVERT"; "ORDSET"}*/
+
+"IFARRAY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IFARRAY"]
+"IFARRAY" -> "A1AGG"
+/*"IFARRAY" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"IFARRAY" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"IFARRAY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "ELAGG"; "BOOLEAN"}*/
+/*"IFARRAY" -> {"INT"; "PRIMARR"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"IFARRAY" -> {"OM"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"}*/
+/*"IFARRAY" -> {"SINT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+/*"IFARRAY" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"IFARRAY" -> {"ABELGRP-"; "ABELMON-"; "PI"; "INS"; "UFD"; "GCDDOM"}*/
+/*"IFARRAY" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"IFARRAY" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IFARRAY" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"IFARRAY" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"IFARRAY" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"IFARRAY" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"INTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INTCAT"]
+/*"INTCAT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTCAT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"INTCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"INTCAT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+"INTCAT" -> "TRANFUN"
+/*"INTCAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
+/*"INTCAT" -> "RETRACT"*/
+
+"INTHEORY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTHEORY"]
+/*"INTHEORY" -> {"NNI"; "INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INTHEORY" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INTHEORY" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INTHEORY" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INTHEORY" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"INTHEORY" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"INTHEORY" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"INTHEORY" -> {"REAL"; "CHARZ"; "STEP"; "SINT"; "PI"; "INS-"; "EUCDOM-"}*/
+/*"INTHEORY" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"INTHEORY" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+/*"INTHEORY" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
+"INTHEORY" -> "A1AGG"
+/*"INTHEORY" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"INTHEORY" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "ELAGG"}*/
+/*"INTHEORY" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"INTHEORY" -> "FLAGG-"*/
+
+"IRREDFFX" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRREDFFX"]
+/*"IRREDFFX" -> "FFIELDC"*/
+"IRREDFFX" -> "FPC"
+/*"IRREDFFX" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"IRREDFFX" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IRREDFFX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"IRREDFFX" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"IRREDFFX" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
+/*"IRREDFFX" -> {"DIFRING"; "INT"; "PI"; "NNI"; "BOOLEAN"; "MONOID-"}*/
+/*"IRREDFFX" -> {"ABELSG-"; "SGROUP-"}*/
+
+"LFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LFCAT"]
+/*"LFCAT" -> "PRIMCAT"*/
+"LFCAT" -> "TRANFUN"
+/*"LFCAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+
+"LODOCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LODOCAT"]
+/*"LODOCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LODOCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"LODOCAT" -> "LMODULE"*/
+"LODOCAT" -> "OREPCAT"
+/*"LODOCAT" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
+/*"LODOCAT" -> {"MODULE"; "ELTAB"; "NNI"; "INT"; "BOOLEAN"; "FIELD"}*/
+/*"LODOCAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"LODOCAT" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+
+"LODOCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODOCAT"]
+/*"LODOCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LODOCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"LODOCAT-" -> "LMODULE"*/
+"LODOCAT-" -> "OREPCAT"
+/*"LODOCAT-" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
+/*"LODOCAT-" -> {"MODULE"; "ELTAB"; "NNI"; "INT"; "BOOLEAN"; "FIELD"}*/
+/*"LODOCAT-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"LODOCAT-" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+
+"LWORD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LWORD"]
+/*"LWORD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"LWORD" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"LWORD" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"LWORD" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
+/*"LWORD" -> {"OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"LWORD" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"LWORD" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"LWORD" -> {"NNI"; "PI"}*/
+"LWORD" -> "A1AGG"
+/*"LWORD" -> "SINT"*/
+
+"MATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MATCAT"]
+"MATCAT" -> "ARR2CAT"
+/*"MATCAT" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MATCAT" -> {"EVALAB"; "IEVALAB"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"MATCAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MATCAT" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"MATCAT" -> {"KONVERT"; "ORDSET"; "NNI"; "INT"; "BOOLEAN"; "SINT"}*/
+/*"MATCAT" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+/*"MATCAT" -> {"OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"MATCAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"MATCAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"MATCAT" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"MATCAT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "FIELD"; "DIVRING"; "INS-"}*/
+
+"MATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MATCAT"]
+"MATCAT-" -> "ARR2CAT"
+/*"MATCAT-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MATCAT-" -> {"EVALAB"; "IEVALAB"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"MATCAT-" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MATCAT-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"MATCAT-" -> {"KONVERT"; "ORDSET"; "NNI"; "INT"; "BOOLEAN"; "SINT"}*/
+/*"MATCAT-" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"MATCAT-" -> {"ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"MATCAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"MATCAT-" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"MATCAT-" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"MATCAT-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "FIELD"; "DIVRING"; "INS-"}*/
+
+"MATSTOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MATSTOR"]
+/*"MATSTOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"MATSTOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"MATSTOR" -> {"LMODULE"; "NNI"; "INT"; "SINT"; "PRIMARR"}*/
+"MATSTOR" -> "A1AGG"
+/*"MATSTOR" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"MATSTOR" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"MATSTOR" -> "BOOLEAN"*/
+
+"MTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MTSCAT",
+          shape=ellipse]
+/*"MTSCAT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
+/*"MTSCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"MTSCAT" -> {"MTSCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"MTSCAT" -> {"MONOID"; "LMODULE"}*/
+"MTSCAT" -> "PSCAT"
+/*"MTSCAT" -> {"AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
+/*"MTSCAT" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "IEVALAB"}*/
+/*"MTSCAT" -> {"EVALAB"; "RADCAT"}*/
+"MTSCAT" -> "TRANFUN"
+/*"MTSCAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+
+"ORESUP" -> "OREPCAT"
+/*"ORESUP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ORESUP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ORESUP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
+/*"ORESUP" -> {"ALGEBRA"; "MODULE"; "INTDOM"; "COMRING"; "ENTIRER"}*/
+/*"ORESUP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"ORESUP" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ORESUP" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"}*/
+/*"ORESUP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"OREPCTO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OREPCTO"]
+/*"OREPCTO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"OREPCTO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+"OREPCTO" -> "OREPCAT"
+/*"OREPCTO" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
+/*"OREPCTO" -> {"MODULE"; "BOOLEAN"; "NNI"; "INT"; "SINT"; "INTDOM"}*/
+/*"OREPCTO" -> {"COMRING"; "ENTIRER"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"OREPCTO" -> {"UFD"; "DIVRING"}*/
+
+"OREUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OREUP"]
+"OREUP" -> "OREPCAT"
+/*"OREUP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"OREUP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"OREUP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
+/*"OREUP" -> {"ALGEBRA"; "MODULE"; "NNI"; "INT"; "FIELD"; "EUCDOM"}*/
+/*"OREUP" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
+/*"OREUP" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"OREUP" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"}*/
+/*"OREUP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"PACFFC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PACFFC",
+          shape=ellipse]
+/*"PACFFC" -> {"FFIELDC"}*/
+"PACFFC" -> "FPC"
+/*"PACFFC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PACFFC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PACFFC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PACFFC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PACFFC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"PACFFC" -> {"STEP"; "DIFRING"}*/
+"PACFFC" -> "PACPERC"
+
+"PLOT3D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLOT3D"]
+/*"PLOT3D" -> {"PSCURVE"; "KOERCE"; "BOOLEAN"; "INT"; "DFLOAT"; "FPS-"}*/
+/*"PLOT3D" -> {"RNS-"; "FIELD-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
+/*"PLOT3D" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PLOT3D" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PLOT3D" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PLOT3D" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"PLOT3D" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"PLOT3D" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"PLOT3D" -> {"LIST"; "ILIST"; "NNI"; "PI"; "LSAGG-"; "STAGG-"}*/
+/*"PLOT3D" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PLOT3D" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PLOT3D" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"PLOT3D" -> {"ELAGG"; "OM"; "SINT"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"PLOT3D" -> {"DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"PLOT3D" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"}*/
+/*"PLOT3D" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "INS"; "OINTDOM"}*/
+/*"PLOT3D" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "INS-"}*/
+"PLOT3D" -> "TRANFUN"
+/*"PLOT3D" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+
+"POLYVEC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYVEC"]
+/*"POLYVEC" -> {"SINT" "NNI" "INT"}*/
+"POLYVEC" -> "A1AGG"
+/*"POLYVEC" -> {"FLAGG" "LNAGG" "IXAGG" "HOAGG" "AGG" "TYPE" "SETCAT"}*/
+/*"POLYVEC" -> {"BASTYPE" "KOERCE" "EVALAB" "IEVALAB" "ELTAGG" "ELTAB"}*/
+/*"POLYVEC" -> {"CLAGG" "KONVERT" "ORDSET" "BOOLEAN" "INS" "UFD" "GCDDOM"} */
+/*"POLYVEC" -> {"INTDOM" "COMRING" "RING" "RNG" "ABELGRP" "CABMON"}*/
+/*"POLYVEC" -> {"ABELMON" "ABELSG" "SGROUP" "MONOID" "LMODULE" "BMODULE"}*/
+/*"POLYVEC" -> {"RMODULE" "ALGEBRA" "MODULE" "ENTIRER" "EUCDOM" "PID"}*/
+/*"POLYVEC" -> {"OINTDOM" "ORDRING" "OAGROUP" "OCAMON" "OAMON" "OASGP"}*/
+/*"POLYVEC" -> {"DIFRING" "RETRACT" "LINEXP" "PATMAB" "CFCAT" "REAL"}*/
+/*"POLYVEC" -> {"CHARZ" "STEP" "INS-" "EUCDOM-" "UFD-" "GCDDOM-" "INTDOM-"}*/
+/*"POLYVEC" -> {"ALGEBRA-" "DIFRING-" "ORDRING-" "MODULE-""RING-"}*/
+/*"POLYVEC" -> {"ABELGRP-" "ABELMON-" "MONOID-" "ORDSET-" "ABELSG-"}*/
+/*"POLYVEC" -> {"SGROUP-" "SETCAT-" "RETRACT-" "BASTYPE-" "PI" "PRIMARR"}*/
+
+"PR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PR"]
+"PR" -> "FAMR"
+/*"PR" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"PR" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"PR" -> {"OAMON"; "OASGP"; "ORDSET"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"PR" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"PR" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"PR" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "BOOLEAN"; "LNAGG-"; "RCAGG-"}*/
+/*"PR" -> {"IXAGG-"; "NNI"; "PI"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PR" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PR" -> {"OCAMON"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+
+"PREASSOC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PREASSOC"]
+/*"PREASSOC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PREASSOC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PREASSOC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PREASSOC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LODOCAT"}*/
+"PREASSOC" -> "OREPCAT"
+/*"PREASSOC" -> {"FRETRCT"; "RETRACT"; "ELTAB"; "NNI"; "INT"; "PI"}*/
+/*"PREASSOC" -> {"PRIMARR"; "SINT"}*/
+"PREASSOC" -> "A1AGG"
+/*"PREASSOC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PREASSOC" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
+/*"PREASSOC" -> "ORDSET"*/
+
+"PRIMARR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PRIMARR",
+          shape=ellipse]
+"PRIMARR" -> "A1AGG"
+/*"PRIMARR" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PRIMARR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"PRIMARR" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"PRIMARR" -> {"INT"; "PRIMARR"; "SINT"; "NNI"; "INS"; "UFD"; "GCDDOM"}*/
+/*"PRIMARR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PRIMARR" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PRIMARR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PRIMARR" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PRIMARR" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"PRIMARR" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"PRIMARR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRIMARR2"]
+/*"PRIMARR2" -> "TYPE"*/
+"PRIMARR2" -> "A1AGG"
+/*"PRIMARR2" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"}*/
+/*"PRIMARR2" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"PRIMARR2" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+
+"PROJSP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PROJSP",
+          shape=ellipse]
+/*"PROJSP" -> {"PRSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PROJSP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"PROJSP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON";  "FFIELDC"}*/
+/*"PROJSP" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PROJSP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PROJSP" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "PI"; "NNI"}*/
+"PROJSP" -> "PACPERC"
+"PROJSP" -> "FPC"
+/*"PROJSP" -> {"CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "LSAGG-"; "STAGG-"}*/
+/*"PROJSP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"PROJSP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"PROJSP" -> {"BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"PROJSP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"PROJSP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
+/*"PROJSP" -> {"ELAGG"; "OM"; "BOOLEAN"}*/
+
+"REDORDER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REDORDER"]
+/*"REDORDER" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"REDORDER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"REDORDER" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"REDORDER" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"REDORDER" -> {"ENTIRER"; "UFD"; "DIVRING"; "LODOCAT"}*/
+"REDORDER" -> "OREPCAT"
+/*"REDORDER" -> {"FRETRCT"; "RETRACT"; "ELTAB"; "INT"; "INS-"; "PRIMARR"}*/
+/*"REDORDER" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "BOOLEAN"}*/
+/*"REDORDER" -> "NNI"*/
+"REDORDER" -> "A1AGG"
+/*"REDORDER" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"REDORDER" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
+/*"REDORDER" -> {"ORDSET"; "SINT"}*/
+
+"SRAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SRAGG"]
+"SRAGG" -> "A1AGG"
+/*"SRAGG" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"SRAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"SRAGG" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"}*/
+/*"SRAGG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SRAGG" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"SRAGG" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"SRAGG" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"SRAGG" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"SRAGG" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "NNI"; "INT"}*/
+
+"SRAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SRAGG"]
+"SRAGG-" -> "A1AGG"
+/*"SRAGG-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"SRAGG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"SRAGG-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"}*/
+/*"SRAGG-" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"SRAGG-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"SRAGG-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"SRAGG-" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"SRAGG-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SRAGG-" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"SRAGG-" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "NNI"; "INT"}*/
+
+"STREAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STREAM"]
+"STREAM" -> "LZSTAGG"
+/*"STREAM" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"STREAM" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"STREAM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "INT"; "LIST"; "ILIST"}*/
+/*"STREAM" -> {"SINT"; "NNI"; "BOOLEAN"; "LSAGG"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"STREAM" -> {"OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"STREAM" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"STREAM" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"STREAM" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"STREAM" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"STREAM" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"SYMPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMPOLY"]
+/*"SYMPOLY" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+/*"SYMPOLY" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+"SYMPOLY" -> "FAMR"
+/*"SYMPOLY" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
+/*"SYMPOLY" -> {"LMODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
+/*"SYMPOLY" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"SYMPOLY" -> {"FRETRCT"; "RETRACT"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
+/*"SYMPOLY" -> {"KONVERT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"}*/
+/*"SYMPOLY" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "DIFRING"; "LINEXP"}*/
+/*"SYMPOLY" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"; "FIELD"; "DIVRING"}*/
+
+"TS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TS"]
+/*"TS" -> {"MTSCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"TS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"TS" -> {"MONOID"; "LMODULE"}*/
+"TS" -> "PSCAT"
+/*"TS" -> {"AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"TS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "IEVALAB"; "EVALAB"}*/
+/*"TS" -> "RADCAT"*/
+"TS" -> "TRANFUN"
+/*"TS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SINT"; "NNI"}*/
+/*"TS" -> {"INT"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"}*/
+/*"TS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"TS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"TS" -> {"CFCAT"; "REAL"; "STEP"; "FIELD"; "DIVRING"}*/
+
+"TUPLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TUPLE"]
+/*"TUPLE" -> {"KOERCE"; "SETCAT"; "BASTYPE"; "TYPE"}*/
+"TUPLE" -> "A1AGG"
+/*"TUPLE" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "EVALAB"; "IEVALAB"}*/
+/*"TUPLE" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"}*/
+/*"TUPLE" -> {"PRIMARR"; "NNI"}*/
+"TUPLE" -> "A1AGG-"
+/*"TUPLE" -> {"BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"TUPLE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"TUPLE" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"TUPLE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"TUPLE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"TUPLE" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"TUPLE" -> {"STEP"; "OM"; "FLAGG-"; "LNAGG-"}*/
+
+"UPSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPSCAT"]
+"UPSCAT" -> "PSCAT"
+/*"UPSCAT" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"UPSCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"UPSCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
+/*"UPSCAT" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"}*/
+/*"UPSCAT" -> {"DIFRING"; "PDRING"; "OAMON"; "OASGP"; "ORDSET"; "INT"}*/
+/*"UPSCAT" -> {"LIST"; "ILIST"; "LSAGG-"}*/
+
+"UPSCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPSCAT"]
+"UPSCAT-" -> "PSCAT"
+/*"UPSCAT-" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"UPSCAT-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"UPSCAT-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"UPSCAT-" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"UPSCAT-" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "OAMON"; "OASGP"}*/
+/*"UPSCAT-" -> {"ORDSET"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+
+"U8VEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U8VEC"]
+"U8VEC" -> "A1AGG"
+/*"U8VEC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"U8VEC" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"U8VEC" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"; "INS"}*/
+/*"U8VEC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"U8VEC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"U8VEC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"U8VEC" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"U8VEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"U8VEC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"U16VEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U16VEC"]
+"U16VEC" -> "A1AGG"
+/*"U16VEC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"U16VEC" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"U16VEC" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"; "INS"}*/
+/*"U16VEC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"U16VEC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"U16VEC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"U16VEC" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"U16VEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"U16VEC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"U32VEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U32VEC"]
+"U32VEC" -> "A1AGG"
+/*"U32VEC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"U32VEC" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"U32VEC" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"; "INS"}*/
+/*"U32VEC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"U32VEC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"U32VEC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"U32VEC" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"U32VEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"U32VEC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"VECTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=VECTCAT"]
+"VECTCAT" -> "A1AGG"
+/*"VECTCAT" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"VECTCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"VECTCAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "ABELSG"}*/
+/*"VECTCAT" -> {"NNI"; "INT"; "ABELMON"; "ABELGRP"; "CABMON"; "MONOID"}*/
+/*"VECTCAT" -> {"SGROUP"; "RING"; "RNG"; "LMODULE"; "INS"; "UFD"; "GCDDOM"}*/
+/*"VECTCAT" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"VECTCAT" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"VECTCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"VECTCAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"VECTCAT" -> {"STEP"; "OM"; "PI"; "RADCAT"}*/
+
+"VECTCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VECTCAT"]
+"VECTCAT-" -> "A1AGG"
+/*"VECTCAT-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"VECTCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"VECTCAT-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"VECTCAT-" -> {"ABELSG"; "NNI"; "INT"; "ABELMON"; "ABELGRP"; "CABMON"}*/
+/*"VECTCAT-" -> {"MONOID"; "SGROUP"; "RING"; "RNG"; "LMODULE"; "INS"}*/
+/*"VECTCAT-" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"VECTCAT-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"VECTCAT-" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"VECTCAT-" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"VECTCAT-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "PI"; "RADCAT"}*/
+
+"XDPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XDPOLY"]
+/*"XDPOLY" -> {"FMCAT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
+/*"XDPOLY" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"XDPOLY" -> {"RMODULE"; "RETRACT"; "MODULE"}*/
+"XDPOLY" -> "XPOLYC"
+/*"XDPOLY" -> {"XFALG"; "RING"; "RNG"; "SGROUP"; "MONOID"; "XALG"}*/
+/*"XDPOLY" -> {"ALGEBRA"; "ORDMON"; "ORDSET"; "INT"; "LIST"; "ILIST"}*/
+/*"XDPOLY" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "COMRING"}*/
+/*"XDPOLY" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"XDPOLY" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"XDPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"XDPOLY" -> "BOOLEAN"*/
+
+"XEXPPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=XEXPPKG"]
+/*"XEXPPKG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"XEXPPKG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"XEXPPKG" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "ORDSET"}*/
+"XEXPPKG" -> "XPOLYC"
+/*"XEXPPKG" -> {"XFALG"; "XALG"; "ALGEBRA"; "RETRACT"; "SINT"; "NNI"}*/
+/*"XEXPPKG" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"XEXPPKG" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"XEXPPKG" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "LINEXP"}*/
+/*"XEXPPKG" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "PI"}*/
+
+"XF" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XF"]
+/*"XF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"XF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"XF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"XF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"XF" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
+"XF" -> "VSPACE"
+/*"XF" -> "CHARZ"*/
+"XF" -> "FPC"
+/*"XF" -> {"CHARNZ"; "FINITE"; "BOOLEAN"; "NNI"; "INT"}*/
+
+"XF-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XF"]
+/*"XF-" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"XF-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"XF-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"XF-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"XF-" -> {"DIVRING"; "RETRACT"}*/
+"XF-" -> "VSPACE"
+/*"XF-" -> "CHARZ"*/
+"XF-" -> "FPC"
+/*"XF-" -> {"CHARNZ"; "FINITE"; "BOOLEAN"; "NNI"; "INT"}*/
+
+"XPBWPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XPBWPOLY"]
+"XPBWPOLY" -> "XPOLYC"
+/*"XPBWPOLY" -> {"XFALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"XPBWPOLY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"XPBWPOLY" -> {"MONOID"; "LMODULE"; "XALG"; "BMODULE"; "RMODULE"}*/
+/*"XPBWPOLY" -> {"ALGEBRA"; "MODULE"; "RETRACT"; "FMCAT"; "COMRING"}*/
+/*"XPBWPOLY" -> {"ORDSET"; "INT"; "BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"XPBWPOLY" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"XPBWPOLY" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"XPBWPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"XPBWPOLY" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "INS"; "UFD"}*/
+/*"XPBWPOLY" -> {"GCDDOM"; "INTDOM"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"XPBWPOLY" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"XPBWPOLY" -> {"DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"XPBWPOLY" -> {"STEP"; "LNAGG-"; "NNI"; "SINT"}*/
+
+"XPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XPOLY"]
+"XPOLY" -> "XPOLYC"
+/*"XPOLY" -> {"XFALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"XPOLY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"XPOLY" -> {"LMODULE"; "XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"XPOLY" -> {"RETRACT"; "COMRING"}*/
+
+"XRPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XRPOLY"]
+"XRPOLY" -> "XPOLYC"
+/*"XRPOLY" -> {"XFALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"XRPOLY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"XRPOLY" -> {"LMODULE"; "XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"XRPOLY" -> {"MODULE"; "RETRACT"; "ORDSET"; "BOOLEAN"; "NNI"; "INT"}*/
+/*"XRPOLY" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"XRPOLY" -> {"COMRING"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"XRPOLY" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"XRPOLY" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"XRPOLY" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"XRPOLY" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
+
+\end{chunk}
+\subsection{Layer9}
+Depends on: BTAGG FLALG LODOCAT MATCAT SRAGG VECTCAT XF PROJSP PACFFC\\
+Used by next layer: IVECTOR PTCAT STRICAT 
+\begin{chunk}{layer9}
+
+LAYER9=\
+  ${OUT}/AFFPL.o    ${OUT}/BITS.o     ${OUT}/DFMAT.o    ${OUT}/DFVEC.o   \
+  ${OUT}/DIRPROD2.o ${OUT}/IMATRIX.o  ${OUT}/INTRVL.o  \
+  ${OUT}/IVECTOR.o  ${OUT}/LOCPOWC.o  \
+  ${OUT}/LODO1.o    ${OUT}/LODO2.o    ${OUT}/LPOLY.o   \
+  ${OUT}/LSMP.o     ${OUT}/LSMP1.o    ${OUT}/MAMA.o     ${OUT}/MATCAT2.o  \
+  ${OUT}/PROJPL.o   ${OUT}/PTCAT.o    ${OUT}/STRICAT.o  ${OUT}/TRIMAT.o  \
+  ${OUT}/U8MAT.o    ${OUT}/U16MAT.o   ${OUT}/U32MAT.o \
+  layer9done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 9 */
+/* Depends on: BTAGG FLALG INTCAT LODOCAT MATCAT SRAGG UPSCAT VECTCAT */
+/* AFFSP */
+
+"AFFPL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AFFPL"]
+"AFFPL" -> "AFFSP"
+/*"AFFPL" -> {"AFSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
+/*"AFFPL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"AFFPL" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"AFFPL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"AFFPL" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+
+"BITS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BITS"]
+"BITS" -> "BTAGG"
+/*"BITS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"; "A1AGG"}*/
+/*"BITS" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"BITS" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "INT"}*/
+/*"BITS" -> {"FINITE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"BITS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"BITS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"BITS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"BITS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"BITS" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"BITS" -> {"STEP"; "OM"}*/
+
+"DFMAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DFMAT"]
+"DFMAT" -> "MATCAT"
+"DFMAT" -> "VECTCAT"
+/*"DFMAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"DFMAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "FPS"; "RNS"; "FIELD"}*/
+/*"DFMAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"DFMAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"DFMAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"DFMAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DFMAT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"DFMAT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"DFMAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "DIFRING"; "OM"}*/
+/*"DFMAT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"DFMAT" -> {"SPFCAT"}*/
+
+"DFVEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DFVEC"]
+"DFVEC" -> "VECTCAT"
+/*"DFVEC" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"DFVEC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"DFVEC" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"}*/
+/*"DFVEC" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"DFVEC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"DFVEC" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DFVEC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"DFVEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
+/*"DFVEC" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
+/*"DFVEC" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+/*"DFVEC" -> {"INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
+
+"DIRPROD2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DIRPROD2"]
+/*"DIRPROD2" -> "TYPE"*/
+"DIRPROD2" -> "VECTCAT"
+/*"DIRPROD2" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"DIRPROD2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"DIRPROD2" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+
+"IMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IMATRIX"]
+"IMATRIX" -> "MATCAT"
+/*"IMATRIX" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"IMATRIX" -> {"KOERCE"; "EVALAB"; "IEVALAB"}*/
+"IMATRIX" -> "VECTCAT"
+/*"IMATRIX" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"IMATRIX" -> {"CLAGG"; "KONVERT"; "ORDSET"; "RING"; "RNG"; "ABELGRP"}*/
+/*"IMATRIX" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IMATRIX" -> {"INT"; "PRIMARR"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"IMATRIX" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"IMATRIX" -> {"ENTIRER"; "FIELD"; "UFD"; "DIVRING"}*/
+
+"INTRVL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTRVL"]
+"INTRVL" -> "INTCAT"
+/*"INTRVL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTRVL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INTRVL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INTRVL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "TRANFUN"}*/
+/*"INTRVL" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
+/*"INTRVL" -> {"RETRACT"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"INTRVL" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"INTRVL" -> {"OASGP"; "REAL"; "KONVERT"; "PATMAB"; "CHARZ"; "INT"}*/
+/*"INTRVL" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"INTRVL" -> {"FLAGG-"; "URAGG-"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"INTRVL" -> {"CFCAT"; "STEP"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"INTRVL" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"INTRVL" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"IVECTOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IVECTOR"]
+"IVECTOR" -> "VECTCAT"
+/*"IVECTOR" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"IVECTOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"IVECTOR" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "RADCAT"}*/
+/*"IVECTOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IVECTOR" -> {"SGROUP"; "MONOID"; "LMODULE"; "INS"; "UFD"; "GCDDOM"}*/
+/*"IVECTOR" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"IVECTOR" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"IVECTOR" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"IVECTOR" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"LOCPOWC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LOCPOWC"]
+/*"LOCPOWC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"LOCPOWC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"*/
+/*"LOCPOWC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"LOCPOWC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"LOCPOWC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"LOCPOWC" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"LOCPOWC" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"LOCPOWC" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"LOCPOWC" -> {"CHARZ"; "STEP"}*/
+"LOCPOWC" -> "UPSCAT"
+/*"LOCPOWC" -> {"PSCAT"; "AMR"; "CHARNZ"; "ELTAB"; "PDRING"}*/
+
+"LODO1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODO1"]
+/*"LODO1" -> {"DIFRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LODO1" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"LODO1" -> "LMODULE"*/
+"LODO1" -> "LODOCAT"
+/*"LODO1" -> {"OREPCAT"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
+/*"LODO1" -> {"ALGEBRA"; "MODULE"; "ELTAB"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"LODO1" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"LODO1" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"LODO1" -> {"OASGP"; "ORDSET"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"LODO1" -> {"REAL"; "CHARZ"; "STEP"}*/
+
+"LODO2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODO2"]
+"LODO2" -> "LODOCAT"
+/*"LODO2" -> {"OREPCAT"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LODO2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"LODO2" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
+/*"LODO2" -> {"ALGEBRA"; "MODULE"; "ELTAB"; "DIFRING"; "FIELD"; "EUCDOM"}*/
+/*"LODO2" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
+/*"LODO2" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"LODO2" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "LINEXP"}*/
+/*"LODO2" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"LPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LPOLY"]
+"LPOLY" -> "FLALG"
+/*"LPOLY" -> {"LIECAT"; "MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"}*/
+/*"LPOLY" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"LPOLY" -> {"KOERCE"; "RMODULE"; "FMCAT"; "RETRACT"; "COMRING"}*/
+/*"LPOLY" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "ORDSET"; "LSAGG"}*/
+/*"LPOLY" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"LPOLY" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"LPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
+/*"LPOLY" -> {"OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"LPOLY" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"LPOLY" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"LPOLY" -> {"BASTYPE-"; "BOOLEAN"; "NNI"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"LPOLY" -> {"GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"LSMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LSMP"]
+/*"LSMP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"LSMP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LSMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LSMP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LSMP" -> {"UFD"; "DIVRING"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"LSMP" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"LSMP" -> {"KONVERT"; "ORDSET"}*/
+"LSMP" -> "MATCAT"
+/*"LSMP" -> {"ARR2CAT"; "NNI"; "INT"; "BOOLEAN"; "PRIMARR"; "SINT"}*/
+/*"LSMP" -> {"A1AGG"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"LSMP" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"LSMP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LIST"; "ILIST"}*/
+
+"LSMP1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LSMP1"]
+/*"LSMP1" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"LSMP1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LSMP1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LSMP1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LSMP1" -> {"UFD"; "DIVRING"}*/
+"LSMP1" -> "VECTCAT"
+/*"LSMP1" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"LSMP1" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"LSMP1" -> {"KONVERT"; "ORDSET"}*/
+
+"MAMA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAMA"]
+/*"MAMA" -> {"FIELD", "EUCDOM", "PID", "GCDDOM", "INTDOM", "COMRING"}*/
+/*"MAMA" -> {"RING", "RNG", "ABELGRP", "CABMON", "ABELMON", "ABELSG"}*/
+/*"MAMA" -> {"SETCAT", "BASTYPE", "KOERCE", "SGROUP", "MONOID"}*/
+/*"MAMA" -> {"LMODULE", "BMODULE", "RMODULE", "ALGEBRA", "MODULE"}*/
+/*"MAMA" -> {"ENTIRER", "UFD", "DIVRING", "FLAGG", "LNAGG", "IXAGG"}*/
+/*"MAMA" -> {"HOAGG", "AGG", "TYPE", "EVALAB", "IEVALAB", "ELTAGG"}*/
+/*"MAMA" -> {"ELTAB", "CLAGG", "KONVERT", "ORDSET"}*/
+"MAMA" -> "MATCAT"
+/*"MAMA" -> {"ARR2CAT", "INT", "LIST", "ILIST", "NNI", "PI", "BOOLEAN"}*/
+/*"MAMA" -> {"LSAGG", "STAGG", "URAGG", "RCAGG", "ELAGG", "OM", "LSAGG-"}*/
+/*"MAMA" -> {"SINT", "INS", "OINTDOM", "ORDRING", "OAGROUP", "OCAMON"}*/
+/*"MAMA" -> {"OAMON", "OASGP", "DIFRING", "RETRACT", "LINEXP", "PATMAB"}*/
+/*"MAMA" -> {"CFCAT", "REAL", "CHARZ", "STEP", "MONOID-", "ABELMON-"}*/
+/*"MAMA" -> {"ORDSET-", "SGROUP-", "ABELSG-", "SETCAT-", "BASTYPE-"}*/
+/*"MAMA" -> {"STAGG-"}*/
+
+"MATCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MATCAT2"]
+/*"MATCAT2" -> {"RING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"MATCAT2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"MATCAT2" -> {"LMODULE"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"MATCAT2" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"MATCAT2" -> {"KONVERT"; "ORDSET"}*/
+"MATCAT2" -> "MATCAT"
+/*"MATCAT2" -> "ARR2CAT"*/
+
+"PROJPL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PROJPL"]
+/*"PROJPL" -> {"PRSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
+"PROJPL" -> "PROJSP"
+/*"PROJPL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PROJPL" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"PROJPL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PROJPL" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+
+"PTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PTCAT"]
+"PTCAT" -> "VECTCAT"
+/*"PTCAT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PTCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"PTCAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+
+"STRICAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=STRICAT"]
+"STRICAT" -> "SRAGG"
+/*"STRICAT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"STRICAT" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"STRICAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "OM"}*/
+
+"TRIMAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TRIMAT"]
+/*"TRIMAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"TRIMAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"TRIMAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"TRIMAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"TRIMAT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"TRIMAT" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+"TRIMAT" -> "MATCAT"
+/*"TRIMAT" -> {"ARR2CAT"; "INT"; "NNI"; "PI"}*/
+
+"ULSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ULSCAT",
+          shape=ellipse]
+/*"ULSCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"ULSCAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"ULSCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ULSCAT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"ULSCAT" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ULSCAT" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"ULSCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+"ULSCAT" -> "UPSCAT"
+/*"ULSCAT" -> {"PSCAT"; "AMR"; "CHARNZ"; "ELTAB"; "PDRING"; "RADCAT"}*/
+/*"ULSCAT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"ULSCAT" -> {"ELEMFUN"; "FIELD"; "DIVRING"}*/
+
+"U8MAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U8MAT"]
+"U8MAT" -> "MATCAT"
+/*"U8MAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"U8MAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INS"; "UFD"; "GCDDOM"}*/
+/*"U8MAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"U8MAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"U8MAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"U8MAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"U8MAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"U8MAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"U8MAT" -> {"CHARZ"; "STEP"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"U8MAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "OM"; "FIELD"; "DIVRING"}*/
+
+"U16MAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U16MAT"]
+"U16MAT" -> "MATCAT"
+/*"U16MAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"U16MAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INS"; "UFD"; "GCDDOM"}*/
+/*"U16MAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"U16MAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"U16MAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"U16MAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"U16MAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"U16MAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"U16MAT" -> {"CHARZ"; "STEP"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"U16MAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "OM"; "FIELD"; "DIVRING"}*/
+
+"U32MAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U32MAT"]
+"U32MAT" -> "MATCAT"
+/*"U32MAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"U32MAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INS"; "UFD"; "GCDDOM"}*/
+/*"U32MAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"U32MAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"U32MAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"U32MAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"U32MAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"U32MAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"U32MAT" -> {"CHARZ"; "STEP"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"U32MAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "OM"; "FIELD"; "DIVRING"}*/
+
+\end{chunk}
+\subsection{Layer10}
+Depends on: IVECTOR PTCAT STRICAT LOCPOWC\\
+Used by next layer: DIRPCAT FAXF PFECAT STRING
+\begin{chunk}{layer10}
+
+LAYER10=\
+  ${OUT}/ASSOCEQ.o  ${OUT}/CARTEN.o   ${OUT}/CLIF.o     ${OUT}/CLIP.o    \
+  ${OUT}/COORDSYS.o ${OUT}/DBASE.o    ${OUT}/DHMATRIX.o ${OUT}/DIOSP.o   \
+  ${OUT}/DIRPCAT.o  ${OUT}/DIRPCAT-.o ${OUT}/D02BBFA.o  ${OUT}/D02BHFA.o \
+  ${OUT}/D02CJFA.o  ${OUT}/FAXF.o     ${OUT}/FAXF-.o    ${OUT}/FFPOLY2.o \
+  ${OUT}/FNLA.o     ${OUT}/GRAY.o     ${OUT}/HB.o       ${OUT}/INBFF.o   \
+  ${OUT}/IRSN.o     ${OUT}/LOP.o      \
+  ${OUT}/MCALCFN.o  ${OUT}/MHROWRED.o ${OUT}/NUMODE.o  \
+  ${OUT}/NUMQUAD.o  ${OUT}/ODESYS.o   ${OUT}/ODETOOLS.o ${OUT}/ORDFUNS.o \
+  ${OUT}/PERMAN.o   ${OUT}/PFECAT.o   ${OUT}/PFECAT-.o  ${OUT}/POINT.o   \
+  ${OUT}/PSEUDLIN.o ${OUT}/PTPACK.o   ${OUT}/REP2.o     ${OUT}/SETMN.o   \
+  ${OUT}/SEX.o      ${OUT}/STRING.o   ${OUT}/SYMFUNC.o  ${OUT}/VECTOR2.o \
+  layer10done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 10 */
+/* depends on: IVECTOR PTCAT STRICAT */
+
+"ASSOCEQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ASSOCEQ"]
+/*"ASSOCEQ" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ASSOCEQ" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ASSOCEQ" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ASSOCEQ" -> {"MODULE"; "ENTIRER"; "LODOCAT"; "OREPCAT"; "FRETRCT"}*/
+/*"ASSOCEQ" -> {"RETRACT"; "ELTAB"; "SINT"; "NNI"; "INT"; "VECTCAT"}*/
+/*"ASSOCEQ" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"ASSOCEQ" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"ASSOCEQ" -> {"CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"}*/
+"ASSOCEQ" -> "IVECTOR"
+/*"ASSOCEQ" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "LIST"; "ILIST"; "PI"}*/
+/*"ASSOCEQ" -> {"BOOLEAN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"ASSOCEQ" -> {"UFD"; "DIVRING"}*/
+
+"CARTEN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CARTEN"]
+/*"CARTEN" -> {"GRALG"; "GRMOD"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"CARTEN" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "ABELMON"}*/
+/*"CARTEN" -> {"ABELSG"; "CABMON"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"CARTEN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
+/*"CARTEN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"CARTEN" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"CARTEN" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"CARTEN" -> {"CHARZ"; "STEP"; "NNI"; "INT"; "MONOID-"; "ABELMON-"}*/
+/*"CARTEN" -> {"ORDSET-"; "SGROUP-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"CARTEN" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"CARTEN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"}*/
+"CARTEN" -> "IVECTOR"
+/*"CARTEN" -> {"IARRAY1"; "SINT"; "PI"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"CARTEN" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"CARTEN" -> {"MODULE-"; "RING-"; "ABELGRP-"; "BOOLEAN"; "LSAGG"}*/
+/*"CARTEN" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"}*/
+/*"CARTEN" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"CARTEN" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "AGG-"}*/
+/*"CARTEN" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+
+"CLIF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CLIF"]
+/*"CLIF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"CLIF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CLIF" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "VSPACE"}*/
+/*"CLIF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"CLIF" -> {"COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "SINT"; "PI"}*/
+/*"CLIF" -> {"NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"; "PRIMARR"}*/
+/*"CLIF" -> {"BOOLEAN"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"CLIF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"CLIF" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS-"; "LIST"; "ILIST"}*/
+/*"CLIF" -> {"LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"CLIF" -> {"ELAGG"; "OM"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"CLIF" -> {"RCAGG-"; "IXAGG-"; "VECTOR"; "VECTCAT"}*/
+"CLIF" -> "IVECTOR"
+/*"CLIF" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
+
+"CLIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CLIP"]
+/*"CLIP" -> {"DFLOAT"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"}*/
+/*"CLIP" -> {"GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"CLIP" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+/*"CLIP" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"; "TRANFUN-"}*/
+/*"CLIP" -> {"SETCAT-"; "ELEMFUN-"; "HYPCAT-"; "ATRIG-"; "TRIGCAT-"}*/
+/*"CLIP" -> {"RADCAT-"; "RETRACT-"; "BASTYPE-"; "FPS"; "RNS"}*/
+/*"CLIP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"CLIP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"CLIP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"CLIP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"CLIP" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"CLIP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"CLIP" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+"CLIP" -> "PTCAT"
+/*"CLIP" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"CLIP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"CLIP" -> {"CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
+/*"CLIP" -> {"STEP"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"CLIP" -> {"STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+/*"CLIP" -> {"ELAGG-"; "FLAGG-"; "INS-"; "PI"; "NNI"; "SINT"}*/
+/*"CLIP" -> {"BOOLEAN"; "URAGG-"}*/
+
+"COORDSYS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COORDSYS"]
+/*"COORDSYS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"COORDSYS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"COORDSYS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"COORDSYS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"COORDSYS" -> {"ENTIRER"; "UFD"; "DIVRING"; "TRANFUN"; "TRIGCAT"}*/
+/*"COORDSYS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
+/*"COORDSYS" -> {"INT"; "PI"; "NNI"}*/
+"COORDSYS" -> "PTCAT"
+/*"COORDSYS" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"COORDSYS" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"COORDSYS" -> {"CLAGG"; "KONVERT"; "ORDSET"}*/
+
+"DBASE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DBASE"]
+/*"DBASE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"}*/
+"DBASE" -> "STRICAT"
+/*"DBASE" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"DBASE" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"DBASE" -> {"CLAGG"; "KONVERT"; "OM"; "INT"; "LIST"; "ILIST"}*/
+/*"DBASE" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "LSAGG"; "STAGG"}*/
+/*"DBASE" -> {"URAGG"; "RCAGG"; "ELAGG"; "NNI"; "SINT"; "PI"}*/
+
+"DHMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DHMATRIX"]
+/*"DHMATRIX" -> {"MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"DHMATRIX" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "FIELD"}*/
+/*"DHMATRIX" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DHMATRIX" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"DHMATRIX" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"DHMATRIX" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "VECTCAT"; "A1AGG"}*/
+/*"DHMATRIX" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"DHMATRIX" -> {"KONVERT"; "ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"DHMATRIX" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "VECTOR"}*/
+"DHMATRIX" -> "IVECTOR"
+/*"DHMATRIX" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"DIOSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DIOSP"]
+/*"DIOSP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"DIOSP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"DIOSP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"DIOSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"DIOSP" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"DIOSP" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"DIOSP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"}*/
+/*"DIOSP" -> {"INT"; "LIST"; "ILIST"; "OAMONS"; "VECTOR"}*/
+"DIOSP" -> "IVECTOR"
+/*"DIOSP" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
+/*"DIOSP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"DIOSP" -> {"BASTYPE-"; "BOOLEAN"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"DIOSP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"DIOSP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "SINT"; "OM"}*/
+
+"DIRPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIRPCAT"]
+/*"DIRPCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DIRPCAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"DIRPCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DIRPCAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"DIRPCAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DIRPCAT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"DIRPCAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"DIRPCAT" -> {"STEP"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"DIRPCAT" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "DIFEXT"; "PDRING"}*/
+/*"DIRPCAT" -> {"FLINEXP"; "FINITE"; "OAMONS"; "VSPACE"; "FIELD"; "DIVRING"}*/
+/*"DIRPCAT" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "CLAGG"; "INT"}*/
+/*"DIRPCAT" -> "VECTOR"*/
+"DIRPCAT" -> "IVECTOR"
+/*"DIRPCAT" -> {"IARRAY1"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"DIRPCAT" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "VECTCAT-"}*/
+/*"DIRPCAT" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"DIRPCAT" -> {"ORDSET-"; "AGG-"}*/
+
+"DIRPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIRPCAT"]
+/*"DIRPCAT-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DIRPCAT-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"DIRPCAT-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DIRPCAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"DIRPCAT-" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"DIRPCAT-" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"DIRPCAT-" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"DIRPCAT-" -> {"REAL"; "CHARZ"; "STEP"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"DIRPCAT-" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"}*/
+/*"DIRPCAT-" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "FINITE"; "OAMONS"; "VSPACE"}*/
+/*"DIRPCAT-" -> {"FIELD"; "DIVRING"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"DIRPCAT-" -> {"CLAGG"; "INT"; "VECTOR"}*/
+"DIRPCAT-" -> "IVECTOR"
+/*"DIRPCAT-" -> {"IARRAY1"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"DIRPCAT-" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "VECTCAT-"}*/
+/*"DIRPCAT-" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"DIRPCAT-" -> "ORDSET-"; "AGG-"}*/
+
+"D02BBFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02BBFA"]
+/*"D02BBFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+/*"D02BBFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"D02BBFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"D02BBFA" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"D02BBFA" -> {"OM"; "LIST"; "ILIST"; "DFLOAT"; "FPS-"; "RNS-"}*/
+/*"D02BBFA" -> {"FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"}*/
+/*"D02BBFA" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "FPS"; "RNS"}*/
+/*"D02BBFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"D02BBFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"D02BBFA" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"D02BBFA" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"D02BBFA" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"D02BBFA" -> {"REAL"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "VECTCAT"}*/
+/*"D02BBFA" -> {"A1AGG"; "VECTOR"}*/
+"D02BBFA" -> "IVECTOR"
+/*"D02BBFA" -> {"IARRAY1"; "PI"}*/
+
+"D02BHFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02BHFA"]
+/*"D02BHFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+/*"D02BHFA" -> {"DFLOAT"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"}*/
+/*"D02BHFA" -> {"GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"D02BHFA" -> {"ORDRING-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"D02BHFA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"D02BHFA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"D02BHFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"D02BHFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"D02BHFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"D02BHFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"D02BHFA" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"D02BHFA" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"}*/
+"D02BHFA" -> "IVECTOR"
+/*"D02BHFA" -> {"IARRAY1"; "PI"}*/
+
+"D02CJFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02CJFA"]
+/*"D02CJFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
+/*"D02CJFA" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"D02CJFA" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"D02CJFA" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
+/*"D02CJFA" -> {"ELAGG"; "OM"; "DFLOAT"; "FPS-"; "RNS-"; "FIELD-"}*/
+/*"D02CJFA" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
+/*"D02CJFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "FPS"; "RNS"; "FIELD"}*/
+/*"D02CJFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"D02CJFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"D02CJFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"D02CJFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"D02CJFA" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"; "RADCAT"}*/
+/*"D02CJFA" -> {"PATMAB"; "CHARZ"; "VECTCAT"; "A1AGG"; "VECTOR"}*/
+"D02CJFA" -> "IVECTOR"
+/*"D02CJFA" -> "IARRAY1"*/
+
+"FAXF" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FAXF"]
+/*"FAXF" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FAXF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FAXF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FAXF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"FAXF" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
+/*"FAXF" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "SINT"; "PI"}*/
+/*"FAXF" -> {"NNI"; "INT"; "VECTOR"}*/
+"FAXF" -> "IVECTOR"
+/*"FAXF" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"FAXF" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"FAXF" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"; "OINTDOM"}*/
+/*"FAXF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "LINEXP"}*/
+/*"FAXF" -> {"PATMAB"; "CFCAT"; "REAL"; "OM"; "BOOLEAN"; "VECTCAT-"}*/
+/*"FAXF" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "LIST"; "ILIST"}*/
+/*"FAXF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "MONOID-"; "ABELMON-"}*/
+/*"FAXF" -> {"ORDSET-"; "SGROUP-"; "INS-"}*/
+
+"FAXF-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAXF"]
+/*"FAXF-" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FAXF-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FAXF-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FAXF-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"FAXF-" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
+/*"FAXF-" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "SINT"; "PI"}*/
+/*"FAXF-" -> {"NNI"; "INT"; "VECTOR"}*/
+"FAXF-" -> "IVECTOR"
+/*"FAXF-" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"FAXF-" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"FAXF-" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"; "OINTDOM"}*/
+/*"FAXF-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "LINEXP"}*/
+/*"FAXF-" -> {"PATMAB"; "CFCAT"; "REAL"; "OM"; "BOOLEAN"; "VECTCAT-"}*/
+/*"FAXF-" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "LIST"; "ILIST"}*/
+/*"FAXF-" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
+/*"FAXF-" -> {"SGROUP-"; "INS-"}*/
+
+"FFPOLY2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFPOLY2"]
+/*"FFPOLY2" -> {"FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFPOLY2" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFPOLY2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFPOLY2" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFPOLY2" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FFIELDC"; "FINITE"}*/
+/*"FFPOLY2" -> {"STEP"; "DIFRING"; "NNI"; "INT"; "PI"; "VECTOR"}*/
+"FFPOLY2" -> "IVECTOR"
+/*"FFPOLY2" -> {"IARRAY1"; "PRIMARR"; "SINT"; "MONOID-"; "ABELMON-"}*/
+
+"FNLA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FNLA"]
+/*"FNLA" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FNLA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"; "MODULE"; "BMODULE"}*/
+/*"FNLA" -> {"LMODULE"; "RMODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"}*/
+/*"FNLA" -> {"MONOID"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"FNLA" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"FNLA" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"; "VECTOR"}*/
+"FNLA" -> "IVECTOR"
+/*"FNLA" -> {"IARRAY1"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "PI"; "NNI"}*/
+
+"GRAY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GRAY"]
+/*"GRAY" -> {"INT"; "VECTOR"}*/
+"GRAY" -> "IVECTOR"
+/*"GRAY" -> {"IARRAY1"; "PI"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"GRAY" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"GRAY" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"GRAY" -> {"CLAGG"; "KONVERT"; "ORDSET"; "SINT"}*/
+
+"HB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=HB"]
+/*"HB" -> {"INT"; "SINT"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"HB" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
+/*"HB" -> {"RING-"; "ABELGRP-"; "BOOLEAN"; "VECTOR"}*/
+"HB" -> "IVECTOR"
+/*"HB" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"HB" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"HB" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"HB" -> {"ORDSET"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+
+"INBFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INBFF"]
+/*"INBFF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"INBFF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"INBFF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"INBFF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"INBFF" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"INBFF" -> {"STEP"; "DIFRING"; "NNI"; "INT"; "LIST"; "VECTOR"}*/
+"INBFF" -> "IVECTOR"
+/*"INBFF" -> {"IARRAY1"; "SINT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"INBFF" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"INBFF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "PI"}*/
+/*"INBFF" -> {"VECTCAT-"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
+/*"INBFF" -> {"A1AGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "BOOLEAN"; "INS-"}*/
+/*"INBFF" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"INBFF" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"INBFF" -> {"ELAGG-"; "FLAGG-"; "URAGG-"}*/
+
+"IRSN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRSN"]
+/*"IRSN" -> {"INT"; "LIST"; "NNI"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"IRSN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"IRSN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"IRSN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"IRSN" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"IRSN" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"IRSN" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"IRSN" -> {"STEP"; "SINT"; "PI"; "OM"; "ILIST"; "LSAGG"}*/
+/*"IRSN" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"IRSN" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"IRSN" -> {"CLAGG"; "FLAGG"; "ELAGG"; "LSAGG-"; "STAGG-"; "BOOLEAN"}*/
+/*"IRSN" -> "VECTOR"*/
+"IRSN" -> "IVECTOR"
+/*"IRSN" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FINITE"; "LOGIC"; "VECTCAT-"}*/
+/*"IRSN" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"IRSN" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+
+"LOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LOP"]
+/*"LOP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"LOP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"LOP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"LOP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"LOP" -> {"PACPERC"; "INT"; "LIST"; "ILIST"; "VECTOR"}*/
+"LOP" -> "IVECTOR"
+/*"LOP" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
+/*"LOP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"LOP" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"LOP" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "LSAGG-"}*/
+/*"LOP" -> {"BOOLEAN"; "STAGG-"; "NNI"; "SINT"}*/
+
+"MCALCFN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MCALCFN"]
+/*"MCALCFN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PDRING"; "RING"; "RNG"}*/
+/*"MCALCFN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"MCALCFN" -> {"LMODULE"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"MCALCFN" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"MCALCFN" -> {"KONVERT"; "ORDSET"; "INT"; "VECTOR"; "LSAGG"; "STAGG"}*/
+/*"MCALCFN" -> {"URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
+/*"MCALCFN" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"MCALCFN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"MCALCFN" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"MCALCFN" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"MCALCFN" -> {"REAL"; "CHARZ"; "STEP"}*/
+"MCALCFN" -> "IVECTOR"
+/*"MCALCFN" -> {"IARRAY1"; "NNI"; "SINT"; "PI"; "LSAGG-"; "STAGG-"}*/
+
+"MHROWRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MHROWRED"]
+/*"MHROWRED" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"MHROWRED" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"MHROWRED" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MHROWRED" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"MHROWRED" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"MHROWRED" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"MHROWRED" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "VECTOR"}*/
+"MHROWRED" -> "IVECTOR"
+/*"MHROWRED" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "BOOLEAN"; "INS"; "UFD"}*/
+/*"MHROWRED" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"MHROWRED" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"MHROWRED" -> {"CHARZ"; "STEP"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"MHROWRED" -> {"RCAGG"; "ELAGG"; "LIST"; "ILIST"; "SINT"; "NNI"}*/
+/*"MHROWRED" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "INS-"; "PI"; "FIELD"}*/
+/*"MHROWRED" -> "DIVRING"*/
+
+"NUMODE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMODE"]
+/*"NUMODE" -> {"NNI"; "INT"; "VECTOR"}*/
+"NUMODE" -> "IVECTOR"
+/*"NUMODE" -> {"IARRAY1"; "PI"; "SINT"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"NUMODE" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"NUMODE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"NUMODE" -> {"CLAGG"; "KONVERT"; "ORDSET"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"NUMODE" -> {"RCAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"NUMODE" -> {"STAGG-"; "VECTCAT-"; "A1AGG-"}*/
+
+"NUMQUAD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMQUAD"]
+/*"NUMQUAD" -> "NNI"*/
+/*"NUMQUAD" -> {"PI"; "BOOLEAN"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"NUMQUAD" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"NUMQUAD" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"NUMQUAD" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"NUMQUAD" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "VECTOR"}*/
+"NUMQUAD" -> "IVECTOR"
+/*"NUMQUAD" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"NUMQUAD" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"NUMQUAD" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "VECTCAT-"}*/
+/*"NUMQUAD" -> "A1AGG-"*/
+
+"ODESYS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODESYS"]
+/*"ODESYS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODESYS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODESYS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ODESYS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ODESYS" -> {"UFD"; "DIVRING"; "LODOCAT"; "OREPCAT"; "FRETRCT"; "RETRACT"}*/
+/*"ODESYS" -> {"ELTAB"; "INT"; "LIST"; "ILIST"; "NNI"; "VECTOR"}*/
+"ODESYS" -> "IVECTOR"
+/*"ODESYS" -> {"IARRAY1"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"ODESYS" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"ODESYS" -> {"ELTAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"ODESYS" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"ODESYS" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "VECTCAT"; "A1AGG"}*/
+/*"ODESYS" -> {"SINT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ODESYS" -> {"OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"ODESYS" -> {"REAL"; "CHARZ"; "STEP"; "BOOLEAN"; "VECTCAT-"; "A1AGG-"}*/
+
+"ODETOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODETOOLS"]
+/*"ODETOOLS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODETOOLS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODETOOLS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ODETOOLS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ODETOOLS" -> {"ENTIRER"; "UFD"; "DIVRING"; "LODOCAT"; "OREPCAT"}*/
+/*"ODETOOLS" -> {"FRETRCT"; "RETRACT"; "ELTAB"; "LSAGG"; "STAGG"}*/
+/*"ODETOOLS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"ODETOOLS" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
+/*"ODETOOLS" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"ODETOOLS" -> {"ILIST"; "VECTOR"; "VECTCAT"; "A1AGG"}*/
+"ODETOOLS" -> "IVECTOR"
+/*"ODETOOLS" -> {"IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"ODETOOLS" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "PATMAB"}*/
+/*"ODETOOLS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"ORDFUNS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ORDFUNS"]
+/*"ORDFUNS" -> {"OAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+/*"ORDFUNS" -> {"KOERCE"; "ABELMON"; "ABELSG"; "SINT"; "NNI"; "INT"}*/
+/*"ORDFUNS" -> "VECTOR"*/
+"ORDFUNS" -> "IVECTOR"
+/*"ORDFUNS" -> {"IARRAY1"; "BOOLEAN"}*/
+
+"PERMAN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PERMAN"]
+/*"PERMAN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PERMAN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PERMAN" -> {"LMODULE"; "INT"; "VECTOR"}*/
+"PERMAN" -> "IVECTOR"
+/*"PERMAN" -> {"IARRAY1"; "PI"; "NNI"; "BOOLEAN"; "SINT"; "VECTCAT"}*/
+/*"PERMAN" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PERMAN" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"PERMAN" -> {"ORDSET"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
+/*"PERMAN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"}*/
+
+"PFECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PFECAT"]
+/*"PFECAT" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PFECAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PFECAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PFECAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PFECAT" -> {"CHARNZ"; "INT"; "VECTOR"}*/
+"PFECAT" -> "IVECTOR"
+/*"PFECAT" -> {"IARRAY1"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+
+"PFECAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PFECAT"]
+/*"PFECAT-" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"-"; "RNG"}*/
+/*"PFECAT-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PFECAT-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PFECAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PFECAT-" -> {"CHARNZ"; "INT"; "VECTOR"}*/
+"PFECAT-" -> "IVECTOR"
+/*"PFECAT-" -> {"IARRAY1"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+
+"POINT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=POINT"]
+"POINT" -> "PTCAT"
+/*"POINT" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"POINT" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"POINT" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"POINT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"POINT" -> {"SGROUP"; "MONOID"; "LMODULE"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"POINT" -> {"RCAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+/*"POINT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"POINT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"POINT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"POINT" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"POINT" -> {"CHARZ"; "STEP"; "NNI"; "PI"; "RADCAT"}*/
+
+"PSEUDLIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PSEUDLIN"]
+/*"PSEUDLIN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PSEUDLIN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PSEUDLIN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PSEUDLIN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PSEUDLIN" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"}*/
+/*"PSEUDLIN" -> {"ILIST"; "BOOLEAN"; "NNI"; "VECTOR"}*/
+"PSEUDLIN" -> "IVECTOR"
+/*"PSEUDLIN" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"PSEUDLIN" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PSEUDLIN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "SINT"}*/
+
+"PTPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PTPACK"]
+/*"PTPACK" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PTPACK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PTPACK" -> {"LMODULE"; "INT"}*/
+"PTPACK" -> "PTCAT"
+/*"PTPACK" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"PTPACK" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"PTPACK" -> {"CLAGG"; "KONVERT"; "ORDSET"; "NNI"}*/
+
+"REP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REP2"]
+/*"REP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"REP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"REP2" -> {"SINT"; "NNI"; "INT"; "PI"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"REP2" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"REP2" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"}*/
+"REP2" -> "IVECTOR"
+/*"REP2" -> {"IARRAY1"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"REP2" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "EUCDOM"}*/
+/*"REP2" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
+/*"REP2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "VECTCAT-"; "A1AGG-"; "FLAGG-"}*/
+/*"REP2" -> {"LNAGG-"; "IXAGG-"; "INS"; "UFD"; "OINTDOM"; "ORDRING"}*/
+/*"REP2" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"REP2" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"REP2" -> {"ELAGG-"; "URAGG-"; "FIELD"; "DIVRING"; "MATCAT"; "ARR2CAT"}*/
+/*"REP2" -> "FINITE"*/
+
+"SETMN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SETMN"]
+/*"SETMN" -> {"FINITE"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "VECTOR"}*/
+"SETMN" -> "IVECTOR"
+/*"SETMN" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
+/*"SETMN" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"SETMN" -> {"BASTYPE-"; "NNI"; "PI"; "SINT"; "LIST"; "ILIST"}*/
+/*"SETMN" -> {"BOOLEAN"; "BTAGG"; "ORDSET"; "LOGIC"; "A1AGG"; "FLAGG"}*/
+/*"SETMN" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"SETMN" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "LSAGG"}*/
+/*"SETMN" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
+
+"SEX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEX"]
+/*"SEX" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
+/*"SEX" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SEX" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"SEX" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"SEX" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SEX" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"SEX" -> {"REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"; "FIELD"}*/
+/*"SEX" -> {"DIVRING"; "RADCAT"; "SEXCAT"}*/
+"SEX" -> "STRICAT"
+/*"SEX" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"SEX" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"SEX" -> {"CLAGG"; "OM"}*/
+
+"STRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STRING"]
+"STRING" -> "STRICAT"
+/*"STRING" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"STRING" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"STRING" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"STRING" -> {"OM"; "INT"; "ORDFIN"; "FINITE"; "INS"; "UFD"}*/
+/*"STRING" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"STRING" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"STRING" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"STRING" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"STRING" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"STRING" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"SYMBOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMBOL",
+          shape=ellipse]
+/*"SYMBOL" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "OM"}*/
+/*"SYMBOL" -> {"PATMAB"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"SYMBOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SYMBOL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SYMBOL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"SYMBOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SYMBOL" -> {"DIFRING"; "RETRACT"; "LINEXP"; "CFCAT"; "REAL"}*/
+/*"SYMBOL" -> {"CHARZ"; "STEP"; "FPS"; "RNS"; "FIELD"; "DIVRING"}*/
+/*"SYMBOL" -> {"RADCAT"; "INT"; "PRIMARR"; "A1AGG-"; "SYMBOL"; "REF"}*/
+/*"SYMBOL" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"SYMBOL" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+"SYMBOL" -> "STRICAT"
+/*"SYMBOL" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"SYMBOL" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"SYMBOL" -> {"CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+/*"SYMBOL" -> {"ILIST"; "NNI"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ORDFIN"}*/
+/*"SYMBOL" -> {"FINITE"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"SYMBOL" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"SYMBOL" -> "BASTYPE-"*/
+
+"SYMFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SYMFUNC"]
+/*"SYMFUNC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SYMFUNC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"SYMFUNC" -> {"PI"; "NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"SYMFUNC" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"SYMFUNC" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"SYMFUNC" -> {"ORDSET"; "ELAGG"; "OM"; "LIST"; "ILIST"; "INS"}*/
+/*"SYMFUNC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
+/*"SYMFUNC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"SYMFUNC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SYMFUNC" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"SYMFUNC" -> {"CHARZ"; "STEP"; "VECTOR"}*/
+"SYMFUNC" -> "IVECTOR"
+/*"SYMFUNC" -> {"IARRAY1"; "SINT"; "VECTCAT"; "A1AGG"; "MONOID-"}*/
+/*"SYMFUNC" -> {"ABELMON-"; "VECTCAT-"; "A1AGG-"}*/
+
+"UPOLYC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPOLYC",
+          shape=ellipse]
+/*"UPOLYC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UPOLYC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UPOLYC" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"UPOLYC" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"UPOLYC" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"UPOLYC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"UPOLYC" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
+/*"UPOLYC" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+/*"UPOLYC" -> {"NNI"; "INT"; "LIST"; "ILIST"; "VECTOR"}*/
+"UPOLYC" -> "IVECTOR"
+/*"UPOLYC" -> {"IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"UPOLYC" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "VECTCAT"}*/
+/*"UPOLYC" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"UPOLYC" -> {"TYPE"; "ELTAGG"; "CLAGG"; "PI"; "BOOLEAN"}*/
+
+"UPOLYC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPOLYC",
+          shape=ellipse]
+/*"UPOLYC-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UPOLYC-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"UPOLYC-" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"UPOLYC-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"UPOLYC-" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"UPOLYC-" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"UPOLYC-" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
+/*"UPOLYC-" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"UPOLYC-" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "NNI"; "INT"}*/
+/*"UPOLYC-" -> {"LIST"; "ILIST"; "VECTOR"}*/
+"UPOLYC-" -> "IVECTOR"
+/*"UPOLYC-" -> {"IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"UPOLYC-" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"}*/
+/*"UPOLYC-" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"UPOLYC-" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "PI"; "BOOLEAN"}*/
+
+"VECTOR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=VECTOR2"]
+/*"VECTOR2" -> {"TYPE"; "TYPE"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"VECTOR2" -> {"IXAGG"; "HOAGG"; "AGG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"VECTOR2" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"VECTOR2" -> {"ORDSET"; "INT"; "VECTOR"}*/
+"VECTOR2" -> "IVECTOR"
+/*"VECTOR2" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"VECTOR2" -> {"IXAGG-"; "LIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"VECTOR2" -> {"ELAGG"; "OM"; "ILIST"}*/
+
+\end{chunk}
+\subsection{Layer11}
+Depends on: DIRPCAT FAXF PFECAT STRING LOP\\
+Used by next layer: DIOPS DPOLCAT FINRALG FRAC RMATCAT RRCC UPXSCAT
+\begin{chunk}{layer11}
+
+LAYER11=\
+  ${OUT}/ASP1.o     ${OUT}/ASP10.o    ${OUT}/ASP24.o    ${OUT}/ASP4.o     \
+  ${OUT}/ASP50.o    ${OUT}/ASP6.o     ${OUT}/ASP73.o    ${OUT}/AXSERV.o   \
+  ${OUT}/BALFACT.o  ${OUT}/BEZOUT.o   ${OUT}/BINARY.o   ${OUT}/BINFILE.o  \
+  ${OUT}/BOUNDZRO.o ${OUT}/BPADICRT.o ${OUT}/BRILL.o    ${OUT}/CDEN.o     \
+  ${OUT}/CHVAR.o    ${OUT}/COMMUPC.o  ${OUT}/CONTFRAC.o ${OUT}/CVMP.o     \
+  ${OUT}/CYCLOTOM.o ${OUT}/CYCLES.o   ${OUT}/DDFACT.o   ${OUT}/DECIMAL.o  \
+  ${OUT}/DIOPS.o    ${OUT}/DIOPS-.o   ${OUT}/DIRPROD.o  ${OUT}/DISPLAY.o  \
+  ${OUT}/DMP.o      ${OUT}/DPMO.o     ${OUT}/DPOLCAT.o  ${OUT}/DPOLCAT-.o \
+  ${OUT}/DSTREE.o   \
+  ${OUT}/D01AJFA.o  ${OUT}/D01AKFA.o  ${OUT}/D01ALFA.o  ${OUT}/D01AMFA.o  \
+  ${OUT}/D01APFA.o  ${OUT}/D01AQFA.o  ${OUT}/EMR.o      ${OUT}/EQ.o       \
+  ${OUT}/ERROR.o    ${OUT}/EVALCYC.o  ${OUT}/EXP3D.o    \
+  ${OUT}/E04DGFA.o  ${OUT}/E04FDFA.o  \
+  ${OUT}/E04GCFA.o  ${OUT}/E04JAFA.o  ${OUT}/E04UCFA.o  ${OUT}/FACUTIL.o  \
+  ${OUT}/FF.o       ${OUT}/FFFACTOR.o  \
+  ${OUT}/FFCG.o     ${OUT}/FFCGX.o    ${OUT}/FFFG.o     \
+  ${OUT}/FFFGF.o    ${OUT}/FFHOM.o    ${OUT}/FFNB.o     ${OUT}/FFNBX.o    \
+  ${OUT}/FFPOLY.o   ${OUT}/FFSQFR.o  \
+  ${OUT}/FFX.o      ${OUT}/FFSLPE.o   ${OUT}/FGLMICPK.o \
+  ${OUT}/FILE.o     ${OUT}/FINAALG.o  ${OUT}/FINAALG-.o ${OUT}/FINRALG.o  \
+  ${OUT}/FINRALG-.o ${OUT}/FFF.o      ${OUT}/FLOATRP.o  ${OUT}/FNAME.o    \
+  ${OUT}/FOP.o      ${OUT}/FORMULA.o  ${OUT}/FORT.o     ${OUT}/FRAC.o     \
+  ${OUT}/FTEM.o     ${OUT}/GENEEZ.o   ${OUT}/GENMFACT.o ${OUT}/GENPGCD.o  \
+  ${OUT}/GALFACTU.o ${OUT}/GALPOLYU.o ${OUT}/GB.o       ${OUT}/GBEUCLID.o \
+  ${OUT}/GBF.o      ${OUT}/GBINTERN.o ${OUT}/GHENSEL.o  ${OUT}/GMODPOL.o  \
+  ${OUT}/GOSPER.o   ${OUT}/GRIMAGE.o  ${OUT}/GROEBSOL.o ${OUT}/HDMP.o     \
+  ${OUT}/HDP.o      ${OUT}/HEXADEC.o  ${OUT}/HEUGCD.o   ${OUT}/HTMLFORM.o \
+  ${OUT}/IBPTOOLS.o \
+  ${OUT}/IFF.o      ${OUT}/IBITS.o    ${OUT}/ICARD.o    ${OUT}/ICDEN.o    \
+  ${OUT}/IDECOMP.o  ${OUT}/IIARRAY2.o ${OUT}/IMATLIN.o  ${OUT}/IMATQF.o   \
+  ${OUT}/INMODGCD.o ${OUT}/INNMFACT.o ${OUT}/INPSIGN.o  ${OUT}/INTERGB.o  \
+  ${OUT}/INTHERTR.o \
+  ${OUT}/INTRAT.o   ${OUT}/INTRF.o    ${OUT}/INTSLPE.o  ${OUT}/INTTR.o    \
+  ${OUT}/ISUMP.o    ${OUT}/LAUPOL.o   ${OUT}/LEADCDET.o ${OUT}/LGROBP.o   \
+  ${OUT}/LIMITRF.o  ${OUT}/LINDEP.o   ${OUT}/LISYSER.o  \
+  ${OUT}/LO.o       ${OUT}/LPEFRAC.o  \
+  ${OUT}/LSPP.o     ${OUT}/MATLIN.o   ${OUT}/MCDEN.o    ${OUT}/MDDFACT.o  \
+  ${OUT}/MFINFACT.o ${OUT}/MFLOAT.o   ${OUT}/MINT.o     ${OUT}/MLIFT.o    \
+  ${OUT}/MMAP.o     ${OUT}/MODMON.o   ${OUT}/MONOTOOL.o ${OUT}/MPCPF.o    \
+  ${OUT}/MPC2.o     ${OUT}/MPC3.o     ${OUT}/MPOLY.o    ${OUT}/MPRFF.o    \
+  ${OUT}/MRATFAC.o  ${OUT}/MULTSQFR.o ${OUT}/NORMRETR.o ${OUT}/NPCOEF.o   \
+  ${OUT}/NSUP.o     ${OUT}/NTPOLFN.o  ${OUT}/ODP.o      ${OUT}/ODEPRIM.o  \
+  ${OUT}/ODEPRRIC.o ${OUT}/OMPKG.o    ${OUT}/OMSERVER.o ${OUT}/PACRATC.o  \
+  ${OUT}/PADEPAC.o   \
+  ${OUT}/PADICRAT.o ${OUT}/PADICRC.o  ${OUT}/PARAMP.o \
+  ${OUT}/PCOMP.o    ${OUT}/PDECOMP.o  \
+  ${OUT}/PF.o       ${OUT}/PFBR.o     ${OUT}/PFBRU.o    ${OUT}/PFORP.o    \
+  ${OUT}/PFOTOOLS.o \
+  ${OUT}/PFRPAC.o   ${OUT}/PGCD.o     ${OUT}/PINTERPA.o ${OUT}/PLEQN.o    \
+  ${OUT}/PLPKCRV.o  \
+  ${OUT}/PMPLCAT.o  ${OUT}/PMQFCAT.o  ${OUT}/PNTHEORY.o ${OUT}/POLUTIL.o  \
+  ${OUT}/POLTOPOL.o ${OUT}/POLYCATQ.o ${OUT}/POLYLIFT.o ${OUT}/POLYROOT.o \
+  ${OUT}/POLY2.o    ${OUT}/POLY2UP.o  ${OUT}/PRS.o      ${OUT}/PSQFR.o    \
+  ${OUT}/PUSHVAR.o  ${OUT}/QALGSET.o  ${OUT}/QFCAT2.o   ${OUT}/RADIX.o    \
+  ${OUT}/RATFACT.o  ${OUT}/RCFIELD.o  ${OUT}/RCFIELD-.o ${OUT}/RDETR.o    \
+  ${OUT}/RDETRS.o   ${OUT}/REAL0.o    ${OUT}/REAL0Q.o   ${OUT}/REALSOLV.o \
+  ${OUT}/RESRING.o  ${OUT}/RETSOL.o   ${OUT}/RF.o       ${OUT}/RFFACTOR.o \
+  ${OUT}/RINTERP.o  ${OUT}/RMATCAT.o  ${OUT}/RMATCAT-.o ${OUT}/RRCC.o     \
+  ${OUT}/RRCC-.o    ${OUT}/SCPKG.o    ${OUT}/SHDP.o     ${OUT}/SHP.o      \
+  ${OUT}/SIGNRF.o   ${OUT}/SMITH.o    ${OUT}/SMP.o      ${OUT}/SMTS.o     \
+  ${OUT}/SOLVEFOR.o ${OUT}/SPLTREE.o  ${OUT}/STINPROD.o ${OUT}/STTF.o     \
+  ${OUT}/STTFNC.o   ${OUT}/SUBRESP.o  ${OUT}/SUBSPACE.o ${OUT}/SUMRF.o    \
+  ${OUT}/SUP.o      ${OUT}/SUPEXPR.o  ${OUT}/SUPFRACF.o ${OUT}/TANEXP.o   \
+  ${OUT}/TEMUTL.o   ${OUT}/TEX.o      ${OUT}/TEXTFILE.o ${OUT}/TREE.o     \
+  ${OUT}/TWOFACT.o  ${OUT}/UNIFACT.o  ${OUT}/UP.o       ${OUT}/UPCDEN.o   \
+  ${OUT}/UPDECOMP.o ${OUT}/UPDIVP.o   ${OUT}/UPMP.o     ${OUT}/UPOLYC2.o  \
+  ${OUT}/UPXSCAT.o  ${OUT}/UPSQFREE.o ${OUT}/VIEWDEF.o  ${OUT}/VIEW2D.o   \
+  ${OUT}/VOID.o     ${OUT}/WEIER.o    ${OUT}/WP.o \
+  layer11done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 11 */
+/* depends on: DIRPCAT FAXF PFECAT STRING */
+
+"ASP1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP1"]
+/*"ASP1" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"; "FIELD"}*/
+/*"ASP1" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"ASP1" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"ASP1" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ASP1" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"ASP1" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"ASP1" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "FMTC"}*/
+/*"ASP1" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+/*"ASP1" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"ASP1" -> {"EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"ASP1" -> "PFECAT"
+
+"ASP10" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP10"]
+/*"ASP10" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"ASP10" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP10" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP10" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP10" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"ASP10" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ASP10" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"ASP10" -> {"FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
+/*"ASP10" -> {"STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP10" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"ASP10" -> "PFECAT"
+/*"ASP10" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"ASP10" -> {"AGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "VECTOR"; "IVECTOR"}*/
+/*"ASP10" -> {"IARRAY1"; "NNI"; "PI"}*/
+
+"ASP24" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP24"]
+/*"ASP24" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
+/*"ASP24" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP24" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP24" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP24" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"ASP24" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ASP24" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"ASP24" -> {"FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
+/*"ASP24" -> {"STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP24" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"ASP24" -> "PFECAT"
+
+"ASP4" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP4"]
+/*"ASP4" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
+/*"ASP4" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP4" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP4" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP4" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP4" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP4" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP4" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP4" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"ASP4" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"ASP4" -> "PFECAT"
+
+"ASP50" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP50"]
+/*"ASP50" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
+/*"ASP50" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP50" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP50" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP50" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ASP50" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ASP50" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
+/*"ASP50" -> {"PATMAB"; "CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"ASP50" -> {"LINEXP"; "CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"ASP50" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"ASP50" -> "PFECAT"
+
+"ASP6" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP6"]
+/*"ASP6" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
+/*"ASP6" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP6" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP6" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP6" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP6" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP6" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP6" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP6" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"ASP6" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"ASP6" -> "PFECAT"
+
+"ASP73" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP73"]
+/*"ASP73" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"ASP73" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP73" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP73" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP73" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP73" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ASP73" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
+/*"ASP73" -> {"PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP73" -> {"CFCAT"; "STEP"; "OM"; "INT"; "VECTOR"; "IVECTOR"}*/
+/*"ASP73" -> {"IARRAY1"; "PI"; "NNI"; "FMTC"; "POLYCAT"; "PDRING"}*/
+/*"ASP73" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
+/*"ASP73" -> "FLINEXP"*/
+"ASP73" -> "PFECAT"
+
+"AXSERV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AXSERV"]
+"AXSERV" -> "STRING"
+/*"AXSERV" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"AXSERV" -> {"A1AGG-"; "ISTRING"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"AXSERV" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"AXSERV" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"AXSERV" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"AXSERV" -> {"OM"; "ILIST"; "NNI"; "SRAGG-"; "LSAGG-"; "STAGG-"}*/
+/*"AXSERV" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "PI"; "STRICAT"; "SRAGG"}*/
+/*"AXSERV" -> {"A1AGG"; "ORDFIN"; "FINITE"}*/
+
+"BALFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BALFACT"]
+/*"BALFACT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"BALFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"BALFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"BALFACT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
+/*"BALFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"BALFACT" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"BALFACT" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"BALFACT" -> "PFECAT"
+/*"BALFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"BALFACT" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "LIST"; "ILIST"}*/
+/*"BALFACT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"BALFACT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
+/*"BALFACT" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+
+"BEZOUT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BEZOUT"]
+/*"BEZOUT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"BEZOUT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"BEZOUT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"BEZOUT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"BEZOUT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"BEZOUT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"BEZOUT" -> {"PATMAB"; "GCDDOM"}*/
+"BEZOUT" -> "PFECAT"
+/*"BEZOUT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"BEZOUT" -> {"PID"; "FIELD"; "DIVRING"; "MATCAT"; "ARR2CAT"; "HOAGG"}*/
+/*"BEZOUT" -> {"AGG"; "TYPE"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"BEZOUT" -> {"NNI"; "INT"; "BOOLEAN"; "SINT"; "PI"}*/
+
+"BINARY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BINARY"]
+/*"BINARY" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"BINARY" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"BINARY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"BINARY" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"BINARY" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
+/*"BINARY" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
+/*"BINARY" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"}*/
+/*"BINARY" -> {"FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"}*/
+/*"BINARY" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"BINARY" -> {"CHARZ"; "CHARNZ"}*/
+"BINARY" -> "PFECAT"
+/*"BINARY" -> {"INS"; "CFCAT"; "OM"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
+/*"BINARY" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
+
+"BINFILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BINFILE"]
+/*"BINFILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"; "INS"}*/
+/*"BINFILE" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"BINFILE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"BINFILE" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"BINFILE" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"BINFILE" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"BINFILE" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"BINFILE" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+"BINFILE" -> "STRING"
+/*"BINFILE" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"BINFILE" -> {"A1AGG-"; "ISTRING"}*/
+
+"BOUNDZRO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BOUNDZRO"]
+/*"BOUNDZRO" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"BOUNDZRO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"BOUNDZRO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"BOUNDZRO" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"BOUNDZRO" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "UPOLYC"}*/
+/*"BOUNDZRO" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"BOUNDZRO" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"BOUNDZRO" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
+"BOUNDZRO" -> "PFECAT"
+/*"BOUNDZRO" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INS"; "OINTDOM"}*/
+/*"BOUNDZRO" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
+/*"BOUNDZRO" -> {"REAL"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"BOUNDZRO" -> {"INT"; "ES"; "OM"}*/
+
+"BPADICRT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BPADICRT"]
+/*"BPADICRT" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"BPADICRT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"BPADICRT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"BPADICRT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"BPADICRT" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"}*/
+/*"BPADICRT" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"BPADICRT" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"BPADICRT" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
+/*"BPADICRT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"BPADICRT" -> {"CHARZ"; "CHARNZ"}*/
+"BPADICRT" -> "PFECAT"
+/*"BPADICRT" -> {"PADICCT"; "FPS"; "RNS"; "RADCAT"; "INS"; "CFCAT"}*/
+/*"BPADICRT" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
+
+"BRILL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BRILL"]
+/*"BRILL" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"BRILL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"BRILL" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"BRILL" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"BRILL" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"BRILL" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"BRILL" -> "GCDDOM"*/
+"BRILL" -> "PFECAT"
+/*"BRILL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"BRILL" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "BOOLEAN"}*/
+/*"BRILL" -> {"INS-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"BRILL" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "FPS"; "RNS"; "RADCAT"}*/
+/*"BRILL" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"BRILL" -> {"ELEMFUN"; "PI"}*/
+
+"CDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CDEN"]
+/*"CDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"CDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"CDEN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"CDEN" -> {"MODULE"; "ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"CDEN" -> {"GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
+/*"CDEN" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"CDEN" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"CDEN" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
+/*"CDEN" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"CDEN" -> {"CHARZ"; "CHARNZ"}*/
+"CDEN" -> "PFECAT"
+/*"CDEN" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
+
+"CHVAR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CHVAR"]
+/*"CHVAR" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"CHVAR" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"CHVAR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CHVAR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"CHVAR" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"CHVAR" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"CHVAR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"CHVAR" -> "PFECAT"
+/*"CHVAR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"CHVAR" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "BOOLEAN"; "PI"; "INS"}*/
+/*"CHVAR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"CHVAR" -> {"CFCAT"; "REAL"; "OM"; "QFCAT"; "FEVALAB"; "PATAB"}*/
+/*"CHVAR" -> {"FPATMAB"; "TYPE"; "SINT"}*/
+
+"COMMUPC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMMUPC"]
+/*"COMMUPC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"COMMUPC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"COMMUPC" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"COMMUPC" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"COMMUPC" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"COMMUPC" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"COMMUPC" -> {"PATMAB"; "GCDDOM"}*/
+"COMMUPC" -> "PFECAT"
+/*"COMMUPC" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"COMMUPC" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"}*/
+
+"CONTFRAC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CONTFRAC"]
+/*"CONTFRAC" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"CONTFRAC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"CONTFRAC" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"}*/
+/*"CONTFRAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
+/*"CONTFRAC" -> {"UFD"; "DIVRING"; "QFCAT"; "RETRACT"; "FEVALAB"; "ELTAB"}*/
+/*"CONTFRAC" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"CONTFRAC" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"CONTFRAC" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"CONTFRAC" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"CONTFRAC" -> "PFECAT"
+/*"CONTFRAC" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"}*/
+/*"CONTFRAC" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"CONTFRAC" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
+/*"CONTFRAC" -> {"NNI"; "LSAGG-"; "INS"; "CFCAT"}*/
+
+"CVMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CVMP"]
+/*"CVMP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"CVMP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"CVMP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "POLYCAT"; "PDRING"}*/
+/*"CVMP" -> {"FAMR"; "AMR"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"CVMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"CVMP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"CVMP" -> "PFECAT"
+/*"CVMP" -> {"UFD"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"CVMP" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "VECTCAT"; "A1AGG"}*/
+/*"CVMP" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"CVMP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "LIST"; "ILIST"; "QFCAT"}*/
+/*"CVMP" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"; "DIFEXT"}*/
+/*"CVMP" -> {"DIFRING"; "PATAB"; "FPATMAB"; "STEP"; "OINTDOM"; "ORDRING"}*/
+/*"CVMP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+
+"CYCLOTOM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CYCLOTOM"]
+/*"CYCLOTOM" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"CYCLOTOM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"CYCLOTOM" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CYCLOTOM" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"CYCLOTOM" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"CYCLOTOM" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"CYCLOTOM" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"CYCLOTOM" -> {"STEP"; "INT"; "NNI"; "SINT"; "LIST"; "UPOLYC"}*/
+/*"CYCLOTOM" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"CYCLOTOM" -> {"EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"CYCLOTOM" -> "PFECAT"
+/*"CYCLOTOM" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"}*/
+
+"CYCLES" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CYCLES"]
+/*"CYCLES" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"CYCLES" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"CYCLES" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"CYCLES" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"CYCLES" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"CYCLES" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"CYCLES" -> {"REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"; "DIVRING"}*/
+/*"CYCLES" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"}*/
+/*"CYCLES" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
+"CYCLES" -> "PFECAT"
+/*"CYCLES" -> {"INT"; "INS-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"CYCLES" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"CYCLES" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "SINT"; "NNI"}*/
+/*"CYCLES" -> {"PI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"CYCLES" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "FAMR"; "AMR"; "FRETRCT"}*/
+
+"DDFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DDFACT"]
+/*"DDFACT" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"DDFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DDFACT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DDFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DDFACT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
+/*"DDFACT" -> {"FINITE"; "STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"DDFACT" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"DDFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"DDFACT" -> "PFECAT"
+/*"DDFACT" -> {"ELTAB"; "DIFEXT"; "NNI"; "INT"; "SINT"; "PI"; "LIST"}*/
+/*"DDFACT" -> {"ILIST"; "BOOLEAN"; "MONOID-"; "ABELMON-"; "INS"; "OINTDOM"}*/
+/*"DDFACT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
+/*"DDFACT" -> "REAL"*/
+
+"DECIMAL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DECIMAL"]
+/*"DECIMAL" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"DECIMAL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"DECIMAL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"DECIMAL" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"DECIMAL" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"DECIMAL" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"DECIMAL" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"DECIMAL" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"}*/
+/*"DECIMAL" -> {"ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DECIMAL" -> {"OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"DECIMAL" -> "PFECAT"
+/*"DECIMAL" -> {"INS"; "CFCAT"; "OM"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
+/*"DECIMAL" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
+
+"DIOPS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIOPS"]
+/*"DIOPS" -> {"BGAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"DIOPS" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
+"DIOPS" -> "STRING"
+/*"DIOPS" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"DIOPS" -> {"A1AGG-"; "ISTRING"}*/
+
+"DIOPS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIOPS"]
+/*"DIOPS-" -> {"BGAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"DIOPS-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"DIOPS-" -> "KONVERT"*/
+"DIOPS-" -> "STRING"
+/*"DIOPS-" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"DIOPS-" -> {"A1AGG-"; "ISTRING"}*/
+
+"DIRPROD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIRPROD"]
+"DIRPROD" -> "DIRPCAT"
+/*"DIRPROD" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"DIRPROD" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"DIRPROD" -> {"FRETRCT"; "RETRACT"; "BMODULE"; "LMODULE"; "ABELGRP"}*/
+/*"DIRPROD" -> {"CABMON"; "ABELMON"; "ABELSG"; "RMODULE"; "DIFEXT"}*/
+/*"DIRPROD" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "DIFRING"; "PDRING"}*/
+/*"DIRPROD" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"; "MODULE"}*/
+/*"DIRPROD" -> {"COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"DIRPROD" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"}*/
+/*"DIRPROD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"}*/
+/*"DIRPROD" -> {"DIVRING"; "INS"; "OINTDOM"; "KONVERT"; "PATMAB"; "CFCAT"}*/
+/*"DIRPROD" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "VECTOR"}*/
+/*"DIRPROD" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "SINT"; "NNI"}*/
+/*"DIRPROD" -> {"BOOLEAN"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "CLAGG"}*/
+/*"DIRPROD" -> "PI"*/
+
+"DISPLAY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DISPLAY"]
+/*"DISPLAY" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+"DISPLAY" -> "STRING"
+/*"DISPLAY" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"DISPLAY" -> {"STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"DISPLAY" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DISPLAY" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"DISPLAY" -> {"KONVERT"; "ORDSET"; "OM"}*/
+
+"DIVRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIVRING",
+           shape=ellipse]
+/*"DIVRING" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DIVRING" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"DIVRING" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DIVRING" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"DIVRING" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"DIVRING" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"DIVRING" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"DIVRING" -> {"REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"}*/
+/*"DIVRING" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
+/*"DIVRING" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"DIVRING" -> {"TYPE"; "CHARNZ"}*/
+"DIVRING" -> "PFECAT"
+/*"DIVRING" -> "INT"*/
+
+"DIVRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIVRING",
+           shape=ellipse]
+/*"DIVRING-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"DIVRING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"DIVRING-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"DIVRING-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"DIVRING-" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"DIVRING-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"DIVRING-" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"DIVRING-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"DIVRING-" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
+/*"DIVRING-" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"}*/
+/*"DIVRING-" -> {"PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
+"DIVRING-" -> "PFECAT"
+/*"DIVRING-" -> "INT"*/
+
+"DMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DMP"]
+/*"DMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"DMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"DMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"DMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"DMP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"DMP" -> "GCDDOM"*/
+"DMP" -> "PFECAT"
+/*"DMP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"DMP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"DMP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+"DMP" -> "DIRPCAT"
+/*"DMP" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DMP" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"DMP" -> {"PID"; "DIVRING"; "ORDFIN"; "FPS"; "RNS"; "REAL"; "RADCAT"}*/
+/*"DMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"}*/
+
+"DPMO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DPMO"]
+"DPMO" -> "DIRPCAT"
+/*"DPMO" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"DPMO" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"}*/
+/*"DPMO" -> {"RETRACT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
+/*"DPMO" -> {"ABELMON"; "ABELSG"; "RMODULE"; "DIFEXT"; "RING"}*/
+/*"DPMO" -> {"RNG"; "SGROUP"; "MONOID"; "DIFRING"; "PDRING"; "FLINEXP"}*/
+/*"DPMO" -> {"LINEXP"; "FINITE"; "ALGEBRA"; "MODULE"; "COMRING"}*/
+/*"DPMO" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"DPMO" -> {"ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"DPMO" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"DPMO" -> {"SINT"; "NNI"; "INT"; "INS"; "OINTDOM"; "KONVERT"}*/
+/*"DPMO" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"DPOLCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DPOLCAT"]
+/*"DPOLCAT" -> {"DVARCAT"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DPOLCAT" -> {"RETRACT"; "POLYCAT"; "PDRING"; "RING"; "RNG"}*/
+/*"DPOLCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"DPOLCAT" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"DPOLCAT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"DPOLCAT" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "EVALAB"}*/
+/*"DPOLCAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"DPOLCAT" -> "GCDDOM"*/
+"DPOLCAT" -> "PFECAT"
+/*"DPOLCAT" -> {"UFD"; "DIFEXT"; "DIFRING"; "OAMONS"; "OCAMON"}*/
+/*"DPOLCAT" -> {"OAMON"; "OASGP"; "NNI"; "INT"; "LIST"}*/
+/*"DPOLCAT" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"}*/
+/*"DPOLCAT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"DPOLCAT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"DPOLCAT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "FLAGG-"}*/
+/*"DPOLCAT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"DPOLCAT" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"DPOLCAT" -> {"BASTYPE-"; "SINT"; "INS"; "EUCDOM"; "PID"}*/
+/*"DPOLCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "CFCAT"; "REAL"; "STEP"}*/
+
+"DPOLCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DPOLCAT"]
+/*"DPOLCAT-" -> {"DVARCAT"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DPOLCAT-" -> {"RETRACT"; "POLYCAT"; "PDRING"; "RING"; "RNG"}*/
+/*"DPOLCAT-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"DPOLCAT-" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"DPOLCAT-" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"DPOLCAT-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "EVALAB"}*/
+/*"DPOLCAT-" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"DPOLCAT-" -> "GCDDOM"*/
+"DPOLCAT-" -> "PFECAT"
+/*"DPOLCAT-" -> {"UFD"; "DIFEXT"; "DIFRING"; "OAMONS"; "OCAMON"}*/
+/*"DPOLCAT-" -> {"OAMON"; "OASGP"; "NNI"; "INT"; "LIST"; "ILIST"}*/
+/*"DPOLCAT-" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"; "STAGG"}*/
+/*"DPOLCAT-" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"DPOLCAT-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"DPOLCAT-" -> {"FLAGG"; "ELAGG"; "OM"; "FLAGG-"; "URAGG-"}*/
+/*"DPOLCAT-" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"DPOLCAT-" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"DPOLCAT-" -> {"SINT"; "INS"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"DPOLCAT-" -> {"ORDRING"; "OAGROUP"; "CFCAT"; "REAL"; "STEP"}*/
+
+"DSTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DSTREE"]
+/*"DSTREE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"DSTREE" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"; "ILIST"}*/
+/*"DSTREE" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"DSTREE" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"DSTREE" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "BOOLEAN"}*/
+"DSTREE" -> "STRING"
+/*"DSTREE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+
+"D01AJFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AJFA"]
+/*"D01AJFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "PI"; "NNI"; "INT"}*/
+"D01AJFA" -> "STRING"
+/*"D01AJFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"D01AJFA" -> {"ISTRING"; "SRAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
+/*"D01AJFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"D01AJFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"D01AJFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"D01AJFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"D01AJFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"D01AJFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"; "INS-"; "EUCDOM-"}*/
+/*"D01AJFA" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"D01AJFA" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"D01AKFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AKFA"]
+/*"D01AKFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+"D01AKFA" -> "STRING"
+/*"D01AKFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"D01AKFA" -> {"ISTRING"; "SRAGG-"; "PI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
+/*"D01AKFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"D01AKFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"D01AKFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"D01AKFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"D01AKFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"D01AKFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"; "INS-"; "EUCDOM-"}*/
+/*"D01AKFA" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"D01AKFA" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"D01ALFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01ALFA"]
+/*"D01ALFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "STRICAT"}*/
+/*"D01ALFA" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"D01ALFA" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"D01ALFA" -> {"CLAGG"; "KONVERT"; "ORDSET"; "OM"; "INT"; "LIST"}*/
+/*"D01ALFA" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+/*"D01ALFA" -> {"NNI"; "INS-"}*/
+"D01ALFA" -> "STRING"
+/*"D01ALFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"D01ALFA" -> {"SRAGG-"; "PI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
+/*"D01ALFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"D01ALFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"D01ALFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"D01ALFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"D01ALFA" -> {"OAMON"; "OASGP"; "REAL"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"D01ALFA" -> {"CHARZ"; "DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"D01ALFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"D01ALFA" -> {"DFLOAT"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+/*"D01ALFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"D01ALFA" -> {"ABELGRP-"; "ABELMON-"}*/
+
+"D01AMFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AMFA"]
+/*"D01AMFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+"D01AMFA" -> "STRING"
+/*"D01AMFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"D01AMFA" -> {"ISTRING"; "SRAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
+/*"D01AMFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"D01AMFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"D01AMFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"D01AMFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"D01AMFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"D01AMFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "PI"; "INS-"; "EUCDOM-"}*/
+/*"D01AMFA" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"D01AMFA" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+/*"D01AMFA" -> "DFLOAT"*/
+
+"D01APFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01APFA"]
+/*"D01APFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "DFLOAT"; "INT"}*/
+/*"D01APFA" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "PI"; "NNI"}*/
+"D01APFA" -> "STRING"
+/*"D01APFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"D01APFA" -> {"SRAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"D01APFA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"D01APFA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"D01APFA" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"D01APFA" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"D01APFA" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
+/*"D01APFA" -> {"PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"}*/
+/*"D01APFA" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "ELAGG-"}*/
+/*"D01APFA" -> {"FLAGG-"; "URAGG-"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"D01APFA" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
+/*"D01APFA" -> {"RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"D01AQFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AQFA"]
+/*"D01AQFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"D01AQFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"D01AQFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"D01AQFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"D01AQFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"D01AQFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"D01AQFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"}*/
+/*"D01AQFA" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"D01AQFA" -> {"ELEMFUN"; "SPFCAT"; "INT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"D01AQFA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"D01AQFA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"D01AQFA" -> {"ELAGG"; "LIST"; "ILIST"; "NNI"; "PI"}*/
+"D01AQFA" -> "STRING"
+/*"D01AQFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"D01AQFA" -> {"SRAGG-"; "INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
+/*"D01AQFA" -> {"QFCAT"; "FEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
+/*"D01AQFA" -> {"FPATMAB"; "CHARNZ"}*/
+"D01AQFA" -> "PFECAT"
+/*"D01AQFA" -> {"DFLOAT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+/*"D01AQFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"D01AQFA" -> {"ABELGRP-"; "ABELMON-"}*/
+
+"EMR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EMR"]
+/*"EMR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"EMR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"EMR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"EMR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
+/*"EMR" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"EMR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"EMR" -> {"KONVERT"; "PATMAB"}*/
+"EMR" -> "PFECAT"
+/*"EMR" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
+/*"EMR" -> {"DIVRING"; "INT"; "NNI"; "BOOLEAN"}*/
+
+"EQ" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EQ"]
+/*"EQ" -> {"TYPE"; "IEVALAB"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELSG"}*/
+/*"EQ" -> {"ABELGRP"; "CABMON"; "ABELMON"; "SGROUP"; "MONOID"; "GROUP"}*/
+/*"EQ" -> {"RING"; "RNG"; "LMODULE"; "BMODULE"; "RMODULE"; "MODULE"}*/
+/*"EQ" -> {"PDRING"; "VSPACE"; "COMRING"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"EQ" -> {"GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"EQ" -> {"EVALAB"; "BOOLEAN"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"EQ" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"EQ" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"EQ" -> {"STEP"; "POLYCAT"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
+"EQ" -> "PFECAT"
+/*"EQ" -> "ES"*/
+
+"ERROR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ERROR"]
+/*"ERROR" -> {"INT"; "LIST"}*/
+"ERROR" -> "STRING"
+/*"ERROR" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+
+"EVALCYC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EVALCYC"]
+/*"EVALCYC" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"EVALCYC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"EVALCYC" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "INS"}*/
+/*"EVALCYC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "EUCDOM"}*/
+/*"EVALCYC" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"EVALCYC" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"EVALCYC" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"}*/
+/*"EVALCYC" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
+/*"EVALCYC" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"EVALCYC" -> "CHARNZ"*/
+"EVALCYC" -> "PFECAT"
+
+"EXP3D" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXP3D"]
+"EXP3D" -> "STRING"
+/*"EXP3D" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; }*/
+/*"EXP3D" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"EXP3D" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"EXP3D" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"EXP3D" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"EXP3D" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"EXP3D" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INT"; "LIST"; "ILIST"; "CHAR"}*/
+/*"EXP3D" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "LSAGG"}*/
+/*"EXP3D" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"EXP3D" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"EXP3D" -> {"FLAGG"; "ELAGG"; "OM"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"EXP3D" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"EXP3D" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"EXP3D" -> {"DFLOAT"; "PTCAT"; "VECTCAT"; "A1AGG"; "PI"}*/
+
+"E04DGFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04DGFA"]
+/*"E04DGFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"E04DGFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"E04DGFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"E04DGFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"E04DGFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"E04DGFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"E04DGFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "LSAGG"}*/
+/*"E04DGFA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"E04DGFA" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"E04DGFA" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"E04DGFA" -> {"ILIST"; "NNI"; "INS-"}*/
+"E04DGFA" -> "STRING"
+/*"E04DGFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"E04DGFA" -> {"DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"E04DGFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "DFLOAT"; "MONOID-"; "ABELMON-"}*/
+/*"E04DGFA" -> {"PI"; "BOOLEAN"}*/
+
+"E04FDFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04FDFA"]
+/*"E04FDFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"E04FDFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"E04FDFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"E04FDFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"E04FDFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"E04FDFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"E04FDFA" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"E04FDFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"E04FDFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"E04FDFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
+/*"E04FDFA" -> {"LIST"; "ILIST"; "NNI"; "INS-"}*/
+"E04FDFA" -> "STRING"
+/*"E04FDFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"E04FDFA" -> {"DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"E04FDFA" -> {"ELEMFUN"; "SPFCAT"; "PI"; "VECTOR"; "EUCDOM-"; "UFD-"}*/
+/*"E04FDFA" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"E04FDFA" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"E04GCFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04GCFA"]
+/*"E04GCFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"E04GCFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"E04GCFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"E04GCFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"E04GCFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"E04GCFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"E04GCFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"E04GCFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"E04GCFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"E04GCFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
+/*"E04GCFA" -> {"LIST"; "ILIST"; "NNI"; "INS-"}*/
+"E04GCFA" -> "STRING"
+/*"E04GCFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"E04GCFA" -> {"DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"E04GCFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "PI"; "DFLOAT"; "VECTOR"}*/
+/*"E04GCFA" -> {"MONOID-"; "ABELMON-"}*/
+
+"E04JAFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04JAFA"]
+/*"E04JAFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
+/*"E04JAFA" -> {"ILIST"; "LSAGG-"; "STAGG-"; "FPS"; "RNS"; "FIELD"}*/
+/*"E04JAFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"E04JAFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"E04JAFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"E04JAFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"E04JAFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"E04JAFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "LSAGG"}*/
+/*"E04JAFA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"E04JAFA" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"E04JAFA" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "DIFRING"}*/
+/*"E04JAFA" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"E04JAFA" -> {"SPFCAT"; "INS-"}*/
+"E04JAFA" -> "STRING"
+/*"E04JAFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"E04JAFA" -> {"STRICAT"; "SRAGG"; "A1AGG"; "NNI"; "EUCDOM-"; "UFD-"}*/
+/*"E04JAFA" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"E04JAFA" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "PI"; "DFLOAT"}*/
+
+"E04UCFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04UCFA"]
+/*"E04UCFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"E04UCFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"E04UCFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"E04UCFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"E04UCFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"E04UCFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"E04UCFA" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"E04UCFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"E04UCFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"E04UCFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
+/*"E04UCFA" -> {"LIST"; "ILIST"; "NNI"; "DIFRING"; "TRANFUN"; "TRIGCAT"}*/
+/*"E04UCFA" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "LSAGG-"}*/
+/*"E04UCFA" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "DFLOAT"; "PI"; "MONOID-"}*/
+/*"E04UCFA" -> {"ABELMON-"; "INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
+/*"E04UCFA" -> {"INS-"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"E04UCFA" -> {"FRETRCT"; "FLINEXP"}*/
+"E04UCFA" -> "PFECAT"
+/*"E04UCFA" -> {"QFCAT"; "FEVALAB"; "DIFEXT"; "PATAB"; "FPATMAB"; "VECTOR"}*/
+/*"E04UCFA" -> "BOOLEAN"*/
+
+"FACUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACUTIL"]
+/*"FACUTIL" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"FACUTIL" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
+/*"FACUTIL" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "POLYCAT"}*/
+/*"FACUTIL" -> {"PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"FACUTIL" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"FACUTIL" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"FACUTIL" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"FACUTIL" -> "PFECAT"
+/*"FACUTIL" -> {"UFD"; "NNI"; "INT"; "LIST"; "FFIELDC"; "FPC"; "FIELD"}*/
+/*"FACUTIL" -> {"EUCDOM"; "PID"; "DIVRING"; "FINITE"; "STEP"; "DIFRING"}*/
+/*"FACUTIL" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"FACUTIL" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"FACUTIL" -> {"ABELMON-"; "PI"; "BOOLEAN"}*/
+
+"FF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FF"]
+"FF" -> "FAXF"
+/*"FF" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"FF" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
+/*"FF" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "KONVERT"; "OAMONS"}*/
+/*"FF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"}*/
+/*"FF" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+
+"FFFFACTOR"  [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFFACTOR"]
+/*"FFFACTOR" -> {"FFIELDC", "FPC", "FIELD", "EUCDOM", "PID", "GCDDOM"}*/
+/*"FFFACTOR" -> {"INTDOM", "COMRING", "RING", "RNG", "ABELGRP", "CABMON"}*/
+/*"FFFACTOR" -> {"ABELMON", "ABELSG", "SETCAT", "BASTYPE", "KOERCE","SGROUP"}*/
+/*"FFFACTOR" -> {"MONOID", "LMODULE", "BMODULE", "RMODULE", "ALGEBRA"}*/
+/*"FFFACTOR" -> {"MODULE", "ENTIRER", "UFD", "DIVRING", "CHARNZ", "FINITE"}*/
+/*"FFFACTOR" -> {"STEP", "DIFRING", "UPOLYC", "POLYCAT", "PDRING", "FAMR"}*/
+/*"FFFACTOR" -> {"AMR", "CHARZ", "FRETRCT", "RETRACT", "EVALAB", "IEVALAB"}*/
+/*"FFFACTOR" -> {"FLINEXP", "LINEXP", "ORDSET", "KONVERT", "PATMAB"}*/
+"FFFACTOR" -> "PFECAT"
+/*"FFFACTOR" -> {"ELTAB", "DIFEXT", "NNI", "INT", "PI", "PRIMARR", "A1AGG"}*/
+/*"FFFACTOR" -> {"FLAGG", "LNAGG", "IXAGG", "HOAGG", "AGG", "TYPE", "ELTAGG"}*/
+/*"FFFACTOR" -> {"CLAGG", "BOOLEAN", "SINT", "LIST", "ILIST", "LSAGG-"}*/
+/*"FFFACTOR" -> {"STAGG-", "INS-", "INS", "OINTDOM", "ORDRING", "OAGROUP"}*/
+/*"FFFACTOR" -> {"OCAMON", "OAMON", "OASGP", "CFCAT", "REAL"}*/
+
+"FFCG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCG"]
+"FFCG" -> "FAXF"
+/*"FFCG" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFCG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFCG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFCG" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFCG" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
+/*"FFCG" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
+/*"FFCG" -> {"KONVERT"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"FFCG" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "LINEXP"}*/
+/*"FFCG" -> {"PATMAB"; "CFCAT"; "REAL"}*/
+
+"FFCGX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCGX"]
+"FFCGX" -> "FAXF"
+/*"FFCGX" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FFCGX" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FFCGX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FFCGX" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"FFCGX" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
+/*"FFCGX" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "OAMONS"; "OCAMON"}*/
+/*"FFCGX" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"FFCGX" -> {"OAGROUP"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+
+"FFFG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFG"]
+/*"FFFG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FFFG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FFFG" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FFFG" -> {"MODULE"; "ENTIRER"; "GCDDOM"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"FFFG" -> {"NNI"; "INT"; "SINT"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"FFFG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"FFFG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"FFFG" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"FFFG" -> {"FAMR"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+"FFFG" -> "PFECAT"
+/*"FFFG" -> {"UFD"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
+/*"FFFG" -> {"DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+/*"FFFG" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"FFFG" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"FFFG" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"FFFG" -> {"MONOID-"; "ABELMON-"; "SGROUP-"; "ABELSG-"; "PI"; "OAMONS"}*/
+/*"FFFG" -> {"OCAMON"; "OAMON"; "OASGP"; "VECTCAT-"; "A1AGG-"; "BOOLEAN"}*/
+
+"FFHOM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFHOM"]
+"FFHOM" -> "FAXF"
+/*"FFHOM" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFHOM" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFHOM" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFHOM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFHOM" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
+/*"FFHOM" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
+/*"FFHOM" -> {"NNI"; "INT"; "BOOLEAN"; "SINT"; "PI"; "PRIMARR"}*/
+/*"FFHOM" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"}*/
+/*"FFHOM" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FFHOM" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"FFHOM" -> "ORDSET"*/
+
+"FFNB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFNB"]
+"FFNB" -> "FAXF"
+/*"FFNB" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFNB" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFNB" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFNB" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFNB" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
+/*"FFNB" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
+/*"FFNB" -> {"KONVERT"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"FFNB" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"}*/
+/*"FFNB" -> {"CFCAT"; "REAL"}*/
+
+"FFNBX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFNBX"]
+"FFNBX" -> "FAXF"
+/*"FFNBX" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFNBX" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFNBX" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFNBX" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFNBX" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
+/*"FFNBX" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
+/*"FFNBX" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"}*/
+/*"FFNBX" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "KONVERT"; "LINEXP"}*/
+/*"FFNBX" -> {"PATMAB"; "CFCAT"; "REAL"}*/
+
+"FFPOLY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFPOLY"]
+/*"FFPOLY" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FFPOLY" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FFPOLY" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FFPOLY" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FFPOLY" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"FFPOLY" -> {"STEP"; "DIFRING"; "INT"; "LIST"; "ILIST"; "PI"}*/
+/*"FFPOLY" -> {"NNI"; "PRIMARR"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"FFPOLY" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"FFPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "SINT"; "BOOLEAN"}*/
+/*"FFPOLY" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
+/*"FFPOLY" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"FFPOLY" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
+/*"FFPOLY" -> {"LINEXP"; "PATMAB"}*/
+"FFPOLY" -> "PFECAT"
+/*"FFPOLY" -> {"DIFEXT"; "LSAGG-"; "STAGG-"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
+/*"FFPOLY" -> {"INS-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FFPOLY" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"FFPOLY" -> {"RCAGG"; "ELAGG"; "OM"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
+/*"FFPOLY" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"FFPOLY" -> {"SETCAT-"; "BASTYPE-"}*/
+
+"FFSQFR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFSQFR"]
+/*"FFSQFR" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FFSQFR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FFSQFR" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FFSQFR" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/ 
+/*"FFSQFR" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"FFSQFR" -> {"STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"FFSQFR" -> {"AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"FFSQFR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"FFSQFR" -> "PFECAT" 
+/*"FFSQFR" -> {"ELTAB"; "DIFEXT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"FFSQFR" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "SINT"; "NNI"}*/
+/*"FFSQFR" -> {"INT"; "BOOLEAN"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"FFSQFR" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
+/*"FFSQFR" -> {"RING-"; "ABELGRP-"}*/
+
+"FFX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFX"]
+"FFX" -> "FAXF"
+/*"FFX" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FFX" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FFX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FFX" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FFX" -> {"UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
+/*"FFX" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "OAMONS"; "OCAMON"}*/
+/*"FFX" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"FFX" -> {"OAGROUP"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+
+"FFSLPE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFSLPE"]
+/*"FFSLPE" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FFSLPE" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FFSLPE" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FFSLPE" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FFSLPE" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"FFSLPE" -> {"STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"FFSLPE" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"FFSLPE" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"FFSLPE" -> "PATMAB"*/
+"FFSLPE" -> "PFECAT"
+/*"FFSLPE" -> {"ELTAB"; "DIFEXT"; "NNI"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
+
+"FGLMICPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FGLMICPK"]
+/*"FGLMICPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FGLMICPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FGLMICPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FGLMICPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"}*/
+/*"FGLMICPK" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"FGLMICPK" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"FGLMICPK" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"FGLMICPK" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+"FGLMICPK" -> "DIRPCAT"
+/*"FGLMICPK" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"FGLMICPK" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"}*/
+/*"FGLMICPK" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
+/*"FGLMICPK" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
+/*"FGLMICPK" -> {"ORDFIN"; "BOOLEAN"; "NNI"; "POLYCAT"; "FAMR"}*/
+/*"FGLMICPK" -> {"AMR"; "CHARZ"; "CHARNZ"; "PATMAB"}*/
+"FGLMICPK" -> "PFECAT"
+/*"FGLMICPK" -> {"LSAGG-"; "STAGG-"; "ELAGG-"}*/
+
+"FILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FILE"]
+/*"FILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"}*/
+"FILE" -> "STRING"
+/*"FILE" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"FILE" -> {"A1AGG-"; "ISTRING"}*/
+
+"FINAALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FINAALG"]
+/*"FINAALG" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FINAALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
+/*"FINAALG" -> {"MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "COMRING"}*/
+/*"FINAALG" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "UPOLYC"}*/
+/*"FINAALG" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "ALGEBRA"}*/
+/*"FINAALG" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"FINAALG" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"FINAALG" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"FINAALG" -> "PFECAT"
+/*"FINAALG" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"FINAALG" -> {"PID"; "FIELD"; "DIVRING"; "SINT"; "PI"; "NNI"; "INT"}*/
+/*"FINAALG" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "BOOLEAN"}*/
+"FINAALG" -> "STRING"
+/*"FINAALG" -> {"CHAR"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"FINAALG" -> {"SRAGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FINAALG" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "ILIST"; "VECTCAT"}*/
+/*"FINAALG" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"FINAALG" -> {"TYPE"; "ELTAGG"; "CLAGG"; "VECTCAT-"; "MONOID-"; "ABELSG-"}*/
+/*"FINAALG" -> "SGROUP-"*/
+
+"FINAALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FINAALG"]
+/*"FINAALG-" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FINAALG-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
+/*"FINAALG-" -> {"MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "COMRING"}*/
+/*"FINAALG-" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "UPOLYC"}*/
+/*"FINAALG-" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "ALGEBRA"}*/
+/*"FINAALG-" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"FINAALG-" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"FINAALG-" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"FINAALG-" -> "PFECAT"
+/*"FINAALG-" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"FINAALG-" -> {"PID"; "FIELD"; "DIVRING"; "SINT"; "PI"; "NNI"}*/
+/*"FINAALG-" -> {"INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "BOOLEAN"}*/
+"FINAALG-" -> "STRING"
+/*"FINAALG-" -> {"CHAR"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"FINAALG-" -> {"ISTRING"; "SRAGG-"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"FINAALG-" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
+/*"FINAALG-" -> {"REAL"; "OM"; "ILIST"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"FINAALG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"FINAALG-" -> {"CLAGG"; "VECTCAT-"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
+
+"FINRALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FINRALG"]
+/*"FINRALG" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FINRALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FINRALG" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "CHARZ"; "CHARNZ"}*/
+/*"FINRALG" -> {"COMRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"FINRALG" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"FINRALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"FINRALG" -> {"PATMAB"; "GCDDOM"}*/
+"FINRALG" -> "PFECAT"
+/*"FINRALG" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"FINRALG" -> {"PID"; "FIELD"; "DIVRING"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"FINRALG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"FINRALG" -> {"CLAGG"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"}*/
+/*"FINRALG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FINRALG" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "SINT"; "PI"; "NNI"}*/
+/*"FINRALG" -> {"VECTCAT-"; "A1AGG-"}*/
+
+"FINRALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FINRALG"]
+/*"FINRALG-" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FINRALG-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FINRALG-" -> {"SGROUP"; "MONOID"; "LMODULE"; "MODULE"; "BMODULE"}*/
+/*"FINRALG-" -> {"RMODULE"; "CHARZ"; "CHARNZ"; "COMRING"; "UPOLYC"}*/
+/*"FINRALG-" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "INTDOM"}*/
+/*"FINRALG-" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"FINRALG-" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"FINRALG-" -> "GCDDOM"*/
+"FINRALG-" -> "PFECAT"
+/*"FINRALG-" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"FINRALG-" -> {"PID"; "FIELD"; "DIVRING"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"FINRALG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"FINRALG-" -> {"CLAGG"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"}*/
+/*"FINRALG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FINRALG-" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "SINT"; "PI"}*/
+/*"FINRALG-" -> {"NNI"; "VECTCAT-"; "A1AGG-"}*/
+
+"FFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFF"]
+/*"FFF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FFF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FFF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FFF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFF" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
+/*"FFF" -> {"DIFRING"; "NNI"; "INT"; "SINT"; "PI"; "INS-"; "INS"; "OINTDOM"}*/
+/*"FFF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"FFF" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"FFF" -> {"CHARZ"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"FFF" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"FFF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"FFF" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"FFF" -> {"ELAGG"; "PRIMARR"; "BOOLEAN"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
+/*"FFF" -> {"SGROUP-"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"FFF" -> {"FRETRCT"; "FLINEXP"}*/
+"FFF" -> "PFECAT"
+/*"FFF" -> "DIFEXT"*/
+
+"FFFGF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFGF"]
+/*"FFFGF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FFFGF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FFFGF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FFFGF" -> {"MODULE"; "ENTIRER"; "GCDDOM"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"FFFGF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"FFFGF" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"FFFGF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"}*/
+/*"FFFGF" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"; "NNI"; "UPOLYC"}*/
+/*"FFFGF" -> {"POLYCAT"; "PDRING"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+"FFFGF" -> "PFECAT"
+/*"FFFGF" -> {"UFD"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
+/*"FFFGF" -> {"DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+/*"FFFGF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "QFCAT"; "FEVALAB"}*/
+/*"FFFGF" -> {"PATAB"; "FPATMAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"}*/
+
+"FLOATRP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLOATRP"]
+/*"FLOATRP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"FLOATRP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
+/*"FLOATRP" -> {"CABMON"; "ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"FLOATRP" -> {"LMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FLOATRP" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FLOATRP" -> {"ENTIRER"; "UFD"; "DIVRING"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"FLOATRP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"FLOATRP" -> {"CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"FLOATRP" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"FLOATRP" -> "PFECAT"
+/*"FLOATRP" -> {"BOOLEAN"; "OM"; "INT"; "LIST"; "ILIST"}*/
+
+"FNAME" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FNAME"]
+/*"FNAME" -> {"FNCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"FNAME" -> "STRING"
+/*"FNAME" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"FNAME" -> {"A1AGG-"; "ISTRING"}*/
+
+"FOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FOP"]
+"FOP" -> "STRING"
+/*"FOP" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
+/*"FOP" -> {"ISTRING"}*/
+
+"FORMULA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FORMULA"]
+/*"FORMULA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"; "LIST"}*/
+"FORMULA" -> "STRING"
+/*"FORMULA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ILIST"}*/
+/*"FORMULA" -> {"LSAGG-"; "STAGG-"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
+/*"FORMULA" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"FORMULA" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"FORMULA" -> {"OM"; "ISTRING"; "PI"; "ELAGG-"; "FLAGG-"; "LSAGG"}*/
+/*"FORMULA" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+
+"FORT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FORT"]
+/*"FORT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FORT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"FORT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"FORT" -> {"ORDSET"; "ELAGG"; "OM"; "STRICAT"; "SRAGG"; "A1AGG"}*/
+/*"FORT" -> {"INT"; "LIST"; "ILIST"}*/
+"FORT" -> "STRING"
+/*"FORT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"FORT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FORT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"FORT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FORT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FORT" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"FORT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"FRAC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRAC"]
+/*"FRAC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FRAC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FRAC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FRAC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FRAC" -> {"UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"FRAC" -> {"IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"FRAC" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"}*/
+/*"FRAC" -> {"ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FRAC" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"FRAC" -> "PFECAT"
+/*"FRAC" -> {"OM"; "INS"; "CFCAT"; "BOOLEAN"; "NNI"; "INT"; "PI"; "SINT"}*/
+/*"FRAC" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"FRAC" -> {"ELTAGG"; "CLAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"; "UPOLYC"}*/
+/*"FRAC" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "LIST"; "ILIST"; "FPS"}*/
+/*"FRAC" -> {"RNS"; "RADCAT"}*/
+
+"FTEM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FTEM"]
+/*"FTEM" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"}*/
+"FTEM" -> "STRING"
+/*"FTEM" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
+/*"FTEM" -> {"ISTRING"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"FTEM" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FTEM" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FTEM" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"FTEM" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"FTEM" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"FTEM" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"FTEM" -> {"STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"FTEM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"FTEM" -> {"ELTAB"; "CLAGG"}*/
+
+"GENEEZ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENEEZ"]
+/*"GENEEZ" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"GENEEZ" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"GENEEZ" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"GENEEZ" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"}*/
+/*"GENEEZ" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"GENEEZ" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"GENEEZ" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"GENEEZ" -> "PFECAT"
+/*"GENEEZ" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
+/*"GENEEZ" -> {"DIVRING"; "NNI"; "INT"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
+/*"GENEEZ" -> {"SGROUP-"; "PI"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"GENEEZ" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "VECTOR"}*/
+/*"GENEEZ" -> {"IVECTOR"; "IARRAY1"; "SINT"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
+/*"GENEEZ" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"GENEEZ" -> {"CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
+/*"GENEEZ" -> {"LIST"; "ILIST"}*/
+
+"GENMFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENMFACT"]
+/*"GENMFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
+/*"GENMFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"GENMFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"GENMFACT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"GENMFACT" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"GENMFACT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"GENMFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"GENMFACT" -> "GCDDOM"*/
+"GENMFACT" -> "PFECAT"
+/*"GENMFACT" -> {"UFD"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"GENMFACT" -> {"DIVRING"; "FINITE"; "STEP"; "DIFRING"}*/
+
+"GENPGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENPGCD"]
+/*"GENPGCD" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"GENPGCD" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+"GENPGCD" -> "PFECAT"
+/*"GENPGCD" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"GENPGCD" -> {"ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"GENPGCD" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
+/*"GENPGCD" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"GENPGCD" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"GENPGCD" -> {"KONVERT"; "PATMAB"; "NNI"; "INT"; "LIST"; "LSAGG"}*/
+/*"GENPGCD" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"GENPGCD" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"GENPGCD" -> {"OM"; "ILIST"; "STEP"; "BOOLEAN"; "PI"; "SINT"; "LSAGG-"}*/
+/*"GENPGCD" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+
+"GALFACTU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALFACTU"]
+/*"GALFACTU" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"GALFACTU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"GALFACTU" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"GALFACTU" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"GALFACTU" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"GALFACTU" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"GALFACTU" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"GALFACTU" -> "PFECAT"
+/*"GALFACTU" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"GALFACTU" -> {"PID"; "FIELD"; "DIVRING"; "FPS"; "RNS"; "ORDRING"}*/
+/*"GALFACTU" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
+/*"GALFACTU" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"GALFACTU" -> {"PI"; "NNI"; "INT"; "MONOID-"; "ABELMON-"; "INS"}*/
+/*"GALFACTU" -> {"OINTDOM"; "CFCAT"; "SINT"; "INS-"}*/
+
+"GALPOLYU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALPOLYU"]
+/*"GALPOLYU" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"GALPOLYU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"GALPOLYU" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"GALPOLYU" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"GALPOLYU" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"GALPOLYU" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"GALPOLYU" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"GALPOLYU" -> "PFECAT"
+/*"GALPOLYU" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"GALPOLYU" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+/*"GALPOLYU" -> {"SINT"; "PI"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"GALPOLYU" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"GALPOLYU" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "VECTOR"; "IVECTOR"}*/
+/*"GALPOLYU" -> "IARRAY1"*/
+
+"GB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GB"]
+/*"GB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"GB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GB" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"GB" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"GB" -> {"ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"GB" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"GB" -> {"KONVERT"; "PATMAB"}*/
+"GB" -> "PFECAT"
+/*"GB" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "INT"; "LIST"}*/
+/*"GB" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"GB" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "BOOLEAN"}*/
+"GB" -> "STRING"
+/*"GB" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"GB" -> {"PI"; "NNI"}*/
+
+"GBEUCLID" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GBEUCLID"]
+/*"GBEUCLID" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"GBEUCLID" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"GBEUCLID" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"GBEUCLID" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"GBEUCLID" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "POLYCAT"}*/
+/*"GBEUCLID" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"GBEUCLID" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"GBEUCLID" -> {"KONVERT"; "PATMAB"}*/
+"GBEUCLID" -> "PFECAT"
+/*"GBEUCLID" -> {"UFD"; "INT"}*/
+"GBEUCLID" -> "STRING"
+/*"GBEUCLID" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"GBEUCLID" -> {"ISTRING"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"GBEUCLID" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"GBEUCLID" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"GBEUCLID" -> {"FLAGG"; "ELAGG"; "OM"; "NNI"}*/
+
+"GBF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GBF"]
+/*"GBF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"GBF" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"GBF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"GBF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "OAMONS"; "OCAMON"}*/
+/*"GBF" -> {"OAMON"; "OASGP"; "ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"GBF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"GBF" -> {"LINEXP"; "KONVERT"; "PATMAB"}*/
+"GBF" -> "PFECAT"
+/*"GBF" -> {"UFD"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
+/*"GBF" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"GBF" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"GBF" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+
+"GBINTERN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GBINTERN"]
+/*"GBINTERN" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"GBINTERN" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"GBINTERN" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"GBINTERN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
+/*"GBINTERN" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "POLYCAT"; "PDRING"}*/
+/*"GBINTERN" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"GBINTERN" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
+/*"GBINTERN" -> "PATMAB"*/
+"GBINTERN" -> "PFECAT"
+/*"GBINTERN" -> {"UFD"; "NNI"; "INT"; "BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"GBINTERN" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"GBINTERN" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
+/*"GBINTERN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
+/*"GBINTERN" -> "PI"*/
+
+"GHENSEL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GHENSEL"]
+/*"GHENSEL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"GHENSEL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"GHENSEL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"GHENSEL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"GHENSEL" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"GHENSEL" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"GHENSEL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"GHENSEL" -> "PFECAT"
+/*"GHENSEL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
+/*"GHENSEL" -> {"DIVRING"; "INT"; "INS-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"GHENSEL" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"GHENSEL" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"}*/
+
+"GMODPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GMODPOL"]
+/*"GMODPOL" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
+/*"GMODPOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GMODPOL" -> {"RMODULE"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "SGROUP"}*/
+/*"GMODPOL" -> {"MONOID"; "FAMR"; "AMR"; "COMRING"; "ALGEBRA"; "CHARZ"}*/
+/*"GMODPOL" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"GMODPOL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"GMODPOL" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"GMODPOL" -> "PFECAT"
+/*"GMODPOL" -> "UFD"*/
+"GMODPOL" -> "DIRPCAT"
+/*"GMODPOL" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "ELTAB"}*/
+/*"GMODPOL" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
+/*"GMODPOL" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
+/*"GMODPOL" -> {"EUCDOM"; "PID"; "DIVRING"}*/
+
+"GOSPER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GOSPER"]
+/*"GOSPER" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"GOSPER" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "INTDOM"}*/
+/*"GOSPER" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
+/*"GOSPER" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"GOSPER" -> {"ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"GOSPER" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"GOSPER" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"GOSPER" -> "PFECAT"
+/*"GOSPER" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "INS"; "OINTDOM"}*/
+/*"GOSPER" -> {"ORDRING"; "OAGROUP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
+/*"GOSPER" -> {"QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"; "FPATMAB"}*/
+/*"GOSPER" -> {"TYPE"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"GOSPER" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"GOSPER" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"GOSPER" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "SINT"}*/
+/*"GOSPER" -> {"NNI"; "PI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "BOOLEAN"}*/
+/*"GOSPER" -> {"VECTCAT"; "A1AGG"}*/
+
+"GRIMAGE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GRIMAGE"]
+/*"GRIMAGE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
+/*"GRIMAGE" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"GRIMAGE" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"GRIMAGE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"GRIMAGE" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"GRIMAGE" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"GRIMAGE" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+/*"GRIMAGE" -> {"FPS"; "RNS"; "FIELD"; "DIVRING"; "RADCAT"; "INT"; "LSAGG"}*/
+/*"GRIMAGE" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"GRIMAGE" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"GRIMAGE" -> {"FLAGG"; "ELAGG"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"}*/
+/*"GRIMAGE" -> {"PI"; "DFLOAT"; "PTCAT"; "VECTCAT"; "A1AGG"; "FPS-"; "RNS-"}*/
+"GRIMAGE" -> "STRING"
+/*"GRIMAGE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "STRICAT"}*/
+/*"GRIMAGE" -> {"SRAGG"; "ISTRING"; "FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"GRIMAGE" -> {"DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"GRIMAGE" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"}*/
+/*"GRIMAGE" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "TRANFUN-"; "SETCAT-"}*/
+/*"GRIMAGE" -> {"ELEMFUN-"; "HYPCAT-"; "ATRIG-"; "TRIGCAT-"; "RADCAT-"}*/
+/*"GRIMAGE" -> {"RETRACT-"; "BASTYPE-"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"GRIMAGE" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "BOOLEAN"; "ELAGG-"}*/
+/*"GRIMAGE" -> {"FLAGG-"; "URAGG-"}*/
+
+"GROEBSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GROEBSOL"]
+/*"GROEBSOL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"GROEBSOL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"GROEBSOL" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"GROEBSOL" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"}*/
+/*"GROEBSOL" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"GROEBSOL" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"GROEBSOL" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"}*/
+/*"GROEBSOL" -> {"LIST"; "ILIST"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"GROEBSOL" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
+/*"GROEBSOL" -> {"LINEXP"; "PATMAB"}*/
+"GROEBSOL" -> "PFECAT"
+/*"GROEBSOL" -> {"UFD"; "NNI"}*/
+"GROEBSOL" -> "DIRPCAT"
+/*"GROEBSOL" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
+/*"GROEBSOL" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
+/*"GROEBSOL" -> {"EUCDOM"; "PID"; "DIVRING"; "ORDFIN"; "SINT"; "BOOLEAN"}*/
+/*"GROEBSOL" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+
+"HDMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HDMP"]
+/*"HDMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"HDMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"HDMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"HDMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"HDMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"HDMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"HDMP" -> "PFECAT"
+/*"HDMP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"HDMP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"HDMP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+"HDMP" -> "DIRPCAT"
+/*"HDMP" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"HDMP" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"HDMP" -> {"PID"; "DIVRING"; "ORDFIN"; "FPS"; "RNS"; "REAL"; "RADCAT"}*/
+/*"HDMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"}*/
+
+"HDP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HDP"]
+"HDP" -> "DIRPCAT"
+/*"HDP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"HDP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"}*/
+/*"HDP" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"HDP" -> {"RMODULE"; "DIFEXT"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"HDP" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"}*/
+/*"HDP" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"HDP" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"HDP" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "SINT"}*/
+/*"HDP" -> {"NNI"; "INT"; "BOOLEAN"; "INS"; "OINTDOM"; "KONVERT"; "PATMAB"}*/
+/*"HDP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"HEXADEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HEXADEC"]
+/*"HEXADEC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"HEXADEC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"HEXADEC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"HEXADEC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"HEXADEC" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"}*/
+/*"HEXADEC" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"HEXADEC" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"HEXADEC" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"HEXADEC" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"HEXADEC" -> "PFECAT"
+/*"HEXADEC" -> {"INS"; "CFCAT"; "OM"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
+/*"HEXADEC" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
+
+"HEUGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=HEUGCD"]
+/*"HEUGCD" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"HEUGCD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"HEUGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"HEUGCD" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"HEUGCD" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"HEUGCD" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"HEUGCD" -> {"PATMAB"; "GCDDOM"}*/
+"HEUGCD" -> "PFECAT"
+/*"HEUGCD" -> {"UFD"; "ELTAB"}*/
+/*"HEUGCD" -> {"DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
+/*"HEUGCD" -> {"DIVRING"; "INT"; "NNI"; "BOOLEAN"; "PI"; "SINT"; "LIST"}*/
+/*"HEUGCD" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"HEUGCD" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"HEUGCD" -> {"OM"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"HEUGCD" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "LSAGG-"; "STAGG-"}*/
+/*"HEUGCD" -> {"ELAGG-"; "FLAGG-"; "OAMONS"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"HEUGCD" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"HEUGCD" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"}*/
+/*"HEUGCD" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "SETCAT-"; "RETRACT-"}*/
+/*"HEUGCD" -> "BASTYPE-"*/
+
+"HTMLFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HTMLFORM"]
+"HTMLFORM" -> "STRING"
+/*"HTMLFORM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"; "STRICAT"}*/
+/*"HTMLFORM" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"HTMLFORM" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"HTMLFORM" -> {"KONVERT"; "ORDSET"; "OM"; "RCAGG"; "BOOLEAN"; "CHAR"}*/
+/*"HTMLFORM" -> {"SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"HTMLFORM" -> {"SRAGG-"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "ELAGG"}*/
+/*"HTMLFORM" -> {"LSAGG-"; "ORDFIN"; "FINITE"; "STAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"HTMLFORM" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"HTMLFORM" -> {"SETCAT-"; "BASTYPE-"; "ELAGG-"; "URAGG-"; "INS-"; "PI"}*/
+/*"HTMLFORM" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"HTMLFORM" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"HTMLFORM" -> {"ABELMON-"; "MONOID-"; "ABELSG-"; "SGROUP-"; "RETRACT-"}*/
+
+"IBPTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IBPTOOLS"]
+/*"IBPTOOLS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IBPTOOLS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"IBPTOOLS" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"IBPTOOLS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"IBPTOOLS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"IBPTOOLS" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"IBPTOOLS" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"IBPTOOLS" -> "PFECAT"
+/*"IBPTOOLS" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"IBPTOOLS" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"; "SINT"; "NNI"; "INT"}*/
+
+"IBITS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IBITS"]
+/*"IBITS" -> {"BTAGG"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"}*/
+/*"IBITS" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"IBITS" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"IBITS" -> "INT"*/
+"IBITS" -> "STRING"
+/*"IBITS" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"IBITS" -> {"ISTRING"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"IBITS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IBITS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"IBITS" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"IBITS" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
+/*"IBITS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+/*"IBITS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "STRICAT"; "SRAGG"; "FINITE"}*/
+
+"ICARD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ICARD"]
+/*"ICARD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ORDFIN"; "FINITE"}*/
+"ICARD" -> "STRING"
+/*"ICARD" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"ICARD" -> {"A1AGG-"; "ISTRING"; "PI"; "NNI"}*/
+
+"ICDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ICDEN"]
+/*"ICDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ICDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ICDEN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ICDEN" -> {"ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"ICDEN" -> {"UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"ICDEN" -> {"IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"ICDEN" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"}*/
+/*"ICDEN" -> {"ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ICDEN" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"ICDEN" -> "PFECAT"
+/*"ICDEN" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
+
+"IDECOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IDECOMP"]
+/*"IDECOMP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"IDECOMP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"IDECOMP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IDECOMP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"IDECOMP" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"IDECOMP" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"IDECOMP" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"IDECOMP" -> {"STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"IDECOMP" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"IDECOMP" -> "PFECAT"
+/*"IDECOMP" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
+/*"IDECOMP" -> {"PATAB"; "FPATMAB"; "TYPE"}*/
+"IDECOMP" -> "DIRPCAT"
+/*"IDECOMP" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "FINITE"; "OAMONS"}*/
+/*"IDECOMP" -> {"VSPACE"; "ORDFIN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"IDECOMP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"IDECOMP" -> {"ILIST"; "NNI"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"IDECOMP" -> {"FLAGG-"; "URAGG-"}*/
+
+"IFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IFF"]
+"IFF" -> "FAXF"
+/*"IFF" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"IFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IFF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"IFF" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
+/*"IFF" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "KONVERT"; "OAMONS"}*/
+/*"IFF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"}*/
+/*"IFF" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+
+"IIARRAY2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IIARRAY2"]
+/*"IIARRAY2" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"IIARRAY2" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"IIARRAY2" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"}*/
+/*"IIARRAY2" -> {"PRIMARR"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"IIARRAY2" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "NNI"; "INS"; "UFD"; "GCDDOM"}*/
+/*"IIARRAY2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"IIARRAY2" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IIARRAY2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"IIARRAY2" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"IIARRAY2" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"IIARRAY2" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "A1AGG"}*/
+"IIARRAY2" -> "STRING"
+/*"IIARRAY2" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "ISTRING"}*/
+
+/* Note that ILIST has a circular self reference */
+"ILIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ILIST",
+          shape=ellipse]
+/*"ILIST" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"ILIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"ILIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"ILIST" -> {"ORDSET"; "ELAGG"; "SINT"; "NNI"; "INT"; "BOOLEAN"; "LIST"}*/
+/*"ILIST" -> {"ILIST"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+"ILIST" -> "STRING"
+/*"ILIST" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "INS"}*/
+/*"ILIST" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"ILIST" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"ILIST" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ILIST" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"ILIST" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"ILIST" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"IMATLIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IMATLIN"]
+/*"IMATLIN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"IMATLIN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IMATLIN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"IMATLIN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"IMATLIN" -> {"ENTIRER"; "UFD"; "DIVRING"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"IMATLIN" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"IMATLIN" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"; "ARR2CAT"}*/
+/*"IMATLIN" -> {"BOOLEAN"; "INT"; "SINT"; "NNI"; "LIST"; "A1AGG"; "PI"}*/
+/*"IMATLIN" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"IMATLIN" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"IMATLIN" -> "PATMAB"*/
+"IMATLIN" -> "PFECAT"
+/*"IMATLIN" -> {"DIFRING"; "DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "PATAB"}*/
+/*"IMATLIN" -> {"FPATMAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"IMATLIN" -> {"OAMON"; "OASGP"; "REAL"; "VECTCAT"; "OM"}*/
+
+"IMATQF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IMATQF"]
+/*"IMATQF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"IMATQF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"IMATQF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"IMATQF" -> {"MODULE"; "ENTIRER"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"IMATQF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"IMATQF" -> {"CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"; "ARR2CAT"; "QFCAT"}*/
+/*"IMATQF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"IMATQF" -> {"RETRACT"; "FEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"IMATQF" -> {"FLINEXP"; "LINEXP"; "PATAB"; "FPATMAB"; "PATMAB"; "STEP"}*/
+/*"IMATQF" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"IMATQF" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"IMATQF" -> "PFECAT"
+
+"INMODGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INMODGCD"]
+/*"INMODGCD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"INMODGCD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"INMODGCD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INMODGCD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"INMODGCD" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"INMODGCD" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"INMODGCD" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"INMODGCD" -> "PFECAT"
+/*"INMODGCD" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
+/*"INMODGCD" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"INMODGCD" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "INT"}*/
+/*"INMODGCD" -> {"LIST"; "ILIST"; "BOOLEAN"; "NNI"; "LSAGG-"; "STAGG-"}*/
+/*"INMODGCD" -> {"ELAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"INMODGCD" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"INMODGCD" -> {"FLAGG"; "ELAGG"; "OM"; "OAMONS"; "FLAGG-"; "PI"}*/
+/*"INMODGCD" -> {"MONOID-"; "ABELMON-"}*/
+
+"INNMFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INNMFACT"]
+/*"INNMFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
+/*"INNMFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"INNMFACT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"INNMFACT" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"INNMFACT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
+/*"INNMFACT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"INNMFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"INNMFACT" -> {"KONVERT"; "PATMAB"}*/
+"INNMFACT" -> "PFECAT"
+/*"INNMFACT" -> {"UFD"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"}*/
+/*"INNMFACT" -> {"SGROUP-"; "LIST"; "ILIST"; "UPOLYC"; "ELTAB"; "DIFRING"}*/
+/*"INNMFACT" -> {"DIFEXT"; "STEP"; "FIELD"; "DIVRING"; "BOOLEAN"; "LSAGG-"}*/
+/*"INNMFACT" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "SINT"; "LSAGG"; "STAGG"}*/
+/*"INNMFACT" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
+/*"INNMFACT" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ABELMON-"}*/
+/*"INNMFACT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+
+"INPSIGN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INPSIGN"]
+/*"INPSIGN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INPSIGN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INPSIGN" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"INPSIGN" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"INPSIGN" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"INPSIGN" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"INPSIGN" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"INPSIGN" -> "PFECAT"
+/*"INPSIGN" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"INPSIGN" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "INS-"}*/
+
+"INTERGB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTERGB"]
+/*"INTERGB" -> {
+/*"INTERGB" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INTERGB" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INTERGB" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INTERGB" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INTERGB" -> {"ENTIRER"; "UFD"; "DIVRING"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"INTERGB" -> {"OASGP"; "ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"INTERGB" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"INTERGB" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+"INTERGB" -> "PFECAT"
+/*"INTERGB" -> {"FFIELDC"; "FPC"; "FINITE"; "STEP"; "DIFRING"; "NNI"; "INT"}*/
+
+"INT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INT",
+          shape=ellipse]
+/*"INT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"INT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"INT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"INT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"INT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"INT" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "NNI"; "DFLOAT"}*/
+"INT" -> "STRING"
+/*"INT" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"INT" -> {"ISTRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"INT" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"INT" -> "PFECAT"
+/*"INT" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"; "INS-"}*/
+
+"INTHERTR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTHERTR"]
+/*"INTHERTR" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INTHERTR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INTHERTR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INTHERTR" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INTHERTR" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"INTHERTR" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"INTHERTR" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"INTHERTR" -> {"KONVERT"; "PATMAB"}*/
+"INTHERTR" -> "PFECAT"
+/*"INTHERTR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"; "INT"}*/
+
+"INTRAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTRAT"]
+/*"INTRAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INTRAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INTRAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INTRAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"INTRAT" -> {"DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"INTRAT" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
+/*"INTRAT" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"INTRAT" -> "PFECAT"
+/*"INTRAT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"}*/
+/*"INTRAT" -> {"PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"INTRAT" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+
+"INTRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTRF"]
+/*"INTRF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"INTRF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INTRF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INTRF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "CHARZ"}*/
+/*"INTRF" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"INTRF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"INTRF" -> {"PATMAB"; "GCDDOM"}*/
+"INTRF" -> "PFECAT"
+/*"INTRF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+/*"INTRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
+/*"INTRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"INTRF" -> {"OAMON"; "OASGP"; "REAL"; "UPOLYC"}*/
+
+"INTSLPE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTSLPE"]
+/*"INTSLPE" -> {"INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"; "UFD"}*/
+/*"INTSLPE" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTSLPE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"INTSLPE" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"INTSLPE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"INTSLPE" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"INTSLPE" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"INTSLPE" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"INTSLPE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"INTSLPE" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"INTSLPE" -> "PFECAT"
+/*"INTSLPE" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"; "LIST"; "ILIST"}*/
+/*"INTSLPE" -> "NNI"*/
+
+"INTTR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTTR"]
+/*"INTTR" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INTTR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INTTR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INTTR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"INTTR" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"INTTR" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"INTTR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"INTTR" -> "PFECAT"
+/*"INTTR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"}*/
+/*"INTTR" -> {"PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"INTTR" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "BOOLEAN"; "NNI"; "INT"}*/
+/*"INTTR" -> {"PRIMARR"; "INS"; "CFCAT"; "LIST"; "ILIST"; "PI"; "LSAGG-"}*/
+/*"INTTR" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
+/*"INTTR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"INTTR" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
+
+"ISUMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ISUMP"]
+/*"ISUMP" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"ISUMP" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "INTDOM"}*/
+/*"ISUMP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
+/*"ISUMP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ISUMP" -> {"ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"ISUMP" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"ISUMP" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"ISUMP" -> "PFECAT"
+/*"ISUMP" -> {"UFD"; "INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"ISUMP" -> {"OAGROUP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"}*/
+/*"ISUMP" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"}*/
+/*"ISUMP" -> {"FPATMAB"; "TYPE"; "INT"; "LIST"; "BOOLEAN"; "NNI"; "ILIST"}*/
+/*"ISUMP" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+
+"LAUPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LAUPOL"]
+/*"LAUPOL" -> {"DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LAUPOL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"LAUPOL" -> {"LMODULE"; "DIFRING"; "PDRING"; "INTDOM"; "COMRING"}*/
+/*"LAUPOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LAUPOL" -> {"KONVERT"; "FRETRCT"; "RETRACT"; "CHARZ"; "CHARNZ"}*/
+/*"LAUPOL" -> {"EUCDOM"; "PID"; "GCDDOM"; "FIELD"; "UFD"; "DIVRING"}*/
+/*"LAUPOL" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "EVALAB"; "IEVALAB"}*/
+/*"LAUPOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "PATMAB"}*/
+"LAUPOL" -> "PFECAT"
+/*"LAUPOL" -> {"ELTAB"; "STEP"; "INT"; "BOOLEAN"; "NNI"; "LIST"; "ILIST"}*/
+/*"LAUPOL" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"LAUPOL" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"LAUPOL" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"LAUPOL" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+
+"LEADCDET" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LEADCDET"]
+/*"LEADCDET" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
+/*"LEADCDET" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
+/*"LEADCDET" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"LEADCDET" -> {"ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"LEADCDET" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
+/*"LEADCDET" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"LEADCDET" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"LEADCDET" -> {"KONVERT"; "PATMAB"}*/
+"LEADCDET" -> "PFECAT"
+/*"LEADCDET" -> {"UFD"; "SINT"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"LEADCDET" -> {"STAGG-"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"LEADCDET" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"LEADCDET" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "PI"}*/
+
+"LGROBP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LGROBP"]
+/*"LGROBP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"LGROBP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"LGROBP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"LGROBP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "VECTCAT"}*/
+/*"LGROBP" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"LGROBP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"LGROBP" -> {"ORDSET"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"}*/
+/*"LGROBP" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
+/*"LGROBP" -> {"LIST"; "ILIST"}*/
+"LGROBP" -> "DIRPCAT"
+/*"LGROBP" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"LGROBP" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"}*/
+/*"LGROBP" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
+/*"LGROBP" -> {"EUCDOM"; "PID"; "UFD"; "DIVRING"; "ORDFIN"; "PI"; "BOOLEAN"}*/
+/*"LGROBP" -> {"VECTCAT-"; "LSAGG-"; "STAGG-"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"LGROBP" -> {"CHARZ"; "CHARNZ"; "PATMAB"}*/
+"LGROBP" -> "PFECAT"
+/*"LGROBP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"}*/
+
+"LIMITRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIMITRF"]
+/*"LIMITRF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"LIMITRF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"LIMITRF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"LIMITRF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
+/*"LIMITRF" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"LIMITRF" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"LIMITRF" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
+"LIMITRF" -> "PFECAT"
+/*"LIMITRF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+/*"LIMITRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
+/*"LIMITRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"LIMITRF" -> {"OAMON"; "OASGP"; "REAL"; "INT"; "OM"; "UPOLYC"; "SINT"}*/
+/*"LIMITRF" -> "NNI"*/
+
+"LINDEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LINDEP"]
+/*"LINDEP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"LINDEP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"LINDEP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"LINDEP" -> {"MODULE"; "ENTIRER"; "LINEXP"; "INT"; "LIST"; "ILIST"}*/
+/*"LINDEP" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"LINDEP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"LINDEP" -> {"CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"LINDEP" -> {"VECTCAT-"; "A1AGG-"; "NNI"; "BOOLEAN"; "INS"; "UFD"}*/
+/*"LINDEP" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"LINDEP" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "PATMAB"}*/
+/*"LINDEP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "INS-"; "FIELD"}*/
+/*"LINDEP" -> {"DIVRING"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"LINDEP" -> {"ORDSET-"; "AGG-"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PDRING"}*/
+/*"LINDEP" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "CHARNZ"}*/
+"LINDEP" -> "PFECAT"
+
+"LISYSER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LISYSER"]
+/*"LISYSER" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"LISYSER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LISYSER" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LISYSER" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"LISYSER" -> {"DIVRING"}*/
+"LISYSER" -> "LOCPOWC"
+/*"LISYSER" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
+/*"LISYSER" -> {"DIFRING"; "PDRING"; "INT"; "LIST"; "ILIST"; "LSAGG"}*/
+/*"LISYSER" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"LISYSER" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
+/*"LISYSER" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "NNI"; "STAGG-"}*/
+
+"LO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LO"]
+/*"LO" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"LO" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "OAGROUP"}*/
+/*"LO" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "COMRING"; "RING"; "RNG"}*/
+/*"LO" -> {"SGROUP"; "MONOID"}*/
+"LO" -> "STRING"
+/*"LO" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"LO" -> {"A1AGG-"; "ISTRING"}*/
+
+"LPEFRAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LPEFRAC"]
+"LPEFRAC" -> "PFECAT"
+/*"LPEFRAC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"LPEFRAC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"LPEFRAC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LPEFRAC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LPEFRAC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "RETRACT"}*/
+/*"LPEFRAC" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
+/*"LPEFRAC" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"LPEFRAC" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
+/*"LPEFRAC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"}*/
+/*"LPEFRAC" -> "CHARNZ"*/
+
+"LSPP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LSPP"]
+/*"LSPP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"LSPP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"LSPP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"LSPP" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"LSPP" -> {"ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"LSPP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"LSPP" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"LSPP" -> "PFECAT"
+/*"LSPP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"LSPP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"LSPP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "VECTOR"; "IVECTOR"}*/
+/*"LSPP" -> {"IARRAY1"; "SINT"; "NNI"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
+/*"LSPP" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"}*/
+/*"LSPP" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "STEP"; "OINTDOM"}*/
+/*"LSPP" -> {"ORDRING"; "OAGROUP"; "REAL"}*/
+
+"MATLIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MATLIN"]
+/*"MATLIN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"MATLIN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"MATLIN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"MATLIN" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"MATLIN" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"; "ARR2CAT"}*/
+/*"MATLIN" -> {"BOOLEAN"; "INT"; "PRIMARR"; "LIST"; "ILIST"; "PI"; "NNI"}*/
+/*"MATLIN" -> {"A1AGG"; "SINT"; "INTDOM"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"MATLIN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"MATLIN" -> {"VECTCAT"; "QFCAT"; "RETRACT"; "FEVALAB"; "DIFEXT"}*/
+/*"MATLIN" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "FPATMAB"}*/
+/*"MATLIN" -> {"PATMAB"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"MATLIN" -> {"OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"MATLIN" -> "PFECAT"
+/*"MATLIN" -> {"INS"; "CFCAT"}*/
+
+"MCDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MCDEN"]
+/*"MCDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"MCDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MCDEN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"MCDEN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"}*/
+/*"MCDEN" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
+/*"MCDEN" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"MCDEN" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"MCDEN" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"MCDEN" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"MCDEN" -> "PFECAT"
+/*"MCDEN" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"MCDEN" -> {"AGG"; "ELTAGG"; "CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"MCDEN" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+
+"MDDFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MDDFACT"]
+/*"MDDFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MDDFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MDDFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"MDDFACT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"MDDFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"MDDFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"MDDFACT" -> {"PATMAB"; "GCDDOM"}*/
+"MDDFACT" -> "PFECAT"
+/*"MDDFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"MDDFACT" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "INS-"; "EUCDOM-"; "INS"}*/
+/*"MDDFACT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"MDDFACT" -> {"CFCAT"; "REAL"; "LIST"; "NNI"; "SINT"; "PI"; "ILIST"}*/
+
+"MFINFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MFINFACT"]
+/*"MFINFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
+/*"MFINFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"MFINFACT" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"MFINFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"MFINFACT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"MFINFACT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"MFINFACT" -> {"STEP"; "DIFRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"MFINFACT" -> {"CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"MFINFACT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+"MFINFACT" -> "PFECAT"
+/*"MFINFACT" -> {"UPOLYC"; "ELTAB"; "DIFEXT"; "INT"; "LIST"; "ILIST"}*/
+/*"MFINFACT" -> {"NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "BOOLEAN"}*/
+/*"MFINFACT" -> {"PI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"MFINFACT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
+/*"MFINFACT" -> {"ELAGG"; "OM"; "SINT"}*/
+
+"MFLOAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MFLOAT"]
+/*"MFLOAT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"MFLOAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"MFLOAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"MFLOAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"MFLOAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"MFLOAT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"MFLOAT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "FMTC"; "INS"; "OINTDOM"}*/
+/*"MFLOAT" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "INT"; "PI"; "NNI"}*/
+/*"MFLOAT" -> {"MONOID-"; "ABELSG-"; "SGROUP-"; "INS-"; "OM"; "EUCDOM-"}*/
+/*"MFLOAT" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"MFLOAT" -> "ORDRING-"*/
+"MFLOAT" -> "STRING"
+/*"MFLOAT" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"MFLOAT" -> {"ISTRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"MFLOAT" -> {"AHYP"; "ELEMFUN"; "BOOLEAN"}*/
+
+"MINT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MINT"]
+/*"MINT" -> {"FMTC"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MINT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"MINT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"MINT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"MINT" -> {"RETRACT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"MINT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"MINT" -> {"KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"MINT" -> {"STEP"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
+"MINT" -> "STRING"
+/*"MINT" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"MINT" -> "ISTRING"*/
+
+"MLIFT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MLIFT"]
+/*"MLIFT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"MLIFT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
+/*"MLIFT" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MLIFT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"MLIFT" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"MLIFT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"MLIFT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+"MLIFT" -> "PFECAT"
+/*"MLIFT" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"MLIFT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"MLIFT" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "SINT"}*/
+/*"MLIFT" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "PI"}*/
+
+"MMAP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MMAP"]
+/*"MMAP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"MMAP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"MMAP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"MMAP" -> {"ENTIRER"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"MMAP" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"MMAP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"MMAP" -> "PFECAT"
+/*"MMAP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"MMAP" -> {"FIELD"; "DIVRING"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
+/*"MMAP" -> {"TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"MMAP" -> {"OASGP"; "REAL"}*/
+
+"MODMON" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODMON"]
+/*"MODMON" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MODMON" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MODMON" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"MODMON" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"MODMON" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"MODMON" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"MODMON" -> {"PATMAB"; "GCDDOM"}*/
+"MODMON" -> "PFECAT"
+/*"MODMON" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"MODMON" -> {"PID"; "FIELD"; "DIVRING"; "FINITE"; "NNI"; "INT"; "MONOID-"}*/
+/*"MODMON" -> {"ABELMON-"; "PI"; "FFIELDC"; "FPC"; "PRIMARR"; "A1AGG-"}*/
+/*"MODMON" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
+/*"MODMON" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "BOOLEAN"}*/
+/*"MODMON" -> {"SINT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"MODMON" -> {"TYPE"; "ELTAGG"; "CLAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"MODMON" -> {"FPS"; "RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"MODMON" -> {"OASGP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
+
+"MONOTOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MONOTOOL"]
+/*"MONOTOOL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"MONOTOOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"MONOTOOL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"MONOTOOL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"MONOTOOL" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
+/*"MONOTOOL" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"MONOTOOL" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"MONOTOOL" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
+"MONOTOOL" -> "PFECAT"
+/*"MONOTOOL" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"; "INT"}*/
+
+"MPCPF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPCPF"]
+/*"MPCPF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"MPCPF" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"MPCPF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"MPCPF" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"MPCPF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
+/*"MPCPF" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"MPCPF" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"MPCPF" -> {"KONVERT"; "PATMAB"}*/
+"MPCPF" -> "PFECAT"
+/*"MPCPF" -> {"UFD"; "INT"; "OM"}*/
+
+"MPC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPC2"]
+/*"MPC2" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
+/*"MPC2" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
+/*"MPC2" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "POLYCAT"}*/
+/*"MPC2" -> {"PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"MPC2" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"MPC2" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"MPC2" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"MPC2" -> "PFECAT"
+/*"MPC2" -> {"UFD"; "NNI"; "INT"}*/
+
+"MPC3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPC3"]
+/*"MPC3" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
+/*"MPC3" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
+/*"MPC3" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "POLYCAT"}*/
+/*"MPC3" -> {"PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"MPC3" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"MPC3" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"MPC3" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"MPC3" -> "PFECAT"
+/*"MPC3" -> {"UFD"; "BOOLEAN"}*/
+
+"MPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MPOLY"]
+/*"MPOLY" -> {"ORDFIN"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
+/*"MPOLY" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"MPOLY" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MPOLY" -> {"FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
+/*"MPOLY" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"MPOLY" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"MPOLY" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"MPOLY" -> "PFECAT"
+/*"MPOLY" -> {"UFD"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+/*"MPOLY" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"MPOLY" -> {"RADCAT"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"; "STEP"}*/
+/*"MPOLY" -> {"UPOLYC"; "ELTAB"; "DIFEXT"}*/
+
+"MPRFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPRFF"]
+/*"MPRFF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"MPRFF" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"MPRFF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"MPRFF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"MPRFF" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"MPRFF" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"MPRFF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"MPRFF" -> "PFECAT"
+/*"MPRFF" -> {"UFD"; "INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"MPRFF" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"; "FIELD"}*/
+/*"MPRFF" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"; "FPATMAB"}*/
+/*"MPRFF" -> {"TYPE"; "FFIELDC"; "FPC"; "FINITE"; "BOOLEAN"; "NNI"; "INT"}*/
+
+"MRATFAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MRATFAC"]
+/*"MRATFAC" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"MRATFAC" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"MRATFAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"MRATFAC" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"MRATFAC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
+/*"MRATFAC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"MRATFAC" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"MRATFAC" -> {"KONVERT"; "PATMAB"}*/
+"MRATFAC" -> "PFECAT"
+/*"MRATFAC" -> {"UFD"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
+/*"MRATFAC" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
+/*"MRATFAC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"; "PI"; "NNI"}*/
+/*"MRATFAC" -> {"INT"; "INS"; "CFCAT"}*/
+
+"MULTSQFR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MULTSQFR"]
+/*"MULTSQFR" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"MULTSQFR" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"MULTSQFR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"MULTSQFR" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"MULTSQFR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
+/*"MULTSQFR" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"MULTSQFR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"MULTSQFR" -> {"KONVERT"; "PATMAB"}*/
+"MULTSQFR" -> "PFECAT"
+/*"MULTSQFR" -> {"UFD"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
+/*"MULTSQFR" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"MULTSQFR" -> {"FLAGG-"; "UPOLYC"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"MULTSQFR" -> {"FIELD"; "DIVRING"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"MULTSQFR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
+/*"MULTSQFR" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INS-"}*/
+/*"MULTSQFR" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"MULTSQFR" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"MULTSQFR" -> "ABELMON-"*/
+
+"NORMRETR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NORMRETR"]
+/*"NORMRETR" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"NORMRETR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"NORMRETR" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"NORMRETR" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"NORMRETR" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
+/*"NORMRETR" -> {"FINITE"; "STEP"; "DIFRING"}*/
+"NORMRETR" -> "FAXF"
+/*"NORMRETR" -> {"XF"; "RETRACT"; "VSPACE"; "CHARZ"; "UPOLYC"; "POLYCAT"}*/
+/*"NORMRETR" -> {"PDRING"; "FAMR"; "AMR"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
+/*"NORMRETR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"NORMRETR" -> "PFECAT"
+/*"NORMRETR" -> {"ELTAB"; "DIFEXT"; "SINT"; "PI"; "NNI"; "INT"; "LSAGG"}*/
+/*"NORMRETR" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"NORMRETR" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"NORMRETR" -> {"LIST"; "ILIST"; "BOOLEAN"}*/
+
+"NPCOEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NPCOEF"]
+/*"NPCOEF" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NPCOEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"NPCOEF" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"NPCOEF" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"NPCOEF" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"NPCOEF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"NPCOEF" -> {"PATMAB"; "GCDDOM"}*/
+"NPCOEF" -> "PFECAT"
+/*"NPCOEF" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"NPCOEF" -> {"FIELD"; "DIVRING"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"NPCOEF" -> {"INT"; "LIST"; "ILIST"; "SINT"; "NNI"; "VECTOR"; "LSAGG"}*/
+/*"NPCOEF" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"NPCOEF" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "BOOLEAN"}*/
+/*"NPCOEF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "PI"; "IVECTOR"}*/
+/*"NPCOEF" -> {"IARRAY1"; "VECTCAT"; "A1AGG"}*/
+
+"NSUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NSUP"]
+/*"NSUP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NSUP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"NSUP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"NSUP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"NSUP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"NSUP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"NSUP" -> "PFECAT"
+/*"NSUP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"NSUP" -> {"FIELD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"; "FPS"}*/
+/*"NSUP" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"NSUP" -> {"REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
+
+"NTPOLFN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NTPOLFN"]
+/*"NTPOLFN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NTPOLFN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NTPOLFN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "INS"; "UFD"; "GCDDOM"}*/
+/*"NTPOLFN" -> {"INTDOM"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"NTPOLFN" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"NTPOLFN" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"NTPOLFN" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"NTPOLFN" -> {"NNI"; "INT"; "BOOLEAN"; "QFCAT"; "FIELD"; "DIVRING"}*/
+/*"NTPOLFN" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"NTPOLFN" -> {"PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
+"NTPOLFN" -> "PFECAT"
+
+"ODP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODP"]
+"ODP" -> "DIRPCAT"
+/*"ODP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ODP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"}*/
+/*"ODP" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODP" -> {"RMODULE"; "DIFEXT"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"ODP" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"}*/
+/*"ODP" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ODP" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"ODP" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "INS"}*/
+/*"ODP" -> {"OINTDOM"; "KONVERT"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"ODP" -> {"STEP"; "OM"}*/
+
+"ODEPRIM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPRIM"]
+/*"ODEPRIM" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODEPRIM" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODEPRIM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ODEPRIM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ODEPRIM" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
+/*"ODEPRIM" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"ODEPRIM" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"ODEPRIM" -> {"KONVERT"; "PATMAB"}*/
+"ODEPRIM" -> "PFECAT"
+/*"ODEPRIM" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LODOCAT"; "OREPCAT"}*/
+/*"ODEPRIM" -> {"NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"ODEPRIM" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"ODEPRIM" -> {"FLAGG"; "ELAGG"; "BOOLEAN"; "LIST"; "ILIST"; "SINT"; "PI"}*/
+
+"ODEPRRIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPRRIC"]
+/*"ODEPRRIC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODEPRRIC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODEPRRIC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ODEPRRIC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ODEPRRIC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
+/*"ODEPRRIC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"ODEPRRIC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"ODEPRRIC" -> {"KONVERT"; "PATMAB"}*/
+"ODEPRRIC" -> "PFECAT"
+/*"ODEPRRIC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LODOCAT"; "OREPCAT"}*/
+/*"ODEPRRIC" -> {"SINT"; "INT"; "NNI"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"ODEPRRIC" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ODEPRRIC" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "BOOLEAN"; "PI"; "LSAGG"}*/
+/*"ODEPRRIC" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"ODEPRRIC" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OAMONS"}*/
+/*"ODEPRRIC" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"ODEPRRIC" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+
+"OMPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OMPKG"]
+"OMPKG" -> "STRING"
+/*"OMPKG" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"OMPKG" -> {"A1AGG-"; "ISTRING"; "BOOLEAN"}*/
+
+"OMSERVER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OMSERVER"]
+/*"OMSERVER" -> {"BOOLEAN"; "INT"; "DFLOAT"}*/
+"OMSERVER" -> "STRING"
+/*"OMSERVER" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+
+"PACRATC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PACRATC"]
+"PACRATC" -> "XF"
+/*"PACRATC" -> {"VSPACE"; "FPC"; "FINITE"; "PACPERC"}*/
+
+"PADEPAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PADEPAC"]
+/*"PADEPAC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PADEPAC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PADEPAC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PADEPAC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PADEPAC" -> {"ENTIRER"; "UFD"; "DIVRING"; "NNI"; "INT"; "UPOLYC"}*/
+/*"PADEPAC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"PADEPAC" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"PADEPAC" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"PADEPAC" -> "PFECAT"
+/*"PADEPAC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+
+"PADICRAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PADICRAT"]
+/*"PADICRAT" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"PADICRAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PADICRAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"PADICRAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PADICRAT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"PADICRAT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"PADICRAT" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"PADICRAT" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
+/*"PADICRAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PADICRAT" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"PADICRAT" -> "PFECAT"
+/*"PADICRAT" -> {"PADICCT"; "FPS"; "RNS"; "RADCAT"; "INS"; "CFCAT"}*/
+/*"PADICRAT" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
+
+"PADICRC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PADICRC"]
+/*"PADICRC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"PADICRC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PADICRC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"PADICRC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PADICRC" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"PADICRC" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"PADICRC" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"PADICRC" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
+/*"PADICRC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PADICRC" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"PADICRC" -> "PFECAT"
+/*"PADICRC" -> {"PADICCT"; "INT"; "INS"; "CFCAT"; "BOOLEAN"; "INS-"}*/
+/*"PADICRC" -> {"LIST"; "ILIST"; "SINT"; "NNI"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PADICRC" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"PADICRC" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "FPS"; "RNS"}*/
+/*"PADICRC" -> {"RADCAT"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
+
+"PARAMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARAMP"]
+"PARAMP" -> "PFECAT"
+"PARAMP" -> "DIRPCAT"
+/*"PARAMP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "FIELD"; "EUCDOM"}*/
+/*"PARAMP" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PARAMP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PARAMP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PARAMP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"PARAMP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"PARAMP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"PARAMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "IXAGG"; "HOAGG"}*/
+/*"PARAMP" -> {"AGG"; "TYPE"; "ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"}*/
+/*"PARAMP" -> {"FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PARAMP" -> {"OAMONS"; "VSPACE"; "UPSCAT"; "PSCAT"; "INT"; "LIST"; "ILIST"}*/
+/*"PARAMP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"}*/
+/*"PARAMP" -> {"ELAGG"; "OM"; "NNI"; "OUTFORM"; "LSAGG-"}*/
+
+"PCOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PCOMP"]
+/*"PCOMP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PCOMP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PCOMP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"PCOMP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"PCOMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"PCOMP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"PCOMP" -> {"PATMAB"; "GCDDOM"}*/
+"PCOMP" -> "PFECAT"
+/*"PCOMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"PCOMP" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"}*/
+
+"PDECOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PDECOMP"]
+/*"PDECOMP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PDECOMP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PDECOMP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"PDECOMP" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"PDECOMP" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"PDECOMP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"PDECOMP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"PDECOMP" -> "PFECAT"
+/*"PDECOMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"PDECOMP" -> {"PID"; "FIELD"; "DIVRING"; "SINT"; "NNI"; "INT"; "BOOLEAN"}*/
+/*"PDECOMP" -> "LIST"*/
+
+"PF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PF"]
+/*"PF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"PF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PF" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PF" -> {"UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"}*/
+"PF" -> "FAXF"
+/*"PF" -> {"XF"; "RETRACT"; "VSPACE"; "CHARZ"; "KONVERT"; "OAMONS"}*/
+/*"PF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"}*/
+/*"PF" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+
+"PFBR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFBR"]
+"PFBR" -> "PFECAT"
+/*"PFBR" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PFBR" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PFBR" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PFBR" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"PFBR" -> {"OASGP"; "ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"PFBR" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PFBR" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "INT"; "PI"; "NNI"}*/
+/*"PFBR" -> {"LIST"; "ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PFBR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"PFBR" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "UPOLYC"; "DIFRING"}*/
+/*"PFBR" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+/*"PFBR" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FFIELDC"; "FPC"; "FINITE"}*/
+
+"PFBRU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFBRU"]
+"PFBRU" -> "PFECAT"
+/*"PFBRU" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PFBRU" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PFBRU" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PFBRU" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"}*/
+/*"PFBRU" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"PFBRU" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"PFBRU" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "ELTAB"; "DIFRING"}*/
+/*"PFBRU" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"; "NNI"}*/
+/*"PFBRU" -> {"INT"; "SINT"; "PI"; "LIST"; "ILIST"; "BOOLEAN"; "LSAGG"}*/
+/*"PFBRU" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"PFBRU" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"}*/
+/*"PFBRU" -> {"STAGG-"; "ELAGG-"}*/
+
+"PFORP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFORP"]
+/*"PFORP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PFORP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"PFORP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"PFORP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"PFORP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+"PFORP" -> "DIRPCAT"
+/*"PFORP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"PFORP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"PFORP" -> {"FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PFORP" -> {"ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"PFORP" -> {"GCDDOM"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+/*"PFORP" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"PFORP" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"PFORP" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PFORP" -> {"RCAGG"; "LNAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"PFORP" -> {"VECTOR"; "SINT"; "PI"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
+/*"PFORP" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
+
+"PFOTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFOTOOLS"]
+/*"PFOTOOLS" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PFOTOOLS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PFOTOOLS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"PFOTOOLS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"PFOTOOLS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"PFOTOOLS" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"PFOTOOLS" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"PFOTOOLS" -> "PFECAT"
+/*"PFOTOOLS" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"PFOTOOLS" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "INS-"; "EUCDOM-"}*/
+/*"PFOTOOLS" -> {"UFD-"; "GCDDOM-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PFOTOOLS" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "QFCAT"}*/
+/*"PFOTOOLS" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OM"}*/
+
+"PFRPAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFRPAC"]
+/*"PFRPAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PFRPAC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PFRPAC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PFRPAC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PFRPAC" -> {"CHARZ"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"PFRPAC" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"PFRPAC" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"PFRPAC" -> "PFECAT"
+/*"PFRPAC" -> {"UFD"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
+/*"PFRPAC" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
+/*"PFRPAC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PFRPAC" -> {"REAL"; "UPOLYC"}*/
+
+"PGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PGCD"]
+/*"PGCD" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"PGCD" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
+/*"PGCD" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PGCD" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"PGCD" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PGCD" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+"PGCD" -> "PFECAT"
+/*"PGCD" -> {"UFD"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
+/*"PGCD" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"PGCD" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"PGCD" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "INS-"; "EUCDOM-"}*/
+/*"PGCD" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"PGCD" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+/*"PGCD" -> {"SINT"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "UPOLYC"}*/
+/*"PGCD" -> {"DIFRING"; "DIFEXT"; "STEP"; "FIELD"; "DIVRING"}*/
+
+"PINTERPA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PINTERPA"]
+/*"PINTERPA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PINTERPA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PINTERPA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PINTERPA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PINTERPA" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"PINTERPA" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"PINTERPA" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"PINTERPA" -> {"KONVERT"; "PATMAB"}*/
+"PINTERPA" -> "PFECAT"
+/*"PINTERPA" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"; "STAGG"}*/
+/*"PINTERPA" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"PINTERPA" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"PINTERPA" -> {"INT"; "LIST"; "ILIST"; "NNI"; "SINT"; "BOOLEAN"}*/
+
+"PLEQN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PLEQN"]
+/*"PLEQN" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PLEQN" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PLEQN" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PLEQN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "ORDSET"}*/
+/*"PLEQN" -> {"KONVERT"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "POLYCAT"}*/
+/*"PLEQN" -> {"PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"PLEQN" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+"PLEQN" -> "PFECAT"
+/*"PLEQN" -> {"UFD"; "BOOLEAN"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"}*/
+/*"PLEQN" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"PLEQN" -> {"STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"; "NNI"}*/
+/*"PLEQN" -> {"INT"; "INS"; "CFCAT"; "OM"; "LIST"; "VECTOR"; "IVECTOR"}*/
+/*"PLEQN" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"PLEQN" -> {"HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "SINT"; "ILIST"; "LSAGG-"}*/
+/*"PLEQN" -> {"STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
+/*"PLEQN" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"PLEQN" -> "PI"*/
+
+"PMPLCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPLCAT"]
+/*"PLPKCRV" -> {"SETCATD"; "PRSPCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PLPKCRV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PLPKCRV" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"PLPKCRV" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PLPKCRV" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "FAMR"; "AMR"}*/
+/*"PLPKCRV" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+"PLPKCRV" -> "DIRPCAT"
+/*"PLPKCRV" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PLPKCRV" -> {"ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"}*/
+/*"PLPKCRV" -> {"LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"PLPKCRV" -> {"OAMON"; "OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "BOOLEAN"}*/
+/*"PLPKCRV" -> {"NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"PLPKCRV" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
+/*"PLPKCRV" -> {"ILIST"; "LSAGG-"}*/
+
+"PMPLCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPLCAT"]
+/*"PMPLCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"PMPLCAT" -> {"OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
+/*"PMPLCAT" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "PATMAB"}*/
+/*"PMPLCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"PMPLCAT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"PMPLCAT" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PMPLCAT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "GCDDOM"}*/
+"PMPLCAT" -> "PFECAT"
+/*"PMPLCAT" -> {"UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"PMPLCAT" -> {"ELAGG-"; "FLAGG-"; "URAGG-"}*/
+
+"PMQFCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMQFCAT"]
+/*"PMQFCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PMQFCAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"PMQFCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PMQFCAT" -> {"MODULE"; "ENTIRER"; "PATMAB"; "KONVERT"; "QFCAT"; "FIELD"}*/
+/*"PMQFCAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"PMQFCAT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"PMQFCAT" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"PMQFCAT" -> {"FPATMAB"; "TYPE"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
+/*"PMQFCAT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"}*/
+/*"PMQFCAT" -> "CHARNZ"*/
+"PMQFCAT" -> "PFECAT"
+
+"PNTHEORY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PNTHEORY"]
+/*"PNTHEORY" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PNTHEORY" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PNTHEORY" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PNTHEORY" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PNTHEORY" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PNTHEORY" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"PNTHEORY" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"PNTHEORY" -> {"REAL"; "CHARZ"; "STEP"; "INT"; "NNI"; "QFCAT"; "FIELD"}*/
+/*"PNTHEORY" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
+/*"PNTHEORY" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"PNTHEORY" -> {"TYPE"; "CHARNZ"}*/
+"PNTHEORY" -> "PFECAT"
+/*"PNTHEORY" -> {"BOOLEAN"; "OM"; "PI"; "SINT"; "INS-"; "EUCDOM-"}*/
+/*"PNTHEORY" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"PNTHEORY" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+/*"PNTHEORY" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
+
+"POLTOPOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLTOPOL"]
+/*"POLTOPOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"POLTOPOL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"POLTOPOL" -> {"LMODULE"; "ORDFIN"; "ORDSET"; "FINITE"; "LSAGG"}*/
+/*"POLTOPOL" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"POLTOPOL" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"POLTOPOL" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"POLTOPOL" -> "ILIST"*/
+"POLTOPOL" -> "DIRPCAT"
+/*"POLTOPOL" -> {"FRETRCT"; "RETRACT"; "BMODULE"; "RMODULE"; "DIFEXT"}*/
+/*"POLTOPOL" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "ALGEBRA"}*/
+/*"POLTOPOL" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"POLTOPOL" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"POLTOPOL" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"POLUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLUTIL"]
+/*"POLUTIL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"POLUTIL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"POLUTIL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"POLUTIL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"POLUTIL" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"POLUTIL" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"POLUTIL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"POLUTIL" -> {"KONVERT"; "PATMAB"}*/
+"POLUTIL" -> "PFECAT"
+/*"POLUTIL" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "BOOLEAN"; "INT"}*/
+/*"POLUTIL" -> {"LIST"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"POLUTIL" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
+/*"POLUTIL" -> {"ELAGG"; "OM"; "ILIST"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"POLUTIL" -> {"OAMON"; "OASGP"; "LSAGG-"; "STAGG-"}*/
+
+"POLYCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=POLYCAT",
+          shape=ellipse]
+/*"POLYCAT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
+/*"POLYCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"POLYCAT" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"POLYCAT" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"POLYCAT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"POLYCAT" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"POLYCAT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"POLYCAT" -> "PFECAT"
+/*"POLYCAT" -> {"UFD"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "NNI"; "LSAGG"}*/
+/*"POLYCAT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"POLYCAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"POLYCAT" -> {"OM"; "LSAGG-"; "STAGG-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"POLYCAT" -> {"INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"POLYCAT" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "VECTCAT"; "A1AGG"}*/
+/*"POLYCAT" -> {"VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
+/*"POLYCAT" -> {"UPOLYC"; "DIFEXT"; "FIELD"; "DIVRING"; "FPS"; "RNS"}*/
+/*"POLYCAT" -> {"RADCAT"; "SEXCAT"}*/
+
+"POLYCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=POLYCAT",
+          shape=ellipse]
+/*"POLYCAT-" -> {"ORDSET";  "SETCAT";  "BASTYPE";  "KOERCE";  "OAMONS"}*/
+/*"POLYCAT-" -> {"OCAMON";  "OAMON";  "OASGP";  "ABELMON";  "ABELSG"}*/
+/*"POLYCAT-" -> {"CABMON";  "POLYCAT";  "PDRING";  "RING";  "RNG"}*/
+/*"POLYCAT-" -> {"ABELGRP";  "SGROUP";  "MONOID";  "LMODULE";  "FAMR"}*/
+/*"POLYCAT-" -> {"AMR";  "BMODULE";  "RMODULE";  "COMRING";  "ALGEBRA"}*/
+/*"POLYCAT-" -> {"MODULE";  "CHARZ";  "CHARNZ";  "INTDOM";  "ENTIRER"}*/
+/*"POLYCAT-" -> {"FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP"}*/
+/*"POLYCAT-" -> {"LINEXP";  "KONVERT";  "PATMAB";  "GCDDOM"}*/
+"POLYCAT-" -> "PFECAT"
+/*"POLYCAT-" -> {"UFD";  "INT";  "LIST";  "ILIST";  "BOOLEAN";  "NNI"}*/
+/*"POLYCAT-" -> {"LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "HOAGG";  "AGG"}*/
+/*"POLYCAT-" -> {"TYPE";  "LNAGG";  "IXAGG";  "ELTAGG";  "ELTAB";  "CLAGG"}*/
+/*"POLYCAT-" -> {"FLAGG";  "ELAGG";  "OM";  "LSAGG-";  "STAGG-";  "VECTOR"}*/
+/*"POLYCAT-" -> {"IVECTOR";  "IARRAY1";  "INS";  "EUCDOM";  "PID"}*/
+/*"POLYCAT-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "DIFRING";  "CFCAT"}*/
+/*"POLYCAT-" -> {"REAL";  "STEP";  "VECTCAT";  "A1AGG";  "VECTCAT-"}*/
+/*"POLYCAT-" -> {"A1AGG-";  "FLAGG-";  "LNAGG-";  "IXAGG-";  "UPOLYC"}*/
+/*"POLYCAT-" -> {"DIFEXT";  "FIELD";  "DIVRING";  "FPS";  "RNS";  "RADCAT"}*/
+/*"POLYCAT-" -> "SEXCAT"*/
+
+/* Note that this depends on POLYCAT in this layer but POLYCAT is */
+/* part of the layer0 clique and thus guaranteed to be compiled. */
+"POLYCATQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYCATQ"]
+/*"POLYCATQ" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"POLYCATQ" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"POLYCATQ" -> {"RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"POLYCATQ" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"POLYCATQ" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"POLYCATQ" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"POLYCATQ" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"POLYCATQ" -> "GCDDOM"*/
+"POLYCATQ" -> "PFECAT"
+/*"POLYCATQ" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "UPOLYC"}*/
+/*"POLYCATQ" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LIST"}*/
+/*"POLYCATQ" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+
+"POLYLIFT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYLIFT"]
+/*"POLYLIFT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"POLYLIFT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"POLYLIFT" -> {"RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"POLYLIFT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"POLYLIFT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"POLYLIFT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"POLYLIFT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"POLYLIFT" -> "GCDDOM"*/
+"POLYLIFT" -> "PFECAT"
+/*"POLYLIFT" -> {"UFD"; "BOOLEAN"}*/
+
+"POLYROOT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYROOT"]
+/*"POLYROOT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"POLYROOT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"POLYROOT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"POLYROOT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"POLYROOT" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"POLYROOT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"POLYROOT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"POLYROOT" -> "GCDDOM"*/
+"POLYROOT" -> "PFECAT"
+/*"POLYROOT" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "INT"; "NNI"}*/
+/*"POLYROOT" -> {"INS-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "DIFRING"}*/
+/*"POLYROOT" -> {"CFCAT"; "REAL"; "STEP"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+
+"POLY2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLY2"]
+/*"POLY2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"POLY2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"POLY2" -> {"LMODULE"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"POLY2" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"POLY2" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"POLY2" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"POLY2" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"POLY2" -> "PFECAT"
+/*"POLY2" -> "UFD"*/
+
+"POLY2UP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLY2UP"]
+/*"POLY2UP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"POLY2UP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"POLY2UP" -> {"LMODULE"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"POLY2UP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"POLY2UP" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"POLY2UP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"POLY2UP" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"POLY2UP" -> "PFECAT"
+/*"POLY2UP" -> "UFD"*/
+
+"PRS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRS"]
+/*"PRS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PRS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"PRS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PRS" -> {"ENTIRER"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"PRS" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PRS" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"PRS" -> "PFECAT"
+/*"PRS" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"PRS" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "VECTOR"; "IVECTOR"}*/
+/*"PRS" -> {"IARRAY1"; "VECTCAT-"; "BOOLEAN"; "PI"; "MONOID-"; "ABELMON-"}*/
+/*"PRS" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"PRS" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "FINITE"; "A1AGG-"; "LIST"}*/
+/*"PRS" -> {"ILIST"; "LSAGG-"; "STAGG-"}*/
+
+"PSQFR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PSQFR"]
+/*"PSQFR" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
+/*"PSQFR" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "GCDDOM"}*/
+/*"PSQFR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"PSQFR" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PSQFR" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"PSQFR" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PSQFR" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+"PSQFR" -> "PFECAT"
+/*"PSQFR" -> {"UFD"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "UPOLYC"; "ELTAB"}*/
+/*"PSQFR" -> {"DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
+/*"PSQFR" -> {"DIVRING"; "NNI"}*/
+
+"PUSHVAR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PUSHVAR"]
+/*"PUSHVAR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PUSHVAR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"PUSHVAR" -> {"LMODULE"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"PUSHVAR" -> {"ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"PUSHVAR" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"PUSHVAR" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"PUSHVAR" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
+/*"PUSHVAR" -> {"PATMAB"; "GCDDOM"}*/
+"PUSHVAR" -> "PFECAT"
+/*"PUSHVAR" -> {"UFD"; "NNI"; "INT"; "BOOLEAN"}*/
+
+"QALGSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QALGSET"]
+/*"QALGSET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "GCDDOM"; "INTDOM"}*/
+/*"QALGSET" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"QALGSET" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"QALGSET" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"QALGSET" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "POLYCAT"; "PDRING"}*/
+/*"QALGSET" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"QALGSET" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
+/*"QALGSET" -> "PATMAB"*/
+"QALGSET" -> "PFECAT"
+/*"QALGSET" -> {"UFD"; "EUCDOM"; "PID"; "INT"; "LIST"; "LSAGG"; "STAGG"}*/
+/*"QALGSET" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"QALGSET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"QALGSET" -> {"OM"; "ILIST"; "NNI"; "BOOLEAN"; "LSAGG-"; "STAGG-"}*/
+/*"QALGSET" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"QALGSET" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"QALGSET" -> {"SETCAT-"; "BASTYPE-"}*/
+
+"QFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=QFCAT",
+          shape=ellipse]
+/*"QFCAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"QFCAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"QFCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"QFCAT" -> {"MODULE"; "ENTIRER"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"QFCAT" -> {"UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"QFCAT" -> {"IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"}*/
+/*"QFCAT" -> {"LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
+/*"QFCAT" -> {"STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"QFCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"QFCAT" -> "PFECAT"
+/*"QFCAT" -> {"DFLOAT"; "INS"; "CFCAT"; "FPS"; "RNS"; "RADCAT"; "INT"}*/
+
+"QFCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QFCAT",
+          shape=ellipse]
+/*"QFCAT-" -> {"INTDOM";  "COMRING";  "RING";  "RNG";  "ABELGRP"}*/
+/*"QFCAT-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
+/*"QFCAT-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
+/*"QFCAT-" -> {"RMODULE";  "ALGEBRA";  "MODULE";  "ENTIRER";  "FIELD"}*/
+/*"QFCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "UFD";  "DIVRING";  "RETRACT"}*/
+/*"QFCAT-" -> {"FEVALAB";  "ELTAB";  "EVALAB";  "IEVALAB";  "DIFEXT"}*/
+/*"QFCAT-" -> {"DIFRING";  "PDRING";  "FLINEXP";  "LINEXP";  "PATAB"}*/
+/*"QFCAT-" -> {"KONVERT";  "FPATMAB";  "TYPE";  "PATMAB";  "STEP"}*/
+/*"QFCAT-" -> {"ORDSET";  "OINTDOM";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
+/*"QFCAT-" -> {"OAMON";  "OASGP";  "REAL";  "CHARZ";  "CHARNZ"}*/
+"QFCAT-" -> "PFECAT"
+/*"QFCAT-" -> {"DFLOAT";  "INS";  "CFCAT";  "FPS";  "RNS";  "RADCAT";  "INT"}*/
+
+/* Note that QFCAT2 depends on QFCAT in the same layer but QFCAT is */
+/* part of the bootstrap clique so it is guaranteed to be compiled */
+"QFCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QFCAT2"]
+/*"QFCAT2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"QFCAT2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"QFCAT2" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"QFCAT2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "QFCAT"; "FIELD"}*/
+/*"QFCAT2" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"QFCAT2" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
+/*"QFCAT2" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"QFCAT2" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
+/*"QFCAT2" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"}*/
+/*"QFCAT2" -> "CHARNZ"*/
+"QFCAT2" -> "PFECAT"
+
+"RADIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RADIX"]
+/*"RADIX" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"RADIX" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"RADIX" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"RADIX" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"RADIX" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
+/*"RADIX" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"RADIX" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"RADIX" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"RADIX" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"RADIX" -> "PFECAT"
+/*"RADIX" -> {"INS"; "CFCAT"; "INT"; "NNI"; "LIST"; "OM"; "ILIST"}*/
+/*"RADIX" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"RADIX" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"RADIX" -> "PI"*/
+"RADIX" -> "STRING"
+/*"RADIX" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"RADIX" -> {"FPS"; "RNS"; "RADCAT"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"RADIX" -> "FRETRCT"*/
+
+"RATFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RATFACT"]
+/*"RATFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"RATFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RATFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"RATFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"RATFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"RATFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"RATFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"RATFACT" -> "PFECAT"
+/*"RATFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"RATFACT" -> {"PID"; "FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"RATFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"RATFACT" -> {"INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "QFCAT"}*/
+/*"RATFACT" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "BOOLEAN"}*/
+
+"RCFIELD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RCFIELD"]
+/*"RCFIELD" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"RCFIELD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"RCFIELD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RCFIELD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"RCFIELD" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"RCFIELD" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"RCFIELD" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"RCFIELD" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"RCFIELD" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"RCFIELD" -> {"TYPE"; "CHARNZ"}*/
+"RCFIELD" -> "PFECAT"
+/*"RCFIELD" -> {"FRETRCT"; "RADCAT"; "NNI"; "INT"; "LSAGG"; "STAGG"}*/
+/*"RCFIELD" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"RCFIELD" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
+/*"RCFIELD" -> {"ILIST"; "LSAGG-"; "STAGG-"; "PI"}*/
+
+"RCFIELD-" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RCFIELD"]
+/*"RCFIELD-" -> {"INS";  "UFD";  "GCDDOM";  "INTDOM";  "COMRING";  "RING"}*/
+/*"RCFIELD-" -> {"RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
+/*"RCFIELD-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP";  "MONOID"}*/
+/*"RCFIELD-" -> {"LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
+/*"RCFIELD-" -> {"ENTIRER";  "EUCDOM";  "PID";  "OINTDOM";  "ORDRING"}*/
+/*"RCFIELD-" -> {"OAGROUP";  "OCAMON";  "OAMON";  "OASGP";  "ORDSET"}*/
+/*"RCFIELD-" -> {"DIFRING";  "KONVERT";  "RETRACT";  "LINEXP";  "PATMAB"}*/
+/*"RCFIELD-" -> {"CFCAT";  "REAL";  "CHARZ";  "STEP";  "QFCAT";  "FIELD"}*/
+/*"RCFIELD-" -> {"DIVRING";  "FEVALAB";  "ELTAB";  "EVALAB";  "IEVALAB"}*/
+/*"RCFIELD-" -> {"DIFEXT";  "PDRING";  "FLINEXP";  "PATAB";  "FPATMAB"}*/
+/*"RCFIELD-" -> {"TYPE";  "CHARNZ"}*/
+"RCFIELD-" -> "PFECAT"
+/*"RCFIELD-" -> {"FRETRCT";  "RADCAT";  "NNI";  "INT";  "LSAGG";  "STAGG"}*/
+/*"RCFIELD-" -> {"URAGG";  "RCAGG";  "HOAGG";  "AGG";  "LNAGG";  "IXAGG"}*/
+/*"RCFIELD-" -> {"ELTAGG";  "CLAGG";  "FLAGG";  "ELAGG";  "OM";  "LIST"}*/
+/*"RCFIELD-" -> {"ILIST";  "LSAGG-";  "STAGG-";  "PI"}*/
+
+"RDETR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDETR"]
+/*"RDETR" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"RDETR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RDETR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"RDETR" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"RDETR" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
+/*"RDETR" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"RDETR" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"RDETR" -> {"KONVERT"; "PATMAB"}*/
+"RDETR" -> "PFECAT"
+/*"RDETR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "BOOLEAN"; "NNI"}*/
+/*"RDETR" -> {"INT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"RDETR" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+
+"RDETRS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDETRS"]
+/*"RDETRS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"RDETRS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RDETRS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RDETRS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"RDETRS" -> {"DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"RDETRS" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
+/*"RDETRS" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"RDETRS" -> "PFECAT"
+/*"RDETRS" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LIST"}*/
+/*"RDETRS" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"RDETRS" -> {"VECTOR"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"RDETRS" -> {"HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "IVECTOR"}*/
+/*"RDETRS" -> {"IARRAY1"; "PI"; "NNI"}*/
+
+"REAL0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REAL0"]
+/*"REAL0" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"REAL0" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"REAL0" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"REAL0" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"REAL0" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"REAL0" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"REAL0" -> {"PATMAB"; "GCDDOM"}*/
+"REAL0" -> "PFECAT"
+/*"REAL0" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"REAL0" -> {"PID"; "FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"REAL0" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"REAL0" -> {"INT"; "OM"; "NNI"; "LIST"; "ILIST"; "PI"; "BOOLEAN"}*/
+/*"REAL0" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"REAL0" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"REAL0" -> {"ABELMON-"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"}*/
+/*"REAL0" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"REAL0" -> {"ELTAGG"; "CLAGG"}*/
+
+"REAL0Q" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REAL0Q"]
+/*"REAL0Q" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"REAL0Q" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"REAL0Q" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"REAL0Q" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"REAL0Q" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"REAL0Q" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"REAL0Q" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"REAL0Q" -> "PFECAT"
+/*"REAL0Q" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"REAL0Q" -> {"PID"; "FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"REAL0Q" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"REAL0Q" -> {"INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "QFCAT"}*/
+/*"REAL0Q" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+
+"REALSOLV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REALSOLV"]
+/*"REALSOLV" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"REALSOLV" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"REALSOLV" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"REALSOLV" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"REALSOLV" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"REALSOLV" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"REALSOLV" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"REALSOLV" -> {"REAL"; "CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"REALSOLV" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+"REALSOLV" -> "PFECAT"
+/*"REALSOLV" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
+/*"REALSOLV" -> {"PATAB"; "FPATMAB"; "TYPE"; "FPS"; "RNS"; "RADCAT"}*/
+
+"RESRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RESRING"]
+/*"RESRING" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"RESRING" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RESRING" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"RESRING" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"RESRING" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"RESRING" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"RESRING" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"RESRING" -> "PFECAT"
+/*"RESRING" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "OAMONS"}*/
+/*"RESRING" -> {"OCAMON"; "OAMON"; "OASGP"; "INT"; "LIST"; "ILIST"}*/
+
+"RETSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RETSOL"]
+/*"RETSOL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"RETSOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RETSOL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"RETSOL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "POLYCAT"}*/
+/*"RETSOL" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"RETSOL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"RETSOL" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"RETSOL" -> "PFECAT"
+/*"RETSOL" -> {"UFD"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
+
+"RF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RF"]
+/*"RF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"RF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"RF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"RF" -> {"ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"RF" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"RF" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"RF" -> "PFECAT"
+/*"RF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"}*/
+/*"RF" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"RF" -> {"STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"RF" -> {"OASGP"; "REAL"; "UPOLYC"}*/
+
+"RFFACTOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFFACTOR"]
+/*"RFFACTOR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"RFFACTOR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"RFFACTOR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RFFACTOR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"RFFACTOR" -> {"INS"; "UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"RFFACTOR" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"RFFACTOR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"RFFACTOR" -> {"STEP"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
+/*"RFFACTOR" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"}*/
+/*"RFFACTOR" -> {"PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
+"RFFACTOR" -> "PFECAT"
+/*"RFFACTOR" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "FFIELDC"; "FPC"}*/
+/*"RFFACTOR" -> "FINITE"*/
+
+"RINTERP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RINTERP"]
+/*"RINTERP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"RINTERP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RINTERP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"RINTERP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"RINTERP" -> {"ENTIRER"; "UFD"; "DIVRING"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"RINTERP" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"RINTERP" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"RINTERP" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+/*"RINTERP" -> {"NNI"; "SINT"; "LSAGG-"; "STAGG-"; "POLYCAT"; "PDRING"}*/
+/*"RINTERP" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"RINTERP" -> {"FLINEXP"; "LINEXP"; "PATMAB"}*/
+"RINTERP" -> "PFECAT" 
+/*"RINTERP" -> {"PI"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
+/*"RINTERP" -> {"ABELSG-"; "SETCAT-"; "BASTYPE-"; "VECTOR"; "IVECTOR"}*/
+/*"RINTERP" -> "IARRAY1"*/
+
+"RMATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RMATCAT"]
+/*"RMATCAT" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"RMATCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"}*/
+/*"RMATCAT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "MODULE"}*/
+/*"RMATCAT" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+"RMATCAT" -> "DIRPCAT"
+/*"RMATCAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"; "DIFEXT"}*/
+/*"RMATCAT" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"}*/
+/*"RMATCAT" -> {"ALGEBRA"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"RMATCAT" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"RMATCAT" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"RMATCAT" -> {"NNI"; "INT"; "BOOLEAN"; "SINT"}*/
+
+"RMATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RMATCAT"]
+/*"RMATCAT-" -> {"BMODULE";  "LMODULE";  "ABELGRP";  "CABMON";  "ABELMON"}*/
+/*"RMATCAT-" -> {"ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE";  "RMODULE"}*/
+/*"RMATCAT-" -> {"HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB";  "MODULE"}*/
+/*"RMATCAT-" -> {"COMRING";  "RING";  "RNG";  "SGROUP";  "MONOID"}*/
+"RMATCAT-" -> "DIRPCAT"
+/*"RMATCAT-" -> {"IXAGG";  "ELTAGG";  "ELTAB";  "FRETRCT";  "RETRACT"}*/
+/*"RMATCAT-" -> {"DIFEXT";  "DIFRING";  "PDRING";  "FLINEXP";  "LINEXP"}*/
+/*"RMATCAT-" -> {"FINITE";  "ALGEBRA";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
+/*"RMATCAT-" -> {"OAMON";  "OASGP";  "ORDSET";  "OAMONS";  "VSPACE"}*/
+/*"RMATCAT-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
+/*"RMATCAT-" -> {"ENTIRER";  "UFD";  "DIVRING";  "NNI";  "INT";  "BOOLEAN"}*/
+/*"RMATCAT-" -> "SINT"*/
+
+"RRCC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RRCC"]
+/*"RRCC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"RRCC" -> {"OAMON"; "OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"RRCC" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RRCC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"RRCC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"RRCC" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"RRCC" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"RRCC" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+"RRCC" -> "PFECAT"
+/*"RRCC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LSAGG"; "STAGG"}*/
+/*"RRCC" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
+/*"RRCC" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
+/*"RRCC" -> {"NNI"; "LSAGG-"; "STAGG-"}*/
+
+"RRCC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RRCC"]
+/*"RRCC-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "ORDRING";  "OAGROUP"}*/
+/*"RRCC-" -> {"OCAMON";  "OAMON";  "OASGP";  "ORDSET";  "ABELMON";  "ABELSG"}*/
+/*"RRCC-" -> {"CABMON";  "ABELGRP";  "RING";  "RNG";  "SGROUP";  "MONOID"}*/
+/*"RRCC-" -> {"LMODULE";  "FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
+/*"RRCC-" -> {"COMRING";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
+/*"RRCC-" -> {"ENTIRER";  "UFD";  "DIVRING";  "UPOLYC";  "POLYCAT"}*/
+/*"RRCC-" -> {"PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ";  "FRETRCT"}*/
+/*"RRCC-" -> {"RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP";  "LINEXP"}*/
+/*"RRCC-" -> {"KONVERT";  "PATMAB"}*/
+"RRCC-" -> "PFECAT"
+/*"RRCC-" -> {"ELTAB";  "DIFRING";  "DIFEXT";  "STEP";  "INT";  "LSAGG"}*/
+/*"RRCC-" -> {"STAGG";  "URAGG";  "RCAGG";  "HOAGG";  "AGG";  "TYPE"}*/
+/*"RRCC-" -> {"LNAGG";  "IXAGG";  "ELTAGG";  "CLAGG";  "FLAGG";  "ELAGG"}*/
+/*"RRCC-" -> {"OM";  "LIST";  "ILIST";  "NNI";  "LSAGG-";  "STAGG-"}*/
+
+"SCPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SCPKG"]
+/*"SCPKG" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"SCPKG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SCPKG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"SCPKG" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"SCPKG" -> {"DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"SCPKG" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"SCPKG" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
+/*"SCPKG" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "VECTOR"}*/
+/*"SCPKG" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "INS"; "OINTDOM"}*/
+/*"SCPKG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"SCPKG" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"SCPKG" -> {"STEP"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"SCPKG" -> {"NNI"; "SINT"; "VECTCAT"; "A1AGG"; "POLYCAT"; "PDRING"}*/
+/*"SCPKG" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
+"SCPKG" -> "PFECAT"
+/*"SCPKG" -> {"BOOLEAN"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PATAB"; "FPATMAB"}*/
+
+"SHDP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SHDP"]
+"SHDP" -> "DIRPCAT"
+/*"SHDP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SHDP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"}*/
+/*"SHDP" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SHDP" -> {"RMODULE"; "DIFEXT"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"SHDP" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"}*/
+/*"SHDP" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"SHDP" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
+/*"SHDP" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"SHDP" -> {"BOOLEAN"; "NNI"; "INT"; "SINT"; "INS"; "OINTDOM"; "KONVERT"}*/
+/*"SHDP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"SHP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SHP"]
+/*"SHP" -> {"OINTDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SHP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SHP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"SHP" -> {"MODULE"; "ENTIRER"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"SHP" -> {"OASGP"; "ORDSET"; "NNI"; "INT"; "LIST"; "PI"; "ILIST"}*/
+/*"SHP" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "SINT"}*/
+/*"SHP" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"SHP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"SHP" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "INS"}*/
+/*"SHP" -> {"UFD"; "GCDDOM"; "EUCDOM"; "PID"; "DIFRING"; "RETRACT"}*/
+/*"SHP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "UPOLYC"}*/
+/*"SHP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"SHP" -> "FLINEXP"*/
+"SHP" -> "PFECAT"
+/*"SHP" -> {"DIFEXT"; "FIELD"; "DIVRING"}*/
+
+"SIGNRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SIGNRF"]
+/*"SIGNRF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SIGNRF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SIGNRF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SIGNRF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"}*/
+/*"SIGNRF" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"SIGNRF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"SIGNRF" -> {"KONVERT"; "PATMAB"}*/
+"SIGNRF" -> "PFECAT"
+/*"SIGNRF" -> {"UFD"; "INT"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+/*"SIGNRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
+/*"SIGNRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"SIGNRF" -> {"OAMON"; "OASGP"; "REAL"; "UPOLYC"; "LIST"; "ILIST"}*/
+
+"SMITH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SMITH"]
+/*"SMITH" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"SMITH" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"SMITH" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"SMITH" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "FLAGG"; "LNAGG"}*/
+/*"SMITH" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"SMITH" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"}*/
+/*"SMITH" -> {"ARR2CAT"; "NNI"; "INT"; "SINT"; "BOOLEAN"; "PI"; "QFCAT"}*/
+/*"SMITH" -> {"FIELD"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "DIFEXT"}*/
+/*"SMITH" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "FPATMAB"}*/
+/*"SMITH" -> {"PATMAB"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"SMITH" -> {"OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"SMITH" -> "PFECAT"
+/*"SMITH" -> {"VECTCAT"; "A1AGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"}*/
+
+"SMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SMP"]
+/*"SMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"SMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"SMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"SMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"SMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"SMP" -> "PFECAT"
+/*"SMP" -> {"UFD"; "BOOLEAN"; "NNI"; "INT"; "PI"; "LSAGG"; "STAGG"}*/
+/*"SMP" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
+/*"SMP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
+/*"SMP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"SMP" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
+/*"SMP" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "FIELD"; "EUCDOM"}*/
+/*"SMP" -> {"PID"; "DIVRING"; "FPS"; "RNS"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"SMP" -> {"OAMON"; "OASGP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"SMP" -> {"CFCAT"; "STEP"; "UPOLYC"; "DIFEXT"}*/
+
+"SMTS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SMTS"]
+/*"SMTS" -> {"MTSCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SMTS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"SMTS" -> {"MONOID"; "LMODULE"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"SMTS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"SMTS" -> {"ENTIRER"; "IEVALAB"; "EVALAB"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"SMTS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "ORDSET"; "POLYCAT"}*/
+/*"SMTS" -> {"FAMR"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
+/*"SMTS" -> {"PATMAB"; "GCDDOM"}*/
+"SMTS" -> "PFECAT"
+/*"SMTS" -> {"UFD"; "NNI"; "INT"; "BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"SMTS" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"SMTS" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"SMTS" -> {"SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"SMTS" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"SMTS" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INS"; "EUCDOM"; "PID"}*/
+/*"SMTS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SMTS" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "PI"; "SINT"; "FIELD"}*/
+/*"SMTS" -> "DIVRING"*/
+
+"SOLVEFOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVEFOR"]
+/*"SOLVEFOR" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SOLVEFOR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SOLVEFOR" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"SOLVEFOR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"SOLVEFOR" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"SOLVEFOR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"SOLVEFOR" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"SOLVEFOR" -> "PFECAT"
+/*"SOLVEFOR" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"SOLVEFOR" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"; "INT"; "LIST"}*/
+/*"SOLVEFOR" -> {"ILIST"; "LSAGG-"; "STAGG-"; "NNI"; "PI"; "SINT"; "INS"}*/
+/*"SOLVEFOR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"SOLVEFOR" -> {"OASGP"; "CFCAT"; "REAL"}*/
+
+"SPLTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SPLTREE"]
+/*"SPLTREE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"SPLTREE" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"; "ILIST"}*/
+/*"SPLTREE" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"SPLTREE" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"SPLTREE" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "BOOLEAN"; "LSAGG"}*/
+/*"SPLTREE" -> {"STAGG"; "URAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"SPLTREE" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "NNI"}*/
+"SPLTREE" -> "STRING"
+/*"SPLTREE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+
+"STINPROD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STINPROD"]
+/*"STINPROD" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"STINPROD" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"STINPROD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"STINPROD" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "FIELD"; "EUCDOM"}*/
+/*"STINPROD" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "QFCAT"; "RETRACT"}*/
+/*"STINPROD" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"STINPROD" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"STINPROD" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
+/*"STINPROD" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"STINPROD" -> {"OASGP"; "REAL"; "CHARNZ"}*/
+"STINPROD" -> "PFECAT"
+
+"STTF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STTF"]
+/*"STTF" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"STTF" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"STTF" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "TRANFUN"; "TRIGCAT"}*/
+/*"STTF" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"STTF" -> "STRING"
+/*"STTF" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
+/*"STTF" -> {"ISTRING"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"STTF" -> {"URAGG-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"STTF" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"STTF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"STTF" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"STTF" -> {"STEP"; "NNI"; "PI"}*/
+
+"STTFNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STTFNC"]
+/*"STTFNC" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"STTFNC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"STTFNC" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "INT"}*/
+"STTFNC" -> "STRING"
+/*"STTFNC" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"STTFNC" -> "ISTRING"*/
+
+"SUBRESP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUBRESP"]
+/*"SUBRESP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SUBRESP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SUBRESP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SUBRESP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
+/*"SUBRESP" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"SUBRESP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"SUBRESP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"SUBRESP" -> "PFECAT"
+/*"SUBRESP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"SUBRESP" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "PRIMARR"}*/
+/*"SUBRESP" -> {"LIST"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"SUBRESP" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "PI"; "ILIST"; "BOOLEAN"}*/
+
+"SUBSPACE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUBSPACE"]
+/*"SUBSPACE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SUBSPACE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"SUBSPACE" -> {"LMODULE"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"SUBSPACE" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"SUBSPACE" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"SUBSPACE" -> {"BASTYPE-"; "NNI"; "BOOLEAN"; "PI"}*/
+"SUBSPACE" -> "STRING"
+/*"SUBSPACE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"SUBSPACE" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"SUBSPACE" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"SUBSPACE" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
+
+"SUMRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUMRF"]
+/*"SUMRF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SUMRF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"SUMRF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"SUMRF" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "POLYCAT"}*/
+/*"SUMRF" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"SUMRF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
+/*"SUMRF" -> {"PATMAB"; "GCDDOM"}*/
+"SUMRF" -> "PFECAT"
+/*"SUMRF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+/*"SUMRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
+/*"SUMRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"SUMRF" -> {"OAMON"; "OASGP"; "REAL"}*/
+
+"SUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUP"]
+/*"SUP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SUP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SUP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"SUP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"SUP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"SUP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"SUP" -> "PFECAT"
+/*"SUP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"SUP" -> {"FIELD"; "DIVRING"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SUP" -> {"FPC"; "INT"; "LIST"; "NNI"; "PI"; "ILIST"; "BOOLEAN"}*/
+/*"SUP" -> {"FFIELDC"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"SUP" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"SUP" -> {"FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "FPS"; "RNS"; "ORDRING"}*/
+/*"SUP" -> {"OAGROUP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
+
+"SUPEXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUPEXPR"]
+/*"SUPEXPR" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SUPEXPR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SUPEXPR" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"SUPEXPR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"SUPEXPR" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"SUPEXPR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"SUPEXPR" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"SUPEXPR" -> "PFECAT"
+/*"SUPEXPR" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"SUPEXPR" -> {"PID"; "FIELD"; "DIVRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"SUPEXPR" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FPS"; "RNS"; "ORDRING"}*/
+/*"SUPEXPR" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
+/*"SUPEXPR" -> {"INS"; "OINTDOM"; "CFCAT"}*/
+
+"SUPFRACF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUPFRACF"]
+/*"SUPFRACF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"SUPFRACF" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"SUPFRACF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SUPFRACF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SUPFRACF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"}*/
+/*"SUPFRACF" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"SUPFRACF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
+/*"SUPFRACF" -> "PATMAB"*/
+"SUPFRACF" -> "PFECAT"
+/*"SUPFRACF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+/*"SUPFRACF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
+/*"SUPFRACF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"}*/
+/*"SUPFRACF" -> "UPOLYC"*/
+
+"TANEXP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TANEXP"]
+/*"TANEXP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"TANEXP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"TANEXP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"TANEXP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"TANEXP" -> {"UFD"; "DIVRING"; "INT"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"TANEXP" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"TANEXP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"TANEXP" -> {"KONVERT"; "PATMAB"}*/
+"TANEXP" -> "PFECAT"
+/*"TANEXP" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INS"; "OINTDOM"}*/
+/*"TANEXP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
+/*"TANEXP" -> {"REAL"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"}*/
+/*"TANEXP" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"TANEXP" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "NNI"; "PI"; "MONOID-"}*/
+/*"TANEXP" -> "ABELMON-"*/
+
+"TEMUTL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TEMUTL"]
+/*"TEMUTL" -> "INT"*/
+"TEMUTL" -> "STRING"
+/*"TEMUTL" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"TEMUTL" -> {"ISTRING"; "SRAGG-"}*/
+
+"TEX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TEX"]
+/*"TEX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"}*/
+"TEX" -> "STRING"
+/*"TEX" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"TEX" -> {"ISTRING"; "ILIST"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
+/*"TEX" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"TEX" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "OM"; "PI"}*/
+/*"TEX" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"TEX" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "ORDFIN"}*/
+/*"TEX" -> {"FINITE"; "SRAGG-"}*/
+
+"TEXTFILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TEXTFILE"]
+/*"TEXTFILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"}*/
+/*"TEXTFILE" -> {"STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"TEXTFILE" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"TEXTFILE" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "OM"}*/
+"TEXTFILE" -> "STRING"
+/*"TEXTFILE" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"TEXTFILE" -> {"A1AGG-"; "ISTRING"; "BOOLEAN"}*/
+
+"TREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TREE"]
+/*"TREE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"TREE" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "NNI"; "INT"; "LIST"}*/
+/*"TREE" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
+/*"TREE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"TREE" -> {"ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"TREE" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"TREE" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"TREE" -> "PI"*/
+"TREE" -> "STRING"
+/*"TREE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+
+"TWOFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TWOFACT"]
+/*"TWOFACT" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"TWOFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"TWOFACT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"TWOFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"TWOFACT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"TWOFACT" -> {"CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "UPOLYC"}*/
+/*"TWOFACT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "FRETRCT"}*/
+/*"TWOFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"TWOFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
+"TWOFACT" -> "PFECAT"
+/*"TWOFACT" -> {"ELTAB"; "DIFEXT"; "INT"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"TWOFACT" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"TWOFACT" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "PI"; "NNI"}*/
+/*"TWOFACT" -> {"LIST"; "ILIST"; "BOOLEAN"}*/
+"TWOFACT" -> "FAXF"
+/*"TWOFACT" -> {"XF"; "VSPACE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"TWOFACT" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"TWOFACT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+
+"UNIFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UNIFACT"]
+/*"UNIFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"UNIFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"UNIFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"UNIFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"UNIFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"UNIFACT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"UNIFACT" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
+"UNIFACT" -> "PFECAT"
+/*"UNIFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"UNIFACT" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"; "INT"; "LIST"}*/
+/*"UNIFACT" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"UNIFACT" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "INS-"; "NNI"}*/
+/*"UNIFACT" -> {"SINT"; "PI"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+/*"UNIFACT" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"UNIFACT" -> {"ABELGRP-"; "ABELMON-"; "MONOID-"; "ORDSET-"; "ABELSG-"}*/
+/*"UNIFACT" -> {"SGROUP-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"UNIFACT" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"UNIFACT" -> {"FLAGG"; "ELAGG"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"UNIFACT" -> {"FLAGG-"; "URAGG-"}*/
+
+"UP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UP"]
+/*"UP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"UP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"UP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"UP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"UP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"UP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"UP" -> "PFECAT"
+/*"UP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"UP" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "FPS"; "RNS"; "ORDRING"}*/
+/*"UP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
+/*"UP" -> {"INS"; "OINTDOM"; "CFCAT"}*/
+
+"UPCDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPCDEN"]
+/*"UPCDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"UPCDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"UPCDEN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"UPCDEN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"}*/
+/*"UPCDEN" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
+/*"UPCDEN" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"UPCDEN" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"UPCDEN" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"UPCDEN" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
+"UPCDEN" -> "PFECAT"
+/*"UPCDEN" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "LSAGG"}*/
+/*"UPCDEN" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"UPCDEN" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+
+"UPDECOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPDECOMP"]
+/*"UPDECOMP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"UPDECOMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"UPDECOMP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"UPDECOMP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "UPOLYC"}*/
+/*"UPDECOMP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"UPDECOMP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"UPDECOMP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"UPDECOMP" -> "PFECAT"
+/*"UPDECOMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"UPDECOMP" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "SINT"}*/
+/*"UPDECOMP" -> {"BOOLEAN"; "LIST"}*/
+
+"UPDIVP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPDIVP"]
+/*"UPDIVP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"UPDIVP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"UPDIVP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"UPDIVP" -> {"MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"UPDIVP" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"UPDIVP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"UPDIVP" -> "PATMAB"; "GCDDOM"}*/
+"UPDIVP" -> "PFECAT"
+/*"UPDIVP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"UPDIVP" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "BOOLEAN"}*/
+
+"UPMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPMP"]
+/*"UPMP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UPMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UPMP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"UPMP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"UPMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"UPMP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"UPMP" -> {"PATMAB"; "GCDDOM"}*/
+"UPMP" -> "PFECAT"
+/*"UPMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"UPMP" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "LIST"; "ILIST"; "MONOID-"}*/
+/*"UPMP" -> "ABELMON-"*/
+
+"UPOLYC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPOLYC2"]
+/*"UPOLYC2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UPOLYC2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"UPOLYC2" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"UPOLYC2" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"UPOLYC2" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"UPOLYC2" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"UPOLYC2" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"UPOLYC2" -> "PFECAT"
+/*"UPOLYC2" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"UPOLYC2" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"}*/
+
+"UPXSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPXSCAT"]
+/*"UPXSCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"UPXSCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"UPXSCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UPXSCAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"UPXSCAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"UPXSCAT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"UPXSCAT" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"UPXSCAT" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"UPXSCAT" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
+/*"UPXSCAT" -> {"FPATMAB"; "TYPE"; "CHARNZ"}*/
+"UPXSCAT" -> "PFECAT"
+/*"UPXSCAT" -> {"UPSCAT"; "PSCAT"; "AMR"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"UPXSCAT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+
+"UPSQFREE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPSQFREE"]
+/*"UPSQFREE" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"UPSQFREE" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"UPSQFREE" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"UPSQFREE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
+/*"UPSQFREE" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"UPSQFREE" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"UPSQFREE" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+"UPSQFREE" -> "PFECAT"
+/*"UPSQFREE" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"UPSQFREE" -> {"PID"; "FIELD"; "DIVRING"; "FFIELDC"; "FPC"; "FINITE"}*/
+/*"UPSQFREE" -> {"INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
+/*"UPSQFREE" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"UPSQFREE" -> {"ABELGRP-"; "NNI"; "BOOLEAN"; "LIST"; "PI"}*/
+
+"VECTOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VECTOR",
+          shape=ellipse]
+/*"VECTOR" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"VECTOR" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"VECTOR" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"VECTOR" -> {"INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
+/*"VECTOR" -> {"SYMBOL"; "REF"; "ALIST"; "LIST"}*/
+"VECTOR" -> "STRING"
+/*"VECTOR" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
+/*"VECTOR" -> {"FLAGG-"; "LNAGG-"; "RADCAT"; "RING"; "RNG"; "ABELGRP"}*/
+/*"VECTOR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"VECTOR" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"VECTOR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"VECTOR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"VECTOR" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"VECTOR" -> {"CHARZ"; "STEP"; "OM"}*/
+
+"VIEWDEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=VIEWDEF"]
+/*"VIEWDEF" -> {"NNI"; "INT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"VIEWDEF" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"VIEWDEF" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"VIEWDEF" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"VIEWDEF" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"VIEWDEF" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"VIEWDEF" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"VIEWDEF" -> "BASTYPE-"*/
+"VIEWDEF" -> "STRING"
+/*"VIEWDEF" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"VIEWDEF" -> {"SRAGG-"; "STRICAT"; "SRAGG"; "A1AGG"}*/
+
+"VIEW2D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VIEW2D"]
+/*"VIEW2D" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "DFLOAT"; "INT"; "BOOLEAN"}*/
+/*"VIEW2D" -> {"PI"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"VIEW2D" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"VIEW2D" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"; "IVECTOR"}*/
+/*"VIEW2D" -> {"IARRAY1"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "SINT"}*/
+"VIEW2D" -> "STRING"
+/*"VIEW2D" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "INS"}*/
+/*"VIEW2D" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"VIEW2D" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"VIEW2D" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"VIEW2D" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"VIEW2D" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"VIEW2D" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "SRAGG-"}*/
+/*"VIEW2D" -> {"STRICAT"; "SRAGG"; "ELAGG-"; "FLAGG-"; "FPS"; "RNS"}*/
+/*"VIEW2D" -> {"FIELD"; "DIVRING"; "RADCAT"}*/
+
+"VOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VOID"]
+"VOID" -> "STRING"
+/*"VOID" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"VOID" -> {"A1AGG-"; "ISTRING"}*/
+
+"WEIER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=WEIER"]
+/*"WEIER" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"WEIER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"WEIER" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"WEIER" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"WEIER" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"; "POLYCAT"}*/
+/*"WEIER" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"WEIER" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"WEIER" -> {"KONVERT"; "PATMAB"}*/
+"WEIER" -> "PFECAT"
+/*"WEIER" -> {"MTSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"WEIER" -> {"HYPCAT"; "AHYP"; "ELEMFUN"}*/
+
+"WP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=WP"]
+/*"WP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
+/*"WP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"WP" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "OAMONS"; "OCAMON"}*/
+/*"WP" -> {"OAMON"; "OASGP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "COMRING"}*/
+/*"WP" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"WP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"WP" -> "GCDDOM"*/
+"WP" -> "PFECAT"
+/*"WP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"WP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"WP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"WP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"WP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"WP" -> {"BASTYPE-"; "NNI"; "BOOLEAN"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
+
+\end{chunk}
+\subsection{Layer12}
+Depends on: DIOPS DPOLCAT FINRALG FRAC RMATCAT RRCC UPXSCAT FFSQFR PACRATC
+PLPKCRV\\
+Used by next layer: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA
+\begin{chunk}{layer12}
+
+LAYER12=\
+  ${OUT}/DIAGG.o   ${OUT}/DIAGG-.o   ${OUT}/DSMP.o     ${OUT}/EXPUPXS.o \
+  ${OUT}/FACTRN.o  ${OUT}/FFFACTSE.o \
+  ${OUT}/FRAMALG.o ${OUT}/FRAMALG-.o ${OUT}/INTFRSP.o  ${OUT}/LPARSPT.o  \
+  ${OUT}/MDAGG.o   ${OUT}/NPOLYGON.o \
+  ${OUT}/ODPOL.o   ${OUT}/PLOT.o     ${OUT}/RFP.o     \
+  ${OUT}/RMCAT2.o  ${OUT}/ROIRC.o    ${OUT}/SDPOL.o   \
+  ${OUT}/SMATCAT.o ${OUT}/SMATCAT-.o ${OUT}/TUBETOOL.o ${OUT}/UPXSCCA.o \
+  ${OUT}/UPXSCCA-.o \
+  layer12done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 12 */
+/* depends on: DIOPS DPOLCAT FFSQFR FINRALG FRAC RMATCAT RRCC UPXSCAT */
+/*             PLPKCRV */
+
+"DFLOAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DFLOAT",
+          shape=ellipse]
+/*"DFLOAT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"DFLOAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DFLOAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DFLOAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DFLOAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"DFLOAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"DFLOAT" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"DFLOAT" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"DFLOAT" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "DFLOAT"; "INT"; "PI"; "NNI"}*/
+/*"DFLOAT" -> {"FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"DFLOAT" -> {"DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"DFLOAT" -> "MODULE-"*/
+"DFLOAT" -> "FRAC"
+/*"DFLOAT" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "INS"; "OINTDOM"; "LINEXP"}*/
+/*"DFLOAT" -> {"CFCAT"; "STEP"; "INS"}*/
+
+"DIAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIAGG"]
+"DIAGG" -> "DIOPS"
+/*"DIAGG" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"DIAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
+/*"DIAGG" -> {"BOOLEAN"; "NNI"; "INT"}*/
+
+"DIAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIAGG"]
+"DIAGG-" -> "DIOPS"
+/*"DIAGG-" -> {"BGAGG";  "HOAGG";  "AGG";  "TYPE";  "SETCAT";  "BASTYPE"}*/
+/*"DIAGG-" -> {"KOERCE";  "EVALAB";  "IEVALAB";  "CLAGG";  "KONVERT"}*/
+/*"DIAGG-" -> {"BOOLEAN";  "NNI";  "INT"}*/
+
+"DSMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DSMP"]
+"DSMP" -> "DPOLCAT"
+/*"DSMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DSMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"DSMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"DSMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"DSMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"DSMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
+/*"DSMP" -> {"UFD"; "DIFEXT"; "DIFRING"; "DVARCAT"; "NNI"; "INT"; "FPS"}*/
+/*"DSMP" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"}*/
+/*"DSMP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
+/*"DSMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"; "ELTAB"}*/
+
+"EXPUPXS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXPUPXS"]
+/*"EXPUPXS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"EXPUPXS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"EXPUPXS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"EXPUPXS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"EXPUPXS" -> {"UFD"; "DIVRING"; "ORDSET"}*/
+"EXPUPXS" -> "UPXSCAT"
+/*"EXPUPXS" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
+/*"EXPUPXS" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"EXPUPXS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "OAMON"; "OASGP"}*/
+/*"EXPUPXS" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "KONVERT"}*/
+/*"EXPUPXS" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+/*"EXPUPXS" -> {"INT"; "LIST"; "ILIST"; "BOOLEAN"; "OM"; "QFCAT"; "FEVALAB"}*/
+/*"EXPUPXS" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"EXPUPXS" -> {"TYPE"; "PFECAT"}*/
+
+"FACTRN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACTRN"]
+"FACTRN" -> "PACRATC"
+/*"FACTRN" -> {"PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FACTRN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FACTRN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FACTRN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FACTRN" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"}*/
+/*"FACTRN" -> {"XF"; "VSPACE"; "FPC"; "CHARNZ"; "FINITE"; "UPOLYC"}*/
+/*"FACTRN" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "FRETRCT"; "EVALAB"}*/
+/*"FACTRN" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"FACTRN" -> {"PFECAT"}*/
+/*"FACTRN" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"; "STAGG"}*/
+/*"FACTRN" -> {"URAGG" "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
+/*"FACTRN" -> {"ELTAGG" "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"} */
+/*"FACTRN" -> {"ILIST" "LSAGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"FACTRN" -> {"OCAMON" "OAMON"; "OASGP"; "CFCAT"; "REAL"; "QFCAT"}*/
+/*"FACTRN" -> {"FEVALAB""PATAB"; "FPATMAB"}*/
+
+"FFFACTSE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFACTSE"]
+/*"FFFACTSE" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"FFFACTSE" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FFFACTSE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FFFACTSE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FFFACTSE" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FFFACTSE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/ 
+/*"FFFACTSE" -> {"DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"}*/
+/*"FFFACTSE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"FFFACTSE" -> {"CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"FFFACTSE" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"FFFACTSE" -> {"KONVERT"; "PATMAB"}*/
+"FFFACTSE" -> "PFECAT"
+"FFFACTSE" -> "FFSQFR"
+/*"FFFACTSE" -> {"ELTAB"; "DIFEXT"}*/
+/*"FFFACTSE" -> {"NNI"; "INT"; "PI"; "PRIMARR"; "A1AGG"; "FLAGG"}*/
+/*"FFFACTSE" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FFFACTSE" -> {"ELTAGG"; "CLAGG"; "BOOLEAN"; "SINT"; "LIST"}*/
+/*"FFFACTSE" -> {"ILIST"; "LSAGG-"; "STAGG-"; "INS-"; "INS"}*/
+/*"FFFACTSE" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FFFACTSE" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+
+"FRAMALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FRAMALG"]
+"FRAMALG" -> "FINRALG"
+/*"FRAMALG" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FRAMALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FRAMALG" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "CHARZ"; "CHARNZ"}*/
+/*"FRAMALG" -> {"COMRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"FRAMALG" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"FRAMALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"FRAMALG" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
+/*"FRAMALG" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+/*"FRAMALG" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"FRAMALG" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "INT"; "VECTOR"}*/
+/*"FRAMALG" -> {"IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"FRAMALG" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"FRAMALG" -> {"OM"; "NNI"; "PI"; "SINT"; "LIST"; "ILIST"}*/
+
+"FRAMALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRAMALG"]
+"FRAMALG-" -> "FINRALG"
+/*"FRAMALG-" -> {"ALGEBRA";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
+/*"FRAMALG-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
+/*"FRAMALG-" -> {"SGROUP";  "MONOID";  "LMODULE";  "MODULE";  "BMODULE"}*/
+/*"FRAMALG-" -> {"RMODULE";  "CHARZ";  "CHARNZ";  "COMRING";  "UPOLYC"}*/
+/*"FRAMALG-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "INTDOM"}*/
+/*"FRAMALG-" -> {"ENTIRER";  "FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB"}*/
+/*"FRAMALG-" -> {"FLINEXP";  "LINEXP";  "ORDSET";  "KONVERT";  "PATMAB"}*/
+/*"FRAMALG-" -> {"GCDDOM";  "PFECAT";  "UFD";  "ELTAB";  "DIFRING"}*/
+/*"FRAMALG-" -> {"DIFEXT";  "STEP";  "EUCDOM";  "PID";  "FIELD";  "DIVRING"}*/
+/*"FRAMALG-" -> {"VECTCAT";  "A1AGG";  "FLAGG";  "LNAGG";  "IXAGG";  "HOAGG"}*/
+/*"FRAMALG-" -> {"AGG";  "TYPE";  "ELTAGG";  "CLAGG";  "INT";  "VECTOR"}*/
+/*"FRAMALG-" -> {"IVECTOR";  "IARRAY1";  "INS";  "OINTDOM";  "ORDRING"}*/
+/*"FRAMALG-" -> {"OAGROUP";  "OCAMON";  "OAMON";  "OASGP";  "CFCAT";  "REAL"}*/
+/*"FRAMALG-" -> {"OM";  "NNI";  "PI";  "SINT";  "LIST";  "ILIST"}*/
+
+"INTFRSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTFRSP"]
+"INTFRSP" -> "PFORP"
+"INTFRSP" -> "PARAMP"
+"INTFRSP" -> "LISYSER"
+/*"INTFRSP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"}*/
+/*"INTFRSP" -> {"DIVCAT"; "LOP"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"INTFRSP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTFRSP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"INTFRSP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"INTFRSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"INTFRSP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"INTFRSP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"INTFRSP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"INTFRSP" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"INTFRSP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
+/*"INTFRSP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"}*/
+/*"INTFRSP" -> {"VSPACE"; "UPSCAT"; "PSCAT"; "FAMONC"; "INT"; "LIST"}*/
+/*"INTFRSP" -> {"ILIST"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"INTFRSP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "VECTOR"}*/
+/*"INTFRSP" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"}*/
+/*"INTFRSP" -> {"LNAGG-"; "IXAGG-"; "LSAGG-"; "SINT"; "PI"; "STAGG-"}*/
+/*"INTFRSP" -> {"ELAGG-"; "OUTFORM"}*/
+
+"LPARSPT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LPARSPT"]
+"LPARSPT" -> "PLPKCRV"
+/*"LPARSPT" -> {"PFECAT"; "DIRPCAT"}*/
+/*"LPARSPT" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "FIELD"}*/
+/*"LPARSPT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"LPARSPT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"LPARSPT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LPARSPT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LPARSPT" -> {"UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"LPARSPT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"LPARSPT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"LPARSPT" -> {"PATMAB"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"LPARSPT" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
+/*"LPARSPT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"}*/
+/*"LPARSPT" -> {"VSPACE"; "UPSCAT"; "PSCAT"; "SINT"; "INT"; "LSAGG"}*/
+/*"LPARSPT" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"}*/
+/*"LPARSPT" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"; "STEP"}*/
+/*"LPARSPT" -> {"UPOLYC"; "PI"; "LSAGG-"; "STAGG-"; "OUTFORM"; "ELAGG-"}*/
+
+"MDAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MDAGG"]
+"MDAGG" -> "DIOPS"
+/*"MDAGG" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"MDAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
+
+"NPOLYGON" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NPOLYGON"]
+/*"NPOLYGON" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"NPOLYGON" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NPOLYGON" -> {"LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"NPOLYGON" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"NPOLYGON" -> {"ENTIRER"; "FRETRCT"; "RETRACT"}*/
+"NPOLYGON" -> "DIRPCAT"
+/*"NPOLYGON" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"NPOLYGON" -> {"ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"NPOLYGON" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"}*/
+/*"NPOLYGON" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "OAMONS"; "VSPACE"}*/
+/*"NPOLYGON" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "INT"}*/
+/*"NPOLYGON" -> {"PI"; "NNI"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"NPOLYGON" -> {"RCAGG"; "LNAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
+/*"NPOLYGON" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"NPOLYGON" -> {"BOOLEAN"}*/
+
+"ODPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODPOL"]
+"ODPOL" -> "DPOLCAT"
+/*"ODPOL" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ODPOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ODPOL" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"ODPOL" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"ODPOL" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"ODPOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+/*"ODPOL" -> {"PFECAT"; "UFD"; "DIFEXT"; "DIFRING"; "DVARCAT"; "FPS"; "RNS"}*/
+/*"ODPOL" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"ODPOL" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"}*/
+/*"ODPOL" -> {"CFCAT"; "STEP"; "UPOLYC"; "ELTAB"}*/
+
+"PLOT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLOT"]
+/*"PLOT" -> {"PPCURVE"; "KOERCE"; "BOOLEAN"; "INT"; "DFLOAT"; "FPS-"}*/
+/*"PLOT" -> {"RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"}*/
+/*"PLOT" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
+/*"PLOT" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"; "ORDSET-"}*/
+/*"PLOT" -> {"ABELSG-"; "SGROUP-"; "TRANFUN-"; "SETCAT-"; "ELEMFUN-"}*/
+/*"PLOT" -> {"HYPCAT-"; "ATRIG-"; "TRIGCAT-"; "RADCAT-"; "RETRACT-"}*/
+/*"PLOT" -> {"BASTYPE-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PLOT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PLOT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"}*/
+/*"PLOT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PLOT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"PLOT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"PLOT" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "PTCAT"; "VECTCAT"}*/
+/*"PLOT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PLOT" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "LIST"}*/
+/*"PLOT" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
+/*"PLOT" -> {"NNI"; "PI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"PLOT" -> {"SINT"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
+/*"PLOT" -> {"STEP"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"PLOT" -> {"ELEMFUN"; "SPFCAT"}*/
+"PLOT" -> "FRAC"
+
+"RFP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFP"]
+/*"RFP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"RFP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"RFP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RFP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"RFP" -> {"INT"; "LIST"; "ILIST"; "PACPERC"; "FFIELDC"; "FPC"; "CHARNZ"}*/
+/*"RFP" -> {"FINITE"; "STEP"; "DIFRING"; "PACFFC"; "UPOLYC"; "POLYCAT"}*/
+/*"RFP" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"RFP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"RFP" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"RFP" -> {"GCDDOM-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"RFP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"RFP" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "QFCAT"; "FEVALAB"; "PATAB"}*/
+/*"RFP" -> {"FPATMAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"RFP" -> {"OASGP"; "REAL"; "INS"; "CFCAT"}*/
+"RFP" -> "PACRATC"
+/*"RFP" -> {"XF"; "VSPACE"; "BOOLEAN"; "NNI"; "FLAGG-"; "URAGG-"}*/
+
+"RMCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RMCAT2"]
+/*"RMCAT2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RMCAT2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RMCAT2" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"RMCAT2" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"; "BMODULE"}*/
+/*"RMCAT2" -> {"RMODULE"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"RMCAT2" -> {"FINITE"; "ALGEBRA"; "MODULE"; "COMRING"; "ORDRING"}*/
+/*"RMCAT2" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "OAMONS"}*/
+/*"RMCAT2" -> {"VSPACE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"RMCAT2" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+"RMCAT2" -> "RMATCAT"
+/*"RMCAT2" -> {"NNI"; "INT"}*/
+
+"ROIRC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ROIRC"]
+"ROIRC" -> "RRCC"
+/*"ROIRC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ROIRC" -> {"OAMON"; "OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"ROIRC" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ROIRC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ROIRC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ROIRC" -> {"UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"ROIRC" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"ROIRC" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"ROIRC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"; "INT"; "LIST"}*/
+/*"ROIRC" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"ROIRC" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"ROIRC" -> {"ILIST"; "PI"; "BOOLEAN"; "INS"; "OINTDOM"; "CFCAT"; "REAL"}*/
+
+"SDPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SDPOL"]
+"SDPOL" -> "DPOLCAT"
+/*"SDPOL" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SDPOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"SDPOL" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"SDPOL" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"SDPOL" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"SDPOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"SDPOL" -> {"GCDDOM"; "PFECAT"; "UFD"; "DIFEXT"; "DIFRING"; "DVARCAT"}*/
+/*"SDPOL" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"}*/
+/*"SDPOL" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
+/*"SDPOL" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"; "ELTAB"}*/
+
+"SMATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SMATCAT"]
+/*"SMATCAT" -> {"DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"SMATCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"SMATCAT" -> {"MONOID"; "LMODULE"; "DIFRING"; "PDRING"; "BMODULE"}*/
+/*"SMATCAT" -> "RMODULE"*/
+"SMATCAT" -> "RMATCAT"
+/*"SMATCAT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "MODULE"}*/
+/*"SMATCAT" -> {"COMRING"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"SMATCAT" -> {"ALGEBRA"; "DIRPCAT"; "IXAGG"; "ELTAGG"; "ELTAB"; "FINITE"}*/
+/*"SMATCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"SMATCAT" -> {"OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"SMATCAT" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "NNI"; "INT"}*/
+/*"SMATCAT" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "KONVERT"}*/
+/*"SMATCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "VECTCAT"}*/
+/*"SMATCAT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "CLAGG"; "LSAGG"; "STAGG"}*/
+/*"SMATCAT" -> {"URAGG"; "RCAGG"; "ELAGG"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"SMATCAT" -> {"VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"SMATCAT" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "INS-"}*/
+
+"SMATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SMATCAT"]
+/*"SMATCAT-" -> {"DIFEXT";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
+/*"SMATCAT-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
+/*"SMATCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "DIFRING";  "PDRING"}*/
+/*"SMATCAT-" -> {"BMODULE";  "RMODULE"}*/
+"SMATCAT-" -> "RMATCAT"
+/*"SMATCAT-" -> {"HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB";  "MODULE"}*/
+/*"SMATCAT-" -> {"COMRING";  "FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP"}*/
+/*"SMATCAT-" -> {"ALGEBRA";  "DIRPCAT";  "IXAGG";  "ELTAGG";  "ELTAB"}*/
+/*"SMATCAT-" -> {"FINITE";  "ORDRING";  "OAGROUP";  "OCAMON";  "OAMON"}*/
+/*"SMATCAT-" -> {"OASGP";  "ORDSET";  "OAMONS";  "VSPACE";  "FIELD"}*/
+/*"SMATCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "ENTIRER"}*/
+/*"SMATCAT-" -> {"UFD";  "DIVRING";  "NNI";  "INT";  "VECTOR";  "IVECTOR"}*/
+/*"SMATCAT-" -> {"IARRAY1";  "INS";  "OINTDOM";  "KONVERT";  "PATMAB"}*/
+/*"SMATCAT-" -> {"CFCAT";  "REAL";  "CHARZ";  "STEP";  "OM";  "VECTCAT"}*/
+/*"SMATCAT-" -> {"A1AGG";  "FLAGG";  "LNAGG";  "CLAGG";  "LSAGG";  "STAGG"}*/
+/*"SMATCAT-" -> {"URAGG";  "RCAGG";  "ELAGG";  "LIST";  "ILIST";  "LSAGG-"}*/
+/*"SMATCAT-" -> {"VECTCAT-";  "A1AGG-";  "FLAGG-";  "LNAGG-";  "IXAGG-"}*/
+/*"SMATCAT-" -> {"CLAGG-";  "HOAGG-";  "ORDSET-";  "AGG-";  "INS-"}*/
+
+"TUBETOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TUBETOOL"]
+/*"TUBETOOL" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"TUBETOOL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"TUBETOOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"TUBETOOL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"TUBETOOL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"TUBETOOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"TUBETOOL" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"TUBETOOL" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+/*"TUBETOOL" -> {"OM"; "INT"; "DFLOAT"; "FPS-"; "RNS-"; "FIELD-"; "LIST"}*/
+/*"TUBETOOL" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
+/*"TUBETOOL" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
+"TUBETOOL" -> "FRAC"
+/*"TUBETOOL" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "SINT"; "PI"; "NNI"}*/
+/*"TUBETOOL" -> {"ILIST"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"TUBETOOL" -> "URAGG-"*/
+
+"UPXSCCA" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPXSCCA"]
+"UPXSCCA" -> "UPXSCAT"
+/*"UPXSCCA" -> {"UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"}*/
+/*"UPXSCCA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"UPXSCCA" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"UPXSCCA" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"UPXSCCA" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
+/*"UPXSCCA" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"UPXSCCA" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"UPXSCCA" -> {"GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "ULSCAT"}*/
+
+"UPXSCCA-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXSCCA"]
+"UPXSCCA-" -> "UPXSCAT"
+/*"UPXSCCA-" -> {"UPSCAT";  "PSCAT";  "AMR";  "RING";  "RNG";  "ABELGRP"}*/
+/*"UPXSCCA-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
+/*"UPXSCCA-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
+/*"UPXSCCA-" -> {"RMODULE";  "COMRING";  "ALGEBRA";  "MODULE";  "CHARZ"}*/
+/*"UPXSCCA-" -> {"CHARNZ";  "INTDOM";  "ENTIRER";  "ELTAB";  "DIFRING"}*/
+/*"UPXSCCA-" -> {"PDRING";  "RADCAT";  "TRANFUN";  "TRIGCAT";  "ATRIG"}*/
+/*"UPXSCCA-" -> {"HYPCAT";  "AHYP";  "ELEMFUN";  "FIELD";  "EUCDOM";  "PID"}*/
+/*"UPXSCCA-" -> {"GCDDOM";  "UFD";  "DIVRING";  "RETRACT";  "ULSCAT"}*/
+
+\end{chunk}
+\subsection{Layer13}
+Depends on: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA RFP\\
+Used by next layer: FSAGG KDAGG MSETAGG MONOGEN
+\begin{chunk}{layer13}
+
+LAYER13=\
+  ${OUT}/AFALGGRO.o ${OUT}/AFALGRES.o \
+  ${OUT}/DPMM.o     ${OUT}/EFUPXS.o  ${OUT}/FFINTBAS.o ${OUT}/FRIDEAL.o  \
+  ${OUT}/FRIDEAL2.o ${OUT}/FRMOD.o   ${OUT}/FSAGG.o    ${OUT}/FSAGG-.o   \
+  ${OUT}/IBATOOL.o  ${OUT}/INTFACT.o ${OUT}/KDAGG.o    ${OUT}/KDAGG-.o   \
+  ${OUT}/MSETAGG.o  ${OUT}/MONOGEN.o ${OUT}/MONOGEN-.o ${OUT}/NFINTBAS.o \
+  layer13done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 13 */
+/* depends on: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA RFP*/
+
+"AFALGGRO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AFALGGRO"]
+"AFALGGRO" -> "DIRPCAT"
+"AFALGGRO" -> "PFECAT"
+/*"AFALGGRO" -> {"PRSPCAT"; "SETCATD"; "PACFFC"; "PACPERC"; "FIELD"}*/
+/*"AFALGGRO" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"AFALGGRO" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"AFALGGRO" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"AFALGGRO" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"AFALGGRO" -> {"UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"AFALGGRO" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"AFALGGRO" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"AFALGGRO" -> {"PATMAB"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"AFALGGRO" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
+/*"AFALGGRO" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
+/*"AFALGGRO" -> {"SINT"; "OUTFORM"; "INT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"AFALGGRO" -> {"RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
+/*"AFALGGRO" -> {"ILIST"; "NNI"; "FFIELDC"; "FPC"; "STEP"; "PI"; "VECTOR"}*/
+/*"AFALGGRO" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "ORDFIN"}*/
+/*"AFALGGRO" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "INS-"}*/
+/*"AFALGGRO" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+
+"AFALGRES" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AFALGRES"]
+"AFALGRES" -> "RFP" 
+/*"AFALGRES" -> {"PRSPCAT"; "LOCPOWC"; "SETCATD"; "PACFFC"; "CHARZ"}*/
+/*"AFALGRES" -> {"PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"AFALGRES" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"AFALGRES" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"AFALGRES" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"AFALGRES" -> {"UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"AFALGRES" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"AFALGRES" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"AFALGRES" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "ELTAB"}*/
+/*"AFALGRES" -> {"DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"AFALGRES" -> {"OASGP"; "OAMONS"; "VSPACE"; "UPOLYC"; "STEP"; "NNI"; "INT"}*/
+/*"AFALGRES" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "FFIELDC"; "FPC"; "PI"}*/
+/*"AFALGRES" -> {"VECTOR"; "OUTFORM"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
+/*"AFALGRES" -> {"SGROUP-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"AFALGRES" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "FLAGG-"}*/
+/*"AFALGRES" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "ENTIRER"; "FLINEXP"}*/
+/*"AFALGRES" -> {"URAGG-"; "DIRPCAT"; "DIFEXT"; "OAMON"}*/
+
+"DPMM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DPMM"]
+/*"DPMM" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"DPMM" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"DPMM" -> {"FRETRCT"; "RETRACT"; "BMODULE"; "LMODULE"; "ABELGRP"}*/
+/*"DPMM" -> {"CABMON"; "ABELMON"; "ABELSG"; "RMODULE"; "DIFEXT"; "RING"}*/
+/*"DPMM" -> {"RNG"; "SGROUP"; "MONOID"; "DIFRING"; "PDRING"; "FLINEXP"}*/
+/*"DPMM" -> {"LINEXP"; "FINITE"; "ALGEBRA"; "MODULE"; "COMRING"; "ORDRING"}*/
+/*"DPMM" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "OAMONS"}*/
+/*"DPMM" -> {"VSPACE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"DPMM" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+"DPMM" -> "SMATCAT"
+/*"DPMM" -> {"RMATCAT"; "SINT"; "PI"; "NNI"; "INT"; "INS"; "OINTDOM"}*/
+/*"DPMM" -> {"KONVERT"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+
+"EFUPXS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EFUPXS"]
+/*"EFUPXS" -> "PTRANFN"*/
+"EFUPXS" -> "UPXSCCA"
+/*"EFUPXS" -> {"UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"}*/
+/*"EFUPXS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"EFUPXS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"EFUPXS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"EFUPXS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
+/*"EFUPXS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"}*/
+/*"EFUPXS" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"EFUPXS" -> {"ULSCAT"; "NNI"; "INT"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"EFUPXS" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"}*/
+/*"EFUPXS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "OM"; "PI"}*/
+/*"EFUPXS" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
+/*"EFUPXS" -> {"A1AGG-"; "ISTRING"}*/
+
+"FFINTBAS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFINTBAS"]
+/*"FFINTBAS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"FFINTBAS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FFINTBAS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FFINTBAS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FFINTBAS" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"FFINTBAS" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"FFINTBAS" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"FFINTBAS" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"FFINTBAS" -> {"FIELD"; "DIVRING"}*/
+"FFINTBAS" -> "FRAMALG"
+/*"FFINTBAS" -> {"FINRALG"; "INT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"FFINTBAS" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "NNI"}*/
+
+"FRIDEAL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRIDEAL"]
+/*"FRIDEAL" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"}*/
+/*"FRIDEAL" -> {"KOERCE"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FRIDEAL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FRIDEAL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FRIDEAL" -> {"ENTIRER"; "QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"FRIDEAL" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"FRIDEAL" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"FRIDEAL" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
+/*"FRIDEAL" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FRIDEAL" -> {"REAL"; "CHARZ"; "CHARNZ"; "PFECAT"; "UPOLYC"; "POLYCAT"}*/
+/*"FRIDEAL" -> {"FAMR"; "AMR"; "FRETRCT"}*/
+"FRIDEAL" -> "FRAMALG"
+/*"FRIDEAL" -> {"FINRALG"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"FRIDEAL" -> {"HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "INT"; "VECTOR"}*/
+/*"FRIDEAL" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "BOOLEAN"}*/
+/*"FRIDEAL" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"}*/
+/*"FRIDEAL" -> {"ILIST"; "LSAGG-"; "SINT"; "NNI"; "MONOID-"; "ABELMON-"}*/
+/*"FRIDEAL" -> {"INS"; "CFCAT"; "STAGG-"; "ELAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"FRIDEAL" -> {"FINITE"; "PI"}*/
+
+"FRIDEAL2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRIDEAL2"]
+/*"FRIDEAL2" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"FRIDEAL2" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FRIDEAL2" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FRIDEAL2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FRIDEAL2" -> {"QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
+/*"FRIDEAL2" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
+/*"FRIDEAL2" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"}*/
+/*"FRIDEAL2" -> {"FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"}*/
+/*"FRIDEAL2" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"FRIDEAL2" -> {"CHARZ"; "CHARNZ"; "PFECAT"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"FRIDEAL2" -> {"AMR"; "FRETRCT"}*/
+"FRIDEAL2" -> "FRAMALG"
+/*"FRIDEAL2" -> {"FINRALG"; "INS"; "CFCAT"; "OM"; "INT"; "VECTOR"; "IVECTOR"}*/
+/*"FRIDEAL2" -> "IARRAY1"*/
+
+"FRMOD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRMOD"]
+"FRMOD" -> "FRAMALG"
+/*"FRMOD" -> {"FINRALG"; "ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FRMOD" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FRMOD" -> {"MONOID"; "LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "CHARZ"}*/
+/*"FRMOD" -> {"CHARNZ"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FRMOD" -> {"ENTIRER"; "QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"FRMOD" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
+/*"FRMOD" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"FRMOD" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
+/*"FRMOD" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "PFECAT"}*/
+/*"FRMOD" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "BOOLEAN"}*/
+/*"FRMOD" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"FRMOD" -> {"AGG"; "ELTAGG"; "CLAGG"; "INT"; "VECTOR"; "IVECTOR"}*/
+/*"FRMOD" -> {"IARRAY1"; "INS"; "CFCAT"; "OM"; "VECTCAT-"; "A1AGG-"; "NNI"}*/
+/*"FRMOD" -> "PI"*/
+
+"FSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FSAGG"]
+"FSAGG" -> "DIAGG"
+/*"FSAGG" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"FSAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
+/*"FSAGG" -> {"SETAGG"; "FINITE"; "NNI"; "INT"; "BOOLEAN"; "SINT"; "PI"}*/
+/*"FSAGG" -> {"INS-"; "ORDSET"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"FSAGG" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"}*/
+/*"FSAGG" -> {"ELAGG"; "OM"; "LSAGG-"}*/
+
+"FSAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FSAGG"]
+"FSAGG-" -> "DIAGG"
+/*"FSAGG-" -> {"DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE";  "SETCAT"}*/
+/*"FSAGG-" -> {"BASTYPE";  "KOERCE";  "EVALAB";  "IEVALAB";  "CLAGG"}*/
+/*"FSAGG-" -> {"KONVERT";  "SETAGG";  "FINITE";  "NNI";  "INT";  "BOOLEAN"}*/
+/*"FSAGG-" -> {"SINT";  "PI";  "INS-";  "ORDSET";  "LIST";  "ILIST"}*/
+/*"FSAGG-" -> {"LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "LNAGG";  "IXAGG"}*/
+/*"FSAGG-" -> {"ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG";  "OM";  "LSAGG-"}*/
+
+"IBATOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IBATOOL"]
+/*"IBATOOL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"IBATOOL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"IBATOOL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IBATOOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"IBATOOL" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"IBATOOL" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"IBATOOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"IBATOOL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
+/*"IBATOOL" -> "DIVRING"*/
+"IBATOOL" -> "FRAMALG"
+/*"IBATOOL" -> {"FINRALG"; "SINT"; "NNI"; "INT"; "PI"; "INS"; "OINTDOM"}*/
+/*"IBATOOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
+/*"IBATOOL" -> {"REAL"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"}*/
+/*"IBATOOL" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"IBATOOL" -> {"TYPE"; "ELTAGG"; "CLAGG"}*/
+
+"INTFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTFACT"]
+/*"INTFACT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"INTFACT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"INTFACT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INTFACT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"INTFACT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"INTFACT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"INTFACT" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"}*/
+/*"INTFACT" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"INTFACT" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"INTFACT" -> {"ABELMON-"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"INTFACT" -> {"PI"; "NNI"; "SINT"; "BOOLEAN"}*/
+"INTFACT" -> "MDAGG"
+/*"INTFACT" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"INTFACT" -> {"IEVALAB"; "CLAGG"}*/
+
+"KDAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=KDAGG"]
+"KDAGG" -> "DIAGG"
+/*"KDAGG" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"KDAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
+/*"KDAGG" -> "BOOLEAN"*/
+
+"KDAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=KDAGG"]
+"KDAGG-" -> "DIAGG"
+/*"KDAGG-" -> {"DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE";  "SETCAT"}*/
+/*"KDAGG-" -> {"BASTYPE";  "KOERCE";  "EVALAB";  "IEVALAB";  "CLAGG"}*/
+/*"KDAGG-" -> {"KONVERT";  "BOOLEAN"}*/
+
+"MSETAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MSETAGG"]
+"MSETAGG" -> "MDAGG"
+/*"MSETAGG" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"MSETAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"MSETAGG" -> {"KONVERT"; "SETAGG"}*/
+
+"MONOGEN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONOGEN"]
+/*"MONOGEN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"MONOGEN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"MONOGEN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"MONOGEN" -> "FRAMALG"
+/*"MONOGEN" -> {"FINRALG"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"MONOGEN" -> {"KONVERT"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"MONOGEN" -> {"FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"MONOGEN" -> {"ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"MONOGEN" -> {"FFIELDC"; "FPC"; "STEP"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"MONOGEN" -> {"AMR"; "EVALAB"; "IEVALAB"; "ORDSET"; "PATMAB"; "PFECAT"}*/
+/*"MONOGEN" -> {"ELTAB"; "NNI"; "INT"; "SINT"; "MONOID-"; "ABELMON-"}*/
+/*"MONOGEN" -> {"ORDSET-"; "SGROUP-"; "PI"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"MONOGEN" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"MONOGEN" -> {"OASGP"; "CFCAT"; "REAL"}*/
+
+"MONOGEN-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONOGEN"]
+/*"MONOGEN-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
+/*"MONOGEN-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
+/*"MONOGEN-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
+"MONOGEN-" -> "FRAMALG"
+/*"MONOGEN-" -> {"FINRALG";  "ALGEBRA";  "MODULE";  "CHARZ";  "CHARNZ"}*/
+/*"MONOGEN-" -> {"KONVERT";  "FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP"}*/
+/*"MONOGEN-" -> {"FINITE";  "FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
+/*"MONOGEN-" -> {"ENTIRER";  "UFD";  "DIVRING";  "DIFEXT";  "DIFRING"}*/
+/*"MONOGEN-" -> {"PDRING";  "FFIELDC";  "FPC";  "STEP";  "UPOLYC"}*/
+/*"MONOGEN-" -> {"POLYCAT";  "FAMR";  "AMR";  "EVALAB";  "IEVALAB"}*/
+/*"MONOGEN-" -> {"ORDSET";  "PATMAB";  "PFECAT";  "ELTAB";  "NNI";  "INT"}*/
+/*"MONOGEN-" -> {"SINT";  "MONOID-";  "ABELMON-";  "ORDSET-";  "SGROUP-"}*/
+/*"MONOGEN-" -> {"PI";  "VECTOR";  "IVECTOR";  "IARRAY1";  "INS";  "OINTDOM"}*/
+/*"MONOGEN-" -> {"ORDRING";  "OAGROUP";  "OCAMON";  "OAMON";  "OASGP"}*/
+/*"MONOGEN-" -> {"CFCAT";  "REAL"}*/
+
+"NFINTBAS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NFINTBAS"]
+/*"NFINTBAS" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NFINTBAS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"NFINTBAS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"NFINTBAS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"NFINTBAS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"NFINTBAS" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"NFINTBAS" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
+/*"NFINTBAS" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"NFINTBAS" -> {"FIELD"; "DIVRING"}*/
+"NFINTBAS" -> "FRAMALG"
+/*"NFINTBAS" -> {"FINRALG"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"}*/
+/*"NFINTBAS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"NFINTBAS" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"NFINTBAS" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"NFINTBAS" -> {"CLAGG"; "LIST"; "ILIST"; "PI"; "NNI"; "INS-"; "EUCDOM-"}*/
+
+\end{chunk}
+\subsection{Layer14}
+Depends on: FSAGG KDAGG MSETAGG MONOGEN\\
+Used by next layer: TBAGG
+\begin{chunk}{layer14}
+
+LAYER14=\
+  ${OUT}/BSD.o \
+  ${OUT}/CCLASS.o   ${OUT}/CPIMA.o   ${OUT}/FSAGG2.o   ${OUT}/GALFACT.o  \
+  ${OUT}/IALGFACT.o ${OUT}/IBACHIN.o  ${OUT}/MMLFORM.o ${OUT}/NORMMA.o   \
+  ${OUT}/ODERED.o   ${OUT}/OMSAGG.o   ${OUT}/PERM.o    ${OUT}/PERMGRP.o  \
+  ${OUT}/PRIMES.o   ${OUT}/PRJALGPK.o \
+  ${OUT}/PWFFINTB.o ${OUT}/RDIST.o   ${OUT}/SAE.o      \
+  ${OUT}/SAEFACT.o  ${OUT}/SAERFFC.o  ${OUT}/SGCF.o    ${OUT}/SPACE3.o   \
+  ${OUT}/TBAGG.o    ${OUT}/TBAGG-.o   ${OUT}/VIEW3D.o  ${OUT}/WFFINTBS.o \
+  layer14done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 14 */
+/* depends on: FSAGG KDAGG MSETAGG MONOGEN */
+
+"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
+        shape=ellipse]
+/*"BSD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "INT"}*/
+/*"BSD" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"BSD" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "OM"; "PATMAB"}*/
+"BSD" -> "FSAGG" 
+
+"CHAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CHAR",
+        shape=ellipse]
+/*"CHAR" -> {"ORDFIN"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
+/*"CHAR" -> {"SINT"; "INT"; "NNI"; "PRIMARR"; "A1AGG-"; "INS"; "UFD"}*/
+/*"CHAR" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"CHAR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CHAR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"CHAR" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"CHAR" -> {"OASGP"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"CHAR" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "PI"}*/
+"CHAR" -> "FSAGG" 
+/*"CHAR" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"CHAR" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "STRING"; "CHAR"; "OUTFORM"}*/
+/*"CHAR" -> {"LIST"; "ISTRING"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
+/*"CHAR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+
+"CCLASS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CCLASS"]
+/*"CCLASS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"}*/
+"CCLASS" -> "FSAGG"
+/*"CCLASS" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"CCLASS" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "ORDFIN"; "ORDSET"}*/
+/*"CCLASS" -> {"INT"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
+/*"CCLASS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "NNI"; "BOOLEAN"; "INS"; "UFD"}*/
+/*"CCLASS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"CCLASS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CCLASS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"CCLASS" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"CCLASS" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"CCLASS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "FLAGG-"; "LNAGG-"}*/
+/*"CCLASS" -> {"BTAGG"; "LOGIC"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"CCLASS" -> {"ELTAGG"; "ELTAB"}*/
+
+"CPIMA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CPIMA"]
+/*"CPIMA" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"CPIMA" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"CPIMA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "UPOLYC"; "POLYCAT"}*/
+/*"CPIMA" -> {"PDRING"; "FAMR"; "AMR"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
+/*"CPIMA" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"CPIMA" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"CPIMA" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
+/*"CPIMA" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+"CPIMA" -> "MONOGEN"
+/*"CPIMA" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "NNI"; "INT"}*/
+
+"FSAGG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSAGG2"]
+/*"FSAGG2" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"FSAGG2" -> "FSAGG"
+/*"FSAGG2" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FSAGG2" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "SETAGG"; "FINITE"}*/
+
+"GALFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALFACT"]
+/*"GALFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"GALFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"GALFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"GALFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"GALFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"GALFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"GALFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
+/*"GALFACT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"GALFACT" -> {"FIELD"; "DIVRING"; "BOOLEAN"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"GALFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"GALFACT" -> {"OM"; "INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"GALFACT" -> {"INTDOM-"; "PI"; "NNI"; "OAMONS"}*/
+"GALFACT" -> "FSAGG"
+/*"GALFACT" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "CLAGG"}*/
+/*"GALFACT" -> {"SETAGG"; "FINITE"; "SINT"; "LIST"; "ILIST"; "ALGEBRA-"}*/
+/*"GALFACT" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"GALFACT" -> {"ABELMON-"; "FPS"; "RNS"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"GALFACT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "LSAGG"; "STAGG"}*/
+/*"GALFACT" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "FLAGG"}*/
+/*"GALFACT" -> {"ELAGG"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"GALFACT" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "MONOID-"; "ORDSET-"}*/
+/*"GALFACT" -> {"ABELSG-"; "SGROUP-"; "CLAGG-"; "HOAGG-"; "AGG-"; "ELTAGG-"}*/
+/*"GALFACT" -> {"SETCAT-"; "BASTYPE-"}*/
+
+"IALGFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IALGFACT"]
+/*"IALGFACT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"IALGFACT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IALGFACT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"IALGFACT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"IALGFACT" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
+/*"IALGFACT" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"IALGFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"IALGFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
+/*"IALGFACT" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
+"IALGFACT" -> "MONOGEN"
+/*"IALGFACT" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "NNI"}*/
+/*"IALGFACT" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"IALGFACT" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"IALGFACT" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
+
+"IBACHIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IBACHIN"]
+/*"IBACHIN" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"IBACHIN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"IBACHIN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"IBACHIN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"IBACHIN" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"IBACHIN" -> {"STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"IBACHIN" -> {"AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"IBACHIN" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"IBACHIN" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "SINT"; "NNI"; "INT"; "LIST"}*/
+/*"IBACHIN" -> {"ILIST"; "LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"IBACHIN" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"IBACHIN" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "PI"}*/
+"IBACHIN" -> "MONOGEN"
+/*"IBACHIN" -> {"FRAMALG"; "FINRALG"; "BOOLEAN"; "STAGG-"; "VECTCAT"}*/
+/*"IBACHIN" -> "A1AGG"*/
+
+"ISTRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ISTRING",
+          shape=ellipse]
+/*"ISTRING" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"ISTRING" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"ISTRING" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"ISTRING" -> {"INT"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
+/*"ISTRING" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "INS"; "UFD"; "GCDDOM"}*/
+/*"ISTRING" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ISTRING" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ISTRING" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ISTRING" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ISTRING" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"ISTRING" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "NNI"; "BOOLEAN"}*/
+"ISTRING" -> "FSAGG"
+/*"ISTRING" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "ORDFIN"}*/
+/*"ISTRING" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"ISTRING" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
+/*"ISTRING" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"}*/
+/*"ISTRING" -> {"URAGG"; "RCAGG"; "ELAGG"}*/
+
+"MMLFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MMLFORM"]
+/*"MMLFORM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"; "STRING"}*/
+/*"MMLFORM" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
+/*"MMLFORM" -> {"ISTRING"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"MMLFORM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"MMLFORM" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"MMLFORM" -> {"ORDSET"; "ELAGG"; "OM"; "STRICAT"; "SRAGG"; "A1AGG"; "PI"}*/
+"MMLFORM" -> "FSAGG"
+/*"MMLFORM" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "ORDFIN"}*/
+/*"MMLFORM" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"MMLFORM" -> "SRAGG-"*/
+
+"NORMMA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NORMMA"]
+/*"NORMMA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NORMMA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"NORMMA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"NORMMA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
+/*"NORMMA" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"NORMMA" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"NORMMA" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "ELTAB"}*/
+/*"NORMMA" -> {"DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
+/*"NORMMA" -> "DIVRING"*/
+"NORMMA" -> "MONOGEN"
+/*"NORMMA" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+
+"ODERED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODERED"]
+/*"ODERED" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODERED" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODERED" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ODERED" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ODERED" -> {"DIVRING"; "LODOCAT"; "OREPCAT"; "FRETRCT"; "RETRACT"}*/
+/*"ODERED" -> {"ELTAB"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"ODERED" -> {"CHARZ"; "CHARNZ"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"ODERED" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "DIFRING"; "DIFEXT"}*/
+/*"ODERED" -> "STEP"*/
+"ODERED" -> "MONOGEN"
+/*"ODERED" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "VECTCAT"}*/
+/*"ODERED" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"ODERED" -> {"ELTAGG"; "CLAGG"; "NNI"; "INT"; "SINT"; "PI"}*/
+
+"OMSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OMSAGG"]
+/*"OMSAGG" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"OMSAGG" -> "MSETAGG"
+/*"OMSAGG" -> {"MDAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"OMSAGG" -> {"IEVALAB"; "CLAGG"; "KONVERT"; "SETAGG"; "PRQAGG"}*/
+
+"PERM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PERM"]
+/*"PERM" -> {"PERMCAT"; "GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"}*/
+/*"PERM" -> {"KOERCE"; "ORDSET"; "FINITE"; "INT"; "BOOLEAN"; "LIST"}*/
+/*"PERM" -> {"ILIST"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PERM" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PERM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PERM" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"PERM" -> {"OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"PERM" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LSAGG-"}*/
+/*"PERM" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "SINT"}*/
+/*"PERM" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PERM" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"PERM" -> {"CLAGG"; "FLAGG"; "ELAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+"PERM" -> "FSAGG"
+/*"PERM" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "NNI"; "INS-"; "EUCDOM-"}*/
+/*"PERM" -> {"UFD-"; "GCDDOM-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"PERM" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT-"}*/
+/*"PERM" -> {"A1AGG-"; "PI"}*/
+
+"PERMGRP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PERMGRP"]
+/*"PERMGRP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "BOOLEAN"}*/
+/*"PERMGRP" -> {"LIST"; "ILIST"; "SINT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"PERMGRP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PERMGRP" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PERMGRP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"PERMGRP" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PERMGRP" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"PERMGRP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LSAGG-"}*/
+/*"PERMGRP" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "LSAGG"}*/
+/*"PERMGRP" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"PERMGRP" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"PERMGRP" -> {"FLAGG"; "ELAGG"; "OAMONS"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"PERMGRP" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"PERMGRP" -> {"BASTYPE-"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"PERMGRP" -> {"A1AGG-"; "VECTCAT"; "A1AGG"}*/
+"PERMGRP" -> "FSAGG"
+/*"PERMGRP" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "PI"}*/
+/*"PERMGRP" -> {"PERMCAT"; "GROUP"}*/
+
+"PRIMES" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRIMES"]
+/*"PRIMES" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PRIMES" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PRIMES" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PRIMES" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"PRIMES" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"PRIMES" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"PRIMES" -> {"REAL"; "CHARZ"; "STEP"; "PI"; "NNI"; "INT"; "MONOID-"}*/
+/*"PRIMES" -> {"ABELSG-"; "SGROUP-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"PRIMES" -> {"VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"PRIMES" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"PRIMES" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"PRIMES" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"PRIMES" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
+/*"PRIMES" -> {"BOOLEAN"; "VECTCAT"; "A1AGG"}*/
+"PRIMES" -> "FSAGG"
+/*"PRIMES" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "LSAGG-"}*/
+/*"PRIMES" -> "STAGG-"*/
+
+"PRJALGPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRJALGPK"]
+"PRJALGPK" -> "AFALGGRO"
+/*"PRJALGPK" -> {"PRSPCAT"; "LOCPOWC"; "SETCATD"; "PACFFC"; "PACPERC"; "RFP"}*/
+/*"PRJALGPK" -> {"PLPKCRV"; "INTERGB"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PRJALGPK" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PRJALGPK" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PRJALGPK" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PRJALGPK" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"PRJALGPK" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"PRJALGPK" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"PRJALGPK" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"PRJALGPK" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"PRJALGPK" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
+/*"PRJALGPK" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
+/*"PRJALGPK" -> {"SINT"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"PRJALGPK" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
+/*"PRJALGPK" -> {"NNI"; "PI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"PRJALGPK" -> {"LSAGG-"; "STAGG-"; "FFIELDC"; "FPC"; "STEP"; "MONOID-"}*/
+/*"PRJALGPK" -> {"ABELMON-"; "ORDSET-"; "SGROUP-"; "ELAGG-"; "FLAGG-"}*/
+/*"PRJALGPK" -> {"URAGG-"; "OUTFORM"}*/
+
+"PWFFINTB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PWFFINTB"]
+/*"PWFFINTB" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PWFFINTB" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PWFFINTB" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PWFFINTB" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PWFFINTB" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
+/*"PWFFINTB" -> {"FINITE"; "STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"PWFFINTB" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"PWFFINTB" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"PWFFINTB" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFEXT"}*/
+"PWFFINTB" -> "MONOGEN"
+/*"PWFFINTB" -> {"FRAMALG"; "FINRALG"; "QFCAT"; "FEVALAB"; "PATAB"}*/
+/*"PWFFINTB" -> {"FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PWFFINTB" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "OM"; "INT"; "LIST"}*/
+/*"PWFFINTB" -> {"ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PWFFINTB" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"PWFFINTB" -> {"CLAGG"; "FLAGG"; "ELAGG"; "PI"; "NNI"; "INS"; "CFCAT"}*/
+/*"PWFFINTB" -> {"VECTCAT"; "A1AGG"}*/
+
+"RDIST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDIST"]
+/*"RDIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
+/*"RDIST" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"RDIST" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RDIST" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"RDIST" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"RDIST" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"RDIST" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"RDIST" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"RDIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"RDIST" -> {"VECTCAT"; "A1AGG"}*/
+"RDIST" -> "FSAGG"
+/*"RDIST" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"}*/
+
+"SAE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SAE"]
+/*"SAE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SAE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SAE" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"SAE" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"SAE" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"SAE" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+/*"SAE" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"SAE" -> {"PID"; "FIELD"; "DIVRING"}*/
+"SAE" -> "MONOGEN"
+/*"SAE" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "NNI"; "INT"}*/
+/*"SAE" -> {"BOOLEAN"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"SAE" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"SAE" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT"}*/
+/*"SAE" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"SAE" -> {"ELTAGG"; "CLAGG"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
+/*"SAE" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SAE" -> {"REAL"; "PI"; "INS"; "CFCAT"; "OAMONS"}*/
+
+"SAEFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SAEFACT"]
+/*"SAEFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SAEFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SAEFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"SAEFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"SAEFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"SAEFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"SAEFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
+/*"SAEFACT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"SAEFACT" -> {"FIELD"; "DIVRING"}*/
+"SAEFACT" -> "MONOGEN"
+/*"SAEFACT" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "INS"}*/
+/*"SAEFACT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SAEFACT" -> {"CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
+/*"SAEFACT" -> "TYPE"*/
+
+"SAERFFC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SAERFFC"]
+/*"SAERFFC" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SAERFFC" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SAERFFC" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"SAERFFC" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"SAERFFC" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"SAERFFC" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"SAERFFC" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
+/*"SAERFFC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"SAERFFC" -> {"FIELD"; "DIVRING"}*/
+"SAERFFC" -> "MONOGEN"
+/*"SAERFFC" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "INS"}*/
+/*"SAERFFC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"SAERFFC" -> {"OASGP"; "CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"}*/
+/*"SAERFFC" -> {"FPATMAB"; "TYPE"}*/
+
+"SGCF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SGCF"]
+/*"SGCF" -> {"INT"; "SINT"; "NNI"; "LIST"; "ILIST"; "LSAGG-"; "VECTOR"}*/
+/*"SGCF" -> {"IVECTOR"; "IARRAY1"; "BOOLEAN"; "STAGG-"; "VECTCAT"}*/
+/*"SGCF" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"SGCF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"SGCF" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTCAT-"; "A1AGG-"}*/
+/*"SGCF" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"SGCF" -> {"RCAGG"; "ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"SGCF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"SGCF" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SGCF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"SGCF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"SGCF" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"SGCF" -> {"STEP"; "ELAGG-"; "URAGG-"}*/
+"SGCF" -> "FSAGG"
+/*"SGCF" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"}*/
+
+"SPACE3" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SPACE3"]
+/*"SPACE3" -> {"SPACEC"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
+/*"SPACE3" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"SPACE3" -> {"MONOID"; "LMODULE"; "BOOLEAN"; "INT"; "LIST"; "LSAGG"}*/
+/*"SPACE3" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"SPACE3" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"SPACE3" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
+/*"SPACE3" -> {"ILIST"; "NNI"; "PI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"SPACE3" -> {"URAGG-"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+"SPACE3" -> "FSAGG"
+/*"SPACE3" -> {"DIAGG" ; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"}*/
+
+"TBAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TBAGG"]
+"TBAGG" -> "KDAGG"
+/*"TBAGG" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"TBAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"TBAGG" -> {"CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"TBAGG" -> {"BOOLEAN"; "NNI"; "INT"; "LIST"; "ILIST"}*/
+
+"TBAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TBAGG"]
+"TBAGG-" -> "KDAGG"
+/*"TBAGG-" -> {"DIAGG";  "DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE"}*/
+/*"TBAGG-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "EVALAB";  "IEVALAB"}*/
+/*"TBAGG-" -> {"CLAGG";  "KONVERT";  "IXAGG";  "ELTAGG";  "ELTAB"}*/
+/*"TBAGG-" -> {"BOOLEAN";  "NNI";  "INT";  "LIST";  "ILIST"}*/
+
+"VIEW3D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VIEW3D"]
+/*"VIEW3D" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "DFLOAT"}*/
+/*"VIEW3D" -> {"BOOLEAN"; "PI"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"}*/
+/*"VIEW3D" -> {"GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"VIEW3D" -> {"ORDRING-"; "MODULE-"; "FRAC"; "RING-"; "ABELGRP-"}*/
+/*"VIEW3D" -> {"ABELMON-"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
+/*"VIEW3D" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"VIEW3D" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"VIEW3D" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"VIEW3D" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"VIEW3D" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"VIEW3D" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"VIEW3D" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"}*/
+/*"VIEW3D" -> "OM"*/
+"VIEW3D" -> "FSAGG"
+/*"VIEW3D" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"VIEW3D" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "LSAGG"; "STAGG"}*/
+/*"VIEW3D" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"VIEW3D" -> {"FLAGG"; "ELAGG"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"VIEW3D" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"VIEW3D" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "INS"; "OINTDOM"}*/
+/*"VIEW3D" -> {"LINEXP"; "CFCAT"; "STEP"; "SRAGG-"; "STRICAT"; "SRAGG"}*/
+/*"VIEW3D" -> "A1AGG"*/
+
+"WFFINTBS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=WFFINTBS"]
+/*"WFFINTBS" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"WFFINTBS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"WFFINTBS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"WFFINTBS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"WFFINTBS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
+/*"WFFINTBS" -> {"FINITE"; "STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"WFFINTBS" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"WFFINTBS" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"WFFINTBS" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFEXT"; "FRAMALG"}*/
+/*"WFFINTBS" -> {"FINRALG"; "INT"; "LIST"; "ILIST"; "SINT"; "PI"; "NNI"}*/
+/*"WFFINTBS" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"}*/
+/*"WFFINTBS" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"WFFINTBS" -> {"ELTAGG"; "CLAGG"}*/
+"WFFINTBS" -> "MONOGEN"
+
+\end{chunk}
+\subsection{Layer15}
+Depends on: TBAGG\\
+Used by next layer: ALIST
+\begin{chunk}{layer15}
+
+LAYER15=\
+  ${OUT}/ALIST.o   ${OUT}/EQTBL.o   ${OUT}/GSTBL.o   ${OUT}/HASHTBL.o \
+  ${OUT}/INTABL.o  ${OUT}/INTFTBL.o ${OUT}/INTPACK.o ${OUT}/IPF.o     \
+  ${OUT}/KAFILE.o  ${OUT}/PATRES.o  ${OUT}/PDEPACK.o ${OUT}/STBL.o    \
+  ${OUT}/STRTBL.o  ${OUT}/TABLE.o   ${OUT}/TBCMPPK.o  \
+  layer15done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 15 */
+/* depends on: TBAGG */
+
+"ALAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ALAGG",
+         shape=ellipse]
+"ALAGG" -> "TBAGG"
+/*"ALAGG" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"ALAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"ALAGG" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "LSAGG"; "STAGG"}*/
+/*"ALAGG" -> {"URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+
+"ALIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALIST"]
+/*"ALIST" -> "ALAGG"*/
+"ALIST" -> "TBAGG"
+/*"ALIST" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"ALIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"ALIST" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "LSAGG"; "STAGG"}*/
+/*"ALIST" -> {"URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"ALIST" -> {"INT"; "LIST"; "ILIST"; "OM"; "INS"; "UFD"; "GCDDOM"}*/
+/*"ALIST" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ALIST" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ALIST" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"ALIST" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ALIST" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"ALIST" -> {"CHARZ"; "STEP"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"ALIST" -> {"URAGG-"; "LNAGG-"; "BOOLEAN"; "STRING"; "CHAR"; "SINT"}*/
+/*"ALIST" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+
+"EQTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EQTBL"]
+"EQTBL" -> "TBAGG"
+/*"EQTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"EQTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"EQTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
+
+"FFIELDC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FFIELDC",
+          shape=ellipse]
+/*"FFIELDC" -> {"FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFIELDC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFIELDC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFIELDC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFIELDC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
+/*"FFIELDC" -> {"DIFRING"; "PI"; "NNI"; "INT"; "LIST"; "ILIST"; "VECTCAT"}*/
+/*"FFIELDC" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FFIELDC" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"FFIELDC" -> {"ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"FFIELDC" -> {"A1AGG-"; "BOOLEAN"; "SINT"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"FFIELDC" -> "OASGP"*/
+"FFIELDC" -> "TBAGG"
+/*"FFIELDC" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "INS-"; "INS"; "OINTDOM"}*/
+/*"FFIELDC" -> {"ORDRING"; "OAGROUP"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"FFIELDC" -> {"REAL"; "CHARZ"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"FFIELDC" -> {"AMR"; "FRETRCT"; "FLINEXP"; "PFECAT"; "DIFEXT"}*/
+
+"FFIELDC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFIELDC",
+          shape=ellipse]
+/*"FFIELDC-" -> {"FPC";  "FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
+/*"FFIELDC-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
+/*"FFIELDC-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
+/*"FFIELDC-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
+/*"FFIELDC-" -> {"ALGEBRA";  "MODULE";  "ENTIRER";  "UFD";  "DIVRING"}*/
+/*"FFIELDC-" -> {"CHARNZ";  "FINITE";  "STEP";  "DIFRING";  "PI";  "NNI"}*/
+/*"FFIELDC-" -> {"INT";  "LIST";  "ILIST";  "VECTCAT";  "A1AGG";  "FLAGG"}*/
+/*"FFIELDC-" -> {"LNAGG";  "IXAGG";  "HOAGG";  "AGG";  "TYPE";  "EVALAB"}*/
+/*"FFIELDC-" -> {"IEVALAB";  "ELTAGG";  "ELTAB";  "CLAGG";  "KONVERT"}*/
+/*"FFIELDC-" -> {"ORDSET";  "VECTOR";  "IVECTOR";  "IARRAY1";  "VECTCAT-"}*/
+/*"FFIELDC-" -> {"A1AGG-";  "BOOLEAN";  "SINT";  "OAMONS";  "OCAMON"}*/
+/*"FFIELDC-" -> {"OAMON";  "OASGP"}*/
+"FFIELDC-" -> "TBAGG"
+/*"FFIELDC-" -> {"KDAGG";  "DIAGG";  "DIOPS";  "BGAGG";  "INS-";  "INS"}*/
+/*"FFIELDC-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "RETRACT";  "LINEXP"}*/
+/*"FFIELDC-" -> {"PATMAB";  "CFCAT";  "REAL";  "CHARZ";  "UPOLYC"}*/
+/*"FFIELDC-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "FRETRCT"}*/
+/*"FFIELDC-" -> {"FLINEXP";  "PFECAT";  "DIFEXT"}*/
+
+"GSTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GSTBL"]
+/*"GSTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"GSTBL" -> "TBAGG"
+/*"GSTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"GSTBL" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
+/*"GSTBL" -> {"ELTAB"; "ORDSET"}*/
+
+"HASHTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HASHTBL"]
+"HASHTBL" -> "TBAGG"
+/*"HASHTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"HASHTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"HASHTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
+
+"INTABL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTABL"]
+"INTABL" -> "TBAGG"
+/*"INTABL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"INTABL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"INTABL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
+
+"INTFTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTFTBL"]
+"INTFTBL" -> "TBAGG"
+/*"INTFTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"INTFTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"INTFTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+
+"INTPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTPACK"]
+/*"INTPACK" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"INTPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"INTPACK" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INTPACK" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INTPACK" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"INTPACK" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"INTPACK" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
+/*"INTPACK" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "LSAGG"}*/
+/*"INTPACK" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"INTPACK" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"INTPACK" -> {"FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "DFLOAT"}*/
+/*"INTPACK" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"INTPACK" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"INTPACK" -> {"FLAGG-"; "LNAGG-"; "BOOLEAN"; "STAGG-"}*/
+"INTPACK" -> "TBAGG"
+/*"INTPACK" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "NNI"; "INS-"; "PI"}*/
+/*"INTPACK" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "ABELSG-"}*/
+/*"INTPACK" -> {"SETCAT-"; "BASTYPE-"; "STRICAT"; "SRAGG"; "A1AGG"}*/
+/*"INTPACK" -> "SPFCAT"*/
+
+"IPF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IPF"]
+/*"IPF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"IPF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"IPF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"IPF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"IPF" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
+/*"IPF" -> {"DIFRING"; "FAXF"; "XF"; "RETRACT"; "VSPACE"; "CHARZ"; "KONVERT"}*/
+/*"IPF" -> {"PI"; "NNI"; "INT"; "LIST"; "BOOLEAN"; "OAMONS"; "OCAMON"}*/
+/*"IPF" -> {"OAMON"; "OASGP"; "ORDSET"}*/
+"IPF" -> "TBAGG"
+/*"IPF" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"IPF" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "SINT"}*/
+/*"IPF" -> {"INS-"; "ILIST"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"IPF" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "VECTOR"; "IVECTOR"}*/
+/*"IPF" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
+/*"IPF" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"IPF" -> "BASTYPE-"*/
+
+"KAFILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=KAFILE"]
+/*"KAFILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"KAFILE" -> "TBAGG"
+/*"KAFILE" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"KAFILE" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
+/*"KAFILE" -> {"ELTAB"; "FNCAT"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"KAFILE" -> {"LIST"; "INT"; "PRIMARR"; "A1AGG-"; "ISTRING"; "LSAGG"}*/
+/*"KAFILE" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"}*/
+/*"KAFILE" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "STRICAT"}*/
+/*"KAFILE" -> {"SRAGG"; "A1AGG"; "ORDFIN"; "FINITE"}*/
+
+"PATRES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PATRES"]
+/*"PATRES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "BOOLEAN"; "ALAGG"}*/
+"PATRES" -> "TBAGG"
+/*"PATRES" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PATRES" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
+/*"PATRES" -> {"ELTAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"PATRES" -> {"FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"}*/
+
+"PDEPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PDEPACK"]
+/*"PDEPACK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"}*/
+/*"PDEPACK" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "ILIST"}*/
+"PDEPACK" -> "TBAGG"
+/*"PDEPACK" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PDEPACK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"PDEPACK" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "NNI"; "SYMBOL"}*/
+/*"PDEPACK" -> {"REF"; "ALIST"; "FLAGG-"; "LNAGG-"; "INS-"; "PI"; "FPS"}*/
+/*"PDEPACK" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"PDEPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PDEPACK" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PDEPACK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"PDEPACK" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"PDEPACK" -> {"REAL"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"}*/
+/*"PDEPACK" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"PDEPACK" -> "ELEMFUN"*/
+
+"STBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STBL"]
+/*"STBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
+"STBL" -> "TBAGG"
+/*"STBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"STBL" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
+/*"STBL" -> {"ELTAB"; "ORDSET"}*/
+
+"STRTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STRTBL"]
+"STRTBL" -> "TBAGG"
+/*"STRTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"STRTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"STRTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "STRICAT"; "SRAGG"}*/
+/*"STRTBL" -> {"A1AGG"; "FLAGG"; "LNAGG"; "ORDSET"; "OM"; "ORDFIN"; "FINITE"}*/
+
+"TABLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TABLE"]
+"TABLE" -> "TBAGG"
+/*"TABLE" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"TABLE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"TABLE" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ALAGG"; "LSAGG"}*/
+/*"TABLE" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"}*/
+/*"TABLE" -> "ELAGG"*/
+
+"TBCMPPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TBCMPPK"]
+/*"TBCMPPK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"; "NNI"; "INT"}*/
+/*"TBCMPPK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
+/*"TBCMPPK" -> {"A1AGG-"; "ISTRING"}*/
+"TBCMPPK" -> "TBAGG"
+/*"TBCMPPK" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"TBCMPPK" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
+/*"TBCMPPK" -> "ELTAB"*/
+
+\end{chunk}
+\subsection{Layer16}
+Depends on: ALIST\\
+Used by next layer: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT 
+\begin{chunk}{layer16}
+
+LAYER16=\
+  ${OUT}/ACF.o      ${OUT}/ACF-.o     ${OUT}/ACPLOT.o   ${OUT}/ANTISYM.o  \
+  ${OUT}/ANY.o      ${OUT}/ASP12.o    ${OUT}/ASP27.o    ${OUT}/ASP28.o    \
+  ${OUT}/ASP30.o    ${OUT}/ASP33.o    ${OUT}/ASP49.o    ${OUT}/ASP55.o    \
+  ${OUT}/ASP7.o     ${OUT}/ASP78.o    ${OUT}/ASP8.o     ${OUT}/ASP9.o     \
+  ${OUT}/ATTRBUT.o  ${OUT}/BLUPPACK.o \
+  ${OUT}/BOP.o      ${OUT}/BOP1.o     ${OUT}/COMMONOP.o \
+  ${OUT}/COMPCAT.o  ${OUT}/COMPCAT-.o ${OUT}/DRAW.o     ${OUT}/DRAWCFUN.o \
+  ${OUT}/DROPT.o    ${OUT}/DROPT0.o   ${OUT}/D01ANFA.o  ${OUT}/D01ASFA.o  \
+  ${OUT}/D03AGNT.o  ${OUT}/EP.o       ${OUT}/E04AGNT.o  ${OUT}/FCPAK1.o   \
+  ${OUT}/FEXPR.o    ${OUT}/FFCAT.o    ${OUT}/FFCAT-.o   ${OUT}/FFCGP.o    \
+  ${OUT}/FFNBP.o    ${OUT}/FFP.o      ${OUT}/FLOAT.o    ${OUT}/FPARFRAC.o \
+  ${OUT}/FR.o       ${OUT}/FRNAALG.o  ${OUT}/FRNAALG-.o ${OUT}/FS.o       \
+  ${OUT}/FS-.o      ${OUT}/FST.o      ${OUT}/FUNCTION.o ${OUT}/GDMP.o     \
+  ${OUT}/GOPT.o     ${OUT}/GOPT0.o    ${OUT}/HACKPI.o   ${OUT}/IDEAL.o    \
+  ${OUT}/INFCLCT.o  \
+  ${OUT}/INFORM.o   ${OUT}/INFORM1.o  ${OUT}/IPRNTPK.o  ${OUT}/IR.o       \
+  ${OUT}/ISUPS.o    ${OUT}/KERNEL.o   ${OUT}/LIB.o      ${OUT}/LMDICT.o   \
+  ${OUT}/LODO.o     ${OUT}/LODOOPS.o  ${OUT}/MATRIX.o   ${OUT}/MKFLCFN.o  \
+  ${OUT}/MSET.o     ${OUT}/M3D.o      ${OUT}/NAGC02.o   ${OUT}/NAGC05.o   \
+  ${OUT}/NAGC06.o   ${OUT}/NAGD01.o   ${OUT}/NAGD02.o   ${OUT}/NAGD03.o   \
+  ${OUT}/NAGE01.o   ${OUT}/NAGE02.o   ${OUT}/NAGE04.o   ${OUT}/NAGF07.o   \
+  ${OUT}/NAGS.o     ${OUT}/NAGSP.o    ${OUT}/NREP.o     ${OUT}/NSDPS.o    \
+  ${OUT}/NUMFMT.o   \
+  ${OUT}/OC.o       ${OUT}/OC-.o      ${OUT}/ODEPACK.o  ${OUT}/ODERAT.o   \
+  ${OUT}/OMERR.o    ${OUT}/OMERRK.o   ${OUT}/OPTPACK.o  ${OUT}/OSI.o      \
+  ${OUT}/OVAR.o     ${OUT}/PACOFF.o   ${OUT}/PACRAT.o  \
+  ${OUT}/PATTERN.o  ${OUT}/PLCS.o     ${OUT}/PMKERNEL.o ${OUT}/PMSYM.o    \
+  ${OUT}/POLY.o     ${OUT}/PRIMELT.o  ${OUT}/QALGSET2.o ${OUT}/QEQUAT.o   \
+  ${OUT}/QUATCAT.o  ${OUT}/QUATCAT-.o ${OUT}/RECLOS.o   ${OUT}/REP1.o     \
+  ${OUT}/RESULT.o   ${OUT}/RFFACT.o   ${OUT}/RMATRIX.o  ${OUT}/ROMAN.o    \
+  ${OUT}/ROUTINE.o  ${OUT}/RPOLCAT.o  ${OUT}/RPOLCAT-.o ${OUT}/RULECOLD.o \
+  ${OUT}/SAOS.o     ${OUT}/SEGBIND.o  ${OUT}/SET.o      ${OUT}/SPECOUT.o  \
+  ${OUT}/SQMATRIX.o ${OUT}/SWITCH.o   ${OUT}/SYMS.o     ${OUT}/SYMTAB.o   \
+  ${OUT}/SYSSOLP.o  ${OUT}/UTSCAT.o   ${OUT}/UTSCAT-.o  ${OUT}/VARIABLE.o \
+  layer16done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 16 */
+/* depends on: ALIST */
+
+"ACF" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ACF"]
+/*"ACF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ACF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ACF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ACF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ACF" -> {"DIVRING"; "RADCAT"; "SYMBOL"; "INT"; "REF"}*/
+"ACF" -> "ALIST"
+/*"ACF" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ACF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"ACF" -> {"NNI"; "PI"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"ACF" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"ACF" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"ACF" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"; "STAGG"}*/
+/*"ACF" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
+/*"ACF" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"}*/
+/*"ACF" -> {"ELAGG-"; "URAGG-"; "BOOLEAN"}*/
+
+"ACF-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ACF"]
+/*"ACF-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "COMRING"}*/
+/*"ACF-" -> {"RING";  "RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
+/*"ACF-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP";  "MONOID"}*/
+/*"ACF-" -> {"LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
+/*"ACF-" -> {"ENTIRER";  "UFD";  "DIVRING";  "RADCAT";  "SYMBOL";  "INT"}*/
+/*"ACF-" -> "REF"*/
+"ACF-" -> "ALIST"
+/*"ACF-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
+/*"ACF-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-";  "ILIST"}*/
+/*"ACF-" -> {"NNI";  "PI";  "UPOLYC";  "POLYCAT";  "PDRING";  "FAMR"}*/
+/*"ACF-" -> {"AMR";  "CHARZ";  "CHARNZ";  "FRETRCT";  "RETRACT";  "EVALAB"}*/
+/*"ACF-" -> {"IEVALAB";  "FLINEXP";  "LINEXP";  "ORDSET";  "KONVERT"}*/
+/*"ACF-" -> {"PATMAB";  "PFECAT";  "ELTAB";  "DIFRING";  "DIFEXT"}*/
+/*"ACF-" -> {"STEP";  "LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "HOAGG"}*/
+/*"ACF-" -> {"AGG";  "TYPE";  "LNAGG";  "IXAGG";  "ELTAGG";  "CLAGG"}*/
+/*"ACF-" -> {"FLAGG";  "ELAGG";  "OM";  "LSAGG-";  "STAGG-";  "ELAGG-"}*/
+/*"ACF-" -> {"URAGG-";  "BOOLEAN"}*/
+
+"ACPLOT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ACPLOT"]
+/*"ACPLOT" -> {"PPCURVE"; "KOERCE"; "PI"; "NNI"; "INT"; "DFLOAT"; "FPS"}*/
+/*"ACPLOT" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ACPLOT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ACPLOT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ACPLOT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ACPLOT" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ACPLOT" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ACPLOT" -> {"CHARZ"; "BOOLEAN"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ACPLOT" -> {"CFCAT"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"ACPLOT" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"ACPLOT" -> {"TYPE"; "CHARNZ"; "PFECAT"; "FPS-"; "RNS-"; "LIST"; "ILIST"}*/
+/*"ACPLOT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "OM"}*/
+/*"ACPLOT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
+/*"ACPLOT" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "SYMBOL"; "REF"}*/
+"ACPLOT" -> "ALIST" 
+/*"ACPLOT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"ACPLOT" -> {"ISTRING"; "SRAGG-"; "LNAGG-"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"ACPLOT" -> {"FRETRCT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"ACPLOT" -> {"ELEMFUN"; "SPFCAT"; "RCAGG-"; "IXAGG-"; "PTCAT"; "VECTCAT"}*/
+/*"ACPLOT" -> "A1AGG"*/
+
+"ANTISYM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ANTISYM"]
+/*"ANTISYM" -> {"LALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ANTISYM" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ANTISYM" -> {"LMODULE"; "RETRACT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ANTISYM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"ANTISYM" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"ANTISYM" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
+/*"ANTISYM" -> {"NNI"; "SINT"; "LSAGG-"; "STAGG-"; "PI"; "INS-"; "EUCDOM-"}*/
+/*"ANTISYM" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"ANTISYM" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "SYMBOL"; "REF"}*/
+"ANTISYM" -> "ALIST"
+/*"ANTISYM" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"ANTISYM" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"ANY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ANY"]
+/*"ANY" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
+"ANY" -> "ALIST"
+/*"ANY" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ANY" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"ANY" -> "LSAGG-"*/
+
+"ASP12" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP12"]
+/*"ASP12" -> {"FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"ASP12" -> "ALIST"
+/*"ASP12" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP12" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"ASP12" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"ASP12" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"ASP12" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ASP12" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"ASP12" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"ASP12" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"ASP12" -> {"CHARZ"; "STEP"; "OM"}*/
+
+"ASP27" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP27"]
+/*"ASP27" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
+/*"ASP27" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP27" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP27" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP27" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"ASP27" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ASP27" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"ASP27" -> {"SINT"; "PI"; "NNI"; "INT"; "SYMBOL"; "REF"}*/
+"ASP27" -> "ALIST"
+/*"ASP27" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"ASP27" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FMTC"}*/
+
+"ASP28" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP28"]
+/*"ASP28" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
+/*"ASP28" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP28" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP28" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP28" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"ASP28" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ASP28" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"ASP28" -> {"SINT"; "PI"; "NNI"; "INT"; "SYMBOL"; "REF"}*/
+"ASP28" -> "ALIST"
+/*"ASP28" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"ASP28" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FMTC"; "VECTOR"}*/
+
+"ASP30" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP30"]
+/*"ASP30" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
+/*"ASP30" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP30" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP30" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP30" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"ASP30" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ASP30" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"ASP30" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+/*"ASP30" -> {"SYMBOL"; "INT"; "REF"}*/
+"ASP30" -> "ALIST"
+/*"ASP30" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP30" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "OM"}*/
+
+"ASP33" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP33"]
+/*"ASP33" -> {"FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"ASP33" -> "ALIST"
+/*"ASP33" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP33" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+
+"ASP49" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP49"]
+/*"ASP49" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
+/*"ASP49" -> {"INT"; "REF"}*/
+"ASP49" -> "ALIST"
+/*"ASP49" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP49" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"ASP49" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP49" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP49" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP49" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP49" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP49" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP49" -> {"CHARZ"; "ES"; "IEVALAB"; "EVALAB"; "VECTCAT"; "A1AGG"}*/
+/*"ASP49" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
+/*"ASP49" -> {"ELTAB"; "CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ASP49" -> {"ELAGG"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP49" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP49" -> {"FRETRCT"; "FLINEXP"; "PFECAT"}*/
+
+"ASP55" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP55"]
+/*"ASP55" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
+/*"ASP55" -> {"INT"; "REF"}*/
+"ASP55" -> "ALIST"
+/*"ASP55" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP55" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"ASP55" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP55" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP55" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP55" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP55" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP55" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP55" -> {"CHARZ"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
+/*"ASP55" -> {"STEP"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "NNI"}*/
+/*"ASP55" -> {"VECTCAT-"; "IXAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ASP55" -> {"HOAGG"; "AGG"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"ASP55" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "LSAGG-"}*/
+/*"ASP55" -> {"ES"; "VECTCAT"; "A1AGG"; "FMTC"; "POLYCAT"; "PDRING"}*/
+/*"ASP55" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"; "PFECAT"}*/
+
+"ASP7" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP7"]
+/*"ASP7" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"ASP7" -> "ALIST"
+/*"ASP7" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP7" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"ASP7" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP7" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP7" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP7" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP7" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP7" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP7" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP7" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP7" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
+
+"ASP78" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP78"]
+/*"ASP78" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"ASP78" -> "ALIST"
+/*"ASP78" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP78" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"ASP78" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP78" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP78" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP78" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP78" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP78" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP78" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP78" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP78" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
+
+"ASP8" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP8"]
+/*"ASP8" -> {"FVC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
+/*"ASP8" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP8" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP8" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP8" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"ASP8" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ASP8" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"ASP8" -> {"SYMBOL"; "INT"; "REF"}*/
+"ASP8" -> "ALIST"
+/*"ASP8" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP8" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
+/*"ASP8" -> {"OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "VECTCAT"}*/
+/*"ASP8" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "EVALAB"}*/
+/*"ASP8" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"; "IVECTOR"}*/
+/*"ASP8" -> {"IARRAY1"; "FMTC"; "NNI"; "OM"; "ILIST"}*/
+
+"ASP9" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP9"]
+/*"ASP9" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"ASP9" -> "ALIST"
+/*"ASP9" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ASP9" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"ASP9" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP9" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP9" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP9" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP9" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP9" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP9" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP9" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP9" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
+
+"ATTRBUT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ATTRBUT"]
+/*"ATTRBUT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"; "FIELD"}*/
+/*"ATTRBUT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"ATTRBUT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"ATTRBUT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ATTRBUT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"ATTRBUT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"ATTRBUT" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INT"}*/
+/*"ATTRBUT" -> {"LIST"; "ILIST"; "SYMBOL"; "REF"}*/
+"ATTRBUT" -> "ALIST"
+/*"ATTRBUT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"ATTRBUT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"BOOLEAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BOOLEAN",
+           shape=ellipse]
+/*"BOOLEAN" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"; "LOGIC"}*/
+/*"BOOLEAN" -> {"KONVERT"; "BOOLEAN"; "INT"; "INS-"; "PI"; "NNI"; "SYMBOL"}*/
+/*"BOOLEAN" -> "REF"*/
+"BOOLEAN" -> "ALIST"
+/*"BOOLEAN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"BOOLEAN" -> {"A1AGG"; "ISTRING"; "SRAGG"; "FLAGG"; "LNAGG"}*/
+
+"BLUPPACK" [color="#88FF44",href="bookvol10.4.pdf#nameddest=BLUPPACK"]
+"BLUPPACK" -> "RFP"
+"BLUPPACK" -> "NPOLYGON"
+/*"BLUPPACK" -> {"BLMETCT"; "PFORP"; "AFFPL"; "PACPERC"; "FIELD"; "EUCDOM"}*/
+/*"BLUPPACK" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"BLUPPACK" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"BLUPPACK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"BLUPPACK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"BLUPPACK" -> {"UFD"; "DIVRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"BLUPPACK" -> {"FRETRCT"; "RETRACT"; "DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"BLUPPACK" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "DIFEXT"}*/
+/*"BLUPPACK" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"}*/
+/*"BLUPPACK" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"BLUPPACK" -> {"OAMONS"; "VSPACE"; "INT"; "LIST"; "ILIST"; "POLYCAT"}*/
+/*"BLUPPACK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"BLUPPACK" -> {"RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"}*/
+/*"BLUPPACK" -> {"LSAGG-"; "STAGG-"; "SINT"; "PI"; "ELAGG-"; "FLAGG-"}*/
+/*"BLUPPACK" -> {"URAGG-"; "BOOLEAN"; "VECTOR"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"BLUPPACK" -> {"STRING"; "CHAR"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"BLUPPACK" -> {"STAGG-"; "LNAGG-"}*/
+
+"BOP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BOP"]
+/*"BOP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"BOP" -> "ALIST"
+/*"BOP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"BOP" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "STRICAT"; "SRAGG"}*/
+/*"BOP" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"BOP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"BOP" -> {"OM"; "BOOLEAN"; "NNI"; "FSAGG"; "DIAGG"; "DIOPS"; "BGAGG"}*/
+/*"BOP" -> {"SETAGG"; "FINITE"; "ORDFIN"}*/
+
+"BOP1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BOP1"]
+/*"BOP1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "SYMBOL"; "INT"; "REF"}*/
+"BOP1" -> "ALIST"
+/*"BOP1" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"BOP1" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
+/*"BOP1" -> {"BOOLEAN"; "KONVERT"}*/
+
+"COMMONOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMMONOP"]
+/*"COMMONOP" -> {"BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
+"COMMONOP" -> "ALIST"
+/*"COMMONOP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"COMMONOP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
+/*"COMMONOP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "PI"}*/
+
+"COMPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMPCAT"]
+/*"COMPCAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"COMPCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"COMPCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "MONOGEN"}*/
+/*"COMPCAT" -> {"FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"COMPCAT" -> {"KONVERT"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"COMPCAT" -> {"FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"COMPCAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"COMPCAT" -> {"FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"COMPCAT" -> {"IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"; "PATAB"}*/
+/*"COMPCAT" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"COMPCAT" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "NNI"; "INT"; "PI"; "INS"}*/
+/*"COMPCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"COMPCAT" -> {"CFCAT"; "REAL"; "BOOLEAN"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"COMPCAT" -> {"AMR"; "LIST"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"COMPCAT" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"COMPCAT" -> {"AGG"; "ELTAGG"; "CLAGG"; "SYMBOL"; "REF"}*/
+"COMPCAT" -> "ALIST"
+/*"COMPCAT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"COMPCAT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "RNS"; "FPS"}*/
+
+"COMPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMPCAT"]
+/*"COMPCAT-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
+/*"COMPCAT-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
+/*"COMPCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
+/*"COMPCAT-" -> {"MONOGEN";  "FRAMALG";  "FINRALG";  "ALGEBRA";  "MODULE"}*/
+/*"COMPCAT-" -> {"CHARZ";  "CHARNZ";  "KONVERT";  "FRETRCT";  "RETRACT"}*/
+/*"COMPCAT-" -> {"FLINEXP";  "LINEXP";  "FINITE";  "FIELD";  "EUCDOM"}*/
+/*"COMPCAT-" -> {"PID";  "GCDDOM";  "INTDOM";  "ENTIRER";  "UFD";  "DIVRING"}*/
+/*"COMPCAT-" -> {"DIFEXT";  "DIFRING";  "PDRING";  "FFIELDC";  "FPC"}*/
+/*"COMPCAT-" -> {"STEP";  "FEVALAB";  "ELTAB";  "EVALAB";  "IEVALAB"}*/
+/*"COMPCAT-" -> {"FPATMAB";  "TYPE";  "PATMAB";  "PATAB";  "ORDSET"}*/
+/*"COMPCAT-" -> {"TRANFUN";  "TRIGCAT";  "ATRIG";  "HYPCAT";  "AHYP"}*/
+/*"COMPCAT-" -> {"ELEMFUN";  "RADCAT";  "PFECAT";  "NNI";  "INT";  "PI"}*/
+/*"COMPCAT-" -> {"INS";  "OINTDOM";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
+/*"COMPCAT-" -> {"OAMON";  "OASGP";  "CFCAT";  "REAL";  "BOOLEAN"}*/
+/*"COMPCAT-" -> {"UPOLYC";  "POLYCAT";  "FAMR";  "AMR";  "LIST";  "OM"}*/
+/*"COMPCAT-" -> {"VECTOR";  "IVECTOR";  "IARRAY1";  "VECTCAT";  "A1AGG"}*/
+/*"COMPCAT-" -> {"FLAGG";  "LNAGG";  "IXAGG";  "HOAGG";  "AGG";  "ELTAGG"}*/
+/*"COMPCAT-" -> {"CLAGG";  "SYMBOL";  "REF"}*/
+"COMPCAT-" -> "ALIST"
+/*"COMPCAT-" -> {"STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
+/*"COMPCAT-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-"}*/
+/*"COMPCAT-" -> {"RNS";  "FPS"}*/
+
+"DRAW" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAW"]
+/*"DRAW" -> {"KONVERT"; "SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
+/*"DRAW" -> "REF"*/
+"DRAW" -> "ALIST"
+/*"DRAW" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"DRAW" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"DRAW" -> {"NNI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"DRAW" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DRAW" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"DRAW" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"DRAW" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"DRAW" -> {"REAL"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"DRAWCFUN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWCFUN"]
+/*"DRAWCFUN" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"DRAWCFUN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DRAWCFUN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DRAWCFUN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DRAWCFUN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"DRAWCFUN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"DRAWCFUN" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"DRAWCFUN" -> {"SYMBOL"; "INT"; "REF"}*/
+"DRAWCFUN" -> "ALIST"
+/*"DRAWCFUN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"DRAWCFUN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"DRAWCFUN" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "DFLOAT"}*/
+/*"DRAWCFUN" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"DRAWCFUN" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "NNI"; "PI"; "PTCAT"}*/
+/*"DRAWCFUN" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"DRAWCFUN" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
+/*"DRAWCFUN" -> {"CLAGG"; "BOOLEAN"}*/
+
+"DROPT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DROPT"]
+/*"DROPT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"DROPT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"DROPT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"DROPT" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+/*"DROPT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"DROPT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"DROPT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"DROPT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"DROPT" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"DROPT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "SYMBOL"; "REF"}*/
+"DROPT" -> "ALIST"
+/*"DROPT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"DROPT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "FPS"}*/
+/*"DROPT" -> {"RNS"; "FIELD"; "DIVRING"; "RADCAT"; "BOOLEAN"}*/
+
+"DROPT0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DROPT0"]
+/*"DROPT0" -> {"SYMBOL"; "INT"; "REF"}*/
+"DROPT0" -> "ALIST"
+/*"DROPT0" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"DROPT0" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"DROPT0" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"DROPT0" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"DROPT0" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"DROPT0" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"DROPT0" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DROPT0" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"DROPT0" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"D01ANFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01ANFA"]
+/*"D01ANFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+/*"D01ANFA" -> {"SYMBOL"; "REF"}*/
+"D01ANFA" -> "ALIST"
+/*"D01ANFA" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"D01ANFA" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"D01ANFA" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"D01ANFA" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"D01ANFA" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"D01ANFA" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"D01ANFA" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"D01ANFA" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"D01ANFA" -> {"CHARZ"; "DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"D01ANFA" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "PI"; "INS-"}*/
+/*"D01ANFA" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"D01ANFA" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"D01ANFA" -> "ABELMON-"*/
+
+"D01ASFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01ASFA"]
+/*"D01ASFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
+/*"D01ASFA" -> {"SYMBOL"; "REF"}*/
+"D01ASFA" -> "ALIST"
+/*"D01ASFA" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"D01ASFA" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"D01ASFA" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"D01ASFA" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"D01ASFA" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"D01ASFA" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"D01ASFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"D01ASFA" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"D01ASFA" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"D01ASFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "PI"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"D01ASFA" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"D01ASFA" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "DFLOAT"}*/
+/*"D01ASFA" -> {"FPS-"; "RNS-"; "FIELD-"; "DIVRING-"}*/
+
+"D03AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D03AGNT"]
+/*"D03AGNT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"D03AGNT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"D03AGNT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"D03AGNT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"D03AGNT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"D03AGNT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"D03AGNT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
+/*"D03AGNT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+/*"D03AGNT" -> {"NNI"; "INT"; "INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
+/*"D03AGNT" -> {"SYMBOL"; "REF"}*/
+"D03AGNT" -> "ALIST"
+/*"D03AGNT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"D03AGNT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
+/*"D03AGNT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"D03AGNT" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"D03AGNT" -> {"FLAGG"; "ELAGG"; "ILIST"; "LSAGG-"; "STAGG-"; "DFLOAT"}*/
+/*"D03AGNT" -> {"PI"; "BOOLEAN"; "ELAGG-"; "URAGG-"; "FPS-"; "RNS-"}*/
+/*"D03AGNT" -> {"FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"}*/
+/*"D03AGNT" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+
+"EP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EP"]
+/*"EP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"EP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"EP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"EP" -> {"MODULE"; "ENTIRER"; "ORDSET"; "KONVERT"; "OM"; "PATMAB"}*/
+/*"EP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"EP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "PFECAT"}*/
+/*"EP" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"}*/
+/*"EP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
+/*"EP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"EP" -> {"REAL"; "NNI"; "INT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"EP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"EP" -> {"FLAGG"; "ELAGG"; "LIST"; "ILIST"; "SINT"; "PI"; "SYMBOL"; "REF"}*/
+"EP" -> "ALIST"
+/*"EP" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"EP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "UPOLYC"; "VECTOR"; "IVECTOR"}*/
+/*"EP" -> "IARRAY1"*/
+
+/* Note that ES has a circular self reference */
+"ES" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ES",
+      shape=ellipse]
+/*"ES" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"ES" -> {"IEVALAB"; "EVALAB"; "CACHSET"; "SYMBOL"; "INT"; "REF"}*/
+"ES" -> "ALIST"
+/*"ES" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"ES" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "FSAGG"}*/
+/*"ES" -> {"DIAGG" ; "DIOPS" ; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "CLAGG"}*/
+/*"ES" -> {"KONVERT"; "SETAGG"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"ES" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"}*/
+/*"ES" -> {"OM"; "PATAB"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "NNI"}*/
+/*"ES" -> {"PATMAB"; "URAGG-"}*/
+
+"ES-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ES",
+       shape=ellipse]
+/*"ES-" -> {"ES";  "ORDSET";  "SETCAT";  "BASTYPE";  "KOERCE";  "RETRACT"}*/
+/*"ES-" -> {"IEVALAB";  "EVALAB";  "CACHSET";  "SYMBOL";  "INT";  "REF"}*/
+"ES-" -> "ALIST"
+/*"ES-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
+/*"ES-" -> {"A1AGG";  "ISTRING";  "SRAGG";  "FLAGG";  "LNAGG";  "BOOLEAN"}*/
+/*"ES-" -> {"FSAGG";  "DIAGG";  "DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE"}*/
+/*"ES-" -> {"CLAGG";  "KONVERT";  "SETAGG";  "FINITE";  "LSAGG";  "STAGG"}*/
+/*"ES-" -> {"URAGG";  "RCAGG";  "LNAGG";  "IXAGG";  "ELTAGG";  "ELTAB"}*/
+/*"ES-" -> {"FLAGG";  "ELAGG";  "OM";  "PATAB";  "ILIST";  "LSAGG"}*/
+/*"ES-" -> {"STAGG";  "ELAGG";  "NNI";  "PATMAB";  "URAGG"}*/
+
+"E04AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=E04AGNT"]
+/*"E04AGNT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"E04AGNT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"E04AGNT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"E04AGNT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"E04AGNT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"E04AGNT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"E04AGNT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
+/*"E04AGNT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+/*"E04AGNT" -> {"DFLOAT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"E04AGNT" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"E04AGNT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "INT"; "LIST"}*/
+/*"E04AGNT" -> {"ILIST"; "SINT"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"E04AGNT" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "INS"}*/
+/*"E04AGNT" -> {"OINTDOM"; "LINEXP"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"}*/
+/*"E04AGNT" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"E04AGNT" -> {"CHARNZ"; "PFECAT"; "BOOLEAN"; "SYMBOL"; "REF"}*/
+"E04AGNT" -> "ALIST"
+/*"E04AGNT" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"E04AGNT" -> {"ISTRING"; "SRAGG-"; "PI"; "VECTOR"}*/
+
+"FCPAK1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FCPAK1"]
+/*"FCPAK1" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FCPAK1" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FCPAK1" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FCPAK1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FCPAK1" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FCPAK1" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"FCPAK1" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+/*"FCPAK1" -> {"SYMBOL"; "INT"; "REF"}*/
+"FCPAK1" -> "ALIST"
+/*"FCPAK1" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"FCPAK1" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"FEXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FEXPR"]
+/*"FEXPR" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"FEXPR" -> {"IEVALAB"; "EVALAB"; "ALGEBRA"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FEXPR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FEXPR" -> {"MODULE"; "BMODULE"; "RMODULE"; "PDRING"; "FMTC"; "INTDOM"}*/
+/*"FEXPR" -> {"COMRING"; "ENTIRER"; "BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
+"FEXPR" -> "ALIST"
+/*"FEXPR" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"FEXPR" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
+/*"FEXPR" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"FEXPR" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"FEXPR" -> {"ELAGG"; "OM"; "ILIST"; "NNI"; "PATMAB"; "INS"; "UFD"}*/
+/*"FEXPR" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"FEXPR" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "CFCAT"}*/
+/*"FEXPR" -> {"REAL"; "CHARZ"; "STEP"; "POLYCAT"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"FEXPR" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "FPS"; "RNS"; "FIELD"}*/
+/*"FEXPR" -> {"DIVRING"; "RADCAT"}*/
+
+"FFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FFCAT"]
+/*"FFCAT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FFCAT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FFCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"FFCAT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"FFCAT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
+/*"FFCAT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"FFCAT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
+/*"FFCAT" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+/*"FFCAT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
+/*"FFCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"FFCAT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"FFCAT" -> {"INT"; "BOOLEAN"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"FFCAT" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "SINT"; "VECTOR"}*/
+/*"FFCAT" -> {"IVECTOR"; "IARRAY1"; "SYMBOL"; "REF"}*/
+"FFCAT" -> "ALIST"
+/*"FFCAT" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"FFCAT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"}*/
+/*"FFCAT" -> {"STAGG-"; "INS"; "CFCAT"; "OM"; "VECTCAT-"; "PI"}*/
+
+"FFCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCAT"]
+/*"FFCAT-" -> {"UPOLYC";  "POLYCAT";  "PDRING";  "RING";  "RNG"}*/
+/*"FFCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
+/*"FFCAT-" -> {"BASTYPE";  "KOERCE";  "SGROUP";  "MONOID";  "LMODULE"}*/
+/*"FFCAT-" -> {"FAMR";  "AMR";  "BMODULE";  "RMODULE";  "COMRING"}*/
+/*"FFCAT-" -> {"ALGEBRA";  "MODULE";  "CHARZ";  "CHARNZ";  "INTDOM"}*/
+/*"FFCAT-" -> {"ENTIRER";  "FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB"}*/
+/*"FFCAT-" -> {"FLINEXP";  "LINEXP";  "ORDSET";  "KONVERT";  "PATMAB"}*/
+/*"FFCAT-" -> {"GCDDOM";  "PFECAT";  "UFD";  "ELTAB";  "DIFRING";  "DIFEXT"}*/
+/*"FFCAT-" -> {"STEP";  "EUCDOM";  "PID";  "FIELD";  "DIVRING";  "QFCAT"}*/
+/*"FFCAT-" -> {"FEVALAB";  "PATAB";  "FPATMAB";  "TYPE";  "OINTDOM"}*/
+/*"FFCAT-" -> {"ORDRING";  "OAGROUP";  "OCAMON";  "OAMON";  "OASGP"}*/
+/*"FFCAT-" -> {"REAL";  "MONOGEN";  "FRAMALG";  "FINRALG";  "FINITE"}*/
+/*"FFCAT-" -> {"FFIELDC";  "FPC";  "INT";  "BOOLEAN";  "NNI";  "VECTCAT"}*/
+/*"FFCAT-" -> {"A1AGG";  "FLAGG";  "LNAGG";  "IXAGG";  "HOAGG";  "AGG"}*/
+/*"FFCAT-" -> {"ELTAGG";  "CLAGG";  "SINT";  "VECTOR";  "IVECTOR"}*/
+/*"FFCAT-" -> {"IARRAY1";  "SYMBOL";  "REF"}*/
+"FFCAT-" -> "ALIST"
+/*"FFCAT-" -> {"LIST";  "STRING";  "CHAR";  "OUTFORM";  "PRIMARR";  "A1AGG-"}*/
+/*"FFCAT-" -> {"ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-";  "ILIST"}*/
+/*"FFCAT-" -> {"LSAGG-";  "STAGG-";  "INS";  "CFCAT";  "OM";  "VECTCAT-"}*/
+/*"FFCAT-" -> "PI"*/
+
+"FFCGP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCGP"]
+/*"FFCGP" -> {"FAXF"; "XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFCGP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFCGP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFCGP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFCGP" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
+/*"FFCGP" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
+/*"FFCGP" -> {"NNI"; "INT"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
+/*"FFCGP" -> {"PI"; "SINT"; "PRIMARR"; "SYMBOL"; "REF"}*/
+"FFCGP" -> "ALIST"
+/*"FFCGP" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "A1AGG-"; "ISTRING"}*/
+/*"FFCGP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "OAMONS"; "OCAMON"}*/
+/*"FFCGP" -> {"OAMON"; "OASGP"; "ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"FFCGP" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"FFCGP" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"FFCGP" -> {"ILIST"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "KONVERT"}*/
+/*"FFCGP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+
+"FFNBP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFNBP"]
+/*"FFNBP" -> {"FAXF"; "XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFNBP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFNBP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFNBP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FFNBP" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
+/*"FFNBP" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
+/*"FFNBP" -> {"SYMBOL"; "INT"; "REF"}*/
+"FFNBP" -> "ALIST"
+/*"FFNBP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"FFNBP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"FFNBP" -> {"PI"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"}*/
+/*"FFNBP" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FFNBP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"FFNBP" -> {"ORDSET"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "TBAGG"}*/
+/*"FFNBP" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "VECTCAT-"; "UPOLYC"}*/
+/*"FFNBP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "FRETRCT"; "FLINEXP"}*/
+/*"FFNBP" -> {"LINEXP"; "PATMAB"; "PFECAT"; "DIFEXT"; "LSAGG"; "STAGG"}*/
+/*"FFNBP" -> {"URAGG"; "RCAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"; "MONOID-"}*/
+/*"FFNBP" -> {"ABELMON-"; "ORDSET-"; "SGROUP-"; "INS-"; "INS"; "OINTDOM"}*/
+/*"FFNBP" -> {"ORDRING"; "OAGROUP"; "CFCAT"; "REAL"; "IXAGG-"; "CLAGG-"}*/
+/*"FFNBP" -> {"HOAGG-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+
+"FFP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFP"]
+/*"FFP" -> {"FAXF"; "XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FFP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FFP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FFP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FFP" -> {"UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
+/*"FFP" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "SYMBOL"; "INT"; "REF"}*/
+"FFP" -> "ALIST"
+/*"FFP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"FFP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
+/*"FFP" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "PI"; "BOOLEAN"}*/
+/*"FFP" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "TBAGG"; "KDAGG"}*/
+/*"FFP" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"FFP" -> {"IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"FFP" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "IXAGG-"; "CLAGG-"}*/
+/*"FFP" -> {"HOAGG-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "ILIST"}*/
+/*"FFP" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "INS-"; "INS"; "OINTDOM"}*/
+/*"FFP" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+
+"FLOAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FLOAT"]
+/*"FLOAT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FLOAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FLOAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FLOAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FLOAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FLOAT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"FLOAT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
+/*"FLOAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "INS-"}*/
+/*"FLOAT" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"FLOAT" -> {"DIFRING-"; "ORDRING-"; "PI"; "NNI"; "MODULE-"; "RING-"}*/
+/*"FLOAT" -> {"ABELGRP-"; "ABELMON-"; "SINT"; "BOOLEAN"; "MONOID-"}*/
+/*"FLOAT" -> {"ABELSG-"; "SGROUP-"; "ORDSET-"; "INS"; "OINTDOM"; "LINEXP"}*/
+/*"FLOAT" -> {"CFCAT"; "STEP"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
+/*"FLOAT" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"FLOAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "STRING"; "CHAR"; "OUTFORM"}*/
+/*"FLOAT" -> {"LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"FLOAT" -> {"LNAGG-"; "SYMBOL"; "REF"}*/
+"FLOAT" -> "ALIST"
+/*"FLOAT" -> "DFLOAT"*/
+
+"FPARFRAC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FPARFRAC"]
+/*"FPARFRAC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "UPOLYC"}*/
+/*"FPARFRAC" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FPARFRAC" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FPARFRAC" -> {"FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"FPARFRAC" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"FPARFRAC" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"FPARFRAC" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "PATMAB"; "GCDDOM"}*/
+/*"FPARFRAC" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"FPARFRAC" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
+"FPARFRAC" -> "ALIST"
+/*"FPARFRAC" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"FPARFRAC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
+/*"FPARFRAC" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
+/*"FPARFRAC" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"FPARFRAC" -> {"PI"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "DPOLCAT"}*/
+/*"FPARFRAC" -> {"INS"; "CFCAT"}*/
+
+"FR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FR"]
+/*"FR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FR" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FR" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FR" -> {"ENTIRER"; "DIFEXT"; "DIFRING"; "PDRING"; "FEVALAB"; "ELTAB"}*/
+/*"FR" -> {"EVALAB"; "IEVALAB"; "FRETRCT"; "RETRACT"; "GCDDOM"; "REAL"}*/
+/*"FR" -> {"KONVERT"; "UFD"; "INT"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
+"FR" -> "ALIST"
+/*"FR" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"FR" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ORDSET"; "BOOLEAN"}*/
+/*"FR" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"FR" -> {"NNI"; "INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"FR" -> {"OCAMON"; "OAMON"; "OASGP"; "LINEXP"; "PATMAB"; "CFCAT"; "CHARZ"}*/
+/*"FR" -> {"STEP"; "DFLOAT"; "LSAGG-"; "STAGG-"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"FR" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"FR" -> {"MODULE-"; "RING-"; "ABELGRP-"; "PI"; "ELAGG-"; "URAGG-"}*/
+
+"FRNAALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FRNAALG"]
+/*"FRNAALG" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
+/*"FRNAALG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FRNAALG" -> {"MONAD"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"}*/
+/*"FRNAALG" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "FIELD"}*/
+/*"FRNAALG" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"}*/
+/*"FRNAALG" -> {"UFD"; "DIVRING"; "SINT"; "PI"; "NNI"; "INT"; "STRING"}*/
+/*"FRNAALG" -> {"CHAR"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"FRNAALG" -> {"SYMBOL"; "REF"}*/
+"FRNAALG" -> "ALIST"
+/*"FRNAALG" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"FRNAALG" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"FRNAALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"FRNAALG" -> {"PATMAB"; "PFECAT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"FRNAALG" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"FRNAALG" -> {"AGG"; "TYPE"; "ELTAGG"; "ELTAB"; "CLAGG"; "VECTCAT-"}*/
+/*"FRNAALG" -> {"ILIST"; "MONOID-"; "ABELSG-"; "SGROUP-"; "INS"; "OINTDOM"}*/
+/*"FRNAALG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"FRNAALG" -> {"CFCAT"; "REAL"; "STEP"; "OM"}*/
+
+"FRNAALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRNAALG"]
+/*"FRNAALG-" -> {"FINAALG";  "NAALG";  "NARNG";  "ABELGRP";  "CABMON"}*/
+/*"FRNAALG-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
+/*"FRNAALG-" -> {"MONAD";  "MODULE";  "BMODULE";  "LMODULE";  "RMODULE"}*/
+/*"FRNAALG-" -> {"COMRING";  "RING";  "RNG";  "SGROUP";  "MONOID";  "FIELD"}*/
+/*"FRNAALG-" -> {"EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "ALGEBRA"}*/
+/*"FRNAALG-" -> {"ENTIRER";  "UFD";  "DIVRING";  "SINT";  "PI";  "NNI"}*/
+/*"FRNAALG-" -> {"INT";  "STRING";  "CHAR";  "OUTFORM";  "LIST";  "PRIMARR"}*/
+/*"FRNAALG-" -> {"A1AGG-";  "ISTRING";  "SYMBOL";  "REF"}*/
+"FRNAALG-" -> "ALIST"
+/*"FRNAALG-" -> {"SRAGG-";  "FLAGG-";  "LNAGG-";  "POLYCAT";  "PDRING"}*/
+/*"FRNAALG-" -> {"FAMR";  "AMR";  "CHARZ";  "CHARNZ";  "FRETRCT";  "RETRACT"}*/
+/*"FRNAALG-" -> {"EVALAB";  "IEVALAB";  "FLINEXP";  "LINEXP";  "ORDSET"}*/
+/*"FRNAALG-" -> {"KONVERT";  "PATMAB";  "PFECAT";  "VECTOR";  "IVECTOR"}*/
+/*"FRNAALG-" -> {"IARRAY1";  "VECTCAT";  "A1AGG";  "FLAGG";  "LNAGG"}*/
+/*"FRNAALG-" -> {"IXAGG";  "HOAGG";  "AGG";  "TYPE";  "ELTAGG";  "ELTAB"}*/
+/*"FRNAALG-" -> {"CLAGG";  "VECTCAT-";  "ILIST";  "MONOID-";  "ABELSG-"}*/
+/*"FRNAALG-" -> {"SGROUP-";  "INS";  "OINTDOM";  "ORDRING";  "OAGROUP"}*/
+/*"FRNAALG-" -> {"OCAMON";  "OAMON";  "OASGP";  "DIFRING";  "CFCAT"}*/
+/*"FRNAALG-" -> {"REAL";  "STEP";  "OM"}*/
+
+"FS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FS"]
+/*"FS" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"FS" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"FS" -> {"PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"; "ABELMON"}*/
+/*"FS" -> {"ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"; "LMODULE"}*/
+/*"FS" -> {"PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"}*/
+/*"FS" -> {"MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"FS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"FS" -> {"SYMBOL"; "INT"; "REF"}*/
+"FS" -> "ALIST"
+/*"FS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"FS" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "BOOLEAN"}*/
+/*"FS" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
+/*"FS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"FS" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "CACHSET"; "NNI"}*/
+/*"FS" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"FS" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"FS" -> {"PFECAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FS" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "PI"; "FPS"}*/
+/*"FS" -> {"RNS"; "RADCAT"; "UPOLYC"; "DIFEXT"; "QFCAT"; "FEVALAB"}*/
+
+"FS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FS"]
+/*"FS-" -> {"ES";  "ORDSET";  "SETCAT";  "BASTYPE";  "KOERCE";  "RETRACT"}*/
+/*"FS-" -> {"IEVALAB";  "EVALAB";  "PATAB";  "KONVERT";  "FPATMAB";  "TYPE"}*/
+/*"FS-" -> {"PATMAB";  "FRETRCT";  "MONOID";  "SGROUP";  "GROUP";  "ABELMON"}*/
+/*"FS-" -> {"ABELSG";  "ABELGRP";  "CABMON";  "RING";  "RNG";  "LMODULE"}*/
+/*"FS-" -> {"PDRING";  "FLINEXP";  "LINEXP";  "CHARZ";  "CHARNZ";  "ALGEBRA"}*/
+/*"FS-" -> {"MODULE";  "BMODULE";  "RMODULE";  "FIELD";  "EUCDOM";  "PID"}*/
+/*"FS-" -> {"GCDDOM";  "INTDOM";  "COMRING";  "ENTIRER";  "UFD";  "DIVRING"}*/
+/*"FS-" -> {"SYMBOL";  "INT";  "REF"}*/
+"FS-" -> "ALIST"
+/*"FS-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
+/*"FS-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-";  "ILIST"}*/
+/*"FS-" -> {"BOOLEAN";  "LSAGG-";  "STAGG-";  "ELAGG-";  "URAGG-";  "LSAGG"}*/
+/*"FS-" -> {"STAGG";  "URAGG";  "RCAGG";  "HOAGG";  "AGG";  "LNAGG"}*/
+/*"FS-" -> {"IXAGG";  "ELTAGG";  "ELTAB";  "CLAGG";  "FLAGG";  "ELAGG"}*/
+/*"FS-" -> {"OM";  "CACHSET";  "NNI";  "RCAGG-";  "IXAGG-";  "CLAGG-"}*/
+/*"FS-" -> {"HOAGG-";  "ORDSET-";  "AGG-";  "ELTAGG-";  "SETCAT-"}*/
+/*"FS-" -> {"BASTYPE-";  "POLYCAT";  "FAMR";  "AMR";  "PFECAT";  "INS"}*/
+/*"FS-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "OCAMON";  "OAMON"}*/
+/*"FS-" -> {"OASGP";  "DIFRING";  "CFCAT";  "REAL";  "STEP";  "PI";  "FPS"}*/
+/*"FS-" -> {"RNS";  "RADCAT";  "UPOLYC";  "DIFEXT";  "QFCAT";  "FEVALAB"}*/
+
+"FST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FST"]
+/*"FST" -> {"KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"FST" -> "ALIST"
+/*"FST" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"FST" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+
+"FUNCTION" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FUNCTION"]
+/*"FUNCTION" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"FUNCTION" -> "ALIST"
+/*"FUNCTION" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"FUNCTION" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"FUNCTION" -> "BOOLEAN"*/
+
+"GDMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GDMP"]
+/*"GDMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"GDMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"GDMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"GDMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"GDMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"GDMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
+/*"GDMP" -> {"UFD"; "DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"GDMP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
+/*"GDMP" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
+/*"GDMP" -> {"EUCDOM"; "PID"; "DIVRING"; "ORDFIN"; "LSAGG"; "STAGG"}*/
+/*"GDMP" -> {"URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"GDMP" -> {"INT"; "LIST"; "ILIST"; "NNI"; "VECTCAT"; "A1AGG"; "VECTOR"}*/
+/*"GDMP" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "SINT"; "PI"}*/
+/*"GDMP" -> {"BOOLEAN"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"GDMP" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG-"}*/
+/*"GDMP" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "FPS"; "RNS"; "REAL"}*/
+/*"GDMP" -> {"RADCAT"; "SYMBOL"; "REF"}*/
+"GDMP" -> "ALIST"
+/*"GDMP" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
+/*"GDMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"}*/
+
+"GOPT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GOPT"]
+/*"GOPT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"GOPT" -> "ALIST"
+/*"GOPT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"GOPT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"GOPT" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
+/*"GOPT" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"GOPT" -> {"SETCAT-"; "BASTYPE-"}*/
+
+"GOPT0" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GOPT0"]
+"GOPT0" -> "STRING"
+/*"GOPT0" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PI";"NNI"; "INT"; "BOOLEAN"}*/
+/*"GOPT0" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
+/*"GOPT0" -> {"A1AGG-"; "ISTRING"; "MONOID-"; "ABELSG-"; "SGROUP-"; }*/
+/*"GOPT0" -> {"ORDSET-"; "SETCAT-"; "BASTYPE-"}*/
+
+"HACKPI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HACKPI"]
+/*"HACKPI" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"HACKPI" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"HACKPI" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"HACKPI" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"HACKPI" -> {"DIVRING"; "CHARZ"; "RETRACT"; "REAL"; "KONVERT"; "INS"}*/
+/*"HACKPI" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"HACKPI" -> {"ORDSET"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "STEP"}*/
+/*"HACKPI" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"HACKPI" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
+/*"HACKPI" -> {"ELTAB"; "DIFEXT"; "SYMBOL"; "INT"; "REF"}*/
+"HACKPI" -> "ALIST"
+/*"HACKPI" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"HACKPI" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
+/*"HACKPI" -> {"DFLOAT"; "OM"; "BOOLEAN"; "FPS"; "RNS"; "RADCAT"}*/
+
+"IDEAL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDEAL"]
+/*"IDEAL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"IDEAL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"IDEAL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IDEAL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"IDEAL" -> {"DIVRING"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"IDEAL" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"IDEAL" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"IDEAL" -> {"LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "NNI"; "INT"; "LIST"}*/
+/*"IDEAL" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"IDEAL" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"IDEAL" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"IDEAL" -> {"FLAGG-"; "SINT"; "SYMBOL"; "REF"}*/
+"IDEAL" -> "ALIST"
+/*"IDEAL" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"IDEAL" -> {"SRAGG-"; "LNAGG-"; "DIRPCAT"; "DIFEXT"; "DIFRING"; "FINITE"}*/
+/*"IDEAL" -> {"ORDRING"; "OAGROUP"; "VSPACE"; "ORDFIN"; "VECTOR"; "IVECTOR"}*/
+/*"IDEAL" -> {"IARRAY1"; "VECTCAT-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
+/*"IDEAL" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT"; "A1AGG"}*/
+
+"INFCLCT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INFCLCT"]
+/*"INFCLCT" -> {"PRSPCT"; LOCPOWC"; PLACESC"; DIVCAT"; BLMETCT"; "AFFPL"}*/
+/*"INFCLCT" -> {SETCATD"; SETCAT"; BASTYPE"; KOERCE"; NNI"; INT"; "OUTFORM"}*/
+/*"INFCLCT" -> {LIST"; SYMBOL"; "REF"}*/
+"INFCLCT" -> "ALIST"
+/*"INFCLCT" -> {STRING"; CHAR"; SINT"; PRIMARR"; A1AGG-"; "ISTRING"}*/
+/*"INFCLCT" -> {SRAGG-"; FLAGG-"; LNAGG-"; ILIST"; LSAGG-"; "STAGG-"}*/
+/*"INFCLCT" -> {ELAGG-"; "URAGG-"}*?
+
+"INFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INFORM"]
+/*"INFORM" -> {"SEXCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "ORDSET"}*/
+/*"INFORM" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"INFORM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"INFORM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INFORM" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"INFORM" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"INFORM" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
+/*"INFORM" -> {"FIELD"; "DIVRING"; "RADCAT"; "INT"; "SYMBOL"; "REF"}*/
+"INFORM" -> "ALIST"
+/*"INFORM" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"INFORM" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "DFLOAT"}*/
+/*"INFORM" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"INFORM" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"INFORM" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"INFORM" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"INFORM" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "NNI"}*/
+/*"INFORM" -> {"STRICAT"; "SRAGG"; "A1AGG"}*/
+
+"INFORM1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFORM1"]
+/*"INFORM1" -> {"TYPE"; "SYMBOL"; "INT"; "REF"}*/
+"INFORM1" -> "ALIST"
+/*"INFORM1" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"INFORM1" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"IPRNTPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IPRNTPK"]
+/*"IPRNTPK" -> {"SYMBOL"; "INT"; "REF"}*/
+"IPRNTPK" -> "ALIST"
+/*"IPRNTPK" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"IPRNTPK" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"IR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IR"]
+/*"IR" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"IR" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "RETRACT"}*/
+/*"IR" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"IR" -> {"SGROUP"; "MONOID"; "ALGEBRA"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"IR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"IR" -> {"ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"IR" -> {"REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"; "DIVRING"}*/
+/*"IR" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"}*/
+/*"IR" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"}*/
+/*"IR" -> {"SYMBOL"; "INT"; "REF"}*/
+"IR" -> "ALIST"
+/*"IR" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"IR" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"IR" -> {"NNI"; "BOOLEAN"; "LFCAT"; "PRIMCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"IR" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "LSAGG-"; "STAGG-"}*/
+/*"IR" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "PI"; "LSAGG"; "STAGG"}*/
+/*"IR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"IR" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+
+"ISUPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ISUPS"]
+/*"ISUPS" -> {"UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ISUPS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ISUPS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"ISUPS" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"ISUPS" -> {"ELTAB"; "DIFRING"; "PDRING"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
+/*"ISUPS" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ISUPS" -> {"OASGP"; "ORDSET"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"ISUPS" -> {"CFCAT"; "REAL"; "STEP"; "BOOLEAN"; "INT"; "OM"; "SINT"}*/
+/*"ISUPS" -> {"NNI"; "PI"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"ISUPS" -> {"FLAGG-"; "URAGG-"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"ISUPS" -> {"AHYP"; "ELEMFUN"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
+/*"ISUPS" -> {"A1AGG-"; "ISTRING"; "SYMBOL"; "REF"}*/
+"ISUPS" -> "ALIST"
+/*"ISUPS" -> {"SRAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ISUPS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"ISUPS" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "FIELD"; "DIVRING"}*/
+
+"KERNEL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=KERNEL"]
+/*"KERNEL" -> {"CACHSET"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "PATAB"}*/
+/*"KERNEL" -> {"KONVERT"; "INT"; "NNI"; "LIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"KERNEL" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"KERNEL" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"KERNEL" -> {"ELAGG"; "OM"; "ILIST"; "SYMBOL"; "REF"}*/
+"KERNEL" -> "ALIST"
+/*"KERNEL" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"KERNEL" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "UFD"}*/
+/*"KERNEL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"KERNEL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"KERNEL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"KERNEL" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"KERNEL" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"KERNEL" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
+/*"KERNEL" -> {"FIELD"; "DIVRING"; "RADCAT"}*/
+
+"LIB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIB"]
+/*"LIB" -> {"TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"}*/
+/*"LIB" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"LIB" -> {"CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "SYMBOL"}*/
+/*"LIB" -> {"INT"; "REF"}*/
+"LIB" -> "ALIST"
+/*"LIB" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"LIB" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "STRICAT"}*/
+/*"LIB" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "ORDSET"; "OM"; "ORDFIN"}*/
+/*"LIB" -> "FINITE"*/
+
+"LIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIST",
+          shape=ellipse]
+/*"LIST" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"LIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"LIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"LIST" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "BOOLEAN"; "ILIST"}*/
+/*"LIST" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "SYMBOL"; "REF"}*/
+"LIST" -> "ALIST"
+/*"LIST" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"LIST" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "UFD"}*/
+/*"LIST" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"LIST" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LIST" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"LIST" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"LIST" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"LIST" -> {"REAL"; "CHARZ"; "STEP"}*/
+
+"LMDICT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LMDICT"]
+/*"LMDICT" -> {"MDAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"LMDICT" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
+/*"LMDICT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
+/*"LMDICT" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"}*/
+/*"LMDICT" -> {"LIST"; "ILIST"; "SYMBOL"; "REF"}*/
+"LMDICT" -> "ALIST"
+/*"LMDICT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"LMDICT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"}*/
+/*"LMDICT" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "NNI"; "BOOLEAN"}*/
+
+"LODO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODO"]
+/*"LODO" -> {"LODOCAT"; "OREPCAT"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"LODO" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"LODO" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
+/*"LODO" -> {"ALGEBRA"; "MODULE"; "ELTAB"; "SYMBOL"; "INT"; "REF"}*/
+"LODO" -> "ALIST"
+/*"LODO" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"LODO" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FIELD"}*/
+/*"LODO" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
+/*"LODO" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"LODO" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"LODO" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"LODOOPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LODOOPS"]
+/*"LODOOPS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"LODOOPS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LODOOPS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LODOOPS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"LODOOPS" -> {"DIVRING"; "LODOCAT"; "OREPCAT"; "FRETRCT"; "RETRACT"}*/
+/*"LODOOPS" -> {"ELTAB"; "SYMBOL"; "INT"; "REF"}*/
+"LODOOPS" -> "ALIST"
+/*"LODOOPS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"LODOOPS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"LODOOPS" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"LODOOPS" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "CLAGG"}*/
+/*"LODOOPS" -> {"KONVERT"; "ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"LODOOPS" -> {"VECTCAT-"; "NNI"; "PI"; "INS-"; "DPOLCAT"; "POLYCAT"}*/
+/*"LODOOPS" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FLINEXP"}*/
+/*"LODOOPS" -> {"LINEXP"; "PATMAB"; "PFECAT"; "DIFEXT"; "DIFRING"}*/
+/*"LODOOPS" -> {"ILIST"; "LSAGG-"; "BOOLEAN"}*/
+
+"MATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MATRIX"]
+/*"MATRIX" -> {"MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"MATRIX" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "KONVERT"}*/
+/*"MATRIX" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"MATRIX" -> {"ELTAB"; "CLAGG"; "ORDSET"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MATRIX" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"MATRIX" -> {"INT"; "PRIMARR"; "NNI"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"MATRIX" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"MATRIX" -> {"ENTIRER"; "FIELD"; "UFD"; "DIVRING"; "INS-"; "VECTOR"}*/
+/*"MATRIX" -> {"IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"MATRIX" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"MATRIX" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "SYMBOL"}*/
+/*"MATRIX" -> "REF"*/
+"MATRIX" -> "ALIST"
+/*"MATRIX" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "A1AGG-"}*/
+/*"MATRIX" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"}*/
+/*"MATRIX" -> {"URAGG"; "RCAGG"; "ELAGG"}*/
+
+"MKFLCFN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKFLCFN"]
+/*"MKFLCFN" -> {"KONVERT"; "SYMBOL"; "INT"; "REF"}*/
+"MKFLCFN" -> "ALIST"
+/*"MKFLCFN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"MKFLCFN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"MKFLCFN" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"MKFLCFN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"MKFLCFN" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ORDSET"}*/
+/*"MKFLCFN" -> {"ELAGG"; "OM"; "STRICAT"; "SRAGG"; "A1AGG"; "LSAGG-"}*/
+/*"MKFLCFN" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "DFLOAT"}*/
+
+"MSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MSET"]
+/*"MSET" -> {"MSETAGG"; "MDAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"MSET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"MSET" -> {"KONVERT"; "SETAGG"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"MSET" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"MSET" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"MSET" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"MSET" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"MSET" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"MSET" -> {"CHARZ"; "STEP"; "INT"; "SYMBOL"; "REF"}*/
+"MSET" -> "ALIST"
+/*"MSET" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"MSET" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"MSET" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"MSET" -> {"ELTAB"; "FLAGG"; "ELAGG"; "OM"; "NNI"; "BOOLEAN"}*/
+
+"M3D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=M3D"]
+/*"M3D" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"M3D" -> {"EVALAB"; "IEVALAB"; "SYMBOL"; "INT"; "REF"}*/
+"M3D" -> "ALIST"
+/*"M3D" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"M3D" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
+/*"M3D" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "PI"; "A1AGG"; "FLAGG"}*/
+/*"M3D" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"M3D" -> {"ORDSET"; "VECTCAT-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
+/*"M3D" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT"; "RING"}*/
+/*"M3D" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"M3D" -> {"MONOID"; "LMODULE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"M3D" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+
+"NAGC02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGC02"]
+/*"NAGC02" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGC02" -> "ALIST"
+/*"NAGC02" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGC02" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGC02" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGC02" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGC02" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGC02" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGC02" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NAGC02" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"NAGC02" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"NAGC05" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGC05"]
+/*"NAGC05" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGC05" -> "ALIST"
+/*"NAGC05" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGC05" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGC05" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGC05" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGC05" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"NAGC05" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"NAGC05" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"NAGC05" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"NAGC05" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"NAGC06" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGC06"]
+/*"NAGC06" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGC06" -> "ALIST"
+/*"NAGC06" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGC06" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGC06" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGC06" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGC06" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGC06" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGC06" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NAGC06" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"NAGC06" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"NAGD01" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGD01"]
+/*"NAGD01" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGD01" -> "ALIST"
+/*"NAGD01" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGD01" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGD01" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGD01" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGD01" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"NAGD01" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"NAGD01" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"NAGD01" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"NAGD01" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"NAGD02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGD02"]
+/*"NAGD02" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGD02" -> "ALIST"
+/*"NAGD02" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGD02" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGD02" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGD02" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGD02" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGD02" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGD02" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NAGD02" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"NAGD02" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"NAGD03" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGD03"]
+/*"NAGD03" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGD03" -> "ALIST"
+/*"NAGD03" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGD03" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGD03" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGD03" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGD03" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGD03" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGD03" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NAGD03" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"NAGD03" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+
+"NAGE01" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGE01"]
+/*"NAGE01" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGE01" -> "ALIST"
+/*"NAGE01" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGE01" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGE01" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGE01" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGE01" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGE01" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGE01" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NAGE01" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"NAGE01" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"NAGE01" -> {"LINEXP"; "CFCAT"; "STEP"}*/
+
+"NAGE02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGE02"]
+/*"NAGE02" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGE02" -> "ALIST"
+/*"NAGE02" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGE02" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGE02" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGE02" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGE02" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"NAGE02" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"NAGE02" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"NAGE02" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"NAGE02" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"}*/
+/*"NAGE02" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+
+"NAGE04" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGE04"]
+/*"NAGE04" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGE04" -> "ALIST"
+/*"NAGE04" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGE04" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGE04" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGE04" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGE04" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGE04" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGE04" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"NAGE04" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"NAGE04" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"}*/
+/*"NAGE04" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+
+"NAGF07" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF07"]
+/*"NAGF07" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGF07" -> "ALIST"
+/*"NAGF07" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGF07" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGF07" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGF07" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGF07" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGF07" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGF07" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NAGF07" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"NAGF07" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"NAGF07" -> {"LINEXP"; "CFCAT"; "STEP"}*/
+
+"NAGS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGS"]
+/*"NAGS" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGS" -> "ALIST"
+/*"NAGS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"NAGS" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"NAGS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"NAGS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"NAGS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"NAGS" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"NAGS" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
+/*"NAGS" -> {"PATMAB"; "CHARZ"}*/
+
+"NAGSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGSP"]
+/*"NAGSP" -> {"SYMBOL"; "INT"; "REF"}*/
+"NAGSP" -> "ALIST"
+/*"NAGSP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NAGSP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"NAGSP" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NAGSP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NAGSP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NAGSP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NAGSP" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NAGSP" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"NAGSP" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"NAGSP" -> {"LINEXP"; "CFCAT"; "STEP"}*/
+
+"NREP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NREP"]
+/*"NREP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"NREP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"NREP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"NREP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"NREP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"NREP" -> {"ORDSET"; "SYMBOL"; "INT"; "REF"}*/
+"NREP" -> "ALIST"
+/*"NREP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"NREP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
+/*"NREP" -> {"OINTDOM"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"NREP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
+/*"NREP" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
+/*"NREP" -> {"FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"; "UPOLYC"; "POLYCAT"}*/
+/*"NREP" -> {"FAMR"; "AMR"; "FRETRCT"}*/
+
+"NSDPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NSDPS"]
+/*"NSDPS" -> {"LOCPOWC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"NSDPS" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"NSDPS" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"NSDPS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NSDPS" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPSCAT"; "PSCAT"; "AMR"}*/
+/*"NSDPS" -> {"CHARZ"; "CHARNZ"; "ELTAB"; "DIFRING"; "PDRING"; "LZSTAGG"}*/
+/*"NSDPS" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"NSDPS" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
+/*"NSDPS" -> {"INT"; "BOOLEAN"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"NSDPS" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RETRACT"; "LINEXP"}*/
+/*"NSDPS" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"; "LIST"; "ILIST"; "SINT"}*/
+/*"NSDPS" -> {"NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"; "FLAGG"}*/
+/*"NSDPS" -> {"ELAGG"; "OM"; "SYMBOL"; "REF"}*/
+"NSDPS" -> "ALIST"
+/*"NSDPS" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"NSDPS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"NSDPS" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"NSDPS" -> {"BASTYPE-"}*/
+
+"NUMFMT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMFMT"]
+/*"NUMFMT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"}*/
+/*"NUMFMT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"NUMFMT" -> {"IXAGG-"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"NUMFMT" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"NUMFMT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"NUMFMT" -> {"KONVERT"; "ORDSET"; "OM"; "BOOLEAN"; "SYMBOL"; "REF"}*/
+"NUMFMT" -> "ALIST"
+/*"NUMFMT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"NUMFMT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"NUMFMT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"NUMFMT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"NUMFMT" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"NUMFMT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "PI"; "NNI"}*/
+/*"NUMFMT" -> {"MONOID-"; "ABELSG-"; "SGROUP-"}*/
+
+"OC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OC"]
+/*"OC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"OC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"OC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"OC" -> {"FRETRCT"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
+/*"OC" -> {"FINITE"; "ORDSET"; "KONVERT"; "CHARZ"; "CHARNZ"; "BOOLEAN"}*/
+/*"OC" -> {"SYMBOL"; "INT"; "REF"}*/
+"OC" -> "ALIST"
+/*"OC" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"OC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FIELD"}*/
+/*"OC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"OC" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"OC" -> {"REAL"; "RADCAT"; "PATMAB"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"OC" -> {"LINEXP"; "CFCAT"; "STEP"}*/
+
+"OC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OC"]
+/*"OC-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON";  "ABELMON"}*/
+/*"OC-" -> {"ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP"}*/
+/*"OC-" -> {"MONOID";  "LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA"}*/
+/*"OC-" -> {"MODULE";  "FRETRCT";  "RETRACT";  "FEVALAB";  "ELTAB"}*/
+/*"OC-" -> {"EVALAB";  "IEVALAB";  "FINITE";  "ORDSET";  "KONVERT"}*/
+/*"OC-" -> {"CHARZ";  "CHARNZ";  "BOOLEAN";  "SYMBOL";  "INT";  "REF"}*/
+"OC-" -> "ALIST"
+/*"OC-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
+/*"OC-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-"}*/
+/*"OC-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "ENTIRER"}*/
+/*"OC-" -> {"UFD";  "DIVRING";  "RNS";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
+/*"OC-" -> {"OAMON";  "OASGP";  "REAL";  "RADCAT";  "PATMAB";  "INS"}*/
+/*"OC-" -> {"OINTDOM";  "DIFRING";  "LINEXP";  "CFCAT";  "STEP"}*/
+
+"ODEPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPACK"]
+/*"ODEPACK" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ODEPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ODEPACK" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ODEPACK" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ODEPACK" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"ODEPACK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"ODEPACK" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "LSAGG"; "STAGG"}*/
+/*"ODEPACK" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"ODEPACK" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"ODEPACK" -> {"FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "INS-"}*/
+/*"ODEPACK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"ODEPACK" -> {"ISTRING"; "SRAGG-"; "TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"}*/
+/*"ODEPACK" -> {"BGAGG"; "NNI"; "SYMBOL"; "REF"}*/
+"ODEPACK" -> "ALIST"
+/*"ODEPACK" -> {"FLAGG-"; "LNAGG-"; "DFLOAT"; "DIFRING"; "TRANFUN"}*/
+/*"ODEPACK" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+/*"ODEPACK" -> {"PI"; "VECTCAT"; "A1AGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"ODEPACK" -> {"VECTCAT-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+
+"ODERAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODERAT"]
+/*"ODERAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODERAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODERAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ODERAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ODERAT" -> {"UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"; "POLYCAT"}*/
+/*"ODERAT" -> {"PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"}*/
+/*"ODERAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"ODERAT" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
+/*"ODERAT" -> {"STEP"; "SYMBOL"; "INT"; "REF"}*/
+"ODERAT" -> "ALIST"
+/*"ODERAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ODERAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS-"}*/
+/*"ODERAT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
+/*"ODERAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"ODERAT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
+/*"ODERAT" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"}*/
+/*"ODERAT" -> {"NNI"; "LSAGG-"; "STAGG-"; "INS"; "CFCAT"; "VECTOR"}*/
+/*"ODERAT" -> {"IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"; "PI"}*/
+/*"ODERAT" -> {"VECTCAT-"; "BOOLEAN"}*/
+
+"OMERR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMERR"]
+/*"OMERR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"OMERR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"OMERR" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"OMERR" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
+/*"OMERR" -> {"SYMBOL"; "REF"}*/
+"OMERR" -> "ALIST"
+/*"OMERR" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"OMERR" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"}*/
+/*"OMERR" -> {"STAGG-"; "PI"}*/
+
+"OMERRK" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMERRK"]
+/*"OMERRK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"OMERRK" -> "ALIST"
+/*"OMERRK" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"OMERRK" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"OPTPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OPTPACK"]
+/*"OPTPACK" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"OPTPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"OPTPACK" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"OPTPACK" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"OPTPACK" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"OPTPACK" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"OPTPACK" -> {"RADCAT"; "PATMAB"; "CHARZ"; "STRING"; "CHAR"; "SINT"}*/
+/*"OPTPACK" -> {"OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"OPTPACK" -> {"SRAGG-"; "ILIST"; "TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"}*/
+/*"OPTPACK" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"OPTPACK" -> {"CLAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "NNI"; "SYMBOL"; "REF"}*/
+"OPTPACK" -> "ALIST"
+/*"OPTPACK" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "INS-"}*/
+/*"OPTPACK" -> {"DFLOAT"; "PI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"OPTPACK" -> {"FLAGG"; "ELAGG"; "OM"; "DIFRING"; "TRANFUN"; "TRIGCAT"}*/
+/*"OPTPACK" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "EUCDOM-"}*/
+/*"OPTPACK" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"OPTPACK" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
+
+"OSI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OSI"]
+/*"OSI" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "SYMBOL"; "REF"}*/
+"OSI" -> "ALIST"
+/*"OSI" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"OSI" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"OVAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OVAR"]
+/*"OVAR" -> {"ORDFIN"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
+/*"OVAR" -> {"KONVERT"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"OVAR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"OVAR" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"OVAR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"OVAR" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"OVAR" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"}*/
+/*"OVAR" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "LSAGG"; "STAGG"}*/
+/*"OVAR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"OVAR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"OVAR" -> {"OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"OVAR" -> {"SYMBOL"; "REF"}*/
+"OVAR" -> "ALIST"
+/*"OVAR" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"OVAR" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "PI"}*/
+
+"PACOFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PACOFF"]
+/*"PACOFF" -> {"PACFFC"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"PACOFF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PACOFF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PACOFF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PACOFF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
+/*"PACOFF" -> {"FINITE"; "STEP"; "DIFRING"; "PACPERC"; "XF"; "RETRACT"}*/
+/*"PACOFF" -> {"VSPACE"; "CHARZ"; "ORDSET"; "NNI"; "INT"; "PI"; "VECTOR"}*/
+/*"PACOFF" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"}*/
+/*"PACOFF" -> {"LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"PACOFF" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "MONOID-"; "ABELMON-"}*/
+/*"PACOFF" -> {"SGROUP-"; "SINT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"PACOFF" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"PACOFF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"PACOFF" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"PACOFF" -> {"RCAGG-"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"PACOFF" -> {"FRETRCT"; "FLINEXP"; "LINEXP"; "PATMAB"; "PFECAT"; "DIFEXT"}*/
+/*"PACOFF" -> {"SYMBOL"; "REF"}*
+"PACOFF" -> "ALIST"
+/*"PACOFF" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
+/*"PACOFF" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PACOFF" -> {"OASGP"; "CFCAT"; "REAL"; "BOOLEAN"; "OAMONS"}*/
+
+"PACRAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PACRAT"]
+/*"PACRAT" -> {"PACRATC"; "PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PACRAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PACRAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE" "SGROUP"}*/
+/*"PACRAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PACRAT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"}*/
+/*"PACRAT" -> {"XF"; "VSPACE"; "FPC"; "CHARNZ"; "FINITE"; "INS"; "OINTDOM"}*/
+/*"PACRAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"PACRAT" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"PACRAT" -> {"STEP"; "INT"; "NNI"; "PI"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"PACRAT" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"PACRAT" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"PACRAT" -> {"SETCAT-"; "BASTYPE-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"PACRAT" -> {"VECTCAT-"; "A1AGG-"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"PACRAT" -> {"AMR"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
+/*"PACRAT" -> {"ELTAB"; "DIFEXT"; "SYMBOL"; "REF"}*/
+"PACRAT" -> "ALIST"
+/*"PACRAT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "ISTRING"}*/
+/*"PACRAT" -> {"SRAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"PACRAT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"PACRAT" -> {"OM"; "BOOLEAN"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
+
+"PATTERN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PATTERN"]
+/*"PATTERN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "SYMBOL"; "INT"}*/
+/*"PATTERN" -> "REF"*/
+"PATTERN" -> "ALIST"
+/*"PATTERN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"PATTERN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"PATTERN" -> {"NNI"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"PATTERN" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"PATTERN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
+/*"PATTERN" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"PATTERN" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"PATTERN" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "PATMAB"; "MONOID"}*/
+/*"PATTERN" -> {"SGROUP"; "ABELMON"; "ABELSG"; "PI"}*/
+
+"PLCS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLCS"]
+/*"PLCS" -> {"PLACESC"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
+/*"PLCS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"PLCS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"PLCS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PLCS" -> {"UFD"; "DIVRING"}*/
+"PLCS" -> "ALIST"
+/*"PLCS" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"; "DIFRING"}*/
+/*"PLCS" -> {"PDRING"; "SYMBOL"; "INT"; "REF"; "LOCPOWC"; "LIST"; "STRING"}*/
+/*"PLCS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"PLCS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PLCS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"PLCS" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
+/*"PLCS" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"PLCS" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"PLCS" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "PI"; "NNI"; "BOOLEAN"}*/
+
+"PMKERNEL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMKERNEL"]
+/*"PMKERNEL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "RETRACT"}*/
+/*"PMKERNEL" -> {"KONVERT"; "PATMAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"PMKERNEL" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"PMKERNEL" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"PMKERNEL" -> {"OM"; "INT"; "LIST"; "ILIST"; "NNI"; "SYMBOL"; "REF"}*/
+"PMKERNEL" -> "ALIST"
+/*"PMKERNEL" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"PMKERNEL" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "MONOID"; "SGROUP"}*/
+/*"PMKERNEL" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "ABELMON"; "ABELSG"}*/
+
+"PMSYM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMSYM"]
+/*"PMSYM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "SYMBOL"; "INT"}*/
+/*"PMSYM" -> "REF"*/
+"PMSYM" -> "ALIST"
+/*"PMSYM" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"PMSYM" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"POLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=POLY"]
+/*"POLY" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"POLY" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"POLY" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"POLY" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"POLY" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"POLY" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+/*"POLY" -> {"PFECAT"; "UFD"; "SYMBOL"; "INT"; "REF"}*/
+"POLY" -> "ALIST"
+/*"POLY" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"POLY" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
+/*"POLY" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"}*/
+/*"POLY" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
+/*"POLY" -> {"INS"; "OINTDOM"; "DIFRING"; "CFCAT"; "STEP"; "UPOLYC"}*/
+/*"POLY" -> {"ELTAB"; "DIFEXT"}*/
+
+"PRIMELT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRIMELT"]
+/*"PRIMELT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PRIMELT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PRIMELT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PRIMELT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PRIMELT" -> {"UFD"; "DIVRING"; "CHARZ"; "SINT"; "NNI"; "INT"; "INS-"}*/
+/*"PRIMELT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PRIMELT" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"PRIMELT" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
+/*"PRIMELT" -> {"PATMAB"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"PRIMELT" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"PRIMELT" -> {"CLAGG-"; "SYMBOL"; "REF"}*/
+"PRIMELT" -> "ALIST"
+/*"PRIMELT" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"PRIMELT" -> {"SRAGG-"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"PRIMELT" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PFECAT"}*/
+
+"QALGSET2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QALGSET2"]
+/*"QALGSET2" -> {"SYMBOL"; "INT"; "REF"}*/
+"QALGSET2" -> "ALIST"
+/*"QALGSET2" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"QALGSET2" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"QALGSET2" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"QALGSET2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"QALGSET2" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"QALGSET2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"QALGSET2" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"QALGSET2" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"QALGSET2" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"QALGSET2" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"QALGSET2" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
+/*"QALGSET2" -> {"FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"; "DIRPCAT"; "IXAGG"}*/
+/*"QALGSET2" -> {"HOAGG"; "AGG"; "ELTAGG"; "FRETRCT"; "FINITE"; "OAMONS"}*/
+/*"QALGSET2" -> {"VSPACE"; "ORDFIN"; "POLYCAT"; "FAMR"; "AMR"; "LSAGG"}*/
+/*"QALGSET2" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"}*/
+/*"QALGSET2" -> {"ELAGG"; "OM"; "BOOLEAN"}*/
+
+"QEQUAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QEQUAT"]
+/*"QEQUAT" -> {"KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"QEQUAT" -> "ALIST"
+/*"QEQUAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"QEQUAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"QUATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=QUATCAT"]
+/*"QUATCAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"QUATCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"QUATCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"QUATCAT" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"QUATCAT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"QUATCAT" -> {"ENTIRER"; "ORDSET"; "DIVRING"; "KONVERT"; "CHARZ"; "CHARNZ"}*/
+/*"QUATCAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "UFD"}*/
+/*"QUATCAT" -> {"BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
+"QUATCAT" -> "ALIST"
+/*"QUATCAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"QUATCAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "RNS"}*/
+/*"QUATCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"QUATCAT" -> {"RADCAT"; "PATMAB"; "INS"; "OINTDOM"; "CFCAT"; "STEP"}*/
+
+"QUATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QUATCAT"]
+/*"QUATCAT-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
+/*"QUATCAT-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
+/*"QUATCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
+/*"QUATCAT-" -> {"ALGEBRA";  "MODULE";  "FRETRCT";  "RETRACT";  "DIFEXT"}*/
+/*"QUATCAT-" -> {"DIFRING";  "PDRING";  "FEVALAB";  "ELTAB";  "EVALAB"}*/
+/*"QUATCAT-" -> {"IEVALAB";  "FLINEXP";  "LINEXP";  "ENTIRER";  "ORDSET"}*/
+/*"QUATCAT-" -> {"DIVRING";  "KONVERT";  "CHARZ";  "CHARNZ";  "FIELD"}*/
+/*"QUATCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "UFD";  "BOOLEAN"}*/
+/*"QUATCAT-" -> {"SYMBOL";  "INT";  "REF"}*/
+"QUATCAT-" -> "ALIST"
+/*"QUATCAT-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
+/*"QUATCAT-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-"}*/
+/*"QUATCAT-" -> {"RNS";  "ORDRING";  "OAGROUP";  "OCAMON";  "OAMON"}*/
+/*"QUATCAT-" -> {"OASGP";  "REAL";  "RADCAT";  "PATMAB";  "INS";  "OINTDOM"}*/
+/*"QUATCAT-" -> {"CFCAT";  "STEP"}*/
+
+"RECLOS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RECLOS"]
+/*"RECLOS" -> {"RCFIELD"; "CHARZ"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"RECLOS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"RECLOS" -> {"MONOID"; "LMODULE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"RECLOS" -> {"OASGP"; "ORDSET"; "COMRING"; "BMODULE"; "RMODULE"; "FIELD"}*/
+/*"RECLOS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "MODULE"}*/
+/*"RECLOS" -> {"ENTIRER"; "UFD"; "DIVRING"; "FRETRCT"; "RETRACT"; "RADCAT"}*/
+/*"RECLOS" -> {"REAL"; "KONVERT"; "PI"; "NNI"; "INT"; "SYMBOL"; "REF"}*/
+"RECLOS" -> "ALIST"
+/*"RECLOS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"RECLOS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
+/*"RECLOS" -> {"OINTDOM"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "STEP"}*/
+/*"RECLOS" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
+/*"RECLOS" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"RECLOS" -> {"SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"RECLOS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"RECLOS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"RECLOS" -> {"OM"; "BOOLEAN"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PDRING"}*/
+/*"RECLOS" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "CHARNZ"; "PFECAT"}*/
+
+"REP1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REP1"]
+/*"REP1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"REP1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"REP1" -> {"INT"; "SINT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"REP1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"REP1" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"REP1" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"REP1" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LIST"}*/
+/*"REP1" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"REP1" -> {"LNAGG-"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"REP1" -> {"A1AGG-"; "IXAGG-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"REP1" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
+/*"REP1" -> {"ELTAB"; "CLAGG"; "PI"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"REP1" -> {"RCAGG"; "ELAGG"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"REP1" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "SYMBOL"; "REF"}*/
+"REP1" -> "ALIST"
+/*"REP1" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
+
+"RESULT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RESULT"]
+/*"RESULT" -> {"TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"}*/
+/*"RESULT" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
+/*"RESULT" -> {"CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
+/*"RESULT" -> {"SYMBOL"; "INT"; "REF"}*/
+"RESULT" -> "ALIST"
+/*"RESULT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"RESULT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+/*"RESULT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "FLAGG"}*/
+/*"RESULT" -> {"ELAGG"; "OM"; "ILIST"}*/
+
+"RFFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFFACT"]
+/*"RFFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"RFFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RFFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"RFFACT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"RFFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"RFFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"RFFACT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
+/*"RFFACT" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+/*"RFFACT" -> {"SYMBOL"; "INT"; "REF"}*/
+"RFFACT" -> "ALIST"
+/*"RFFACT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"RFFACT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
+/*"RFFACT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"RFFACT" -> {"CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
+/*"RFFACT" -> "TYPE"*/
+
+"RMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RMATRIX"]
+/*"RMATRIX" -> {"RMATCAT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
+/*"RMATRIX" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RMATRIX" -> {"RMODULE"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"RMATRIX" -> {"MODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"RMATRIX" -> {"VSPACE"; "KONVERT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"RMATRIX" -> {"INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"; "NNI"}*/
+/*"RMATRIX" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"RMATRIX" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ORDSET"}*/
+/*"RMATRIX" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
+"RMATRIX" -> "ALIST"
+/*"RMATRIX" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"RMATRIX" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"ROMAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ROMAN"]
+/*"ROMAN" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"ROMAN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"ROMAN" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ROMAN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"ROMAN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ROMAN" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"ROMAN" -> {"REAL"; "CHARZ"; "STEP"; "SYMBOL"; "INT"; "REF"}*/
+"ROMAN" -> "ALIST"
+/*"ROMAN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ROMAN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"ROUTINE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ROUTINE"]
+/*"ROUTINE" -> {"TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"}*/
+/*"ROUTINE" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"ROUTINE" -> {"IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"ROUTINE" -> {"ORDSET"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
+/*"ROUTINE" -> {"INT"; "PRIMARR"; "A1AGG-"; "ISTRING"; "BOOLEAN"; "ILIST"}*/
+/*"ROUTINE" -> {"LSAGG-"; "STAGG-"; "PI"; "NNI"; "SYMBOL"; "REF"}*/
+"ROUTINE" -> "ALIST"
+/*"ROUTINE" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"ROUTINE" -> {"RCAGG"; "LNAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+
+"RPOLCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RPOLCAT"]
+/*"RPOLCAT" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"RPOLCAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RPOLCAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"RPOLCAT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"RPOLCAT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"RPOLCAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"RPOLCAT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "OAMONS"; "OCAMON"}*/
+/*"RPOLCAT" -> {"OAMON"; "OASGP"; "NNI"; "INT"; "LIST"; "BOOLEAN"; "ILIST"}*/
+/*"RPOLCAT" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "FINITE"; "SINT"}*/
+/*"RPOLCAT" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "INS"}*/
+/*"RPOLCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "DIFRING"; "CFCAT"; "REAL"}*/
+/*"RPOLCAT" -> {"STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"}*/
+/*"RPOLCAT" -> {"FPATMAB"; "TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"RPOLCAT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"RPOLCAT" -> {"FLAGG"; "ELAGG"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
+/*"RPOLCAT" -> {"A1AGG-"; "ISTRING"; "SYMBOL"; "REF"}*/
+"RPOLCAT" -> "ALIST"
+/*"RPOLCAT" -> {"SRAGG-"; "LNAGG-"; "STRICAT"; "SRAGG"; "A1AGG"}*/
+/*"RPOLCAT" -> {"FPS"; "RNS"; "RADCAT"}*/
+
+"RPOLCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RPOLCAT"]
+/*"RPOLCAT-" -> {"POLYCAT";  "PDRING";  "RING";  "RNG";  "ABELGRP"}*/
+/*"RPOLCAT-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
+/*"RPOLCAT-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "FAMR"}*/
+/*"RPOLCAT-" -> {"AMR";  "BMODULE";  "RMODULE";  "COMRING";  "ALGEBRA"}*/
+/*"RPOLCAT-" -> {"MODULE";  "CHARZ";  "CHARNZ";  "INTDOM";  "ENTIRER"}*/
+/*"RPOLCAT-" -> {"FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP"}*/
+/*"RPOLCAT-" -> {"LINEXP";  "ORDSET";  "KONVERT";  "PATMAB";  "GCDDOM"}*/
+/*"RPOLCAT-" -> {"PFECAT";  "UFD";  "OAMONS";  "OCAMON";  "OAMON";  "OASGP"}*/
+/*"RPOLCAT-" -> {"NNI";  "INT";  "LIST";  "BOOLEAN";  "ILIST";  "EUCDOM"}*/
+/*"RPOLCAT-" -> {"PID";  "FIELD";  "DIVRING";  "FINITE";  "SINT";  "OM"}*/
+/*"RPOLCAT-" -> {"LSAGG-";  "STAGG-";  "ELAGG-";  "FLAGG-";  "INS"}*/
+/*"RPOLCAT-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "DIFRING";  "CFCAT"}*/
+/*"RPOLCAT-" -> {"REAL";  "STEP";  "QFCAT";  "FEVALAB";  "ELTAB";  "DIFEXT"}*/
+/*"RPOLCAT-" -> {"PATAB";  "FPATMAB";  "TYPE";  "LSAGG";  "STAGG";  "URAGG"}*/
+/*"RPOLCAT-" -> {"RCAGG";  "HOAGG";  "AGG";  "LNAGG";  "IXAGG";  "ELTAGG"}*/
+/*"RPOLCAT-" -> {"CLAGG";  "FLAGG";  "ELAGG";  "STRING";  "CHAR";  "OUTFORM"}*/
+/*"RPOLCAT-" -> {"PRIMARR";  "A1AGG-";  "ISTRING";  "SYMBOL";  "REF"}*/
+"RPOLCAT-" -> "ALIST"
+/*"RPOLCAT-" -> {"SRAGG-";  "LNAGG-";  "STRICAT";  "SRAGG";  "A1AGG"}*/
+/*"RPOLCAT-" -> {"FPS";  "RNS";  "RADCAT"}*/
+
+"RULECOLD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RULECOLD"]
+/*"RULECOLD" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"RULECOLD" -> "ALIST"
+/*"RULECOLD" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"RULECOLD" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"RULECOLD" -> "BOOLEAN"*/
+
+"SAOS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SAOS"]
+/*"SAOS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
+/*"SAOS" -> {"INT"; "REF"}*/
+"SAOS" -> "ALIST"
+/*"SAOS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"SAOS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"SEGBIND" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEGBIND"]
+/*"SEGBIND" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
+/*"SEGBIND" -> "REF"*/
+"SEGBIND" -> "ALIST"
+/*"SEGBIND" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"SEGBIND" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"SEGBIND" -> "BOOLEAN"*/
+
+"SET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SET"]
+/*"SET" -> {"FSAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"SET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
+/*"SET" -> {"KONVERT"; "SETAGG"; "FINITE"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"SET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"; "ELAGG"; "INS"; "UFD"}*/
+/*"SET" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SET" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"SET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
+/*"SET" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"SET" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"SET" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "SYMBOL"; "INT"; "REF"}*/
+"SET" -> "ALIST"
+/*"SET" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"SET" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
+/*"SET" -> {"STAGG"; "URAGG"; "RCAGG"; "ILIST"; "NNI"; "BOOLEAN"}*/
+
+"SPECOUT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SPECOUT"]
+/*"SPECOUT" -> {"SYMBOL"; "INT"; "REF"}*/
+"SPECOUT" -> "ALIST"
+/*"SPECOUT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"SPECOUT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"SQMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SQMATRIX"]
+/*"SQMATRIX" -> {"SMATCAT"; "DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SQMATRIX" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SQMATRIX" -> {"SGROUP"; "MONOID"; "LMODULE"; "DIFRING"; "PDRING"}*/
+/*"SQMATRIX" -> {"BMODULE"; "RMODULE"; "RMATCAT"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"SQMATRIX" -> {"EVALAB"; "IEVALAB"; "MODULE"; "COMRING"; "FRETRCT"}*/
+/*"SQMATRIX" -> {"RETRACT"; "FLINEXP"; "LINEXP"; "ALGEBRA"; "KONVERT"}*/
+/*"SQMATRIX" -> {"NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"SQMATRIX" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"SQMATRIX" -> {"ORDSET"; "ELAGG"; "OM"; "LIST"; "ILIST"; "EUCDOM"}*/
+/*"SQMATRIX" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "FIELD"; "UFD"}*/
+/*"SQMATRIX" -> {"DIVRING"; "SYMBOL"; "REF"}*/
+"SQMATRIX" -> "ALIST"
+/*"SQMATRIX" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"SQMATRIX" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "OINTDOM"}*/
+/*"SQMATRIX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "PATMAB"}*/
+/*"SQMATRIX" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+
+"SWITCH" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SWITCH"]
+/*"SWITCH" -> {"KOERCE"; "INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"SWITCH" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
+/*"SWITCH" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"SWITCH" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INS"}*/
+/*"SWITCH" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"SWITCH" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"SWITCH" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"SWITCH" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"SWITCH" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
+/*"SWITCH" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"}*/
+/*"SWITCH" -> {"SYMBOL"; "REF"}*/
+"SWITCH" -> "ALIST"
+/*"SWITCH" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"SWITCH" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"SYMS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMS"]
+/*"SYMS" -> {"KOERCE"; "ORDSET"; "SETCAT"; "BASTYPE"; "SYMBOL"; "INT"; "REF"}*/
+"SYMS" -> "ALIST"
+/*"SYMS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"SYMS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+
+"SYMTAB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMTAB"]
+/*"SYMTAB" -> {"KOERCE"; "ORDSET"; "SETCAT"; "BASTYPE"; "INS"; "UFD"}*/
+/*"SYMTAB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SYMTAB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"SYMTAB" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"SYMTAB" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"SYMTAB" -> {"OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"SYMTAB" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"; "LIST"}*/
+/*"SYMTAB" -> {"ILIST"; "OM"; "SYMBOL"; "REF"}*/
+"SYMTAB" -> "ALIST"
+/*"SYMTAB" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"SYMTAB" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"}*/
+/*"SYMTAB" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"SYMTAB" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+
+"SYSSOLP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SYSSOLP"]
+/*"SYSSOLP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SYSSOLP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SYSSOLP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SYSSOLP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"}*/
+/*"SYSSOLP" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"SYSSOLP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"SYSSOLP" -> {"KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "QFCAT"}*/
+/*"SYSSOLP" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
+/*"SYSSOLP" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
+/*"SYSSOLP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"SYSSOLP" -> {"OASGP"; "REAL"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"SYSSOLP" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
+/*"SYSSOLP" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"SYSSOLP" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "NNI"; "SYMBOL"; "REF"}*/
+"SYSSOLP" -> "ALIST"
+/*"SYSSOLP" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"SYSSOLP" -> {"ISTRING"; "SRAGG-"; "LNAGG-"; "BOOLEAN"; "DIRPCAT"}*/
+/*"SYSSOLP" -> {"FINITE"; "OAMONS"; "VSPACE"; "ORDFIN"; "VECTOR"; "IVECTOR"}*/
+/*"SYSSOLP" -> {"IARRAY1"; "VECTCAT-"; "VECTCAT"; "A1AGG"}*/
+
+"UTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UTSCAT"]
+/*"UTSCAT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
+/*"UTSCAT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"UTSCAT" -> {"UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"UTSCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"UTSCAT" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"UTSCAT" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"UTSCAT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "BOOLEAN"; "INT"}*/
+/*"UTSCAT" -> {"SYMBOL"; "REF"}*/
+"UTSCAT" -> "ALIST"
+/*"UTSCAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"UTSCAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"UTSCAT" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"UTSCAT" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"UTSCAT" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"}*/
+/*"UTSCAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"UTSCAT" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "RETRACT"; "LINEXP"}*/
+/*"UTSCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+
+"UTSCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTSCAT"]
+/*"UTSCAT-" -> {"OAMONS";  "OCAMON";  "OAMON";  "OASGP";  "ORDSET"}*/
+/*"UTSCAT-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "ABELMON";  "ABELSG"}*/
+/*"UTSCAT-" -> {"CABMON";  "UPSCAT";  "PSCAT";  "AMR";  "RING";  "RNG"}*/
+/*"UTSCAT-" -> {"ABELGRP";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
+/*"UTSCAT-" -> {"RMODULE";  "COMRING";  "ALGEBRA";  "MODULE";  "CHARZ"}*/
+/*"UTSCAT-" -> {"CHARNZ";  "INTDOM";  "ENTIRER";  "ELTAB";  "DIFRING"}*/
+/*"UTSCAT-" -> {"PDRING";  "RADCAT";  "TRANFUN";  "TRIGCAT";  "ATRIG"}*/
+/*"UTSCAT-" -> {"HYPCAT";  "AHYP";  "ELEMFUN";  "BOOLEAN";  "INT"}*/
+/*"UTSCAT-" -> {"SYMBOL";  "REF"}*/
+"UTSCAT-" -> "ALIST"
+/*"UTSCAT-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM"}*/
+/*"UTSCAT-" -> {"PRIMARR";  "A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-"}*/
+/*"UTSCAT-" -> {"LNAGG-";  "ILIST";  "NNI";  "LSAGG";  "STAGG";  "URAGG"}*/
+/*"UTSCAT-" -> {"RCAGG";  "HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB"}*/
+/*"UTSCAT-" -> {"LNAGG";  "IXAGG";  "ELTAGG";  "CLAGG";  "KONVERT";  "FLAGG"}*/
+/*"UTSCAT-" -> {"ELAGG";  "OM";  "LSAGG-";  "FIELD";  "EUCDOM";  "PID"}*/
+/*"UTSCAT-" -> {"GCDDOM";  "UFD";  "DIVRING";  "INS";  "OINTDOM";  "ORDRING"}*/
+/*"UTSCAT-" -> {"OAGROUP";  "RETRACT";  "LINEXP";  "PATMAB";  "CFCAT"}*/
+/*"UTSCAT-" -> {"REAL";  "STEP"}*/
+
+"VARIABLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VARIABLE"]
+/*"VARIABLE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
+"VARIABLE" -> "ALIST"
+/*"VARIABLE" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"VARIABLE" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"VARIABLE" -> "BOOLEAN"*/
+
+\end{chunk}
+\subsection{Layer17}
+Depends on: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT NSDPS \\
+Used by next layer: ACFS EXPRSOL FDIVCAT UFPS ULSCCAT UTSSOL 
+
+The clique1.spad file is used because "MYEXPR" and "MYUP" are 
+mutually dependent. Rather than add one to the bootstrap we let the
+compiler resolve them in one step. This same technique might be useful
+for other cliques in bootstrap. This needs to be investigated.
+\begin{chunk}{layer17}
+
+LAYER17=\
+  ${OUT}/ACFS.o     ${OUT}/ACFS-.o    ${OUT}/AF.o       ${OUT}/AFFPLPS.o  \
+  ${OUT}/ALGFACT.o  \
+  ${OUT}/ALGFF.o    ${OUT}/ALGMANIP.o ${OUT}/ALGMFACT.o ${OUT}/ALGPKG.o   \
+  ${OUT}/ALGSC.o    ${OUT}/AN.o       ${OUT}/APPRULE.o  ${OUT}/ASP19.o    \
+  ${OUT}/ASP20.o    ${OUT}/ASP31.o    ${OUT}/ASP35.o    ${OUT}/ASP41.o    \
+  ${OUT}/ASP42.o    ${OUT}/ASP74.o    ${OUT}/ASP77.o    ${OUT}/ASP80.o    \
+  ${OUT}/CDFMAT.o   ${OUT}/CDFVEC.o   \
+  ${OUT}/CINTSLPE.o ${OUT}/COMBF.o    ${OUT}/COMPFACT.o ${OUT}/COMPLEX.o  \
+  ${OUT}/COMPLPAT.o ${OUT}/CMPLXRT.o  ${OUT}/CPMATCH.o  ${OUT}/CRFP.o     \
+  ${OUT}/CTRIGMNP.o ${OUT}/D01WGTS.o  ${OUT}/D02AGNT.o  ${OUT}/D03EEFA.o  \
+  ${OUT}/DBLRESP.o  ${OUT}/D01AGNT.o  ${OUT}/DERHAM.o   ${OUT}/DFSFUN.o   \
+  ${OUT}/DRAWCURV.o ${OUT}/DTP.o      \
+  ${OUT}/D01TRNS.o  ${OUT}/E04NAFA.o  ${OUT}/EF.o       \
+  ${OUT}/EFSTRUC.o  ${OUT}/ELFUTS.o   ${OUT}/ESTOOLS.o  ${OUT}/EXPEXPAN.o \
+  ${OUT}/EXPRODE.o  ${OUT}/EXPRTUBE.o ${OUT}/EXPR2.o    ${OUT}/FC.o       \
+  ${OUT}/FDIVCAT.o  ${OUT}/FDIVCAT-.o ${OUT}/FDIV2.o    ${OUT}/FFCAT2.o   \
+  ${OUT}/FLOATCP.o  ${OUT}/FORDER.o   ${OUT}/FORTRAN.o  ${OUT}/FRNAAF2.o  \
+  ${OUT}/FSPRMELT.o ${OUT}/FSRED.o    ${OUT}/FSUPFACT.o ${OUT}/FSPECF.o   \
+  ${OUT}/FS2.o      ${OUT}/FS2UPS.o   ${OUT}/GAUSSFAC.o ${OUT}/GCNAALG.o  \
+  ${OUT}/GDRAW.o    \
+  ${OUT}/GENUFACT.o ${OUT}/GENUPS.o   ${OUT}/GTSET.o    ${OUT}/GPOLSET.o  \
+  ${OUT}/IAN.o      ${OUT}/INEP.o     ${OUT}/INFPROD0.o ${OUT}/INFSP.o    \
+  ${OUT}/INPRODFF.o ${OUT}/INPRODPF.o ${OUT}/INTAF.o    ${OUT}/INTALG.o   \
+  ${OUT}/INTEF.o    ${OUT}/INTG0.o    ${OUT}/INTHERAL.o ${OUT}/INTPAF.o   \
+  ${OUT}/INTPM.o    ${OUT}/INTTOOLS.o ${OUT}/ITRIGMNP.o ${OUT}/JORDAN.o   \
+  ${OUT}/KOVACIC.o  ${OUT}/LF.o       ${OUT}/LIE.o      ${OUT}/LODOF.o    \
+  ${OUT}/LSQM.o     ${OUT}/MCMPLX.o   ${OUT}/MULTFACT.o \
+  ${MID}/clique1.spad \
+  ${OUT}/NAGF01.o   ${OUT}/NAGF02.o   ${OUT}/NAGF04.o   ${OUT}/NCEP.o     \
+  ${OUT}/NLINSOL.o  ${OUT}/NSMP.o     ${OUT}/NUMERIC.o  ${OUT}/OCT.o      \
+  ${OUT}/OCTCT2.o   ${OUT}/ODEPAL.o   ${OUT}/ODERTRIC.o ${OUT}/OMEXPR.o   \
+  ${OUT}/PACEXTC.o  ${OUT}/PADE.o     \
+  ${OUT}/PAN2EXPR.o ${OUT}/PFO.o      ${OUT}/PFOQ.o     ${OUT}/PICOERCE.o \
+  ${OUT}/PLACES.o   ${OUT}/PLACESPS.o \
+  ${OUT}/PMASSFS.o  ${OUT}/PMFS.o     ${OUT}/PMPREDFS.o ${OUT}/PROJPLPS.o \
+  ${OUT}/PSETPK.o   \
+  ${OUT}/QUAT.o     ${OUT}/QUATCT2.o  ${OUT}/RADFF.o    ${OUT}/RDEEF.o    \
+  ${OUT}/RDEEFS.o   ${OUT}/RDIV.o     ${OUT}/RSETCAT.o  ${OUT}/RSETCAT-.o \
+  ${OUT}/RSETGCD.o  ${OUT}/RULE.o     ${OUT}/RULESET.o  ${OUT}/SD.o       \
+  ${OUT}/SIGNEF.o   ${OUT}/SIMPAN.o   ${OUT}/SFORT.o    ${OUT}/SOLVESER.o \
+  ${OUT}/SOLVETRA.o ${OUT}/SUMFS.o    ${OUT}/SUTS.o     ${OUT}/TOOLSIGN.o \
+  ${OUT}/TRIGMNIP.o ${OUT}/TRMANIP.o  ${OUT}/UFPS.o     ${OUT}/ULSCCAT.o  \
+  ${OUT}/ULSCCAT-.o ${OUT}/UPXSSING.o ${OUT}/UTSODE.o   ${OUT}/UTSODETL.o \
+  ${OUT}/UTSSOL.o   ${OUT}/UTS2.o     ${OUT}/WUTSET.o  \
+  layer17done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 17 */
+/* depends on: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT */
+
+"ACFS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ACFS"]
+"ACFS" -> "ACF"
+/*"ACFS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ACFS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ACFS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ACFS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ACFS" -> {"UFD"; "DIVRING"; "RADCAT"}*/
+"ACFS" -> "FS"
+/*"ACFS" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
+/*"ACFS" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"}*/
+/*"ACFS" -> {"PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "INT"}*/
+/*"ACFS" -> {"LIST"; "ILIST"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"ACFS" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"}*/
+
+"ACFS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ACFS"]
+"ACFS-" -> "ACF"
+/*"ACFS-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "COMRING"}*/
+/*"ACFS-" -> {"RING";  "RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
+/*"ACFS-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP";  "MONOID"}*/
+/*"ACFS-" -> {"LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
+/*"ACFS-" -> {"ENTIRER";  "UFD";  "DIVRING";  "RADCAT"}*/
+"ACFS-" -> "FS"
+/*"ACFS-" -> {"ES";  "ORDSET";  "RETRACT";  "IEVALAB";  "EVALAB";  "PATAB"}*/
+/*"ACFS-" -> {"KONVERT";  "FPATMAB";  "TYPE";  "PATMAB";  "FRETRCT"}*/
+/*"ACFS-" -> {"GROUP";  "PDRING";  "FLINEXP";  "LINEXP";  "CHARZ";  "CHARNZ"}*/
+/*"ACFS-" -> {"INT";  "LIST";  "ILIST";  "UPOLYC";  "POLYCAT";  "FAMR"}*/
+/*"ACFS-" -> {"AMR";  "PFECAT";  "ELTAB";  "DIFRING";  "DIFEXT";  "STEP"}*/
+/*"ACFS-" -> "NNI"*/
+
+"AF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AF"]
+/*"AF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
+/*"AF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"AF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"AF" -> {"MODULE"; "ENTIRER"}*/
+"AF" -> "FS"
+/*"AF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"AF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"AF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"AF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
+/*"AF" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"AF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+/*"AF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "UPOLYC"; "POLYCAT"}*/
+/*"AF" -> {"FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
+/*"AF" -> {"STEP"; "NNI"}*/
+"AF" -> "ACF"
+/*"AF" -> {"RADCAT"; "BOOLEAN"; "CACHSET"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"AF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "INS-"}*/
+
+"AFFPLPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AFFPLPS"]
+/*"AFFPLPS" -> {"AFSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"AFFPLPS" -> "PACFFC"
+/*"AFFPLPS" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"AFFPLPS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"AFFPLPS" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"AFFPLPS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"AFFPLPS" -> {"UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"}*/
+/*"AFFPLPS" -> {"PACPERC"; "PACOFF"; "AFFPL"}*/
+
+"ALGFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGFACT"]
+/*"ALGFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ALGFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ALGFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"ALGFACT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"ALGFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"ALGFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"ALGFACT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
+/*"ALGFACT" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+/*"ALGFACT" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ES"; "LSAGG"}*/
+/*"ALGFACT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
+/*"ALGFACT" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"ALGFACT" -> {"CACHSET"; "PATAB"; "ELAGG-"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"ALGFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"ALGFACT" -> {"QFCAT"; "FEVALAB"; "FPATMAB"}*/
+"ALGFACT" -> "ACF"
+/*"ALGFACT" -> {"RADCAT"; "NNI"; "BOOLEAN"; "MONOGEN"; "FRAMALG"; "FINRALG"}*/
+/*"ALGFACT" -> {"FINITE"; "FFIELDC"; "FPC"}*/
+
+"ALGFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALGFF"]
+/*"ALGFF" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ALGFF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ALGFF" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"ALGFF" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"ALGFF" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"ALGFF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"ALGFF" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
+/*"ALGFF" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+"ALGFF" -> "FFCAT"
+/*"ALGFF" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"ALGFF" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
+/*"ALGFF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"ALGFF" -> {"BOOLEAN"; "NNI"; "INT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"ALGFF" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "SINT"; "INS"}*/
+/*"ALGFF" -> {"CFCAT"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"ALGFF" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"ALGFF" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "OAMONS"}*/
+
+"ALGMANIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGMANIP"]
+/*"ALGMANIP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ALGMANIP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ALGMANIP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ALGMANIP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "FIELD"; "EUCDOM"}*/
+/*"ALGMANIP" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "ES"; "ORDSET"}*/
+/*"ALGMANIP" -> {"RETRACT"; "IEVALAB"; "EVALAB"; "SYMBOL"; "INT"; "REF"}*/
+/*"ALGMANIP" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"ALGMANIP" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"ALGMANIP" -> {"LNAGG-"; "ILIST"; "LSAGG-"; "CACHSET"; "UPOLYC"}*/
+/*"ALGMANIP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"ALGMANIP" -> {"FRETRCT"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"ALGMANIP" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "STAGG-"}*/
+/*"ALGMANIP" -> {"ELAGG-"; "URAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ALGMANIP" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"ALGMANIP" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "PATAB"; "BOOLEAN"}*/
+"ALGMANIP" -> "FS"
+/*"ALGMANIP" -> {"FPATMAB"; "GROUP"; "RADCAT"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"ALGMANIP" -> {"GCDDOM-"; "NNI"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
+/*"ALGMANIP" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "INS"}*/
+/*"ALGMANIP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ALGMANIP" -> {"OASGP"; "CFCAT"; "REAL"}*/
+
+"ALGMFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGMFACT"]
+/*"ALGMFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
+/*"ALGMFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"ALGMFACT" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
+/*"ALGMFACT" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"ALGMFACT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"ALGMFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"ALGMFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"ALGMFACT" -> {"GCDDOM"; "PFECAT"; "UFD"; "ES"}*/
+"ALGMFACT" -> "ACF"
+/*"ALGMFACT" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "RADCAT"; "UPOLYC"}*/
+/*"ALGMFACT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "REAL"}*/
+
+"ALGPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGPKG"]
+/*"ALGPKG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ALGPKG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ALGPKG" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ALGPKG" -> {"MODULE"; "ENTIRER"}*/
+"ALGPKG" -> "FRNAALG"
+/*"ALGPKG" -> {"FINAALG"; "NAALG"; "NARNG"; "MONAD"; "PI"; "NNI"; "INT"}*/
+/*"ALGPKG" -> {"SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"}*/
+/*"ALGPKG" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"ALGPKG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"ALGPKG" -> {"VECTCAT-"; "A1AGG-"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
+/*"ALGPKG" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ALGPKG" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"ALGPKG" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
+/*"ALGPKG" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "BOOLEAN"; "LIST"}*/
+/*"ALGPKG" -> "ILIST"*/
+
+"ALGSC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALGSC"]
+"ALGSC" -> "FRNAALG"
+/*"ALGSC" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
+/*"ALGSC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
+/*"ALGSC" -> {"MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
+/*"ALGSC" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"}*/
+/*"ALGSC" -> {"MONOID"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"; "SMATCAT"}*/
+/*"ALGSC" -> {"DIFEXT"; "DIFRING"; "PDRING"; "RMATCAT"; "HOAGG"; "AGG"}*/
+/*"ALGSC" -> {"TYPE"; "EVALAB"; "IEVALAB"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
+/*"ALGSC" -> {"LINEXP"; "INT"; "VECTOR"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"ALGSC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"}*/
+/*"ALGSC" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "IVECTOR"}*/
+/*"ALGSC" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
+/*"ALGSC" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"ALGSC" -> {"BASTYPE-"; "SINT"; "PI"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"ALGSC" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "LIST"; "ILIST"}*/
+/*"ALGSC" -> {"LSAGG-"; "STAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"}*/
+/*"ALGSC" -> {"OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"; "LSAGG"; "STAGG"}*/
+/*"ALGSC" -> {"URAGG"; "RCAGG"; "ELAGG"; "BOOLEAN"; "POLYCAT"; "FAMR"}*/
+/*"ALGSC" -> {"AMR"; "CHARNZ"; "PFECAT"}*/
+
+"AN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AN"]
+/*"AN" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"AN" -> {"IEVALAB"; "EVALAB"}*/
+"AN" -> "ACF"
+/*"AN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"AN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"AN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"AN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RADCAT"}*/
+/*"AN" -> {"LINEXP"; "REAL"; "KONVERT"; "CHARZ"; "DIFRING"; "INS"}*/
+/*"AN" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"AN" -> {"PATMAB"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
+/*"AN" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"AN" -> {"CHARNZ"; "PFECAT"; "FPS"; "RNS"; "CACHSET"}*/
+
+"APPRULE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=APPRULE"]
+/*"APPRULE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
+/*"APPRULE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"APPRULE" -> {"PATMAB"; "ORDSET"; "KONVERT"}*/
+"APPRULE" -> "FS"
+/*"APPRULE" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"}*/
+/*"APPRULE" -> {"TYPE"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"APPRULE" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"}*/
+/*"APPRULE" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"APPRULE" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "PI"}*/
+/*"APPRULE" -> {"NNI"; "SINT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"APPRULE" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"APPRULE" -> {"FLAGG"; "ELAGG"; "OM"; "INS-"}*/
+
+"ASP19" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP19"]
+/*"ASP19" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
+/*"ASP19" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"ASP19" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"ASP19" -> {"LNAGG-"; "ILIST"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"ASP19" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ASP19" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"ASP19" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ASP19" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"ASP19" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"ASP19" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+"ASP19" -> "FS"
+/*"ASP19" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
+/*"ASP19" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
+/*"ASP19" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
+/*"ASP19" -> {"ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"}*/
+/*"ASP19" -> {"STEP"; "FMTC"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"ASP19" -> {"VECTCAT-"; "IXAGG-"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"ASP19" -> {"RCAGG"; "ELAGG"; "LSAGG-"; "PI"; "POLYCAT"; "FAMR"}*/
+/*"ASP19" -> {"AMR"; "PFECAT"}*/
+
+"ASP20" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP20"]
+/*"ASP20" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
+/*"ASP20" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ASP20" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ASP20" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP20" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"ASP20" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"ASP20" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"ASP20" -> {"CHARZ"; "ES"; "IEVALAB"; "EVALAB"; "SINT"; "PI"; "NNI"}*/
+/*"ASP20" -> {"INT"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"ASP20" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"ASP20" -> {"LNAGG-"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP20" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP20" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
+/*"ASP20" -> {"DIFEXT"; "PATAB"; "FPATMAB"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"ASP20" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
+"ASP20" -> "FS"
+/*"ASP20" -> "GROUP"*/
+
+"ASP31" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP31"]
+/*"ASP31" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
+/*"ASP31" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"ASP31" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"ASP31" -> {"BOOLEAN"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"ASP31" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ASP31" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"}*/
+/*"ASP31" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ASP31" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ASP31" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"ASP31" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+"ASP31" -> "FS"
+/*"ASP31" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
+/*"ASP31" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
+/*"ASP31" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
+/*"ASP31" -> {"ELTAB"; "CLAGG"; "NNI"; "ILIST"; "VECTOR"; "IVECTOR"}*/
+/*"ASP31" -> {"IARRAY1"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"; "STEP"}*/
+/*"ASP31" -> {"OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "FMTC"}*/
+/*"ASP31" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
+
+"ASP35" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP35"]
+/*"ASP35" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SINT"}*/
+/*"ASP35" -> {"NNI"; "INT"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"ASP35" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"ASP35" -> {"FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"ASP35" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ASP35" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"}*/
+/*"ASP35" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ASP35" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"ASP35" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"ASP35" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+"ASP35" -> "FS"
+/*"ASP35" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
+/*"ASP35" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
+/*"ASP35" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
+/*"ASP35" -> {"ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"}*/
+/*"ASP35" -> {"STEP"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG"}*/
+/*"ASP35" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "FMTC"; "POLYCAT"}*/
+/*"ASP35" -> {"FAMR"; "AMR"; "PFECAT"}*/
+
+"ASP41" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP41"]
+/*"ASP41" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
+/*"ASP41" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"ASP41" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"ASP41" -> {"LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"ASP41" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ASP41" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"}*/
+/*"ASP41" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ASP41" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ASP41" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"ASP41" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+"ASP41" -> "FS"
+/*"ASP41" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
+/*"ASP41" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
+/*"ASP41" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"ASP41" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"ASP41" -> {"VECTCAT-"; "IXAGG-"; "NNI"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"ASP41" -> {"CFCAT"; "STEP"; "OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ASP41" -> {"ELAGG"; "FMTC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
+
+"ASP42" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP42"]
+/*"ASP42" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
+/*"ASP42" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"ASP42" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"ASP42" -> {"FLAGG-"; "LNAGG-"; "NNI"; "ILIST"; "FPS"; "RNS"; "FIELD"}*/
+/*"ASP42" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"ASP42" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"ASP42" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"ASP42" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"ASP42" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ASP42" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+"ASP42" -> "FS"
+/*"ASP42" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
+/*"ASP42" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
+/*"ASP42" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
+/*"ASP42" -> {"ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"}*/
+/*"ASP42" -> {"STEP"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG"}*/
+/*"ASP42" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "VECTCAT-"; "IXAGG-"}*/
+/*"ASP42" -> {"FMTC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
+
+"ASP74" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP74"]
+/*"ASP74" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"; "FIELD"}*/
+/*"ASP74" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"ASP74" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"ASP74" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ASP74" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"ASP74" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"ASP74" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "ES"}*/
+/*"ASP74" -> {"IEVALAB"; "EVALAB"; "NNI"; "INT"; "INS"; "OINTDOM"}*/
+/*"ASP74" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "OM"; "PI"; "FMTC"}*/
+/*"ASP74" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"ASP74" -> {"FLINEXP"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
+/*"ASP74" -> {"PATAB"; "FPATMAB"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"ASP74" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
+"ASP74" -> "FS"
+/*"ASP74" -> "GROUP"*/
+
+"ASP77" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP77"]
+/*"ASP77" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"ASP77" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ASP77" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ASP77" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ASP77" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ASP77" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ASP77" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"ASP77" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
+"ASP77" -> "FS"
+/*"ASP77" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
+/*"ASP77" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
+/*"ASP77" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"ASP77" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"ASP77" -> {"CFCAT"; "STEP"; "BOOLEAN"; "FMTC"; "POLYCAT"; "FAMR"}*/
+/*"ASP77" -> {"AMR"; "PFECAT"; "QFCAT"; "FEVALAB"; "DIFEXT"}*/
+
+"ASP80" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP80"]
+/*"ASP80" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
+/*"ASP80" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"ASP80" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"ASP80" -> {"BOOLEAN"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"ASP80" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ASP80" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"}*/
+/*"ASP80" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ASP80" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ASP80" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"ASP80" -> {"RADCAT"; "PATMAB"; "CHARZ"; "FMTC"; "ES"; "IEVALAB"}*/
+/*"ASP80" -> {"EVALAB"; "PI"; "NNI"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ASP80" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"ASP80" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
+/*"ASP80" -> {"DIFEXT"; "PATAB"; "FPATMAB"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
+/*"ASP80" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
+"ASP80" -> "FS"
+/*"ASP80" -> "GROUP"*/
+
+"CDFMAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CDFMAT"]
+"CDFMAT" -> "COMPCAT"
+/*"CDFMAT" -> {"MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
+/*"CDFMAT" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "FPS"; "RNS"}*/
+/*"CDFMAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"CDFMAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"CDFMAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"CDFMAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"CDFMAT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"CDFMAT" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "MONOGEN"}*/
+/*"CDFMAT" -> {"FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
+/*"CDFMAT" -> {"LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"}*/
+/*"CDFMAT" -> {"FPC"; "STEP"; "FEVALAB"; "ELTAB"; "FPATMAB"; "PATAB"}*/
+/*"CDFMAT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"CDFMAT" -> {"PFECAT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"CDFMAT" -> {"ELTAGG"; "CLAGG"; "INT"; "SINT"; "NNI"; "OM"; "SPFCAT"}*/
+
+"CDFVEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CDFVEC"]
+"CDFVEC" -> "COMPCAT"
+/*"CDFVEC" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"CDFVEC" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"*/
+/*"CDFVEC" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
+/*"CDFVEC" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"CDFVEC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"CDFVEC" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"CDFVEC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"CDFVEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
+/*"CDFVEC" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INT"; "SINT"; "NNI"; "MONOGEN"}*/
+/*"CDFVEC" -> {"FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
+/*"CDFVEC" -> {"LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"}*/
+/*"CDFVEC" -> {"FPC"; "STEP"; "FEVALAB"; "FPATMAB"; "PATAB"; "TRANFUN"}*/
+/*"CDFVEC" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PFECAT"}*/
+/*"CDFVEC" -> {"OM"; "SPFCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
+
+"CINTSLPE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CINTSLPE"]
+/*"CINTSLPE" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"CINTSLPE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"CINTSLPE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CINTSLPE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"CINTSLPE" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"CINTSLPE" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"CINTSLPE" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"CINTSLPE" -> {"REAL"; "CHARZ"; "STEP"}*/
+"CINTSLPE" -> "COMPCAT"
+/*"CINTSLPE" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"CINTSLPE" -> {"FLINEXP"; "FINITE"; "FIELD"; "DIVRING"; "DIFEXT"}*/
+/*"CINTSLPE" -> {"PDRING"; "FFIELDC"; "FPC"; "FEVALAB"; "ELTAB"}*/
+/*"CINTSLPE" -> {"EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"}*/
+/*"CINTSLPE" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"CINTSLPE" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "INT"; "VECTOR"}*/
+/*"CINTSLPE" -> {"IVECTOR"; "IARRAY1"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"CINTSLPE" -> {"AMR"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"}*/
+
+"COMBF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMBF"]
+/*"COMBF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"COMBF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"COMBF" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"COMBF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+"COMBF" -> "FS"
+/*"COMBF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"COMBF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"COMBF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"COMBF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
+/*"COMBF" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"COMBF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"COMBF" -> {"BOOLEAN"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"COMBF" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"COMBF" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"; "LSAGG-"; "STAGG-"}*/
+/*"COMBF" -> {"ELAGG-"; "URAGG-"; "CACHSET"; "RADCAT"; "INS"; "OINTDOM"}*/
+/*"COMBF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"COMBF" -> {"CFCAT"; "REAL"; "STEP"; "INS-"; "ELEMFUN"}*/
+
+"COMPFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMPFACT"]
+/*"COMPFACT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"COMPFACT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"COMPFACT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"COMPFACT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"COMPFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"COMPFACT" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"COMPFACT" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"COMPFACT" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"COMPFACT" -> {"FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"COMPFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"COMPFACT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+"COMPFACT" -> "COMPCAT"
+/*"COMPFACT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
+/*"COMPFACT" -> {"FPC"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"COMPFACT" -> {"ELEMFUN"; "RADCAT"; "INT"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"COMPFACT" -> {"GCDDOM-"; "SINT"; "NNI"; "OM"; "LIST"}*/
+
+"COMPLEX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMPLEX"]
+"COMPLEX" -> "COMPCAT"
+/*"COMPLEX" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "RING"; "RNG"}*/
+/*"COMPLEX" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"COMPLEX" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"COMPLEX" -> {"MODULE"; "BMODULE"; "RMODULE"; "CHARZ"; "CHARNZ"}*/
+/*"COMPLEX" -> {"COMRING"; "KONVERT"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
+/*"COMPLEX" -> {"LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"COMPLEX" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"}*/
+/*"COMPLEX" -> {"DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"}*/
+/*"COMPLEX" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"}*/
+/*"COMPLEX" -> {"PATAB"; "ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"COMPLEX" -> {"AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"; "OM"; "BOOLEAN"}*/
+/*"COMPLEX" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "INS"; "OINTDOM"}*/
+/*"COMPLEX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"COMPLEX" -> {"CFCAT"; "REAL"; "RNS"; "FPS"; "OAMONS"}*/
+
+"COMPLPAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMPLPAT"]
+/*"COMPLPAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "COMRING"}*/
+/*"COMPLPAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"COMPLPAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"COMPLPAT" -> "COMPCAT"
+/*"COMPLPAT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"}*/
+/*"COMPLPAT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
+/*"COMPLPAT" -> {"LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"COMPLPAT" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"}*/
+/*"COMPLPAT" -> {"PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
+/*"COMPLPAT" -> {"EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"; "PATAB"}*/
+/*"COMPLPAT" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"COMPLPAT" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "SYMBOL"; "INT"; "REF"}*/
+/*"COMPLPAT" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"COMPLPAT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"COMPLPAT" -> {"LNAGG-"; "BOOLEAN"}*/
+
+"CMPLXRT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CMPLXRT"]
+/*"CMPLXRT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"CMPLXRT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"CMPLXRT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
+/*"CMPLXRT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"CMPLXRT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"CMPLXRT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"CMPLXRT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
+/*"CMPLXRT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
+/*"CMPLXRT" -> {"FIELD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"CMPLXRT" -> {"OAMON"; "OASGP"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
+/*"CMPLXRT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"CMPLXRT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"CMPLXRT" -> {"INS"; "OINTDOM"; "CFCAT"; "REAL"; "ILIST"}*/
+"CMPLXRT" -> "COMPCAT"
+/*"CMPLXRT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
+/*"CMPLXRT" -> {"FPC"; "FEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"}*/
+/*"CMPLXRT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
+/*"CMPLXRT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+
+"CPMATCH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CPMATCH"]
+/*"CPMATCH" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PATMAB"; "COMRING"; "RING"}*/
+/*"CPMATCH" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"CPMATCH" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"CPMATCH" -> "COMPCAT"
+/*"CPMATCH" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"}*/
+/*"CPMATCH" -> {"CHARZ"; "CHARNZ"; "KONVERT"; "FRETRCT"; "RETRACT"}*/
+/*"CPMATCH" -> {"FLINEXP"; "LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"CPMATCH" -> {"GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"}*/
+/*"CPMATCH" -> {"DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"}*/
+/*"CPMATCH" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"}*/
+/*"CPMATCH" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"CPMATCH" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "SYMBOL"; "INT"; "REF"}*/
+/*"CPMATCH" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"CPMATCH" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"CPMATCH" -> {"LNAGG-"; "NNI"; "POLYCAT"; "FAMR"; "AMR"}*/
+
+"CRFP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CRFP"]
+/*"CRFP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"CRFP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"CRFP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"CRFP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"CRFP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"CRFP" -> {"ORDSET"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"CRFP" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"CRFP" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
+/*"CRFP" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
+"CRFP" -> "COMPCAT"
+/*"CRFP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"CRFP" -> {"FEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
+/*"CRFP" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "INT"; "NNI"}*/
+/*"CRFP" -> {"QFCAT"; "OINTDOM"; "REAL"; "PI"; "OM"; "BOOLEAN"; "LSAGG"}*/
+/*"CRFP" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"CRFP" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"CRFP" -> {"SINT"; "INS"; "CFCAT"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"CRFP" -> {"LNAGG-"; "MONOID-"; "ABELMON-"; "RNS"}*/
+
+"CTRIGMNP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CTRIGMNP"]
+/*"CTRIGMNP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"CTRIGMNP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"CTRIGMNP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"CTRIGMNP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
+"CTRIGMNP" -> "ACF"
+/*"CTRIGMNP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"CTRIGMNP" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"CTRIGMNP" -> {"AHYP"; "ELEMFUN"}*/
+"CTRIGMNP" -> "FS"
+/*"CTRIGMNP" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"CTRIGMNP" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"CTRIGMNP" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"CTRIGMNP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"CTRIGMNP" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"CTRIGMNP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"CTRIGMNP" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+"CTRIGMNP" -> "COMPCAT"
+/*"CTRIGMNP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"}*/
+/*"CTRIGMNP" -> {"DIFRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "PFECAT"}*/
+/*"CTRIGMNP" -> {"CACHSET"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"CTRIGMNP" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"CTRIGMNP" -> "SRAGG-"*/
+
+"D01WGTS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D01WGTS"]
+/*"D01WGTS" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"D01WGTS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"D01WGTS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"D01WGTS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"D01WGTS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"D01WGTS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"D01WGTS" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
+/*"D01WGTS" -> "CHARZ"*/
+"D01WGTS" -> "FS"
+/*"D01WGTS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"D01WGTS" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"}*/
+/*"D01WGTS" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"D01WGTS" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"D01WGTS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"D01WGTS" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"D01WGTS" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "NNI"}*/
+/*"D01WGTS" -> {"LSAGG-"; "STAGG-"; "BOOLEAN"; "DIFRING"; "TRANFUN"}*/
+/*"D01WGTS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
+/*"D01WGTS" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "INS"}*/
+/*"D01WGTS" -> {"OINTDOM"; "CFCAT"; "STEP"; "DFLOAT"; "FPS-"; "RNS-"}*/
+
+"D02AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D02AGNT"]
+/*"D02AGNT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"D02AGNT" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
+/*"D02AGNT" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"D02AGNT" -> {"KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"}*/
+/*"D02AGNT" -> {"LIST"; "ILIST"; "DFLOAT"; "NNI"; "PI"; "FPS"; "RNS"}*/
+/*"D02AGNT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"D02AGNT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"D02AGNT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"D02AGNT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"D02AGNT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
+/*"D02AGNT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "VECTCAT"; "A1AGG"; "VECTOR"}*/
+/*"D02AGNT" -> {"IVECTOR"; "IARRAY1"; "DIFRING"; "TRANFUN"; "TRIGCAT"}*/
+/*"D02AGNT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "VECTCAT-"}*/
+/*"D02AGNT" -> {"A1AGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "BOOLEAN"}*/
+"D02AGNT" -> "FS"
+/*"D02AGNT" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"D02AGNT" -> {"FLINEXP"; "LINEXP"; "CHARNZ"; "MATCAT"; "ARR2CAT"}*/
+/*"D02AGNT" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"}*/
+/*"D02AGNT" -> {"DIFEXT"; "PFECAT"; "LNAGG-"; "IXAGG-"; "SINT"; "SYMBOL"}*/
+/*"D02AGNT" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
+/*"D02AGNT" -> {"PRIMARR"; "ISTRING"; "SRAGG-"}*/
+
+"D03EEFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D03EEFA"]
+/*"D03EEFA" -> {"PDECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"}*/
+/*"D03EEFA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"D03EEFA" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"D03EEFA" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
+/*"D03EEFA" -> {"OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"}*/
+/*"D03EEFA" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "PI"; "MONOID-"; "ABELMON-"}*/
+/*"D03EEFA" -> {"DFLOAT"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"D03EEFA" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"D03EEFA" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"D03EEFA" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"D03EEFA" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"D03EEFA" -> {"OAMON"; "OASGP"; "REAL"; "RETRACT"; "RADCAT"}*/
+/*"D03EEFA" -> {"PATMAB"; "CHARZ"; "VECTOR"}*/
+"D03EEFA" -> "FS"
+/*"D03EEFA" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"D03EEFA" -> {"FLINEXP"; "LINEXP"; "CHARNZ"}*/
+
+"DBLRESP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DBLRESP"]
+/*"DBLRESP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"DBLRESP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"DBLRESP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"DBLRESP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"DBLRESP" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
+/*"DBLRESP" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"DBLRESP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"DBLRESP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
+/*"DBLRESP" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
+"DBLRESP" -> "FFCAT"
+/*"DBLRESP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
+/*"DBLRESP" -> {"FPC"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"DBLRESP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"DBLRESP" -> {"OASGP"; "REAL"; "NNI"; "INT"; "PI"}*/
+
+"D01AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D01AGNT"]
+/*"D01AGNT" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"D01AGNT" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"D01AGNT" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"D01AGNT" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
+/*"D01AGNT" -> {"NNI"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"D01AGNT" -> {"A1AGG-"; "ISTRING"; "LSAGG-"; "STAGG-"; "FPS"; "RNS"}*/
+/*"D01AGNT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"D01AGNT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"D01AGNT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"D01AGNT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"D01AGNT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"D01AGNT" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"; "DIFRING"}*/
+/*"D01AGNT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"D01AGNT" -> {"ELEMFUN"; "SPFCAT"; "ELAGG-"; "FLAGG-"}*/
+"D01AGNT" -> "FS"
+/*"D01AGNT" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"D01AGNT" -> {"FLINEXP"; "LINEXP"; "CHARNZ"; "INS"; "OINTDOM"; "CFCAT"}*/
+/*"D01AGNT" -> {"STEP"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"; "BOOLEAN"}*/
+
+"DERHAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DERHAM"]
+/*"DERHAM" -> {"LALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"DERHAM" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"DERHAM" -> {"MONOID"; "LMODULE"; "RETRACT"}*/
+"DERHAM" -> "FS"
+/*"DERHAM" -> {"ES"; "ORDSET"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"DERHAM" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"DERHAM" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"}*/
+/*"DERHAM" -> {"BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"DERHAM" -> {"INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "LSAGG"}*/
+/*"DERHAM" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"DERHAM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
+/*"DERHAM" -> {"LIST"; "ILIST"; "SINT"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"DERHAM" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"DERHAM" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"DERHAM" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
+/*"DERHAM" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+
+"DFSFUN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DFSFUN"]
+/*"DFSFUN" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"DFSFUN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DFSFUN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DFSFUN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DFSFUN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"DFSFUN" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"DFSFUN" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"}*/
+/*"DFSFUN" -> {"NNI"; "INT"; "PI"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"}*/
+/*"DFSFUN" -> {"UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"DFSFUN" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"DFSFUN" -> {"ABELMON-"; "MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
+/*"DFSFUN" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+/*"DFSFUN" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"DFSFUN" -> {"ELEMFUN"; "SPFCAT"}*/
+"DFSFUN" -> "COMPCAT"
+/*"DFSFUN" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"DFSFUN" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"}*/
+/*"DFSFUN" -> {"FPC"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"}*/
+/*"DFSFUN" -> {"TYPE"; "PATAB"; "PFECAT"; "FRAC"}*/
+
+"DRAWCURV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWCURV"]
+/*"DRAWCURV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DRAWCURV" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"DRAWCURV" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"DRAWCURV" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
+"DRAWCURV" -> "FS"
+/*"DRAWCURV" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"DRAWCURV" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"DRAWCURV" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"DRAWCURV" -> {"GCDDOM"; "UFD"; "DIVRING"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"DRAWCURV" -> {"PFECAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"DRAWCURV" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"}*/
+/*"DRAWCURV" -> {"STEP"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"DRAWCURV" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"DRAWCURV" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"DRAWCURV" -> {"ELAGG-"; "URAGG-"; "OM"; "FPS"; "RNS"; "RADCAT"}*/
+
+"DTP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DTP"]
+"DTP" -> ""INFCLCT"
+/*"DTP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "DIVCAT"; "DSTRCAT"}*/
+/*"DTP" -> {"BLMETCT"; "PFORP"; "AFFPL"; "PARAMP"; "PLPKCRV"; "BLUPPACK"}*/
+/*"DTP" -> {"LPARSPT"; "DIV"; "PRJALGPK"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"DTP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"DTP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"DTP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"DTP" -> {"ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"DTP" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"DTP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"DTP" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "ELTAB"}*/
+/*"DTP" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DTP" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "UPSCAT"; "PSCAT"}*/
+/*"DTP" -> {"FAMONC"; "RCAGG"; "INT"; "PI"; "NNI"; "SINT"; "BOOLEAN"; "LIST"}*/
+/*"DTP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "VECTOR"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"DTP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SYMBOL"; "REF"}*/
+/*"DTP" -> {"ALIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"DTP" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"D01TRNS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01TRNS"]
+/*"D01TRNS" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "STRING"; "CHAR"}*/
+/*"D01TRNS" -> {"SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
+/*"D01TRNS" -> {"ISTRING"; "SRAGG-"; "SYMBOL"; "REF"; "ALIST"; "FLAGG-"}*/
+/*"D01TRNS" -> {"LNAGG-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"D01TRNS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"D01TRNS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"D01TRNS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"D01TRNS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"D01TRNS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
+/*"D01TRNS" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"}*/
+/*"D01TRNS" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"D01TRNS" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
+/*"D01TRNS" -> {"FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"; "OM"; "FPS"}*/
+/*"D01TRNS" -> {"RNS"; "RADCAT"}*/
+"D01TRNS" -> "FS" 
+/*"D01TRNS" -> {"ES"; "FRETRCT"; "GROUP"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"D01TRNS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "DFLOAT"; "PI"}*/
+/*"D01TRNS" -> {"NNI"; "BOOLEAN"; "ILIST"}*/
+
+"E04NAFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04NAFA"]
+/*"E04NAFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
+/*"E04NAFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"E04NAFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"E04NAFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"E04NAFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"E04NAFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"E04NAFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "STRING"}*/
+/*"E04NAFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"E04NAFA" -> {"A1AGG-"; "ISTRING"; "STRICAT"; "SRAGG"; "A1AGG"}*/
+/*"E04NAFA" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"E04NAFA" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "OM"}*/
+/*"E04NAFA" -> {"NNI"; "DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"E04NAFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"E04NAFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "ELAGG-"}*/
+/*"E04NAFA" -> {"FLAGG-"; "DFLOAT"; "PI"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"E04NAFA" -> {"AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"; "LINEXP"; "PFECAT"}*/
+/*"E04NAFA" -> "VECTCAT"*/
+"E04NAFA" -> "FS"
+/*"E04NAFA" -> {"ES"; "PATAB"; "FPATMAB"; "GROUP"; "INS-"; "INS"}*/
+/*"E04NAFA" -> {"OINTDOM"; "CFCAT"; "STEP"; "MONOID-"; "ABELMON-"; "BOOLEAN"}*/
+
+"EF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EF"]
+/*"EF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
+/*"EF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"EF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"EF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"}*/
+"EF" -> "FS"
+/*"EF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"EF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"EF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"EF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"; "SYMBOL"; "INT"}*/
+/*"EF" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"EF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"EF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"EF" -> {"ILIST"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"EF" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "OM"}*/
+/*"EF" -> {"INS-"; "LSAGG-"; "STAGG-"; "PI"; "NNI"; "BOOLEAN"; "CACHSET"}*/
+
+"EFSTRUC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EFSTRUC"]
+/*"EFSTRUC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"EFSTRUC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"EFSTRUC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"EFSTRUC" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"}*/
+"EFSTRUC" -> "ACF"
+/*"EFSTRUC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"EFSTRUC" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"EFSTRUC" -> {"AHYP"; "ELEMFUN"}*/
+"EFSTRUC" -> "FS"
+/*"EFSTRUC" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"EFSTRUC" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"EFSTRUC" -> {"CHARZ"; "CHARNZ"; "COMBOPC"; "CFCAT"; "CACHSET"; "BOOLEAN"}*/
+/*"EFSTRUC" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
+/*"EFSTRUC" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"EFSTRUC" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "INS"}*/
+/*"EFSTRUC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"EFSTRUC" -> {"DIFRING"; "REAL"; "STEP"; "PI"; "NNI"; "SINT"; "SYMBOL"}*/
+/*"EFSTRUC" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
+/*"EFSTRUC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "URAGG-"}*/
+/*"EFSTRUC" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"EFSTRUC" -> {"VECTCAT"; "A1AGG"; "VECTCAT-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"EFSTRUC" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+
+"ELFUTS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ELFUTS"]
+/*"ELFUTS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ELFUTS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ELFUTS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ELFUTS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ELFUTS" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
+"ELFUTS" -> "UTSCAT"
+/*"ELFUTS" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
+/*"ELFUTS" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"ELFUTS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "LIST"}*/
+/*"ELFUTS" -> {"ILIST"; "LSAGG-"; "STAGG-"}*/
+
+"ESTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESTOOLS"]
+/*"ESTOOLS" -> {"INT"; "LIST"; "ILIST"; "NNI"; "FPS"; "RNS"; "FIELD"}*/
+/*"ESTOOLS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"ESTOOLS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"ESTOOLS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ESTOOLS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ESTOOLS" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ESTOOLS" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
+/*"ESTOOLS" -> {"RADCAT"; "PATMAB"; "CHARZ"; "SINT"; "LSAGG-"; "DFLOAT"}*/
+/*"ESTOOLS" -> {"FPS-"; "RNS-"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
+/*"ESTOOLS" -> {"CFCAT"; "STEP"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"ESTOOLS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "QFCAT"; "FEVALAB"}*/
+/*"ESTOOLS" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"}*/
+/*"ESTOOLS" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"}*/
+/*"ESTOOLS" -> {"LZSTAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"ESTOOLS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "VECTOR"; "VECTCAT"}*/
+/*"ESTOOLS" -> {"A1AGG"; "FLAGG"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"ESTOOLS" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"ESTOOLS" -> {"HOAGG-"; "BOOLEAN"; "LSAGG"; "ELAGG"; "STAGG-"}*/
+"ESTOOLS" -> "FS"
+/*"ESTOOLS" -> {"ES"; "FRETRCT"; "GROUP"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
+/*"ESTOOLS" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"ESTOOLS" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"ESTOOLS" -> {"ABELMON-"; "PI"; "TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"}*/
+/*"ESTOOLS" -> {"BGAGG"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"}*/
+
+"EXPEXPAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXPEXPAN"]
+"EXPEXPAN" -> "ACF"
+/*"EXPEXPAN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"EXPEXPAN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"EXPEXPAN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"EXPEXPAN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"EXPEXPAN" -> {"ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
+/*"EXPEXPAN" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"EXPEXPAN" -> "FS"
+/*"EXPEXPAN" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
+/*"EXPEXPAN" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
+/*"EXPEXPAN" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
+/*"EXPEXPAN" -> {"QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "STEP"}*/
+/*"EXPEXPAN" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"EXPEXPAN" -> {"OASGP"; "REAL"; "PFECAT"; "FAMR"; "AMR"; "PI"; "NNI"}*/
+/*"EXPEXPAN" -> {"INT"; "INS"; "CFCAT"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"EXPEXPAN" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"EXPEXPAN" -> {"CLAGG"; "FLAGG"; "ELAGG"; "LIST"; "ILIST"; "STRING"}*/
+/*"EXPEXPAN" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"EXPEXPAN" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "FPS"}*/
+/*"EXPEXPAN" -> {"RNS"; "UPOLYC"; "POLYCAT"}*/
+
+"EXPRODE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPRODE"]
+/*"EXPRODE" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"EXPRODE" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"EXPRODE" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"EXPRODE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "KONVERT"}*/
+"EXPRODE" -> "FS"
+/*"EXPRODE" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"}*/
+/*"EXPRODE" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"EXPRODE" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"EXPRODE" -> {"GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
+/*"EXPRODE" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"EXPRODE" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
+/*"EXPRODE" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"EXPRODE" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "CACHSET"; "UPOLYC"}*/
+/*"EXPRODE" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFEXT"}*/
+/*"EXPRODE" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"EXPRODE" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"EXPRODE" -> {"OM"; "ILIST"}*/
+
+"EXPRTUBE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPRTUBE"]
+/*"EXPRTUBE" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"EXPRTUBE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"EXPRTUBE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"EXPRTUBE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"EXPRTUBE" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"EXPRTUBE" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"EXPRTUBE" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"EXPRTUBE" -> {"CHARZ"; "STEP"; "OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"EXPRTUBE" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"EXPRTUBE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"EXPRTUBE" -> {"INT"; "LIST"; "ILIST"; "NNI"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"EXPRTUBE" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"EXPRTUBE" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
+"EXPRTUBE" -> "FS"
+/*"EXPRTUBE" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"EXPRTUBE" -> {"FLINEXP"; "CHARNZ"; "FIELD"; "DIVRING"; "FPS"; "RNS"}*/
+/*"EXPRTUBE" -> "RADCAT"*/
+
+"EXPR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPR2"]
+/*"EXPR2" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
+/*"EXPR2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"EXPR2" -> {"MONOID"; "LMODULE"}*/
+"EXPR2" -> "FS"
+/*"EXPR2" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"EXPR2" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"EXPR2" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"}*/
+/*"EXPR2" -> {"BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"EXPR2" -> {"INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"FC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FC"]
+/*"FC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SINT"; "INS"; "UFD"; "GCDDOM"}*/
+/*"FC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FC" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"FC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"FC" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"FC" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"; "LIST"; "ILIST"}*/
+/*"FC" -> {"LSAGG-"; "STAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"FC" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"FC" -> {"FLAGG-"; "LNAGG-"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"FC" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"; "STRICAT"}*/
+/*"FC" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"FC" -> {"TYPE"; "ELTAGG"; "ELTAB"; "CLAGG"; "OM"; "NNI"; "DFLOAT"}*/
+/*"FC" -> {"BOOLEAN"; "FMTC"; "FPS"; "RNS"; "FIELD"; "DIVRING"; "RADCAT"}*/
+"FC" -> "COMPCAT"
+/*"FC" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"; "FFIELDC"}*/
+/*"FC" -> {"FPC"; "FEVALAB"; "FPATMAB"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
+/*"FC" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "VECTOR"; "IVECTOR"}*/
+/*"FC" -> {"IARRAY1"; "VECTCAT-"}*/
+"FC" -> "FS"
+/*"FC" -> {"ES"; "GROUP"}*/
+
+"FDIVCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FDIVCAT"]
+/*"FDIVCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FDIVCAT" -> {"BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FDIVCAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"FDIVCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FDIVCAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"FDIVCAT" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"FDIVCAT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"FDIVCAT" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"FDIVCAT" -> {"DIFEXT"; "STEP"}*/
+"FDIVCAT" -> "FFCAT"
+/*"FDIVCAT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+
+"FDIVCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FDIVCAT"]
+/*"FDIVCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
+/*"FDIVCAT-" -> {"BASTYPE";  "KOERCE";  "FIELD";  "EUCDOM";  "PID"}*/
+/*"FDIVCAT-" -> {"GCDDOM";  "INTDOM";  "COMRING";  "RING";  "RNG";  "SGROUP"}*/
+/*"FDIVCAT-" -> {"MONOID";  "LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA"}*/
+/*"FDIVCAT-" -> {"MODULE";  "ENTIRER";  "UFD";  "DIVRING";  "UPOLYC"}*/
+/*"FDIVCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ"}*/
+/*"FDIVCAT-" -> {"FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP"}*/
+/*"FDIVCAT-" -> {"LINEXP";  "ORDSET";  "KONVERT";  "PATMAB";  "PFECAT"}*/
+/*"FDIVCAT-" -> {"ELTAB";  "DIFRING";  "DIFEXT";  "STEP"}*/
+"FDIVCAT-" -> "FFCAT"
+/*"FDIVCAT-" -> {"MONOGEN";  "FRAMALG";  "FINRALG";  "FINITE";  "FFIELDC"}*/
+/*"FDIVCAT-" -> "FPC"*/
+
+"FDIV2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FDIV2"]
+/*"FDIV2" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FDIV2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FDIV2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FDIV2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"FDIV2" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"FDIV2" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"FDIV2" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"FDIV2" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+"FDIV2" -> "FFCAT"
+/*"FDIV2" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+
+"FFCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFCAT2"]
+/*"FFCAT2" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FFCAT2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FFCAT2" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FFCAT2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FFCAT2" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"FFCAT2" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"FFCAT2" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"FFCAT2" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"FFCAT2" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+"FFCAT2" -> "FFCAT"
+/*"FFCAT2" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+
+"FLOATCP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLOATCP"]
+/*"FLOATCP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"FLOATCP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FLOATCP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FLOATCP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FLOATCP" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FLOATCP" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"FLOATCP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"FLOATCP" -> {"REAL"; "CHARZ"; "STEP"}*/
+"FLOATCP" -> "COMPCAT"
+/*"FLOATCP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"FLOATCP" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"}*/
+/*"FLOATCP" -> {"FPC"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"}*/
+/*"FLOATCP" -> {"TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"FLOATCP" -> {"AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"; "POLYCAT"; "FAMR"}*/
+/*"FLOATCP" -> {"AMR"; "BOOLEAN"; "OM"; "INT"; "LIST"; "ILIST"; "QFCAT"}*/
+
+"FORDER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FORDER"]
+/*"FORDER" -> {"FINITE"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"}*/
+/*"FORDER" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FORDER" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"FORDER" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FORDER" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
+/*"FORDER" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"FORDER" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"FORDER" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
+/*"FORDER" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
+"FORDER" -> "FFCAT"
+/*"FORDER" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FFIELDC"}*/
+/*"FORDER" -> {"FPC"; "SINT"; "NNI"; "INT"}*/
+
+"FORTRAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FORTRAN"]
+/*"FORTRAN" -> {"FORTCAT"; "TYPE"; "KOERCE"; "SINT"; "SYMBOL"; "INT"}*/
+/*"FORTRAN" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "OUTFORM"}*/
+/*"FORTRAN" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"FORTRAN" -> {"LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"FORTRAN" -> {"RCAGG-"; "IXAGG-"; "ORDSET"; "SETCAT"; "BASTYPE"; "KONVERT"}*/
+/*"FORTRAN" -> {"OM"; "PATMAB"; "FMTC"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"FORTRAN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"FORTRAN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FORTRAN" -> {"MODULE"; "ENTIRER"; "RETRACT"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"FORTRAN" -> {"RCAGG"; "HOAGG"; "AGG"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"FORTRAN" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"FORTRAN" -> {"NNI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FORTRAN" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FORTRAN" -> {"OASGP"; "REAL"; "RADCAT"; "CHARZ"; "INS"; "OINTDOM"}*/
+/*"FORTRAN" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+"FORTRAN" -> "COMPCAT"
+/*"FORTRAN" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"FORTRAN" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"; "FPC"}*/
+/*"FORTRAN" -> {"FEVALAB"; "FPATMAB"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
+/*"FORTRAN" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PFECAT"}*/
+
+"FRNAAF2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRNAAF2"]
+"FRNAAF2" -> "FRNAALG"
+/*"FRNAAF2" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
+/*"FRNAAF2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FRNAAF2" -> {"MONAD"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"}*/
+/*"FRNAAF2" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "PI"}*/
+/*"FRNAAF2" -> {"NNI"; "INT"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+
+"FSPRMELT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSPRMELT"]
+/*"FSPRMELT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FSPRMELT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FSPRMELT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FSPRMELT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"FSPRMELT" -> "CHARZ"*/
+"FSPRMELT" -> "FS"
+/*"FSPRMELT" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"FSPRMELT" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"FSPRMELT" -> {"FLINEXP"; "LINEXP"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"FSPRMELT" -> {"GCDDOM"; "UFD"; "DIVRING"; "CACHSET"; "POLYCAT"; "FAMR"}*/
+/*"FSPRMELT" -> {"AMR"; "PFECAT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"FSPRMELT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"FSPRMELT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
+/*"FSPRMELT" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"FSPRMELT" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"FSPRMELT" -> {"FLAGG-"; "LNAGG-"; "NNI"; "ACF"; "RADCAT"; "BOOLEAN"}*/
+/*"FSPRMELT" -> {"UPOLYC"; "DIFRING"; "DIFEXT"; "STEP"; "PI"}*/
+
+"FSRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSRED"]
+/*"FSRED" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"FSRED" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FSRED" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FSRED" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
+"FSRED" -> "FS"
+/*"FSRED" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"FSRED" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"FSRED" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"FSRED" -> {"GCDDOM"; "UFD"; "DIVRING"; "CACHSET"; "INS"; "OINTDOM"}*/
+/*"FSRED" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"FSRED" -> {"CFCAT"; "REAL"; "STEP"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"FSRED" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "QFCAT"; "FEVALAB"; "OM"; "INT"}*/
+
+"FSUPFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSUPFACT"]
+/*"FSUPFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FSUPFACT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"FSUPFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"FSUPFACT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
+"FSUPFACT" -> "FS"
+/*"FSUPFACT" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"FSUPFACT" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"FSUPFACT" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"FSUPFACT" -> {"GCDDOM"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"FSUPFACT" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"FSUPFACT" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"FSUPFACT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"FSUPFACT" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+"FSUPFACT" -> "ACF"
+/*"FSUPFACT" -> {"RADCAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"FSUPFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "QFCAT"}*/
+/*"FSUPFACT" -> {"FEVALAB"; "BOOLEAN"; "CACHSET"}*/
+
+"FSPECF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSPECF"]
+/*"FSPECF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"FSPECF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FSPECF" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FSPECF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+"FSPECF" -> "FS"
+/*"FSPECF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"FSPECF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"FSPECF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"FSPECF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
+/*"FSPECF" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"FSPECF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"FSPECF" -> {"LNAGG-"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "SPFCAT"}*/
+/*"FSPECF" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "INS-"}*/
+/*"FSPECF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
+/*"FSPECF" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"FSPECF" -> {"OM"; "ELEMFUN"}*/
+
+"FS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FS2"]
+/*"FS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"FS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FS2" -> "ORDSET"*/
+"FS2" -> "FS"
+/*"FS2" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"FS2" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"FS2" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"}*/
+/*"FS2" -> {"BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FS2" -> {"INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "CACHSET"}*/
+
+"FS2UPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FS2UPS"]
+/*"FS2UPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"FS2UPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"FS2UPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"FS2UPS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"FS2UPS" -> {"RETRACT"; "LINEXP"}*/
+"FS2UPS" -> "ACF"
+/*"FS2UPS" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+/*"FS2UPS" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"FS2UPS" -> "FS"
+/*"FS2UPS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"FS2UPS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"FS2UPS" -> {"CHARZ"; "CHARNZ"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FS2UPS" -> {"OASGP"; "UPSCAT"; "PSCAT"; "AMR"; "ELTAB"; "DIFRING"}*/
+/*"FS2UPS" -> {"PTRANFN"; "NNI"; "INT"; "INS-"; "POLYCAT"; "FAMR"; "PFECAT"}*/
+/*"FS2UPS" -> {"BOOLEAN"; "LIST"; "ILIST"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"FS2UPS" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"FS2UPS" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"}*/
+/*"FS2UPS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"FS2UPS" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"FS2UPS" -> {"URAGG-"; "INS"; "OINTDOM"; "CFCAT"; "REAL"; "STEP"; "PI"}*/
+/*"FS2UPS" -> {"CACHSET"; "STRICAT"; "SRAGG"; "A1AGG"}*/
+
+"GAUSSFAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GAUSSFAC"]
+/*"GAUSSFAC" -> {"INT"; "INS-"; "EUCDOM-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
+/*"GAUSSFAC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"GAUSSFAC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"GAUSSFAC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"GAUSSFAC" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"GAUSSFAC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
+/*"GAUSSFAC" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"GAUSSFAC" -> {"CHARZ"; "STEP"; "BOOLEAN"; "PI"; "NNI"; "UFD-"; "GCDDOM-"}*/
+/*"GAUSSFAC" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
+/*"GAUSSFAC" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"; "ORDSET-"}*/
+/*"GAUSSFAC" -> {"ABELSG-"; "SGROUP-"; "LIST"; "ILIST"; "OM"; "LSAGG-"}*/
+/*"GAUSSFAC" -> "STAGG-"*/
+"GAUSSFAC" -> "COMPCAT"
+/*"GAUSSFAC" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"GAUSSFAC" -> {"FLINEXP"; "FINITE"; "FIELD"; "DIVRING"; "DIFEXT"}*/
+/*"GAUSSFAC" -> {"PDRING"; "FFIELDC"; "FPC"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"GAUSSFAC" -> {"IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
+/*"GAUSSFAC" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"}*/
+
+"GCNAALG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GCNAALG"]
+"GCNAALG" -> "FRNAALG"
+/*"GCNAALG" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
+/*"GCNAALG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GCNAALG" -> {"MONAD"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"}*/
+/*"GCNAALG" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "POLYCAT"}*/
+/*"GCNAALG" -> {"PDRING"; "FAMR"; "AMR"; "ALGEBRA"; "CHARZ"; "CHARNZ"}*/
+/*"GCNAALG" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"GCNAALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"GCNAALG" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "QFCAT"; "FIELD"}*/
+/*"GCNAALG" -> {"EUCDOM"; "PID"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
+/*"GCNAALG" -> {"DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"; "OINTDOM"}*/
+/*"GCNAALG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"GCNAALG" -> {"SMATCAT"; "RMATCAT"; "HOAGG"; "AGG"; "SINT"; "PI"; "NNI"}*/
+/*"GCNAALG" -> {"INT"; "STRING"; "CHAR"; "OUTFORM"; "LIST"; "PRIMARR"}*/
+/*"GCNAALG" -> {"A1AGG-"; "ISTRING"; "SYMBOL"; "REF"; "ALIST"; "SRAGG-"}*/
+/*"GCNAALG" -> {"FLAGG-"; "LNAGG-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"GCNAALG" -> {"VECTCAT-"; "IXAGG-"; "INS"; "CFCAT"; "OM"; "ILIST"}*/
+/*"GCNAALG" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"GCNAALG" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"GCNAALG" -> "BOOLEAN"*/
+
+"GDRAW" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GDRAW"]
+"GDRAW" -> "FS"
+/*"GDRAW" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"GDRAW" -> {"A1AGG-"; "ISTRING"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"GDRAW" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"GDRAW" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GDRAW" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"GDRAW" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"GDRAW" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"GDRAW" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "ES"}*/
+/*"GDRAW" -> {"IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "FRETRCT"}*/
+/*"GDRAW" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "PI"; "NNI"}*/
+/*"GDRAW" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"GDRAW" -> {"AHYP"; "ELEMFUN"; "DFLOAT"}*/
+
+"GENUFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENUFACT"]
+/*"GENUFACT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"GENUFACT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"GENUFACT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"GENUFACT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"GENUFACT" -> {"INS"; "UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"GENUFACT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"GENUFACT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"GENUFACT" -> {"STEP"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"GENUFACT" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"GENUFACT" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"}*/
+/*"GENUFACT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"GENUFACT" -> {"FFIELDC"; "FPC"; "FINITE"}*/
+"GENUFACT" -> "COMPCAT"
+/*"GENUFACT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "TRANFUN"; "TRIGCAT"}*/
+/*"GENUFACT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "ES"}*/
+"GENUFACT" -> "ACF"
+/*"GENUFACT" -> "OM"*/
+
+"GENUPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENUPS"]
+/*"GENUPS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"GENUPS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GENUPS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"GENUPS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"}*/
+"GENUPS" -> "ACF"
+/*"GENUPS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"GENUPS" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"GENUPS" -> {"AHYP"; "ELEMFUN"}*/
+"GENUPS" -> "FS"
+/*"GENUPS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"GENUPS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"GENUPS" -> {"CHARZ"; "CHARNZ"; "INT"; "NNI"; "INS"; "OINTDOM"}*/
+/*"GENUPS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"GENUPS" -> {"CFCAT"; "REAL"; "STEP"; "OM"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"GENUPS" -> "GCDDOM-"*/
+
+"GTSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GTSET"]
+/*"GTSET" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"GTSET" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"GTSET" -> {"KONVERT"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"GTSET" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"GTSET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
+/*"GTSET" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+"GTSET" -> "RPOLCAT"
+/*"GTSET" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"GTSET" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+/*"GTSET" -> {"GCDDOM"; "PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"GTSET" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"GTSET" -> {"IXAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"GTSET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"GTSET" -> {"BOOLEAN"; "FINITE"}*/
+
+"GPOLSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GPOLSET"]
+/*"GPOLSET" -> {"PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"}*/
+/*"GPOLSET" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "KONVERT"}*/
+/*"GPOLSET" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"GPOLSET" -> {"SGROUP"; "MONOID"; "LMODULE"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"GPOLSET" -> {"OASGP"; "ORDSET"}*/
+"GPOLSET" -> "RPOLCAT"
+/*"GPOLSET" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"GPOLSET" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"GPOLSET" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"GPOLSET" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "LSAGG"; "STAGG"}*/
+/*"GPOLSET" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"GPOLSET" -> {"FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"GPOLSET" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"GPOLSET" -> "IXAGG-"*/
+
+"IAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IAN"]
+/*"IAN" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"IAN" -> {"IEVALAB"; "EVALAB"}*/
+"IAN" -> "ACF"
+/*"IAN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"IAN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"IAN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"IAN" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "LINEXP"}*/
+/*"IAN" -> {"REAL"; "KONVERT"; "CHARZ"; "DIFRING"; "INS"; "OINTDOM"}*/
+/*"IAN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "PATMAB"}*/
+/*"IAN" -> {"CFCAT"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
+/*"IAN" -> {"PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
+/*"IAN" -> {"PFECAT"; "FPS"; "RNS"}*/
+"IAN" -> "FS"
+/*"IAN" -> {"FRETRCT"; "GROUP"; "OM"; "BOOLEAN"; "CACHSET"; "POLYCAT"}*/
+/*"IAN" -> {"FAMR"; "AMR"; "INT"; "LIST"; "ILIST"; "NNI"; "UPOLYC"}*/
+"IAN" -> "COMPCAT"
+/*"IAN" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"IAN" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+
+"INEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INEP"]
+/*"INEP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INEP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INEP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INEP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"INEP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"INEP" -> {"ORDSET"; "INS"; "OINTDOM"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"INEP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
+/*"INEP" -> {"FPS"; "RNS"; "RADCAT"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"INEP" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"INEP" -> {"TYPE"; "CHARNZ"; "PFECAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"INEP" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"INEP" -> {"AMR"; "FRETRCT"; "NNI"; "INT"; "SINT"; "VECTOR"; "IVECTOR"}*/
+/*"INEP" -> {"IARRAY1"; "LIST"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+"INEP" -> "COMPCAT"
+/*"INEP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
+/*"INEP" -> {"FPC"; "PI"}*/
+
+"INFPROD0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFPROD0"]
+/*"INFPROD0" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"INFPROD0" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INFPROD0" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INFPROD0" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
+"INFPROD0" -> "UTSCAT"
+/*"INFPROD0" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARNZ"; "ELTAB"; "DIFRING"}*/
+/*"INFPROD0" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"INFPROD0" -> {"HYPCAT"; "AHYP"; "ELEMFUN"}*/
+
+"INFSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFSP"]
+/*"INFSP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INFSP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INFSP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"INFSP" -> {"MODULE"; "ENTIRER"; "FIELD"; "EUCDOM"; "PID"; "UFD"}*/
+/*"INFSP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"INFSP" -> {"ORDSET"; "INS"; "OINTDOM"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"INFSP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"}*/
+/*"INFSP" -> {"RNS"; "RADCAT"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"INFSP" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"INFSP" -> {"TYPE"; "CHARNZ"; "PFECAT"; "OM"; "NNI"; "INT"; "POLYCAT"}*/
+/*"INFSP" -> {"FAMR"; "AMR"; "FRETRCT"}*/
+"INFSP" -> "COMPCAT"
+/*"INFSP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"INFSP" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"INFSP" -> {"UPOLYC"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"INFSP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"INFSP" -> {"FLAGG"; "ELAGG"; "LSAGG-"; "STAGG-"; "PRIMARR"; "PI"}*/
+/*"INFSP" -> {"DIRPCAT"; "OAMONS"; "VSPACE"; "ORDFIN"; "BOOLEAN"; "ELAGG-"}*/
+/*"INFSP" -> "FLAGG-"*/
+
+"INPRODFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INPRODFF"]
+/*"INPRODFF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INPRODFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INPRODFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INPRODFF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INPRODFF" -> {"ENTIRER"; "UFD"; "DIVRING"; "FINITE"; "KONVERT"; "UPOLYC"}*/
+/*"INPRODFF" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"INPRODFF" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"INPRODFF" -> {"LINEXP"; "ORDSET"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"INPRODFF" -> {"DIFEXT"; "STEP"; "MONOGEN"; "FRAMALG"; "FINRALG"}*/
+/*"INPRODFF" -> {"FFIELDC"; "FPC"}*/
+"INPRODFF" -> "UTSCAT"
+/*"INPRODFF" -> {"UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"INPRODFF" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"INPRODFF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"INPRODFF" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "BOOLEAN"}*/
+
+"INPRODPF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INPRODPF"]
+/*"INPRODPF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INPRODPF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INPRODPF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INPRODPF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INPRODPF" -> {"ENTIRER"; "UFD"; "DIVRING"; "FINITE"; "KONVERT"}*/
+"INPRODPF" -> "UTSCAT"
+/*"INPRODPF" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
+/*"INPRODPF" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"INPRODPF" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INS"; "OINTDOM"}*/
+/*"INPRODPF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"INPRODPF" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+
+"INTAF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTAF"]
+/*"INTAF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
+/*"INTAF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INTAF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INTAF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"}*/
+"INTAF" -> "ACF"
+/*"INTAF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"}*/
+"INTAF" -> "FS"
+/*"INTAF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"INTAF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"INTAF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "CACHSET"; "UPOLYC"}*/
+/*"INTAF" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"INTAF" -> {"DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "OINTDOM"; "ORDRING"}*/
+/*"INTAF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "NNI"; "INT"}*/
+/*"INTAF" -> {"SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"INTAF" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"INTAF" -> {"FLAGG-"; "LNAGG-"}*/
+
+"INTALG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTALG"]
+/*"INTALG" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"INTALG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"INTALG" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"INTALG" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
+"INTALG" -> "ACF"
+/*"INTALG" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"INTALG" -> "RADCAT"*/
+"INTALG" -> "FS"
+/*"INTALG" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"INTALG" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"INTALG" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"INTALG" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+"INTALG" -> "FFCAT"
+/*"INTALG" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"INTALG" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"INTALG" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"INTALG" -> {"FLAGG-"; "LNAGG-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"INTALG" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "VECTOR"}*/
+/*"INTALG" -> {"IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"INTALG" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "ILIST"}*/
+/*"INTALG" -> {"QFCAT"; "FEVALAB"; "LSAGG-"; "STAGG-"; "ELAGG-"; "NNI"}*/
+/*"INTALG" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "INS-"}*/
+/*"INTALG" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "BOOLEAN"; "PI"; "CACHSET"}*/
+
+"INTEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTEF"]
+/*"INTEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INTEF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INTEF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "CHARZ"}*/
+/*"INTEF" -> {"RETRACT"; "LINEXP"}*/
+"INTEF" -> "ACF"
+/*"INTEF" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+/*"INTEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"INTEF" -> "FS"
+/*"INTEF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"INTEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"INTEF" -> {"CHARNZ"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"INTEF" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"INTEF" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "ILIST"; "UPOLYC"}*/
+/*"INTEF" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"INTEF" -> {"DIFEXT"; "STEP"; "CACHSET"; "QFCAT"; "FEVALAB"; "OINTDOM"}*/
+/*"INTEF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"INTEF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"INTEF" -> {"LFCAT"; "PRIMCAT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"INTEF" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"INTEF" -> {"FLAGG"; "ELAGG"; "OM"}*/
+
+"INTG0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTG0"]
+/*"INTG0" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTG0" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"INTG0" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"INTG0" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
+/*"INTG0" -> {"ORDSET"; "CHARZ"; "LINEXP"}*/
+"INTG0" -> "FS"
+/*"INTG0" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"INTG0" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"INTG0" -> {"CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
+"INTG0" -> "ACF"
+/*"INTG0" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"INTG0" -> {"ELEMFUN"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"INTG0" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"INTG0" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "CACHSET"; "ILIST"; "UPOLYC"}*/
+/*"INTG0" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"INTG0" -> {"DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "OINTDOM"; "ORDRING"}*/
+/*"INTG0" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "NNI"}*/
+/*"INTG0" -> {"LODOCAT"; "OREPCAT"}*/
+
+"INTHERAL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTHERAL"]
+/*"INTHERAL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"INTHERAL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"INTHERAL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"INTHERAL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INTHERAL" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"INTHERAL" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"INTHERAL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"INTHERAL" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"INTHERAL" -> {"DIFEXT"; "STEP"}*/
+"INTHERAL" -> "FFCAT"
+/*"INTHERAL" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
+/*"INTHERAL" -> {"FPC"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"INTHERAL" -> {"PI"; "NNI"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"INTHERAL" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"}*/
+/*"INTHERAL" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
+/*"INTHERAL" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "QFCAT"; "FEVALAB"}*/
+/*"INTHERAL" -> {"PATAB"; "FPATMAB"}*/
+
+"INTPAF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTPAF"]
+/*"INTPAF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTPAF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INTPAF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INTPAF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "ORDSET"}*/
+/*"INTPAF" -> {"CHARZ"; "LINEXP"}*/
+"INTPAF" -> "FS"
+/*"INTPAF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"INTPAF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"INTPAF" -> {"CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
+"INTPAF" -> "ACF"
+/*"INTPAF" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"INTPAF" -> {"ELEMFUN"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"INTPAF" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"INTPAF" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"INTPAF" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"INTPAF" -> {"QFCAT"; "FEVALAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"INTPAF" -> {"OAMON"; "OASGP"; "REAL"; "OM"; "BOOLEAN"; "NNI"; "CACHSET"}*/
+/*"INTPAF" -> {"PI"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"INTPAF" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"INTPAF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "LODOCAT"; "OREPCAT"}*/
+
+"INTPM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTPM"]
+/*"INTPM" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"INTPM" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INTPM" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INTPM" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LINEXP"}*/
+"INTPM" -> "ACF"
+/*"INTPM" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+/*"INTPM" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"INTPM" -> "FS"
+/*"INTPM" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"INTPM" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"INTPM" -> {"CHARZ"; "CHARNZ"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"}*/
+/*"INTPM" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"INTPM" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "OINTDOM"}*/
+/*"INTPM" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"INTPM" -> {"CFCAT"; "REAL"; "STEP"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"INTPM" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"INTPM" -> {"FLAGG"; "ELAGG"; "OM"; "ILIST"; "PI"; "NNI"; "LFCAT"}*/
+/*"INTPM" -> {"PRIMCAT"; "CACHSET"; "BOOLEAN"; "LSAGG-"; "POLYCAT"; "FAMR"}*/
+/*"INTPM" -> {"AMR"; "PFECAT"; "UPOLYC"; "DIFEXT"; "STAGG-"; "ELAGG-"}*/
+/*"INTPM" -> {"URAGG-"; "SPFCAT"}*/
+
+"INTTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTTOOLS"]
+/*"INTTOOLS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"INTTOOLS" -> "FS"
+/*"INTTOOLS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"INTTOOLS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
+/*"INTTOOLS" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"}*/
+/*"INTTOOLS" -> {"RING"; "RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"INTTOOLS" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
+/*"INTTOOLS" -> {"RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"INTTOOLS" -> {"COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "CACHSET"; "INT"}*/
+/*"INTTOOLS" -> {"LIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"INTTOOLS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"INTTOOLS" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"INTTOOLS" -> {"NNI"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"INTTOOLS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"INTTOOLS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ELEMFUN"; "POLYCAT"}*/
+/*"INTTOOLS" -> {"FAMR"; "AMR"; "PFECAT"; "UPOLYC"; "DIFRING"; "DIFEXT"}*/
+/*"INTTOOLS" -> {"STEP"; "LFCAT"; "PRIMCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"INTTOOLS" -> {"ATRIG"; "HYPCAT"; "AHYP"}*/
+
+"ITRIGMNP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ITRIGMNP"]
+/*"ITRIGMNP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"ITRIGMNP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"ITRIGMNP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"ITRIGMNP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+"ITRIGMNP" -> "FS"
+/*"ITRIGMNP" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"ITRIGMNP" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"ITRIGMNP" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"ITRIGMNP" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
+/*"ITRIGMNP" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "BOOLEAN"}*/
+"ITRIGMNP" -> "COMPCAT"
+/*"ITRIGMNP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"}*/
+/*"ITRIGMNP" -> {"DIFRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
+/*"ITRIGMNP" -> {"PFECAT"; "OM"; "CACHSET"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"ITRIGMNP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"ITRIGMNP" -> {"CLAGG"; "FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"}*/
+/*"ITRIGMNP" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"ITRIGMNP" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"ITRIGMNP" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"ITRIGMNP" -> {"URAGG-"; "POLYCAT"; "FAMR"; "AMR"}*/
+
+"JORDAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=JORDAN"]
+/*"JORDAN" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"JORDAN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"; "MODULE"}*/
+/*"JORDAN" -> {"BMODULE"; "LMODULE"; "RMODULE"}*/
+"JORDAN" -> "FRNAALG"
+/*"JORDAN" -> {"FINAALG"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"JORDAN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"}*/
+/*"JORDAN" -> {"ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"JORDAN" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"JORDAN" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"JORDAN" -> {"PATMAB"; "PFECAT"}*/
+
+"KOVACIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=KOVACIC"]
+/*"KOVACIC" -> {"CHARZ"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"KOVACIC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"KOVACIC" -> {"MONOID"; "LMODULE"}*/
+"KOVACIC" -> "ACF"
+/*"KOVACIC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"KOVACIC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"KOVACIC" -> {"UFD"; "DIVRING"; "RADCAT"; "RETRACT"; "UPOLYC"}*/
+/*"KOVACIC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"KOVACIC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"KOVACIC" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"KOVACIC" -> {"DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
+/*"KOVACIC" -> {"TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"KOVACIC" -> {"OASGP"; "REAL"; "PI"; "NNI"; "INT"; "LIST"; "ILIST"}*/
+/*"KOVACIC" -> "BOOLEAN"*/
+
+"LF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LF"]
+/*"LF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
+/*"LF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"LF" -> {"MODULE"; "ENTIRER"}*/
+"LF" -> "FS"
+/*"LF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"LF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"LF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"LF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
+/*"LF" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SYMBOL"}*/
+/*"LF" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"LF" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"LF" -> {"LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"LF" -> {"PI"; "NNI"; "BOOLEAN"}*/
+
+"LIE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIE"]
+/*"LIE" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LIE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"; "MODULE"; "BMODULE"}*/
+/*"LIE" -> {"LMODULE"; "RMODULE"}*/
+"LIE" -> "FRNAALG"
+/*"LIE" -> {"FINAALG"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"LIE" -> {"PI"; "NNI"; "INT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"LIE" -> {"INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"}*/
+/*"LIE" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"LIE" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"LIE" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+
+"LODOF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LODOF"]
+/*"LODOF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"LODOF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"LODOF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"LODOF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"LODOF" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
+/*"LODOF" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"LODOF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"LODOF" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
+/*"LODOF" -> {"STEP"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"LODOF" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"LODOF" -> {"OASGP"; "REAL"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"LODOF" -> {"STAGG-"; "SINT"; "NNI"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"LODOF" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"LODOF" -> {"FLAGG"; "ELAGG"; "PI"; "ELAGG-"; "MONOID-"; "ABELMON-"}*/
+"LODOF" -> "ACF"
+/*"LODOF" -> {"RADCAT"; "ES"}*/
+
+"LSQM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LSQM"]
+/*"LSQM" -> {"SMATCAT"; "DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"LSQM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"LSQM" -> {"MONOID"; "LMODULE"; "DIFRING"; "PDRING"; "BMODULE"; "RMODULE"}*/
+/*"LSQM" -> {"RMATCAT"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"LSQM" -> {"MODULE"; "COMRING"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"LSQM" -> "ALGEBRA"*/
+"LSQM" -> "FRNAALG"
+/*"LSQM" -> {"FINAALG"; "NAALG"; "NARNG"; "MONAD"; "INTDOM"; "ENTIRER"}*/
+/*"LSQM" -> {"PI"; "NNI"; "INT"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"LSQM" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"LSQM" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTCAT-"; "A1AGG-"}*/
+/*"LSQM" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
+/*"LSQM" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "EUCDOM"; "PID"}*/
+/*"LSQM" -> {"GCDDOM"; "FIELD"; "UFD"; "DIVRING"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"LSQM" -> {"CHARZ"; "CHARNZ"; "PATMAB"; "PFECAT"; "INS"; "OINTDOM"}*/
+/*"LSQM" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
+/*"LSQM" -> {"REAL"; "STEP"}*/
+
+"OMEXPR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OMEXPR"]
+/*"OMEXPR" -> {"OM"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"}*/
+/*"OMEXPR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"OMEXPR" -> {"MONOID"; "LMODULE"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"OMEXPR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"OMEXPR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"OMEXPR" -> {"FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
+/*"OMEXPR" -> {"STAGG-"; "PI"; "SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"}*/
+/*"OMEXPR" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"OMEXPR" -> {"FLAGG-"; "LNAGG-"}*/
+"OMEXPR" -> "FS"
+/*"OMEXPR" -> {"ES"; "RETRACT"; "PATAB"; "FPATMAB"; "PATMAB"; "FRETRCT"}*/
+/*"OMEXPR" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
+/*"OMEXPR" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
+/*"OMEXPR" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
+/*"OMEXPR" -> "DIVRING"*/
+
+"MCMPLX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MCMPLX"]
+/*"MCMPLX" -> {"FMTC"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MCMPLX" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MCMPLX" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"MCMPLX" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
+"MCMPLX" -> "COMPCAT"
+/*"MCMPLX" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARZ"; "CHARNZ"}*/
+/*"MCMPLX" -> {"KONVERT"; "FRETRCT"; "FLINEXP"; "LINEXP"; "FINITE"}*/
+/*"MCMPLX" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"MCMPLX" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"}*/
+/*"MCMPLX" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"}*/
+/*"MCMPLX" -> {"PATMAB"; "PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"MCMPLX" -> {"AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"; "FPS"; "RNS"}*/
+/*"MCMPLX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"MCMPLX" -> {"INS"; "OINTDOM"; "CFCAT"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"MCMPLX" -> {"AMR"; "OAMONS"}*/
+
+"MULTFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MULTFACT"]
+/*"MULTFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
+/*"MULTFACT" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
+/*"MULTFACT" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"MULTFACT" -> {"ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"MULTFACT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
+/*"MULTFACT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"MULTFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"MULTFACT" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "INS"; "OINTDOM"}*/
+/*"MULTFACT" -> {"ORDRING"; "OAGROUP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
+"MULTFACT" -> "COMPCAT"
+/*"MULTFACT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FIELD"}*/
+/*"MULTFACT" -> {"DIVRING"; "DIFEXT"; "FFIELDC"; "FPC"; "FEVALAB"; "ELTAB"}*/
+/*"MULTFACT" -> {"FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"MULTFACT" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "UPOLYC"}*/
+
+/* MYEXPR and MYUP are mutually dependent */
+/* We remove them and create a new node */
+"MYEXPR/MYUP" [color="blue",href="bookvol10.3.pdf#nameddest=MYEXPR"]
+"MYEXPR/MYUP" -> "FS"
+
+/*"MYEXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MYEXPR"]*/
+/*"MYEXPR" -> "MYUP"*/ /* clique1.spad */
+/*"MYEXPR" -> {"FS"; "ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MYEXPR" -> {"RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"MYEXPR" -> {"TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"}*/
+/*"MYEXPR" -> {"ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"}*/
+/*"MYEXPR" -> {"LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
+/*"MYEXPR" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
+/*"MYEXPR" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
+/*"MYEXPR" -> {"DIVRING"; "COMBOPC"; "CFCAT"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"MYEXPR" -> {"PFECAT"; "UPOLYC"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"MYEXPR" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"MYEXPR" -> {"OASGP"; "REAL"; "FPS"; "RNS"; "RADCAT"; "QFCAT"}*/
+/*"MYEXPR" -> {"FEVALAB"; "CACHSET"}*/
+
+/*"MYUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MYUP"]*/
+/*"MYUP" -> "MYEXPR"*/ /* clique1.spad */
+/*"MYUP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"MYUP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"MYUP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"MYUP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"MYUP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"MYUP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+/*"MYUP" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"MYUP" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "FPS"}*/
+/*"MYUP" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"MYUP" -> {"REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
+
+"NAGF01" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF01"]
+/*"NAGF01" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"NAGF01" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"NAGF01" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"}*/
+/*"NAGF01" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"NAGF01" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"NAGF01" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"NAGF01" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"NAGF01" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"NAGF01" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+/*"NAGF01" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
+"NAGF01" -> "COMPCAT"
+/*"NAGF01" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"NAGF01" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"; "FPC"}*/
+/*"NAGF01" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"}*/
+/*"NAGF01" -> {"PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"NAGF01" -> {"ELEMFUN"; "PFECAT"}*/
+
+"NAGF02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF02"]
+/*"NAGF02" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"NAGF02" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"NAGF02" -> {"FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"NAGF02" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NAGF02" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"NAGF02" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"NAGF02" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"NAGF02" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"NAGF02" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS-"}*/
+/*"NAGF02" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"NAGF02" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"NAGF02" -> {"ABELMON-"; "MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
+/*"NAGF02" -> {"DFLOAT"; "PI"; "NNI"}*/
+"NAGF02" -> "COMPCAT"
+/*"NAGF02" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"NAGF02" -> {"FLINEXP"; "LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"}*/
+/*"NAGF02" -> {"PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"}*/
+/*"NAGF02" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"}*/
+/*"NAGF02" -> {"PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"NAGF02" -> {"AHYP"; "ELEMFUN"; "PFECAT"}*/
+
+"NAGF04" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF04"]
+/*"NAGF04" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"NAGF04" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"NAGF04" -> {"FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"NAGF04" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NAGF04" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"NAGF04" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"NAGF04" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
+/*"NAGF04" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
+/*"NAGF04" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
+"NAGF04" -> "COMPCAT"
+/*"NAGF04" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
+/*"NAGF04" -> {"FLINEXP"; "LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"NAGF04" -> {"FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"NAGF04" -> {"IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
+/*"NAGF04" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PFECAT"; "INS"}*/
+/*"NAGF04" -> {"OINTDOM"; "CFCAT"; "DFLOAT"}*/
+
+"NCEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NCEP"]
+/*"NCEP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"NCEP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"NCEP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"NCEP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"NCEP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"NCEP" -> {"ORDSET"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"NCEP" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"NCEP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "OINTDOM"; "DIFRING"}*/
+/*"NCEP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"NCEP" -> {"CHARZ"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"NCEP" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"NCEP" -> {"TYPE"; "CHARNZ"; "PFECAT"}*/
+"NCEP" -> "COMPCAT"
+/*"NCEP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FRETRCT"; "FINITE"; "FFIELDC"}*/
+/*"NCEP" -> {"FPC"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"NCEP" -> {"ELEMFUN"; "RADCAT"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
+
+"NLINSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NLINSOL"]
+/*"NLINSOL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"NLINSOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"NLINSOL" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"NLINSOL" -> {"MODULE"; "ENTIRER"; "ORDSET"; "KONVERT"; "OM"; "PATMAB"}*/
+/*"NLINSOL" -> {"INT"; "LIST"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"NLINSOL" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"NLINSOL" -> {"FLINEXP"; "LINEXP"; "GCDDOM"; "PFECAT"; "UFD"}*/
+"NLINSOL" -> "ACF"
+/*"NLINSOL" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "RADCAT"; "ILIST"}*/
+/*"NLINSOL" -> {"LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"NLINSOL" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"NLINSOL" -> {"CLAGG"; "FLAGG"; "ELAGG"; "NNI"; "INS"; "OINTDOM"}*/
+/*"NLINSOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"NLINSOL" -> {"CFCAT"; "REAL"; "STEP"; "QFCAT"; "FEVALAB"; "DIFEXT"}*/
+/*"NLINSOL" -> {"PATAB"; "FPATMAB"}*/
+
+"NSMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NSMP"]
+"NSMP" -> "RPOLCAT"
+/*"NSMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"NSMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"NSMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"NSMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"NSMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"NSMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
+/*"NSMP" -> {"UFD"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"NSMP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"NSMP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"NSMP" -> {"BASTYPE-"; "BOOLEAN"; "MONOID-"; "ABELMON-"; "PI"; "EUCDOM"}*/
+/*"NSMP" -> {"PID"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"NSMP" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"}*/
+/*"NSMP" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"}*/
+/*"NSMP" -> {"FPATMAB"; "TYPE"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
+
+"NUMERIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMERIC"]
+/*"NUMERIC" -> {"KONVERT"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"NUMERIC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"NUMERIC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+"NUMERIC" -> "COMPCAT"
+/*"NUMERIC" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"}*/
+/*"NUMERIC" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
+/*"NUMERIC" -> {"LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"NUMERIC" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"}*/
+/*"NUMERIC" -> {"PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
+/*"NUMERIC" -> {"EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"; "PATAB"}*/
+/*"NUMERIC" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"NUMERIC" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "FPS"; "RNS"; "ORDRING"}*/
+/*"NUMERIC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "OM"}*/
+/*"NUMERIC" -> {"POLYCAT"; "FAMR"; "AMR"}*/
+
+"OCT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OCT"]
+"OCT" -> "OC"
+/*"OCT" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"OCT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"OCT" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
+/*"OCT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FINITE"; "ORDSET"}*/
+/*"OCT" -> {"KONVERT"; "CHARZ"; "CHARNZ"; "COMRING"}*/
+"OCT" -> "QUATCAT"
+/*"OCT" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "ENTIRER"}*/
+/*"OCT" -> {"DIVRING"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"OCT" -> {"UFD"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"OCT" -> {"OASGP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "RNS"; "RADCAT"}*/
+
+"OCTCT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OCTCT2"]
+"OCTCT2" -> "OC"
+/*"OCTCT2" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"OCTCT2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"OCTCT2" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FRETRCT"}*/
+/*"OCTCT2" -> {"RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FINITE"}*/
+/*"OCTCT2" -> {"ORDSET"; "KONVERT"; "CHARZ"; "CHARNZ"; "COMRING"}*/
+
+"ODEPAL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPAL"]
+/*"ODEPAL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODEPAL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODEPAL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ODEPAL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ODEPAL" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
+/*"ODEPAL" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"ODEPAL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"ODEPAL" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+"ODEPAL" -> "FFCAT"
+/*"ODEPAL" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"ODEPAL" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
+/*"ODEPAL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"ODEPAL" -> {"LODOCAT"; "OREPCAT"}*/
+
+"ODERTRIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODERTRIC"]
+/*"ODERTRIC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"ODERTRIC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ODERTRIC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"ODERTRIC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ODERTRIC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
+/*"ODERTRIC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
+/*"ODERTRIC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"ODERTRIC" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"ODERTRIC" -> {"DIFEXT"; "STEP"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
+/*"ODERTRIC" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"ODERTRIC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"ODERTRIC" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
+/*"ODERTRIC" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"ODERTRIC" -> {"ILIST"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ODERTRIC" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"ODERTRIC" -> {"FLAGG"; "ELAGG"; "OM"; "BOOLEAN"}*/
+"ODERTRIC" -> "UTSCAT"
+/*"ODERTRIC" -> {"UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"ODERTRIC" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"ODERTRIC" -> "ACF"
+/*"ODERTRIC" -> {"LSAGG-"; "STAGG-"}*/
+
+"PACEXTC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PACEXTC"]
+"PACEXTC" -> "PACRAT"
+/*"PACEXTC" -> {"PACRATC"; "PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PACEXTC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PACEXTC" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"PACEXTC" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PACEXTC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"PACEXTC" -> {"DIVRING"; "CHARZ"; "RETRACT"; "XF"; "VSPACE";}*/
+/*"PACEXTC" -> {"FPC"; "CHARNZ"; "FINITE"}*/
+
+"PADE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PADE"]
+/*"PADE" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PADE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PADE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PADE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"PADE" -> "DIVRING"*/
+"PADE" -> "UTSCAT"
+/*"PADE" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
+/*"PADE" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"PADE" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "UPOLYC"; "POLYCAT"}*/
+/*"PADE" -> {"FAMR"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"PADE" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "DIFEXT"}*/
+/*"PADE" -> {"STEP"; "NNI"; "INT"; "SINT"; "LIST"; "ILIST"; "PI"}*/
+
+"PAN2EXPR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PAN2EXPR"]
+/*"PAN2EXPR" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PAN2EXPR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"PAN2EXPR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PAN2EXPR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"PAN2EXPR" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PAN2EXPR" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"PAN2EXPR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+/*"PAN2EXPR" -> {"STEP"; "ES"; "IEVALAB"; "EVALAB"}*/
+"PAN2EXPR" -> "ACF"
+/*"PAN2EXPR" -> {"FIELD"; "DIVRING"; "RADCAT"}*/
+"PAN2EXPR" -> "FS"
+/*"PAN2EXPR" -> {"PATAB"; "FPATMAB"; "TYPE"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"PAN2EXPR" -> {"FLINEXP"; "CHARNZ"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"PAN2EXPR" -> {"PFECAT"; "OM"}*/
+
+"PFO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFO"]
+/*"PFO" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
+/*"PFO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PFO" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PFO" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
+"PFO" -> "FS"
+/*"PFO" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"PFO" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"PFO" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"PFO" -> {"GCDDOM"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"PFO" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+"PFO" -> "FFCAT"
+/*"PFO" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"PFO" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PFO" -> {"OASGP"; "CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "CACHSET"}*/
+/*"PFO" -> {"INT"; "LIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"PFO" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"PFO" -> {"OM"; "ILIST"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
+/*"PFO" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG-"; "PI"; "INTDOM-"}*/
+/*"PFO" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"PFO" -> {"ABELGRP-"; "ABELMON-"; "VECTCAT"; "A1AGG"; "BOOLEAN"}*/
+
+"PFOQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFOQ"]
+/*"PFOQ" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PFOQ" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PFOQ" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
+/*"PFOQ" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"PFOQ" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PFOQ" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
+/*"PFOQ" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"PFOQ" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
+"PFOQ" -> "FFCAT"
+/*"PFOQ" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"PFOQ" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PFOQ" -> {"OASGP"; "CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"}*/
+/*"PFOQ" -> {"FPATMAB"; "TYPE"; "OM"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"PFOQ" -> {"NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "PI"; "INTDOM-"}*/
+/*"PFOQ" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
+/*"PFOQ" -> {"ABELGRP-"; "ABELMON-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"PFOQ" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
+
+"PLACES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLACES"]
+/*"PLACES" -> {"PLACESC"; "SETCATD"; "LOCPOWC"; "DIV"}*/
+"PLACES" -> "NSDPS"
+"PLACES" -> "PLCS"
+/*"PLACES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"}*/
+/*"PLACES" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PLACES" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PLACES" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"PLACES" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+
+"PLACESPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLACESPS"]
+/*"PLACESPS" -> {"PLCS"; "PLACESC"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"PLACESPS" -> "PACOFF"
+/*"PLACESPS" -> {"PACFFC"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"PLACESPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"PLACESPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"PLACESPS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PLACESPS" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
+/*"PLACESPS" -> {"DIFRING"; "PACPERC"}*/
+
+"PICOERCE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PICOERCE"]
+/*"PICOERCE" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"PICOERCE" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"PICOERCE" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"PICOERCE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "INS"; "UFD"}*/
+/*"PICOERCE" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"PICOERCE" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "RETRACT"}*/
+/*"PICOERCE" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+/*"PICOERCE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"PICOERCE" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
+/*"PICOERCE" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"}*/
+"PICOERCE" -> "FS"
+/*"PICOERCE" -> {"ES"; "PATAB"; "FPATMAB"; "TYPE"; "GROUP"}*/
+
+"PMASSFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMASSFS"]
+/*"PMASSFS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"PMASSFS" -> "FS"
+/*"PMASSFS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"PMASSFS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
+/*"PMASSFS" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"}*/
+/*"PMASSFS" -> {"RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"}*/
+/*"PMASSFS" -> {"CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"}*/
+/*"PMASSFS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
+/*"PMASSFS" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"}*/
+
+"PMFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMFS"]
+/*"PMFS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"; "RING"}*/
+/*"PMFS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"PMFS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"PMFS" -> {"ENTIRER"; "ORDSET"; "PATMAB"}*/
+"PMFS" -> "FS"
+/*"PMFS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"PMFS" -> {"FPATMAB"; "TYPE"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"PMFS" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"PMFS" -> {"GCDDOM"; "UFD"; "DIVRING"; "CACHSET"; "INT"; "LIST"; "ILIST"}*/
+/*"PMFS" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+
+"PMPREDFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPREDFS"]
+/*"PMPREDFS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+"PMPREDFS" -> "FS"
+/*"PMPREDFS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"PMPREDFS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
+/*"PMPREDFS" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"}*/
+/*"PMPREDFS" -> {"RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"}*/
+/*"PMPREDFS" -> {"CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"}*/
+/*"PMPREDFS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PMPREDFS" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"}*/
+/*"PMPREDFS" -> {"LSAGG-"; "STAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"PMPREDFS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"PMPREDFS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"PSETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PSETCAT",
+          shape=ellipse]
+/*"PSETCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"; "HOAGG"; "AGG"}*/
+/*"PSETCAT" -> {"TYPE"; "EVALAB"; "IEVALAB"; "KONVERT"; "RING"; "RNG"}*/
+/*"PSETCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"PSETCAT" -> {"MONOID"; "LMODULE"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"PSETCAT" -> {"OASGP"; "ORDSET"}*/
+"PSETCAT" -> "RPOLCAT"
+/*"PSETCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"PSETCAT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"PSETCAT" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"PSETCAT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"}*/
+/*"PSETCAT" -> {"LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"PSETCAT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"}*/
+/*"PSETCAT" -> {"OM"; "ELAGG-"; "FLAGG-"; "BOOLEAN"; "URAGG-"; "LNAGG-"}*/
+/*"PSETCAT" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "EUCDOM"; "PID"}*/
+
+"PSETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PSETCAT",
+          shape=ellipse]
+/*"PSETCAT-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "CLAGG";  "HOAGG"}*/
+/*"PSETCAT-" -> {"AGG";  "TYPE";  "EVALAB";  "IEVALAB";  "KONVERT";  "RING"}*/
+/*"PSETCAT-" -> {"RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
+/*"PSETCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "OAMONS";  "OCAMON"}*/
+/*"PSETCAT-" -> {"OAMON";  "OASGP";  "ORDSET"}*/
+"PSETCAT-" -> "RPOLCAT"
+/*"PSETCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "BMODULE"}*/
+/*"PSETCAT-" -> {"RMODULE";  "COMRING";  "ALGEBRA";  "MODULE";  "CHARZ"}*/
+/*"PSETCAT-" -> {"CHARNZ";  "INTDOM";  "ENTIRER";  "FRETRCT";  "RETRACT"}*/
+/*"PSETCAT-" -> {"FLINEXP";  "LINEXP";  "PATMAB";  "GCDDOM";  "PFECAT"}*/
+/*"PSETCAT-" -> {"UFD";  "INT";  "LIST";  "ILIST";  "LSAGG-";  "STAGG-"}*/
+/*"PSETCAT-" -> {"LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "LNAGG";  "IXAGG"}*/
+/*"PSETCAT-" -> {"ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG";  "OM";  "ELAGG-"}*/
+/*"PSETCAT-" -> {"FLAGG-";  "BOOLEAN";  "URAGG-";  "LNAGG-";  "RCAGG-"}*/
+/*"PSETCAT-" -> {"IXAGG-";  "CLAGG-";  "EUCDOM";  "PID"}*/
+
+"PROJPLPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PROJPLPS"]
+/*"PROJPLPS" -> {"PRSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"PROJPLPS" -> {"PACFFC"}*/
+"PROJPLPS" -> "PACOFF"
+/*"PROJPLPS" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"PROJPLPS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PROJPLPS" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PROJPLPS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"PROJPLPS" -> {"DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "PACPERC"}*/
+
+"PSETPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PSETPK"]
+/*"PSETPK" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"PSETPK" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"PSETPK" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"PSETPK" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"PSETPK" -> {"OASGP"; "ORDSET"}*/
+"PSETPK" -> "RPOLCAT"
+/*"PSETPK" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"PSETPK" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"PSETPK" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
+/*"PSETPK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PSETPK" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"PSETPK" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"PSETPK" -> {"ELAGG-"; "BOOLEAN"; "FLAGG-"; "NNI"; "TSETCAT"; "PSETCAT"}*/
+/*"PSETPK" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "EUCDOM"}*/
+/*"PSETPK" -> "PID"*/
+
+"QUAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QUAT"]
+"QUAT" -> "QUATCAT"
+/*"QUAT" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"QUAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"QUAT" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
+/*"QUAT" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
+/*"QUAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ENTIRER"; "ORDSET"; "DIVRING"}*/
+/*"QUAT" -> {"KONVERT"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"QUAT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "UFD"; "INS"; "OINTDOM"}*/
+/*"QUAT" -> "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "PATMAB"}*/
+/*"QUAT" -> "CFCAT"; "REAL"; "STEP"; "RNS"; "RADCAT"}*/
+
+"QUATCT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QUATCT2"]
+"QUATCT2" -> "QUATCAT"
+/*"QUATCT2" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"QUATCT2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"QUATCT2" -> {"MONOID"; "LMODULE"; "MODULE"; "BMODULE"; "RMODULE"}*/
+/*"QUATCT2" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
+/*"QUATCT2" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"QUATCT2" -> {"LINEXP"; "ENTIRER"; "ORDSET"; "DIVRING"; "KONVERT"}*/
+/*"QUATCT2" -> {"CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"QUATCT2" -> {"INTDOM"; "COMRING"; "UFD"}*/
+
+"RADFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RADFF"]
+"RADFF" -> "FFCAT"
+/*"RADFF" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "RING"; "RNG"}*/
+/*"RADFF" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RADFF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "MODULE"; "BMODULE"}*/
+/*"RADFF" -> {"RMODULE"; "CHARZ"; "CHARNZ"; "COMRING"; "KONVERT"; "FRETRCT"}*/
+/*"RADFF" -> {"RETRACT"; "FLINEXP"; "LINEXP"; "FINITE"; "FIELD"; "EUCDOM"}*/
+/*"RADFF" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"RADFF" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"}*/
+/*"RADFF" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "EVALAB"; "IEVALAB"}*/
+/*"RADFF" -> {"ORDSET"; "PATMAB"; "PFECAT"; "ELTAB"; "QFCAT"; "FEVALAB"}*/
+/*"RADFF" -> {"PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"RADFF" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "NNI"; "INT"; "BOOLEAN"}*/
+/*"RADFF" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "INS"; "CFCAT"; "OM"; "SINT"}*/
+/*"RADFF" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
+/*"RADFF" -> {"ELTAGG"; "CLAGG"; "PRIMARR"; "A1AGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"RADFF" -> {"LIST"; "ILIST"; "LSAGG-"; "PI"; "OAMONS"}*/
+
+"RDEEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDEEF"]
+/*"RDEEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"RDEEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RDEEF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RDEEF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"RDEEF" -> {"CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"; "TRIGCAT"}*/
+/*"RDEEF" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"RDEEF" -> "ACF"
+/*"RDEEF" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+"RDEEF" -> "FS"
+/*"RDEEF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"RDEEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"RDEEF" -> {"CHARNZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"RDEEF" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"RDEEF" -> {"ELAGG"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
+/*"RDEEF" -> {"DIFRING"; "DIFEXT"; "STEP"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
+/*"RDEEF" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"RDEEF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "OM"}*/
+/*"RDEEF" -> {"CACHSET"; "ILIST"; "BOOLEAN"; "NNI"; "INS"; "OINTDOM"}*/
+/*"RDEEF" -> "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"RDEEF" -> "CFCAT"; "REAL"; "PI"}*/
+
+"RDEEFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDEEFS"]
+/*"RDEEFS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"RDEEFS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RDEEFS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"RDEEFS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "CHARZ"; "RETRACT"}*/
+/*"RDEEFS" -> {"LINEXP"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"RDEEFS" -> {"AHYP"; "ELEMFUN"}*/
+"RDEEFS" -> "ACF"
+/*"RDEEFS" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+"RDEEFS" -> "FS"
+/*"RDEEFS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"RDEEFS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"RDEEFS" -> {"CHARNZ"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
+/*"RDEEFS" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LIST"; "ILIST"}*/
+/*"RDEEFS" -> {"CACHSET"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+
+"RDIV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDIV"]
+/*"RDIV" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"RDIV" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"RDIV" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RDIV" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"RDIV" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"RDIV" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"RDIV" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"RDIV" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+"RDIV" -> "FFCAT"
+/*"RDIV" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
+/*"RDIV" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
+/*"RDIV" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+
+"RSETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RSETCAT"]
+/*"RSETCAT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"RSETCAT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RSETCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RSETCAT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "TSETCAT"}*/
+/*"RSETCAT" -> {"PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"RSETCAT" -> {"IEVALAB"; "KONVERT"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"RSETCAT" -> {"OASGP"; "ORDSET"}*/
+"RSETCAT" -> "RPOLCAT"
+/*"RSETCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"RSETCAT" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+/*"RSETCAT" -> {"PFECAT"; "UFD"; "BOOLEAN"; "INT"; "LIST"; "ILIST"}*/
+/*"RSETCAT" -> {"FINITE"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"RSETCAT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
+/*"RSETCAT" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "URAGG-"}*/
+/*"RSETCAT" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+
+"RSETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RSETCAT"]
+/*"RSETCAT-" -> {"GCDDOM";  "INTDOM";  "COMRING";  "RING";  "RNG"}*/
+/*"RSETCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
+/*"RSETCAT-" -> {"BASTYPE";  "KOERCE";  "SGROUP";  "MONOID";  "LMODULE"}*/
+/*"RSETCAT-" -> {"BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE";  "ENTIRER"}*/
+/*"RSETCAT-" -> {"TSETCAT";  "PSETCAT";  "CLAGG";  "HOAGG";  "AGG";  "TYPE"}*/
+/*"RSETCAT-" -> {"EVALAB";  "IEVALAB";  "KONVERT";  "OAMONS";  "OCAMON"}*/
+/*"RSETCAT-" -> {"OAMON";  "OASGP";  "ORDSET"}*/
+"RSETCAT-" -> "RPOLCAT"
+/*"RSETCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ"}*/
+/*"RSETCAT-" -> {"FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP";  "PATMAB"}*/
+/*"RSETCAT-" -> {"PFECAT";  "UFD";  "BOOLEAN";  "INT";  "LIST";  "ILIST"}*/
+/*"RSETCAT-" -> {"FINITE";  "NNI";  "LSAGG-";  "STAGG-";  "ELAGG-"}*/
+/*"RSETCAT-" -> {"FLAGG-";  "LSAGG";  "STAGG";  "URAGG";  "RCAGG"}*/
+/*"RSETCAT-" -> {"LNAGG";  "IXAGG";  "ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG"}*/
+/*"RSETCAT-" -> "OM";  "URAGG-";  "LNAGG-";  "RCAGG-";  "IXAGG-";  "CLAGG-"}*/
+
+"RSETGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RSETGCD"]
+/*"RSETGCD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"RSETGCD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RSETGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"RSETGCD" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"}*/
+/*"RSETGCD" -> {"OAMON"; "OASGP"; "ORDSET"}*/
+"RSETGCD" -> "RPOLCAT"
+/*"RSETGCD" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"RSETGCD" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"RSETGCD" -> {"LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "RSETCAT"}*/
+/*"RSETGCD" -> {"TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"RSETGCD" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
+/*"RSETGCD" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "BOOLEAN"; "INT"}*/
+/*"RSETGCD" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"RSETGCD" -> {"OM"; "NNI"; "INS-"}*/
+
+"RULE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RULE"]
+/*"RULE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ELTAB"; "RETRACT"}*/
+"RULE" -> "FS"
+/*"RULE" -> {"ES"; "ORDSET"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"RULE" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
+/*"RULE" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"}*/
+/*"RULE" -> {"RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"}*/
+/*"RULE" -> {"CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"}*/
+/*"RULE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
+/*"RULE" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "OM"; "BOOLEAN"}*/
+/*"RULE" -> {"LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"RULE" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"RULE" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"RULE" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+
+"RULESET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RULESET"]
+/*"RULESET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ELTAB"}*/
+"RULESET" -> "FS"
+/*"RULESET" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
+/*"RULESET" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"}*/
+/*"RULESET" -> {"SGROUP"; "GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"}*/
+/*"RULESET" -> {"RING"; "RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"RULESET" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
+/*"RULESET" -> {"RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"RULESET" -> {"COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"}*/
+/*"RULESET" -> {"ILIST"; "FSAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"}*/
+/*"RULESET" -> {"AGG"; "CLAGG"; "SETAGG"; "FINITE"}*/
+
+"SD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SD",
+        shape=ellipse]
+/*"SD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"SD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MODULE"; "BMODULE"; "LMODULE"}*/
+/*"SD" -> {"RMODULE"; "RETRACT"; "ES"; "ORDSET"; "IEVALAB"; "EVALAB"}*/
+/*"SD" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
+/*"SD" -> {"MONOID"; "GROUP"; "RING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"SD" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"SD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"SD" -> {"NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"SD" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"SD" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"SD" -> {"BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"SD" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"SD" -> {"FLAGG"; "ELAGG"; "OM"; "PI"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"SD" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"SD" -> {" ISTRING"; "SRAGG";-" BOOLEAN"; "BSD"}*/
+"SD" -> "FS"
+
+"SIGNEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SIGNEF"]
+/*"SIGNEF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SIGNEF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"SIGNEF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"SIGNEF" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"; "GCDDOM"}*/
+/*"SIGNEF" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+/*"SIGNEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"SIGNEF" -> "FS"
+/*"SIGNEF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"SIGNEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"SIGNEF" -> {"CHARZ"; "CHARNZ"; "NNI"; "INT"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"SIGNEF" -> {"PFECAT"; "CACHSET"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
+/*"SIGNEF" -> {"ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"SIGNEF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
+/*"SIGNEF" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"SIGNEF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "FPS"}*/
+/*"SIGNEF" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SIGNEF" -> {"REAL"; "DIFRING"; "INTCAT"; "QFCAT"; "FEVALAB"; "DIFEXT"}*/
+/*"SIGNEF" -> {"STEP"; "OINTDOM"; "PI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"SIGNEF" -> {"URAGG-"; "INS-"}*/
+
+"SIMPAN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SIMPAN"]
+/*"SIMPAN" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"SIMPAN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SIMPAN" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SIMPAN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"SIMPAN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"SIMPAN" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"SIMPAN" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
+"SIMPAN" -> "FS"
+/*"SIMPAN" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"SIMPAN" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"SIMPAN" -> {"FIELD"; "DIVRING"}*/
+
+"SFORT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SFORT"]
+/*"SFORT" -> {"FORTCAT"; "TYPE"; "KOERCE"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
+"SFORT" -> "FS"
+/*"SFORT" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"SFORT" -> {"FPATMAB"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"}*/
+/*"SFORT" -> {"ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"}*/
+/*"SFORT" -> {"LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
+/*"SFORT" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
+/*"SFORT" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
+/*"SFORT" -> {"DIVRING"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"SFORT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"SFORT" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
+
+"SOLVESER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVESER"]
+/*"SOLVESER" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SOLVESER" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SOLVESER" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SOLVESER" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "SYMBOL"}*/
+/*"SOLVESER" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"SOLVESER" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"SOLVESER" -> {"FLAGG-"; "LNAGG-"}*/
+"SOLVESER" -> "FS"
+/*"SOLVESER" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"SOLVESER" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"SOLVESER" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"SOLVESER" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
+/*"SOLVESER" -> {"FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
+/*"SOLVESER" -> {"STEP"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "ILIST"}*/
+/*"SOLVESER" -> {"PI"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
+/*"SOLVESER" -> {"HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
+
+"SOLVETRA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVETRA"]
+/*"SOLVETRA" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
+/*"SOLVETRA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SOLVETRA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"SOLVETRA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"SOLVETRA" -> {"ENTIRER"; "RETRACT"; "LINEXP"; "CHARZ"; "INT"; "LIST"}*/
+/*"SOLVETRA" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"SOLVETRA" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
+/*"SOLVETRA" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
+/*"SOLVETRA" -> {"OM"; "NNI"; "QFCAT"; "FIELD"; "UFD"; "DIVRING"; "FEVALAB"}*/
+/*"SOLVETRA" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "PATAB"}*/
+/*"SOLVETRA" -> {"FPATMAB"; "PATMAB"; "STEP"; "OINTDOM"; "ORDRING"}*/
+/*"SOLVETRA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARNZ"}*/
+/*"SOLVETRA" -> {"PFECAT"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"SOLVETRA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"SOLVETRA" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"SOLVETRA" -> {"AMR"; "FRETRCT"}*/
+"SOLVETRA" -> "FS"
+/*"SOLVETRA" -> {"ES"; "GROUP"; "LSAGG-"; "STAGG-"; "CACHSET"; "PI"; "ACFS"}*/
+/*"SOLVETRA" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"SOLVETRA" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
+/*"SOLVETRA" -> {"SPFCAT"; "ELAGG-"; "URAGG-"; "FPS"; "RNS"; "INTCAT"}*/
+/*"SOLVETRA" -> {"COMPCAT"; "MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"}*/
+/*"SOLVETRA" -> {"FFIELDC"; "FPC"}*/
+
+"SUMFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUMFS"]
+/*"SUMFS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"SUMFS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SUMFS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SUMFS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"}*/
+"SUMFS" -> "FS"
+/*"SUMFS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"SUMFS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"SUMFS" -> {"CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"SUMFS" -> {"UFD"; "DIVRING"; "COMBOPC"; "CFCAT"}*/
+"SUMFS" -> "ACF"
+/*"SUMFS" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"SUMFS" -> {"ELEMFUN"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"SUMFS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"SUMFS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"SUMFS" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"SUMFS" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "CACHSET"; "ILIST"; "BOOLEAN"}*/
+
+"SUTS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUTS"]
+/*"SUTS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SUTS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+"SUTS" -> "UTSCAT"
+/*"SUTS" -> {"UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"SUTS" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"SUTS" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"SUTS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "BOOLEAN"}*/
+/*"SUTS" -> {"NNI"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"SUTS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"SUTS" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"SUTS" -> {"STEP"; "OM"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
+/*"SUTS" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "FIELD"; "DIVRING"; "OAMONS"}*/
+
+"TOOLSIGN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TOOLSIGN"]
+/*"TOOLSIGN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"TOOLSIGN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"TOOLSIGN" -> {"LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"TOOLSIGN" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"TOOLSIGN" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"TOOLSIGN" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
+/*"TOOLSIGN" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"TOOLSIGN" -> {"CHARZ"; "STEP"}*/
+"TOOLSIGN" -> "FS"
+/*"TOOLSIGN" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"TOOLSIGN" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"; "FIELD"}*/
+/*"TOOLSIGN" -> {"DIVRING"; "OM"; "INT"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"TOOLSIGN" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
+/*"TOOLSIGN" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
+/*"TOOLSIGN" -> {"PRIMARR"; "A1AGG-"; "ISTRING"}*/
+
+"TRIGMNIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TRIGMNIP"]
+/*"TRIGMNIP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"TRIGMNIP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"TRIGMNIP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"TRIGMNIP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"TRIGMNIP" -> {"RETRACT"; "LINEXP"}*/
+"TRIGMNIP" -> "ACF"
+/*"TRIGMNIP" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+/*"TRIGMNIP" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"TRIGMNIP" -> "FS"
+/*"TRIGMNIP" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"TRIGMNIP" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"TRIGMNIP" -> {"CHARZ"; "CHARNZ"; "INT"; "LIST"; "ILIST"}*/
+"TRIGMNIP" -> "COMPCAT"
+/*"TRIGMNIP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"}*/
+/*"TRIGMNIP" -> {"DIFRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
+/*"TRIGMNIP" -> {"PFECAT"; "OM"; "SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"}*/
+/*"TRIGMNIP" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"TRIGMNIP" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"TRIGMNIP" -> {"INS-"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"TRIGMNIP" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
+/*"TRIGMNIP" -> {"ELAGG"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "BOOLEAN"}*/
+
+"TRMANIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TRMANIP"]
+/*"TRMANIP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "GCDDOM"; "INTDOM"}*/
+/*"TRMANIP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"TRMANIP" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"TRMANIP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+"TRMANIP" -> "FS"
+/*"TRMANIP" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"TRMANIP" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"TRMANIP" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"TRMANIP" -> {"PID"; "UFD"; "DIVRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"TRMANIP" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SYMBOL"; "INT"; "REF"}*/
+/*"TRMANIP" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"TRMANIP" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"TRMANIP" -> {"LNAGG-"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"TRMANIP" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"TRMANIP" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"; "LSAGG-"; "STAGG-"}*/
+/*"TRMANIP" -> {"BOOLEAN"; "ELAGG-"; "URAGG-"; "CACHSET"; "POLYCAT"}*/
+/*"TRMANIP" -> {"FAMR"; "AMR"; "PFECAT"}*/
+
+"TSETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TSETCAT",
+          shape=ellipse]
+/*"TSETCAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"TSETCAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"TSETCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"TSETCAT" -> {"MODULE"; "ENTIRER"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"}*/
+/*"TSETCAT" -> {"TYPE"; "EVALAB"; "IEVALAB"; "KONVERT"; "OAMONS"; "OCAMON"}*/
+/*"TSETCAT" -> {"OAMON"; "OASGP"; "ORDSET"}*/
+"TSETCAT" -> "RPOLCAT"
+/*"TSETCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"TSETCAT" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+/*"TSETCAT" -> {"GCDDOM"; "PFECAT"; "UFD"; "BOOLEAN"; "INT"; "LIST"}*/
+/*"TSETCAT" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"TSETCAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"TSETCAT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"TSETCAT" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "NNI"; "INS-"; "FINITE"}*/
+
+"TSETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TSETCAT",
+          shape=ellipse]
+/*"TSETCAT-" -> {"INTDOM";  "COMRING";  "RING";  "RNG";  "ABELGRP"}*/
+/*"TSETCAT-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
+/*"TSETCAT-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
+/*"TSETCAT-" -> {"RMODULE";  "ALGEBRA";  "MODULE";  "ENTIRER";  "PSETCAT"}*/
+/*"TSETCAT-" -> {"CLAGG";  "HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB"}*/
+/*"TSETCAT-" -> {"KONVERT";  "OAMONS";  "OCAMON";  "OAMON";  "OASGP"}*/
+/*"TSETCAT-" -> "ORDSET"*/
+"TSETCAT-" -> "RPOLCAT"
+/*"TSETCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ"}*/
+/*"TSETCAT-" -> {"FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP";  "PATMAB"}*/
+/*"TSETCAT-" -> {"GCDDOM";  "PFECAT";  "UFD";  "BOOLEAN";  "INT";  "LIST"}*/
+/*"TSETCAT-" -> {"ILIST";  "LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "LNAGG"}*/
+/*"TSETCAT-" -> {"IXAGG";  "ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG";  "OM"}*/
+/*"TSETCAT-" -> {"LSAGG-";  "STAGG-";  "ELAGG-";  "FLAGG-";  "URAGG-"}*/
+/*"TSETCAT-" -> {"LNAGG-";  "RCAGG-";  "IXAGG-";  "CLAGG-";  "NNI"}*/
+/*"TSETCAT-" -> {"INS-";  "FINITE"}*/
+
+"UFPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UFPS"]
+/*"UFPS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UFPS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+"UFPS" -> "UTSCAT"
+/*"UFPS" -> {"UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"UFPS" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"UFPS" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"UFPS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "OAMONS"; "OCAMON"}*/
+/*"UFPS" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
+/*"UFPS" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "KONVERT"; "RETRACT"}*/
+/*"UFPS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "FIELD"; "DIVRING"}*/
+
+"ULSCCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ULSCCAT"]
+/*"ULSCCAT" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"}*/
+/*"ULSCCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"ULSCCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ULSCCAT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"ULSCCAT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
+/*"ULSCCAT" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"ULSCCAT" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"ULSCCAT" -> {"UFD"; "DIVRING"; "RETRACT"; "QFCAT"; "FEVALAB"; "EVALAB"}*/
+/*"ULSCCAT" -> {"IEVALAB"; "DIFEXT"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"ULSCCAT" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
+/*"ULSCCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ULSCCAT" -> {"OASGP"; "REAL"; "PFECAT"}*/
+"ULSCCAT" -> "UTSCAT"
+/*"ULSCCAT" -> {"INS"; "CFCAT"}*/
+
+"ULSCCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ULSCCAT"]
+/*"ULSCCAT-" -> {"ULSCAT";  "UPSCAT";  "PSCAT";  "AMR";  "RING";  "RNG"}*/
+/*"ULSCCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
+/*"ULSCCAT-" -> {"BASTYPE";  "KOERCE";  "SGROUP";  "MONOID";  "LMODULE"}*/
+/*"ULSCCAT-" -> {"BMODULE";  "RMODULE";  "COMRING";  "ALGEBRA";  "MODULE"}*/
+/*"ULSCCAT-" -> {"CHARZ";  "CHARNZ";  "INTDOM";  "ENTIRER";  "ELTAB"}*/
+/*"ULSCCAT-" -> {"DIFRING";  "PDRING";  "RADCAT";  "TRANFUN";  "TRIGCAT"}*/
+/*"ULSCCAT-" -> {"ATRIG";  "HYPCAT";  "AHYP";  "ELEMFUN";  "FIELD"}*/
+/*"ULSCCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "UFD";  "DIVRING";  "RETRACT"}*/
+/*"ULSCCAT-" -> {"QFCAT";  "FEVALAB";  "EVALAB";  "IEVALAB";  "DIFEXT"}*/
+/*"ULSCCAT-" -> {"FLINEXP";  "LINEXP";  "PATAB";  "KONVERT";  "FPATMAB"}*/
+/*"ULSCCAT-" -> {"TYPE";  "PATMAB";  "STEP";  "ORDSET";  "OINTDOM"}*/
+/*"ULSCCAT-" -> {"ORDRING";  "OAGROUP";  "OCAMON";  "OAMON";  "OASGP"}*/
+/*"ULSCCAT-" -> {"REAL";  "PFECAT"}*/
+"ULSCCAT-" -> "UTSCAT"
+/*"ULSCCAT-" -> {"INS";  "CFCAT"}*/
+
+"UPXSSING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXSSING"]
+"UPXSSING" -> "ACF"
+/*"UPXSSING" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"UPXSSING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UPXSSING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"UPXSSING" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"UPXSSING" -> {"ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
+/*"UPXSSING" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"UPXSSING" -> "FS"
+/*"UPXSSING" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
+/*"UPXSSING" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
+/*"UPXSSING" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
+/*"UPXSSING" -> {"FAMR"; "AMR"; "UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"}*/
+/*"UPXSSING" -> {"ELTAB"; "DIFRING"; "NNI"; "INT"; "LIST"; "ILIST"; "INS"}*/
+/*"UPXSSING" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"UPXSSING" -> {"OASGP"; "CFCAT"; "REAL"; "STEP"; "BOOLEAN"; "OM"}*/
+/*"UPXSSING" -> {"LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"UPXSSING" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
+/*"UPXSSING" -> {"ELAGG"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"UPXSSING" -> {"A1AGG-"; "ISTRING"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"}*/
+
+"UTSODE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTSODE"]
+/*"UTSODE" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"UTSODE" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"UTSODE" -> {"MONOID"; "LMODULE"; "MODULE"; "BMODULE"; "RMODULE"}*/
+"UTSODE" -> "UTSCAT"
+/*"UTSODE" -> {"UPSCAT"; "PSCAT"; "AMR"; "COMRING"; "CHARZ"; "CHARNZ"}*/
+/*"UTSODE" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"}*/
+/*"UTSODE" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"UTSODE" -> {"ELEMFUN"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"UTSODE" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"UTSODE" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"UTSODE" -> {"KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
+
+"UTSODETL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTSODETL"]
+/*"UTSODETL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UTSODETL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"UTSODETL" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"UTSODETL" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"UTSODETL" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
+/*"UTSODETL" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"UTSODETL" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
+/*"UTSODETL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"UTSODETL" -> {"PID"; "FIELD"; "DIVRING"; "LODOCAT"; "OREPCAT"}*/
+"UTSODETL" -> "UTSCAT"
+/*"UTSODETL" -> {"UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"UTSODETL" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"; "SINT"}*/
+/*"UTSODETL" -> {"VECTOR"; "IVECTOR"; "IARRAY1"}*/
+
+"UTSSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTSSOL"]
+/*"UTSSOL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"UTSSOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UTSSOL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UTSSOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"UTSSOL" -> {"UFD"; "DIVRING"}*/
+"UTSSOL" -> "UTSCAT"
+/*"UTSSOL" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
+/*"UTSSOL" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"UTSSOL" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"; "LSAGG"}*/
+/*"UTSSOL" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"UTSSOL" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
+/*"UTSSOL" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "UPOLYC"; "POLYCAT"}*/
+/*"UTSSOL" -> {"FAMR"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+/*"UTSSOL" -> {"PFECAT"; "DIFEXT"; "STEP"; "LZSTAGG"}*/
+
+"UTS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTS2"]
+/*"UTS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UTS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+"UTS2" -> "UTSCAT"
+/*"UTS2" -> {"UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
+/*"UTS2" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
+/*"UTS2" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"UTS2" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+
+"WUTSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=WUTSET"]
+/*"WUTSET" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"WUTSET" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"WUTSET" -> {"KONVERT"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"WUTSET" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"WUTSET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"WUTSET" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+"WUTSET" -> "RPOLCAT"
+/*"WUTSET" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"WUTSET" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+/*"WUTSET" -> {"GCDDOM"; "PFECAT"; "UFD"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"WUTSET" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"}*/
+/*"WUTSET" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"WUTSET" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"WUTSET" -> {"CLAGG-"; "BOOLEAN"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"WUTSET" -> {"SETCAT-"; "BASTYPE-"; "FINITE"}*/
+
+\end{chunk}
+\subsection{Layer18}
+Depends on: ACFS EXPRSOL FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL 
+Used in next layer: EXPRSOL SFRTCAT
+\begin{chunk}{layer18}
+
+LAYER18=\
+  ${OUT}/DEFINTEF.o ${OUT}/DEFINTRF.o ${OUT}/DFINTTLS.o ${OUT}/EFULS.o    \
+  ${OUT}/ESCONT.o   ${OUT}/EXPR.o     ${OUT}/EXPRSOL.o  ${OUT}/EXPR2UPS.o \
+  ${OUT}/FACTEXT.o  \
+  ${OUT}/FDIV.o     ${OUT}/FSCINT.o   ${OUT}/FSINT.o    ${OUT}/FS2EXPXP.o \
+  ${OUT}/GSERIES.o  ${OUT}/HELLFDIV.o ${OUT}/INTDIVP.o  \
+  ${OUT}/INVLAPLA.o ${OUT}/IR2F.o     \
+  ${OUT}/IRRF2F.o   ${OUT}/LAPLACE.o  ${OUT}/LIMITPS.o  ${OUT}/LODEEF.o   \
+  ${OUT}/NODE1.o    ${OUT}/NOTTING.o \
+  ${OUT}/NTSCAT.o   ${OUT}/ODECONST.o ${OUT}/ODEEF.o    \
+  ${OUT}/ODEINT.o   ${OUT}/QCMPACK.o  ${OUT}/REGSET.o   ${OUT}/REP.o      \
+  ${OUT}/RGCHAIN.o  ${OUT}/RSDCMPK.o  ${OUT}/SFRTCAT.o  ${OUT}/SOLVERAD.o \
+  ${OUT}/SULS.o     ${OUT}/SUPXS.o    ${OUT}/UFPS1.o    ${OUT}/ULS.o      \
+  ${OUT}/ULSCONS.o  ${OUT}/UPXS.o     ${OUT}/UPXSCONS.o ${OUT}/UTS.o      \
+  ${OUT}/UTSZ.o \
+  layer18done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 18 */
+/* depends on: ACFS FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL */
+
+"DEFINTEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DEFINTEF"]
+/*"DEFINTEF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DEFINTEF" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"DEFINTEF" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DEFINTEF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"DEFINTEF" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
+/*"DEFINTEF" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PRIMCAT"}*/
+"DEFINTEF" -> "ACFS"
+/*"DEFINTEF" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"DEFINTEF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"DEFINTEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"DEFINTEF" -> {"CHARNZ"; "SPFCAT"; "BOOLEAN"; "CACHSET"; "SYMBOL"; "INT"}*/
+/*"DEFINTEF" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"DEFINTEF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"DEFINTEF" -> {"LNAGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DEFINTEF" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
+/*"DEFINTEF" -> {"OM"; "ILIST"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
+/*"DEFINTEF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
+/*"DEFINTEF" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+
+"DEFINTRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DEFINTRF"]
+/*"DEFINTRF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"DEFINTRF" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"DEFINTRF" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"DEFINTRF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"DEFINTRF" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "FS"; "ES"}*/
+/*"DEFINTRF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"DEFINTRF" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"DEFINTRF" -> {"FIELD"; "UFD"; "DIVRING"; "BOOLEAN"; "POLYCAT"; "FAMR"}*/
+/*"DEFINTRF" -> {"AMR"; "PFECAT"; "INT"; "LIST"; "ILIST"; "QFCAT"; "FEVALAB"}*/
+/*"DEFINTRF" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "STEP"; "OINTDOM"; "ORDRING"}*/
+/*"DEFINTRF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+"DEFINTRF" -> "ACFS"
+/*"DEFINTRF" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"DEFINTRF" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
+/*"DEFINTRF" -> "SPFCAT"*/
+
+"DFINTTLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DFINTTLS"]
+/*"DFINTTLS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"DFINTTLS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"DFINTTLS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"DFINTTLS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"DFINTTLS" -> {"RETRACT"; "LINEXP"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"DFINTTLS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"DFINTTLS" -> "ACFS"
+/*"DFINTTLS" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
+/*"DFINTTLS" -> {"RADCAT"; "FS"; "ES"; "IEVALAB"; "EVALAB"; "PATAB"}*/
+/*"DFINTTLS" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
+/*"DFINTTLS" -> {"GROUP"; "PDRING"; "FLINEXP"; "CHARZ"; "CHARNZ"; "NNI"}*/
+/*"DFINTTLS" -> {"INT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"DFINTTLS" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
+/*"DFINTTLS" -> {"OM"; "BOOLEAN"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"DFINTTLS" -> {"LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SYMBOL"; "REF"}*/
+/*"DFINTTLS" -> {"ALIST"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "POLYCAT"}*/
+/*"DFINTTLS" -> {"FAMR"; "AMR"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
+/*"DFINTTLS" -> {"DIFEXT"; "LSAGG-"; "INS-"}*/
+
+"EFULS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EFULS"]
+/*"EFULS" -> "PTRANFN"*/
+"EFULS" -> "ULSCCAT"
+/*"EFULS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"}*/
+/*"EFULS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"EFULS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"EFULS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"EFULS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
+/*"EFULS" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"EFULS" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"EFULS" -> {"UFD"; "DIVRING"; "RETRACT"; "QFCAT"; "FEVALAB"; "EVALAB"}*/
+/*"EFULS" -> {"IEVALAB"; "DIFEXT"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"}*/
+/*"EFULS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"}*/
+/*"EFULS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
+/*"EFULS" -> {"PFECAT"; "UTSCAT"; "NNI"; "INT"; "INS"; "CFCAT"; "PI"}*/
+/*"EFULS" -> {"OM"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
+/*"EFULS" -> {"PRIMARR"; "A1AGG-"; "ISTRING"}*/
+
+"ESCONT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESCONT"]
+/*"ESCONT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"ESCONT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"ESCONT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"ESCONT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"ESCONT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
+/*"ESCONT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
+/*"ESCONT" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"}*/
+/*"ESCONT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"ESCONT" -> {"SPFCAT"; "DFLOAT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"ESCONT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"ESCONT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "INT"}*/
+/*"ESCONT" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"ESCONT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "STRING"; "CHAR"}*/
+/*"ESCONT" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "INS"}*/
+/*"ESCONT" -> {"OINTDOM"; "LINEXP"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"}*/
+/*"ESCONT" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "CHARNZ"}*/
+/*"ESCONT" -> {"PFECAT"; "FS"; "ES"; "FRETRCT"; "GROUP"; "NNI"; "SYMBOL"}*/
+/*"ESCONT" -> {"REF"; "ALIST"; "SRAGG-"; "PI"; "VECTCAT"; "A1AGG"}*/
+"ESCONT" -> "ACFS"
+/*"ESCONT" -> {"ACF"; "COMBOPC"; "LFCAT"; "PRIMCAT"; "VECTOR"; "IVECTOR"}*/
+/*"ESCONT" -> {"IARRAY1"; "VECTCAT-"}*/
+
+"EXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXPR"]
+/*"EXPR" -> {"FS"; "ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"EXPR" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"EXPR" -> {"PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"; "ABELMON"}*/
+/*"EXPR" -> {"ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"; "LMODULE"}*/
+/*"EXPR" -> {"PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"}*/
+/*"EXPR" -> {"MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"EXPR" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
+"EXPR" -> "ACFS"
+/*"EXPR" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"EXPR" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
+/*"EXPR" -> {"SPFCAT"; "BOOLEAN"; "CACHSET"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"EXPR" -> {"PFECAT"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"EXPR" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"EXPR" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"EXPR" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
+/*"EXPR" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"}*/
+/*"EXPR" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"EXPR" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"}*/
+/*"EXPR" -> {"PI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "QFCAT"}*/
+/*"EXPR" -> {"FEVALAB"; "DIFEXT"; "DIFRING"; "STEP"; "OINTDOM"; "ORDRING"}*/
+/*"EXPR" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "UPOLYC"}*/
+/*"EXPR" -> {"INS"; "FPS"; "RNS"; "LF"}*/
+
+"EXPRSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPRSOL"]
+"EXPRSOL" -> "UTSSOL" /* by loadlib */
+/*"EXPRSOL" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
+/*"EXPRSOL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"EXPRSOL" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"EXPRSOL" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "KONVERT"}*/
+/*"EXPRSOL" -> {"FS"; "ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
+/*"EXPRSOL" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"EXPRSOL" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
+/*"EXPRSOL" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "UTSCAT"; "UPSCAT"}*/
+/*"EXPRSOL" -> {"PSCAT"; "AMR"; "ELTAB"; "DIFRING"; "RADCAT"; "TRANFUN"}*/
+/*"EXPRSOL" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SYMBOL"}*/
+/*"EXPRSOL" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"EXPRSOL" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"EXPRSOL" -> {"FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+
+"EXPR2UPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPR2UPS"]
+/*"EXPR2UPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"EXPR2UPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"EXPR2UPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"EXPR2UPS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"EXPR2UPS" -> {"RETRACT"; "LINEXP"; "ACF"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"EXPR2UPS" -> {"UFD"; "DIVRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"EXPR2UPS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FS"; "ES"; "IEVALAB"}*/
+/*"EXPR2UPS" -> {"EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
+/*"EXPR2UPS" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARZ"; "CHARNZ"}*/
+/*"EXPR2UPS" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"EXPR2UPS" -> {"OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
+"EXPR2UPS" -> "ULSCCAT"
+/*"EXPR2UPS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "ELTAB"; "QFCAT"}*/
+/*"EXPR2UPS" -> {"FEVALAB"; "DIFEXT"; "PFECAT"; "BOOLEAN"; "STRING"}*/
+/*"EXPR2UPS" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"EXPR2UPS" -> {"A1AGG-"; "ISTRING"; "NNI"; "ILIST"; "UPXSCCA"; "UPXSCAT"}*/
+
+"FACTEXT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACTEXT"]
+"FACTEXT" -> "PACEXTC"
+/*"FACTEXT" -> {"PACRATC"; "PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FACTEXT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"FACTEXT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"FACTEXT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"FACTEXT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"}*/
+/*"FACTEXT" -> {"XF"; "VSPACE"; "FPC"; "CHARNZ"; "FINITE"; "UPOLYC"}*/
+/*"FACTEXT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "FRETRCT"; "EVALAB"}*/
+/*"FACTEXT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"FACTEXT" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"FACTEXT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FACTEXT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"FACTEXT" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "NNI"}*/
+
+"FDIV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FDIV"]
+"FDIV" -> "FDIVCAT"
+/*"FDIV" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FDIV" -> {"BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"FDIV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"FDIV" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FDIV" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"FDIV" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"FDIV" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
+/*"FDIV" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"FDIV" -> {"FFCAT"; "MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
+/*"FDIV" -> {"FPC"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
+/*"FDIV" -> {"A1AGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"FDIV" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "NNI"; "PI"; "VECTCAT"}*/
+/*"FDIV" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"FDIV" -> {"ELTAGG"; "CLAGG"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"FDIV" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "QFCAT"; "FEVALAB"; "PATAB"}*/
+/*"FDIV" -> "FPATMAB"*/
+
+"FSCINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSCINT"]
+/*"FSCINT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"FSCINT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FSCINT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FSCINT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FSCINT" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
+/*"FSCINT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+"FSCINT" -> "ACFS"
+/*"FSCINT" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"FSCINT" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"FSCINT" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"FSCINT" -> {"INT"; "LIST"; "ILIST"; "COMPCAT"; "MONOGEN"; "FRAMALG"}*/
+/*"FSCINT" -> {"FINRALG"; "FINITE"; "DIFEXT"; "DIFRING"; "FFIELDC"; "FPC"}*/
+/*"FSCINT" -> {"STEP"; "FEVALAB"; "ELTAB"; "PFECAT"; "OM"; "LFCAT"}*/
+/*"FSCINT" -> {"PRIMCAT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"FSCINT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"FSCINT" -> {"FLAGG"; "ELAGG"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"FSCINT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "SYMBOL"}*/
+/*"FSCINT" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"FSCINT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+
+"FSINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSINT"]
+/*"FSINT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"FSINT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"FSINT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"FSINT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"FSINT" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
+/*"FSINT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PRIMCAT"}*/
+"FSINT" -> "ACFS"
+/*"FSINT" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"FSINT" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"FSINT" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"FSINT" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"FSINT" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"FSINT" -> {"FLAGG-"; "LNAGG-"; "NNI"; "ILIST"; "COMPCAT"; "MONOGEN"}*/
+/*"FSINT" -> {"FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"; "DIFRING"}*/
+/*"FSINT" -> {"FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"; "PFECAT"}*/
+/*"FSINT" -> {"OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"FSINT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"FSINT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
+/*"FSINT" -> {"IXAGG-"; "CLAGG-"; "CACHSET"; "BOOLEAN"}*/
+
+"FS2EXPXP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FS2EXPXP"]
+/*"FS2EXPXP" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"FS2EXPXP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"FS2EXPXP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"FS2EXPXP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"FS2EXPXP" -> {"ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"FS2EXPXP" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FS"; "ES"; "ORDSET"}*/
+/*"FS2EXPXP" -> {"RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
+/*"FS2EXPXP" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
+/*"FS2EXPXP" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "PI"; "NNI"; "INT"}*/
+/*"FS2EXPXP" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"FS2EXPXP" -> {"OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "CACHSET"}*/
+/*"FS2EXPXP" -> {"LIST"; "ILIST"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"FS2EXPXP" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"FS2EXPXP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "QFCAT"; "FEVALAB"}*/
+/*"FS2EXPXP" -> {"ELTAB"; "DIFEXT"; "PFECAT"; "UPXSCCA"; "UPXSCAT"}*/
+/*"FS2EXPXP" -> {"UPSCAT"; "PSCAT"; "AMR"}*/
+"FS2EXPXP" -> "ULSCCAT"
+/*"FS2EXPXP" -> {"ULSCAT"; "INS-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"FS2EXPXP" -> {"OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"FS2EXPXP" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
+/*"FS2EXPXP" -> {"ELAGG"; "STRICAT"; "SRAGG"; "A1AGG"}*/
+
+"GSERIES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GSERIES"]
+/*"GSERIES" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"GSERIES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"GSERIES" -> {"LMODULE"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"}*/
+/*"GSERIES" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"GSERIES" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"}*/
+/*"GSERIES" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"GSERIES" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"GSERIES" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"}*/
+/*"GSERIES" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"GSERIES" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"GSERIES" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"GSERIES" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"GSERIES" -> {"ORDSET"; "ELAGG"; "OM"; "PATMAB"; "ILIST"; "LSAGG-"}*/
+/*"GSERIES" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
+"GSERIES" -> "ACFS"
+/*"GSERIES" -> {"ACF"; "FS"; "ES"; "RETRACT"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
+/*"GSERIES" -> {"GROUP"; "FLINEXP"; "LINEXP"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"GSERIES" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"GSERIES" -> {"STEP"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"}*/
+
+"HELLFDIV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HELLFDIV"]
+"HELLFDIV" -> "FDIVCAT"
+/*"HELLFDIV" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"HELLFDIV" -> {"BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"HELLFDIV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
+/*"HELLFDIV" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"HELLFDIV" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
+/*"HELLFDIV" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"HELLFDIV" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"HELLFDIV" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
+/*"HELLFDIV" -> {"DIFEXT"; "STEP"; "FFCAT"; "MONOGEN"; "FRAMALG"; "FINRALG"}*/
+/*"HELLFDIV" -> {"FINITE"; "FFIELDC"; "FPC"; "INT"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"HELLFDIV" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"HELLFDIV" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"HELLFDIV" -> {"BOOLEAN"; "NNI"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"HELLFDIV" -> {"URAGG-"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"HELLFDIV" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"HELLFDIV" -> {"REAL"; "OM"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
+/*"HELLFDIV" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "VECTOR"}*/
+/*"HELLFDIV" -> {"IVECTOR"; "IARRAY1"; "INS"; "CFCAT"; "PI"}*/
+
+"INTDIVP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTDIVP"]
+"INTDIVP" -> "DTP"
+/*"INTDIVP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "DIVCAT"}*/
+/*"INTDIVP" -> {"INFCLCT"; "DSTRCAT"; "BLMETCT"; "PFORP"; "PARAMP"}*/
+/*"INTDIVP" -> {"PRJALGPK"; "LPARSPT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"INTDIVP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"INTDIVP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INTDIVP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"INTDIVP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
+/*"INTDIVP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"INTDIVP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"INTDIVP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"INTDIVP" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
+/*"INTDIVP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
+/*"INTDIVP" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "UPSCAT"}*/
+/*"INTDIVP" -> {"PSCAT"; "FAMONC"; "RCAGG"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"INTDIVP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"INTDIVP" -> {"ILIST"; "LSAGG-"; "BOOLEAN"; "NNI"; "OUTFORM"}*/
+
+"INVLAPLA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INVLAPLA"]
+/*"INVLAPLA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"INVLAPLA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"INVLAPLA" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"INVLAPLA" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"INVLAPLA" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
+/*"INVLAPLA" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"INVLAPLA" -> {"PRIMCAT"; "SPFCAT"}*/
+"INVLAPLA" -> "ACFS"
+/*"INVLAPLA" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"INVLAPLA" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"INVLAPLA" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"INVLAPLA" -> {"CHARNZ"; "BOOLEAN"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
+/*"INVLAPLA" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"}*/
+/*"INVLAPLA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
+/*"INVLAPLA" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
+/*"INVLAPLA" -> {"LIST"; "ILIST"; "NNI"; "CACHSET"; "PI"; "INS"; "OINTDOM"}*/
+/*"INVLAPLA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"INVLAPLA" -> {"CFCAT"; "REAL"}*/
+
+"IR2F" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IR2F"]
+/*"IR2F" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"IR2F" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"IR2F" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"IR2F" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "ORDSET"; "LINEXP"}*/
+"IR2F" -> "ACFS"
+/*"IR2F" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
+/*"IR2F" -> {"FS"; "ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"IR2F" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"IR2F" -> {"CHARZ"; "CHARNZ"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"IR2F" -> {"AHYP"; "ELEMFUN"; "INT"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
+/*"IR2F" -> {"ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"IR2F" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"}*/
+/*"IR2F" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "INS-"; "BOOLEAN"; "INS"}*/
+/*"IR2F" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"IR2F" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "NNI"; "PI"; "CACHSET"}*/
+/*"IR2F" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFEXT"}*/
+/*"IR2F" -> {"OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"IR2F" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"IR2F" -> {"FLAGG"; "ELAGG"}*/
+
+"IRRF2F" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRRF2F"]
+/*"IRRF2F" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"IRRF2F" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"IRRF2F" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"IRRF2F" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "ORDSET"}*/
+/*"IRRF2F" -> {"LINEXP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"IRRF2F" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"IRRF2F" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "FS"; "ES"; "PATAB"}*/
+/*"IRRF2F" -> {"FPATMAB"; "TYPE"; "GROUP"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"IRRF2F" -> {"DIVRING"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
+/*"IRRF2F" -> {"DIFRING"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"IRRF2F" -> {"OAMON"; "OASGP"; "REAL"}*/
+"IRRF2F" -> "ACFS"
+/*"IRRF2F" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"IRRF2F" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
+/*"IRRF2F" -> {"SPFCAT"; "INT"; "LIST"; "ILIST"}*/
+
+"LAPLACE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LAPLACE"]
+/*"LAPLACE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"LAPLACE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"LAPLACE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LAPLACE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LAPLACE" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"; "TRIGCAT"}*/
+/*"LAPLACE" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PRIMCAT"}*/
+"LAPLACE" -> "ACFS"
+/*"LAPLACE" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"LAPLACE" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"LAPLACE" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"LAPLACE" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"LAPLACE" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"LAPLACE" -> {"FLAGG-"; "LNAGG-"; "NNI"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"LAPLACE" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"LAPLACE" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"}*/
+/*"LAPLACE" -> {"BOOLEAN"; "STAGG-"; "ELAGG-"; "URAGG-"; "UPOLYC"; "POLYCAT"}*/
+/*"LAPLACE" -> {"FAMR"; "AMR"; "PFECAT"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"LAPLACE" -> {"CACHSET"; "PI"}*/
+
+"LIMITPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIMITPS"]
+/*"LIMITPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"LIMITPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"LIMITPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"LIMITPS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
+/*"LIMITPS" -> {"RETRACT"; "LINEXP"; "ACF"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"LIMITPS" -> {"UFD"; "DIVRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
+/*"LIMITPS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FS"; "ES"; "IEVALAB"; "EVALAB"}*/
+/*"LIMITPS" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
+/*"LIMITPS" -> {"GROUP"; "PDRING"; "FLINEXP"; "CHARZ"; "CHARNZ"; "LSAGG"}*/
+/*"LIMITPS" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"LIMITPS" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
+/*"LIMITPS" -> {"LIST"; "ILIST"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"LIMITPS" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"LIMITPS" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "PI"; "INS"}*/
+/*"LIMITPS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"LIMITPS" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"; "FEVALAB"}*/
+/*"LIMITPS" -> {"DIFEXT"; "PFECAT"; "UPXSCCA"; "UPXSCAT"; "UPSCAT"}*/
+/*"LIMITPS" -> {"PSCAT"; "AMR"}*/
+"LIMITPS" -> "ULSCCAT"
+/*"LIMITPS" -> {"ULSCAT"; "INS-"}*/
+
+"LODEEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LODEEF"]
+/*"LODEEF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
+/*"LODEEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"LODEEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"LODEEF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"LODEEF" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
+"LODEEF" -> "ACFS"
+/*"LODEEF" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"LODEEF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"LODEEF" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"LODEEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"LODEEF" -> {"PRIMCAT"; "LODOCAT"; "OREPCAT"; "ELTAB"; "CACHSET"}*/
+/*"LODEEF" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "NNI"; "INT"; "LSAGG"}*/
+/*"LODEEF" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"LODEEF" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
+/*"LODEEF" -> {"BOOLEAN"; "UPOLYC"; "DIFRING"; "DIFEXT"; "STEP"; "QFCAT"}*/
+/*"LODEEF" -> {"FEVALAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"LODEEF" -> {"OAMON"; "OASGP"; "REAL"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"LODEEF" -> {"FLAGG-"; "URAGG-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
+/*"LODEEF" -> {"INS"; "CFCAT"; "VECTCAT"; "A1AGG"}*/
+
+"NODE1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NODE1"]
+/*"NODE1" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
+/*"NODE1" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NODE1" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"NODE1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"NODE1" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
+"NODE1" -> "ACFS"
+/*"NODE1" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"NODE1" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"NODE1" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"NODE1" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"NODE1" -> {"PRIMCAT"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"NODE1" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"NODE1" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "CACHSET"; "ILIST"; "LSAGG"}*/
+/*"NODE1" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"NODE1" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "POLYCAT"}*/
+/*"NODE1" -> {"FAMR"; "AMR"; "PFECAT"; "NNI"; "PI"; "LSAGG-"; "STAGG-"}*/
+
+"NOTTING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NOTTING"]
+/*"NOTTING" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"} */
+/*"NOTTING" -> {"KOERCE"; "FFIELDC"; "FPC"} */
+/* "NOTTING" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"} */
+/* "NOTTING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"} */
+/* "NOTTING" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"} */
+/* "NOTTING" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"} */
+/* "NOTTING" -> {"DIFRING"; "NNI"; "INT"} */
+"NOTTING" -> "UFPS"
+
+"NTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NTSCAT"]
+"NTSCAT" -> "RSETCAT"
+/*"NTSCAT" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"NTSCAT" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"NTSCAT" -> "KONVERT"*/
+
+"ODECONST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODECONST"]
+/*"ODECONST" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
+/*"ODECONST" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ODECONST" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"ODECONST" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"ODECONST" -> {"ENTIRER"; "RETRACT"; "LINEXP"; "CHARZ"}*/
+"ODECONST" -> "ACFS"
+/*"ODECONST" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"ODECONST" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"ODECONST" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"ODECONST" -> {"CHARNZ"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
+/*"ODECONST" -> {"ELEMFUN"; "PRIMCAT"; "LODOCAT"; "OREPCAT"; "ELTAB"}*/
+/*"ODECONST" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "UPOLYC"; "POLYCAT"}*/
+/*"ODECONST" -> {"FAMR"; "AMR"; "PFECAT"; "DIFRING"; "DIFEXT"; "STEP"}*/
+/*"ODECONST" -> {"SINT"; "NNI"}*/
+
+"ODEEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEEF"]
+/*"ODEEF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
+/*"ODEEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ODEEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ODEEF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ODEEF" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
+"ODEEF" -> "ACFS"
+/*"ODEEF" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"ODEEF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"ODEEF" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"ODEEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"ODEEF" -> {"PRIMCAT"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"}*/
+/*"ODEEF" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
+/*"ODEEF" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"ODEEF" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
+/*"ODEEF" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
+/*"ODEEF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+/*"ODEEF" -> {"CACHSET"; "LSAGG-"; "STAGG-"; "ELAGG-"; "PI"; "POLYCAT"}*/
+/*"ODEEF" -> {"FAMR"; "AMR"; "PFECAT"}*/
+
+"ODEINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEINT"]
+/*"ODEINT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
+/*"ODEINT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"ODEINT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ODEINT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ODEINT" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
+"ODEINT" -> "ACFS"
+/*"ODEINT" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
+/*"ODEINT" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"ODEINT" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
+/*"ODEINT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"ODEINT" -> {"PRIMCAT"; "INT"; "LIST"; "ILIST"; "INS"; "OINTDOM"}*/
+/*"ODEINT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
+/*"ODEINT" -> {"CFCAT"; "REAL"; "STEP"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"ODEINT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
+/*"ODEINT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"}*/
+/*"ODEINT" -> {"ELAGG-"; "CACHSET"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"ODEINT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"ODEINT" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
+
+"QCMPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QCMPACK"]
+/*"QCMPACK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"QCMPACK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"QCMPACK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"QCMPACK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
+/*"QCMPACK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
+/*"QCMPACK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"QCMPACK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"QCMPACK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
+"QCMPACK" -> "RSETCAT"
+/*"QCMPACK" -> {"TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"QCMPACK" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"}*/
+/*"QCMPACK" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"QCMPACK" -> {"ELTAB"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "FLAGG-"}*/
+/*"QCMPACK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"QCMPACK" -> {"ISTRING"; "NNI"; "BOOLEAN"; "URAGG-"; "LNAGG-"}*/
+/*"QCMPACK" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+
+"REGSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=REGSET"]
+"REGSET" -> "RSETCAT"
+/*"REGSET" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"REGSET" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"REGSET" -> {"KONVERT"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"REGSET" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"REGSET" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"REGSET" -> {"ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"REGSET" -> {"RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"REGSET" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+/*"REGSET" -> {"PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"REGSET" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"REGSET" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
+/*"REGSET" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "BOOLEAN"; "INS-"}*/
+/*"REGSET" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
+/*"REGSET" -> {"BASTYPE-"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
+/*"REGSET" -> {"A1AGG-"; "ISTRING"; "NNI"; "FINITE"}*/
+
+"REP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REP"]
+/*"REP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"REP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"REP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"REP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
+/*"REP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"REP" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
+/*"REP" -> {"REAL"; "CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"REP" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
+/*"REP" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
+/*"REP" -> {"PATAB"; "FPATMAB"; "TYPE"; "FS"; "ES"; "GROUP"; "OM"; "NNI"}*/
+/*"REP" -> {"INT"; "SINT"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"REP" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"REP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
+"REP" -> "ACFS"
+/*"REP" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"REP" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "LFCAT"; "PRIMCAT"; "SPFCAT"}*/
+/*"REP" -> {"ILIST"; "MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "PI"; "LSAGG"}*/
+/*"REP" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"REP" -> {"FLAGG"; "ELAGG"}*/
+
+"RGCHAIN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RGCHAIN"]
+"RGCHAIN" -> "RSETCAT"
+/*"RGCHAIN" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RGCHAIN" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"RGCHAIN" -> {"KONVERT"; "ORDFIN"; "ORDSET"; "FINITE"; "GCDDOM"; "INTDOM"}*/
+/*"RGCHAIN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"RGCHAIN" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RGCHAIN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RPOLCAT"}*/
+/*"RGCHAIN" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"RGCHAIN" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
+/*"RGCHAIN" -> {"PFECAT"; "UFD"}*/
+
+"RSDCMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RSDCMPK"]
+/*"RSDCMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"RSDCMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"RSDCMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RSDCMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
+/*"RSDCMPK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
+/*"RSDCMPK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"RSDCMPK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"RSDCMPK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
+"RSDCMPK" -> "RSETCAT"
+/*"RSDCMPK" -> {"TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"RSDCMPK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
+/*"RSDCMPK" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"RSDCMPK" -> {"ILIST"; "LSAGG-"; "NNI"; "STAGG-"; "ELAGG-"; "BOOLEAN"}*/
+/*"RSDCMPK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"RSDCMPK" -> {"ISTRING"; "FLAGG-"}*/
+
+"SFRTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SFRTCAT"]
+"SFRTCAT" -> "RSETCAT"
+/*"SFRTCAT" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SFRTCAT" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"SFRTCAT" -> "KONVERT"*/
+
+"SOLVERAD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVERAD"]
+/*"SOLVERAD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"SOLVERAD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"SOLVERAD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"SOLVERAD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"SOLVERAD" -> {"ORDSET"; "CHARZ"; "BOOLEAN"; "FS"; "ES"; "RETRACT"}*/
+/*"SOLVERAD" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
+/*"SOLVERAD" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"SOLVERAD" -> {"LINEXP"; "CHARNZ"; "FIELD"; "UFD"; "DIVRING"}*/
+"SOLVERAD" -> "ACFS"
+/*"SOLVERAD" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"SOLVERAD" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
+/*"SOLVERAD" -> {"SPFCAT"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"}*/
+/*"SOLVERAD" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"SOLVERAD" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "POLYCAT"}*/
+/*"SOLVERAD" -> {"FAMR"; "AMR"; "PFECAT"; "NNI"; "ILIST"; "LSAGG-"}*/
+/*"SOLVERAD" -> {"STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"SOLVERAD" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
+/*"SOLVERAD" -> {"FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "PI"}*/
+
+"SULS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SULS"]
+/*"SULS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SULS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+"SULS" -> "ULSCCAT"
+/*"SULS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"SULS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"SULS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
+/*"SULS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"}*/
+/*"SULS" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"SULS" -> {"QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"}*/
+/*"SULS" -> {"LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
+/*"SULS" -> {"STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"SULS" -> {"OAMON"; "OASGP"; "REAL"; "PFECAT"; "INT"; "NNI"; "BOOLEAN"}*/
+/*"SULS" -> {"POLYCAT"; "FAMR"; "FRETRCT"; "INS"; "CFCAT"; "UTSCAT"}*/
+/*"SULS" -> {"OAMONS"; "FPS"; "RNS"; "UPOLYC"; "OM"}*/
+
+"SUPXS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUPXS"]
+/*"SUPXS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"SUPXS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"SUPXS" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"}*/
+/*"SUPXS" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"SUPXS" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"}*/
+/*"SUPXS" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"SUPXS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
+/*"SUPXS" -> "RETRACT"*/
+"SUPXS" -> "ULSCCAT"
+/*"SUPXS" -> {"ULSCAT"; "QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"SUPXS" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"SUPXS" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"SUPXS" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "PFECAT"; "INS"; "CFCAT"}*/
+/*"SUPXS" -> {"INT"; "NNI"; "OM"}*/
+
+"UFPS1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UFPS1"]
+"UFPS1" -> "UFPS" /* imported by macro */
+/*"UFPS1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UFPS1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"UFPS1" -> "LMODULE"*/
+
+"ULS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ULS"]
+/*"ULS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"ULS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+"ULS" -> "ULSCCAT"
+/*"ULS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"ULS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"ULS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
+/*"ULS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"}*/
+/*"ULS" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
+/*"ULS" -> {"QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"}*/
+/*"ULS" -> {"LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
+/*"ULS" -> {"STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
+/*"ULS" -> {"OAMON"; "OASGP"; "REAL"; "PFECAT"; "INT"; "UTSCAT"; "OAMONS"}*/
+/*"ULS" -> {"FPS"; "RNS"; "INS"; "CFCAT"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
+/*"ULS" -> {"FRETRCT"; "OM"}*/
+
+"ULSCONS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ULSCONS"]
+"ULSCONS" -> "ULSCCAT"
+/*"ULSCONS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"}*/
+/*"ULSCONS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"ULSCONS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ULSCONS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"ULSCONS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
+/*"ULSCONS" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"ULSCONS" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"ULSCONS" -> {"UFD"; "DIVRING"; "RETRACT"; "QFCAT"; "FEVALAB"; "EVALAB"}*/
+/*"ULSCONS" -> {"IEVALAB"; "DIFEXT"; "FLINEXP"; "LINEXP"; "PATAB"}*/
+/*"ULSCONS" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
+/*"ULSCONS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"ULSCONS" -> {"OASGP"; "REAL"; "PFECAT"; "UTSCAT"; "INT"; "NNI"; "BOOLEAN"}*/
+/*"ULSCONS" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"ULSCONS" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"ULSCONS" -> {"OAMONS"; "POLYCAT"; "FAMR"; "FRETRCT"; "ABELMON-"}*/
+/*"ULSCONS" -> {"SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"ULSCONS" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"ULSCONS" -> {"FLAGG-"; "LNAGG-"; "INS"; "CFCAT"; "LSAGG"; "STAGG"}*/
+/*"ULSCONS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"ULSCONS" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"}*/
+/*"ULSCONS" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
+"ULSCONS" -> "ACFS"
+/*"ULSCONS" -> {"ACF"; "FS"; "ES"; "GROUP"; "FPS"; "RNS"; "UPOLYC"}*/
+
+"UPXS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXS"]
+/*"UPXS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UPXS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UPXS" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"}*/
+/*"UPXS" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
+/*"UPXS" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"}*/
+/*"UPXS" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
+/*"UPXS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
+"UPXS" -> "ULSCCAT"
+/*"UPXS" -> {"ULSCAT"; "QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
+/*"UPXS" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"UPXS" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"UPXS" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "PFECAT"; "INS"; "CFCAT"}*/
+/*"UPXS" -> {"INT"; "INS-"; "NNI"; "PI"}*/
+/*"UPXS" -> "BOOLEAN"*/
+/*"UPXS" -> {"LIST"; "ILIST"; "SINT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"UPXS" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
+/*"UPXS" -> {"ELAGG"; "OM"; "LSAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
+/*"UPXS" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"UPXS" -> {"FLAGG-"; "LNAGG-"}*/
+
+"UPXSCONS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXSCONS"]
+/*"UPXSCONS" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"}*/
+/*"UPXSCONS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"UPXSCONS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UPXSCONS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
+/*"UPXSCONS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
+/*"UPXSCONS" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
+/*"UPXSCONS" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"UPXSCONS" -> {"UFD"; "DIVRING"; "RETRACT"; "ULSCAT"; "INS"; "OINTDOM"}*/
+/*"UPXSCONS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"UPXSCONS" -> {"KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
+/*"UPXSCONS" -> {"OM"; "INT"; "NNI"; "PI"; "INS-"; "EUCDOM-"; "UFD-"}*/
+/*"UPXSCONS" -> {"GCDDOM-"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"}*/
+/*"UPXSCONS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"UPXSCONS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"UPXSCONS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"UPXSCONS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"UPXSCONS" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+/*"UPXSCONS" -> {"RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
+"UPXSCONS" -> "ACFS"
+/*"UPXSCONS" -> {"ACF"; "FS"; "ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"}*/
+/*"UPXSCONS" -> {"FLINEXP"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"}*/
+
+"UTS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTS"]
+/*"UTS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"UTS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"UTS" -> {"UTSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
+/*"UTS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"UTS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
+/*"UTS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"}*/
+/*"UTS" -> {"BOOLEAN"; "SINT"; "PI"; "SYMBOL"; "REF"; "ALIST"; "LIST"}*/
+/*"UTS" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"UTS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"UTS" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"UTS" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "RETRACT"}*/
+/*"UTS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "QFCAT"}*/
+/*"UTS" -> {"FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"; "PATAB"}*/
+/*"UTS" -> {"FPATMAB"; "TYPE"; "PFECAT"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"UTS" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"UTS" -> {"FLAGG"; "ELAGG"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"UTS" -> {"URAGG-"; "RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
+"UTS" -> "ACFS"
+/*"UTS" -> {"ACF"; "FS"; "ES"; "FRETRCT"; "GROUP"; "OAMONS"}*/
+
+"UTSZ" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTSZ"]
+/*"UTSZ" -> {"UTSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"}*/
+/*"UTSZ" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"UTSZ" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"UTSZ" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
+/*"UTSZ" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
+/*"UTSZ" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"}*/
+/*"UTSZ" -> {"BOOLEAN"; "SINT"; "PI"; "SYMBOL"; "REF"; "ALIST"; "LIST"}*/
+/*"UTSZ" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
+/*"UTSZ" -> {"SRAGG"; "FLAGG-"; "LNAGG-"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"UTSZ" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"UTSZ" -> {"OCAMON.o"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "RETRACT"}*/
+/*"UTSZ" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "QFCAT"; "FEVALAB"}*/
+/*"UTSZ" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
+/*"UTSZ" -> {"TYPE"; "PFECAT"; "OM"; "PRIMCAT"}*/
+"UTSZ" -> "ACFS"
+/*"UTSZ" -> {"ACF"; "FS"; "ES"; "FRETRCT"; "GROUP"; "ILIST"; "OAMONS"}*/
+
+\end{chunk}
+\subsection{Layer19}
+Depends on: EXPRSOL SFRTCAT FACTEXT INTDIVP DTP\\
+Next layer depends on: RECOP
+\begin{chunk}{layer19}
+
+LAYER19=\
+  ${OUT}/GPAFF.o    \
+  ${OUT}/IRURPK.o   ${OUT}/LAZM3PK.o  ${OUT}/LEXTRIPK.o ${OUT}/NORMPK.o  \
+  ${OUT}/PACEXT.o   \
+  ${OUT}/RECOP.o    ${OUT}/RURPK.o    ${OUT}/SFRGCD.o   ${OUT}/SFQCMPK.o \
+  ${OUT}/SNTSCAT.o  ${OUT}/SRDCMPK.o  ${OUT}/SREGSET.o  ${OUT}/ZDSOLVE.o \
+  layer19done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 19 */
+/* EXPRSOL SFRTCAT */
+
+"GPAFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GPAFF"]
+"GPAFF" -> "INTDIVP"
+"GPAFF" -> "DTP"
+/*"GPAFF" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "DIVCAT"}*/
+/*"GPAFF" -> {"INFCLCT"; "DSTRCAT"; "BLMETCT"; "PACFFC"; "PACPERC"}*/
+/*"GPAFF" -> {"PFORP"; "PLPKCRV"; "INTFRSP"; "PRJALGPK"; "PARAMP"; "LPARSPT"}*/
+/*"GPAFF" -> {"UTSZ"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"GPAFF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"GPAFF" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"GPAFF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"GPAFF" -> {"ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"GPAFF" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"GPAFF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+/*"GPAFF" -> {"PFECAT"; "DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"GPAFF" -> {"ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
+/*"GPAFF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
+/*"GPAFF" -> {"UPSCAT"; "PSCAT"; "FAMONC"; "RCAGG"; "BOOLEAN"; "INT"}*/
+/*"GPAFF" -> {"LIST"; "ILIST"; "INS"; "OINTDOM"; "CFCAT"; "REAL"; "STEP"}*/
+/*"GPAFF" -> {"LSAGG"; "STAGG"; "URAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
+/*"GPAFF" -> {"OM"; "NNI"; "LSAGG-"; "STAGG-"; "ORDFIN"; "LOGIC"; "ELAGG-"}*/
+/*"GPAFF" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+/*"GPAFF" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"GPAFF" -> {"PI"; "FFIELDC"; "FPC"; "MONOID-"; "ABELMON-"; "SGROUP-"}*/
+/*"GPAFF" -> {"ABELSG-"; "SINT"; "OUTFORM"}*/
+
+"IRURPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRURPK"]
+/*"IRURPK" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"IRURPK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"IRURPK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"IRURPK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"IRURPK" -> {"CHARZ"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"IRURPK" -> {"RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
+/*"IRURPK" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"IRURPK" -> {"LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
+"IRURPK" -> "SFRTCAT"
+/*"IRURPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"}*/
+/*"IRURPK" -> {"TYPE"; "NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"IRURPK" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"IRURPK" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
+/*"IRURPK" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "BOOLEAN"}*/
+
+"LAZM3PK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LAZM3PK"]
+/*"LAZM3PK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"LAZM3PK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"LAZM3PK" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"LAZM3PK" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"LAZM3PK" -> {"OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"LAZM3PK" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"LAZM3PK" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"LAZM3PK" -> {"PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"}*/
+/*"LAZM3PK" -> {"HOAGG"; "AGG"; "TYPE"}*/
+"LAZM3PK" -> "SFRTCAT"
+/*"LAZM3PK" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"LAZM3PK" -> {"FLAGG-"; "BOOLEAN"}*/
+
+"LEXTRIPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LEXTRIPK"]
+/*"LEXTRIPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"LEXTRIPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"LEXTRIPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"LEXTRIPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDFIN"}*/
+/*"LEXTRIPK" -> {"ORDSET"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"LEXTRIPK" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"LEXTRIPK" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"LEXTRIPK" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"LEXTRIPK" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"LEXTRIPK" -> "IXAGG-"; "CLAGG-"; "BOOLEAN"}*/
+"LEXTRIPK" -> "SFRTCAT"
+/*"LEXTRIPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"}*/
+
+"NORMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NORMPK"]
+/*"NORMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"NORMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"NORMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"NORMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"}*/
+/*"NORMPK" -> {"OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"}*/
+/*"NORMPK" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"NORMPK" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"NORMPK" -> {"PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"}*/
+/*"NORMPK" -> {"HOAGG"; "AGG"; "TYPE"}*/
+"NORMPK" -> "SFRTCAT"
+/*"NORMPK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
+/*"NORMPK" -> {"A1AGG-"; "ISTRING"; "NNI"; "BOOLEAN"; "ILIST"}*/
+/*"NORMPK" -> {"LSAGG-"; "STAGG-"}*/
+
+"PACEXT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PACEXT"]
+/*"PACEXT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PACEXT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PACEXT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PACEXT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"PACEXT" -> {"DIVRING"; "CHARZ"; "RETRACT"; "XF"; "VSPACE"; "FPC"}*/
+/*"PACEXT" -> {"CHARNZ"; "FINITE"; "PI"; "NNI"; "INT"; "LIST"; "ILIST"}*/
+/*"PACEXT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
+/*"PACEXT" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
+/*"PACEXT" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"PACEXT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"PACEXT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"PACEXT" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "VECTOR"; "IVECTOR"}*/
+/*"PACEXT" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "UPOLYC"; "POLYCAT"}*/
+/*"PACEXT" -> {"PDRING"; "FAMR"; "AMR"; "FRETRCT"; "FLINEXP"; "LINEXP"}*/
+/*"PACEXT" -> {"PATMAB"; "PFECAT"; "DIFRING"; "DIFEXT"; "STEP"; "SYMBOL"}*/
+/*"PACEXT" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"PACEXT" -> {"PRIMARR"; "ISTRING"; "SRAGG-"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"PACEXT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
+/*"PACEXT" -> {"BOOLEAN"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "PACPERC"}*/
+/*"PACEXT" -> {"PACRATC"; "PACRAT"}*/
+"PACEXT" -> "FACTEXT"
+
+"RECOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RECOP"]
+"RECOP" -> "EXPRSOL"     /* by loadlib */
+/*"RECOP" -> {"UFPS"; "UTSSOL"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"RECOP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"RECOP" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"RECOP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "KONVERT"; "FS"}*/
+/*"RECOP" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"}*/
+/*"RECOP" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"RECOP" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"RECOP" -> {"GCDDOM"; "UFD"; "DIVRING"; "COMBOPC"; "CFCAT"; "SYMBOL"}*/
+/*"RECOP" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"RECOP" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
+/*"RECOP" -> {"LNAGG-"; "PI"; "NNI"; "ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"}*/
+/*"RECOP" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
+/*"RECOP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"}*/
+/*"RECOP" -> {"URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "MONOID-"; "ABELMON-"}*/
+/*"RECOP" -> {"ORDSET-"; "SGROUP-"; "ABELSG-"; "SETCAT-"; "BASTYPE-"}*/
+/*"RECOP" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "DIFRING"}*/
+/*"RECOP" -> {"DIFEXT"; "STEP"; "BOOLEAN"; "CACHSET"; "INS-"}*/
+
+"RURPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RURPK"]
+/*"RURPK" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"RURPK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"RURPK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"RURPK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
+/*"RURPK" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
+/*"RURPK" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"RURPK" -> {"FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
+/*"RURPK" -> {"ORDFIN"; "ORDSET"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"RURPK" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+/*"RURPK" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
+/*"RURPK" -> {"FLAGG"; "ELAGG"; "OM"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
+/*"RURPK" -> {"CLAGG-"; "BOOLEAN"}*/
+"RURPK" -> "SFRTCAT"
+/*"RURPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"}*/
+
+"SFRGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SFRGCD"]
+/*"SFRGCD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SFRGCD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"SFRGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
+/*"SFRGCD" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
+/*"SFRGCD" -> {"OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"SFRGCD" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
+/*"SFRGCD" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
+/*"SFRGCD" -> {"PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"}*/
+/*"SFRGCD" -> {"HOAGG"; "AGG"; "TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"SFRGCD" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"}*/
+/*"SFRGCD" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"SFRGCD" -> {"INS-"; "NNI"; "ELAGG-"; "FLAGG-"; "OM"}*/
+"SFRGCD" -> "SFRTCAT"
+
+"SFQCMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SFQCMPK"]
+/*"SFQCMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SFQCMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SFQCMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"SFQCMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
+/*"SFQCMPK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
+/*"SFQCMPK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"SFQCMPK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"SFQCMPK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"}*/
+/*"SFQCMPK" -> {"PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "INT"; "LIST"}*/
+/*"SFQCMPK" -> {"ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
+/*"SFQCMPK" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"}*/
+/*"SFQCMPK" -> {"ELAGG"; "OM"; "ELAGG-"; "FLAGG-"; "STRING"; "CHAR"; "SINT"}*/
+/*"SFQCMPK" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "NNI"; "BOOLEAN"}*/
+"SFQCMPK" -> "SFRTCAT"
+/*"SFQCMPK" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
+
+"SNTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SNTSCAT"]
+"SNTSCAT" -> "SFRTCAT"
+/*"SNTSCAT" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"}*/
+/*"SNTSCAT" -> {"KOERCE"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"SNTSCAT" -> {"IEVALAB"; "KONVERT"; "NTSCAT"}*/
+
+"SRDCMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SRDCMPK"]
+/*"SRDCMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"SRDCMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
+/*"SRDCMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"SRDCMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
+/*"SRDCMPK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
+/*"SRDCMPK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
+/*"SRDCMPK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
+/*"SRDCMPK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
+"SRDCMPK" -> "SFRTCAT"
+/*"SRDCMPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"}*/
+/*"SRDCMPK" -> {"TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"SRDCMPK" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
+/*"SRDCMPK" -> {"LIST"; "ILIST"; "LSAGG-"; "NNI"; "STAGG-"; "ELAGG-"}*/
+/*"SRDCMPK" -> {"BOOLEAN"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
+/*"SRDCMPK" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "FLAGG-"}*/
+
+"SREGSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SREGSET"]
+"SREGSET" -> "SFRTCAT"
+/*"SREGSET" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"}*/
+/*"SREGSET" -> {"KOERCE"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
+/*"SREGSET" -> {"IEVALAB"; "KONVERT"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"SREGSET" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"SREGSET" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"SREGSET" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"SREGSET" -> {"ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
+/*"SREGSET" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
+/*"SREGSET" -> {"PATMAB"; "PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"SREGSET" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"SREGSET" -> {"IXAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"SREGSET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
+/*"SREGSET" -> {"BOOLEAN"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"SREGSET" -> {"SETCAT-"; "BASTYPE-"; "NNI"; "MONOID-"; "ABELMON-"}*/
+/*"SREGSET" -> "SGROUP-"; "ABELSG-"; "INS-"; "STRING"; "CHAR"; "SINT"}*/
+/*"SREGSET" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "FINITE"}*/
+
+"ZDSOLVE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ZDSOLVE"]
+/*"ZDSOLVE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"ZDSOLVE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
+/*"ZDSOLVE" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"ZDSOLVE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
+/*"ZDSOLVE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "REAL"}*/
+/*"ZDSOLVE" -> {"KONVERT"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
+/*"ZDSOLVE" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "ORDFIN"; "FINITE"; "BOOLEAN"}*/
+/*"ZDSOLVE" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"}*/
+/*"ZDSOLVE" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
+"ZDSOLVE" -> "SFRTCAT"
+/*"ZDSOLVE" -> {"QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
+/*"ZDSOLVE" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"ZDSOLVE" -> {"PATAB"; "FPATMAB"; "PATMAB"; "STEP"; "OINTDOM"; "CHARNZ"}*/
+/*"ZDSOLVE" -> {"PFECAT"; "RCFIELD"; "FRETRCT"; "RADCAT"; "LSAGG"; "STAGG"}*/
+/*"ZDSOLVE" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "FLAGG"}*/
+/*"ZDSOLVE" -> {"ELAGG"; "OM"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"*/
+
+\end{chunk}
+\subsection{Layer20}
+Depends on: RECOP
+Next layer depends on: GUESS
+\begin{chunk}{layer20}
+
+LAYER20=\
+  ${OUT}/GUESS.o ${OUT}/INFCLSPT.o \
+  layer20done
+    
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 20 */
+
+"GUESS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESS"]
+/*"GUESS" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/ 
+/*"GUESS" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"}*/ 
+"GUESS" -> "RECOP"  /* by loadlib */
+/*"GUESS" -> {"UFPS1"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
+/*"GUESS" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
+/*"GUESS" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"GUESS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"GUESS" -> {"ENTIRER"; "UFD"; "DIVRING"; "FS"; "ES"; "ORDSET"; "RETRACT"}*/
+/*"GUESS" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
+/*"GUESS" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "LINEXP"}*/
+/*"GUESS" -> {"CHARZ"; "CHARNZ"; "COMBOPC"; "CFCAT"; "LSAGG"; "STAGG"}*/
+/*"GUESS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"GUESS" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
+/*"GUESS" -> {"ILIST"; "PI"; "NNI"; "LSAGG-"; "STAGG-"; "SINT"; "INS-"}*/
+/*"GUESS" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
+/*"GUESS" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
+/*"GUESS" -> {"ABELMON-"; "QFCAT"; "FEVALAB"; "DIFEXT"; "DIFRING"; "STEP"}*/
+/*"GUESS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"GUESS" -> {"REAL"; "PFECAT"; "ORDFIN"; "FINITE"; "POLYCAT"; "FAMR"}*/
+/*"GUESS" -> {"AMR"; "UPOLYC"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
+/*"GUESS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
+/*"GUESS" -> {"UTSCAT"; "UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
+/*"GUESS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INS"; "VECTOR"}*/
+/*"GUESS" -> {"BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "LNAGG-"; "MONOID-"}*/
+/*"GUESS" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "SETCAT-"; "RETRACT-"}*/
+/*"GUESS" -> {"BASTYPE-"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "IXAGG-"}*/
+/*"GUESS" -> {"RCAGG-"; "CLAGG-"}*/
+
+"INFCLSPT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INFCLSPT"]
+"INFCLSPT" -> "INFCLCT"
+/*"INFCLSPT" -> {"SETCATD"; "AFFPL"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
+/*"INFCLSPT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"INFCLSPT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
+/*"INFCLSPT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"INFCLSPT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"}*/
+/*"INFCLSPT" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
+/*"INFCLSPT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
+/*"INFCLSPT" -> {"KONVERT"; "PATMAB"; "PFECAT"; "DIRPCAT"; "IXAGG"; "HOAGG"}*/
+/*"INFCLSPT" -> {"AGG"; "TYPE"; "ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"}*/
+/*"INFCLSPT" -> {"FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"INFCLSPT" -> {"OAMONS"; "VSPACE"; "PRSPCAT"; "LOCPOWC"; "UPSCAT"; "PSCAT"}*/
+/*"INFCLSPT" -> {"PLACESC"; "DIVCAT"; "FAMONC"; "BLMETCT"; "SINT"; "NNI"}*/
+/*"INFCLSPT" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
+/*"INFCLSPT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"}*/
+/*"INFCLSPT" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
+/*"INFCLSPT" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
+/*"INFCLSPT" -> {"SETCAT-"; "BASTYPE-"; "BOOLEAN"; "VECTOR"; "PACPERC"; "PI"}*/
+/*"INFCLSPT" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
+/*"INFCLSPT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+
+\end{chunk}
+\subsection{Layer21}
+Depends on: GUESS
+Next layer depends on: GUESSF1 INFCLSPT 
+\begin{chunk}{layer21}
+
+LAYER21=\
+  ${OUT}/GUESSAN.o  ${OUT}/GUESSINT.o ${OUT}/GUESSF1.o  ${OUT}/GUESSP.o \
+  ${OUT}/GUESSUP.o  ${OUT}/ICP.o      \
+  layer21done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 21 */
+/* GUESS */
+
+"GUESSAN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSAN"]
+/*"GUESSAN" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/
+/*"GUESSAN" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
+"GUESSAN" -> "GUESS" /* by loadlib */
+/*"GUESSAN" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
+/*"GUESSAN" -> {"IEVALAB"; "EVALAB"; "ACF"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"GUESSAN" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"GUESSAN" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"GUESSAN" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"GUESSAN" -> {"DIVRING"; "RADCAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
+/*"GUESSAN" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "LINEXP"}*/
+/*"GUESSAN" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FS"; "PATAB"}*/
+/*"GUESSAN" -> {"FPATMAB"; "TYPE"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
+/*"GUESSAN" -> {"CHARNZ"; "OM"}*/
+
+"GUESSINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSINT"]
+/*"GUESSINT" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/ 
+/*"GUESSINT" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
+"GUESSINT" -> "GUESS" /* by loadlib */
+/*"GUESSINT" -> {"INS"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"GUESSINT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"GUESSINT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
+/*"GUESSINT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"GUESSINT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
+/*"GUESSINT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
+/*"GUESSINT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"GUESSINT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"}*/
+/*"GUESSINT" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
+/*"GUESSINT" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"}*/
+/*"GUESSINT" -> {"CHARNZ"; "PFECAT"; "FS"; "ES"; "FRETRCT"; "GROUP"; "OM"}*/
+
+"GUESSF1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSF1"]
+/*"GUESSF1" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/ 
+/*"GUESSF1" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
+"GUESSF1" -> "GUESS" /* by loadlib */
+/*"GUESSF1" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
+/*"GUESSF1" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
+/*"GUESSF1" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
+/*"GUESSF1" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
+/*"GUESSF1" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
+/*"GUESSF1" -> {"STEP"; "DIFRING"; "KONVERT"; "INS"; "OINTDOM"; "ORDRING"}*/
+/*"GUESSF1" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RETRACT"}*/
+/*"GUESSF1" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
+
+"GUESSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSP"]
+/*"GUESSP" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"} */ 
+/*"GUESSP" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
+"GUESSP" -> "GUESS" /* by loadlib */
+/*"GUESSP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
+/*"GUESSP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
+/*"GUESSP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
+/*"GUESSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
+/*"GUESSP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
+/*"GUESSP" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
+/*"GUESSP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"GUESSP" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"GUESSP" -> {"PFECAT"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
+/*"GUESSP" -> {"DIFEXT"; "PATAB"; "FPATMAB"; "TYPE"; "FS"; "ES"}*/
+/*"GUESSP" -> {"GROUP"; "OM"}*/
+
+"GUESSUP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSUP"]
+/*"GUESSUP" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"} */  
+/*"GUESSUP" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"} */ 
+"GUESSUP" -> "GUESS" 
+/*"GUESSUP" -> {"MYEXPR"; "MYUP"; "INS"; "UFD"; "GCDDOM"; "INTDOM"} */
+/*"GUESSUP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"} */
+/*"GUESSUP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"} */
+/*"GUESSUP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"} */
+/*"GUESSUP" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"} */
+/*"GUESSUP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"} */
+/*"GUESSUP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
+/*"GUESSUP" -> {"CHARZ"; "STEP"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
+/*"GUESSUP" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
+/*"GUESSUP" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"; "QFCAT"}*/
+/*"GUESSUP" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "FS"; "ES"}*/
+/*"GUESSUP" -> {"GROUP"; "COMBOPC"}*/
+
+"ICP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ICP"]
+/*"ICP" -> {"DIVCAT"; "PROJPL"; "NSDPS"; "DIV"}*/
+"ICP" -> "PLACES"
+"ICP" -> "INFCLSPT"
+/*"ICP" -> {"INFCLCT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
+/*"ICP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
+/*"ICP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"ICP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
+/*"ICP" -> {"UFD"; "DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"ICP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
+/*"ICP" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
+/*"ICP" -> {"INT"; "LIST"; "ILIST"; "DIRPCAT"; "FRETRCT"; "RETRACT"}*/
+/*"ICP" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"}*/
+/*"ICP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"}*/
+/*"ICP" -> {"VSPACE"; "PLACESC"; "BLMETCT"; "SYMBOL"; "REF"; "ALIST"}*/
+/*"ICP" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
+/*"ICP" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"}*/
+/*"ICP" -> {"ELAGG-"; "URAGG-"}*/
+
+\end{chunk}
+\subsection{Layer22}
+Depends on: GUESSF1
+\begin{chunk}{layer22}
+
+LAYER22=\
+  ${OUT}/GUESSF.o ${OUT}/INFCLSPS.o  \
+  layer22done
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 22 */
+/* GUESSF */
+
+"GUESSF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSF"]
+/*"GUESSF" -> { "NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR" ; "UTSSOL" } */
+/*"GUESSF" -> { "EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1" } */
+/*"GUESSF" -> "GUESS"*/ /* by loadlib */
+"GUESSF" -> "GUESSF1" /* by loadlib */
+/*"GUESSF" -> { "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM" } */
+/*"GUESSF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"} */
+/*"GUESSF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"} */
+/*"GUESSF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"} */
+/*"GUESSF" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"} */
+/*"GUESSF" -> {"STEP"; "DIFRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"} */
+/*"GUESSF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "RETRACT"} */
+/*"GUESSF" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "FS"; "ES" } */
+/*"GUESSF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "FRETRCT"} */
+/*"GUESSF" -> {"GROUP"; "PDRING"; "FLINEXP"} */
+
+"INFCLSPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INFCLSPS"]
+"INFCLSPS" -> "PROJPLPS"
+/*"INFCLSPS" -> {"PACOFF"; "NSDPS"; "PLACESPS"; "DIV"; "DIVCAT"; "INFCLCT"}*/
+/*"INFCLSPS" -> {"INFCLSPT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
+/*"INFCLSPS" -> {"PACFFC"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
+/*"INFCLSPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
+/*"INFCLSPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
+/*"INFCLSPS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
+/*"INFCLSPS" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
+/*"INFCLSPS" -> {"DIFRING"; "PACPERC"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
+/*"INFCLSPS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
+/*"INFCLSPS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
+/*"INFCLSPS" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "DIRPCAT"}*/
+/*"INFCLSPS" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "PDRING"; "FLINEXP"}*/
+/*"INFCLSPS" -> {"LINEXP"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"INFCLSPS" -> {"OASGP"; "OAMONS"; "VSPACE"; "PLACESC"; "BLMETCT"}*/
+/*"INFCLSPS" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
+/*"INFCLSPS" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
+/*"INFCLSPS" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
+
+\end{chunk}
+\subsection{Layer23}
+Depends on: INFCLSPS
+
+Note that PAFF and PAFFFF form clique2.spad. Each one depends on the other.
+\begin{chunk}{layer23}
+
+LAYER23=\
+  ${MID}/clique2.spad \
+  layer23done
+
+\end{chunk}
+\begin{chunk}{layerpic}
+/* layer 23 */
+
+"PAFF" -> "PAFFFF"
+"PAFF" -> "INFCLSPS"
+/*"PAFF" -> {"BLMETCT"; "GPAFF"; "PFORP"; "PACOFF"; "PROJPLPS"; "PLACESPS"}*/
+/*"PAFF" -> {"NSDPS"; "LOCPOWC"; "DIV"; "SETCATD"; "PLACESC"; "DIVCAT"}*/
+/*"PAFF" -> {"INFCLCT"; "DSTREE"; "DSTRCAT"; "PRSPCAT"; "UTSZ"; "PACFFC"}*/
+/*"PAFF" -> {"PACPERC"; "PROJPL"; "PLACES"; "INFCLSPT"; "PROJPL"; "ICP"}*/
+/*"PAFF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PAFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PAFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PAFF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"PAFF" -> {"DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"PAFF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PAFF" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"PAFF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PAFF" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"PAFF" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "DIRPCAT"; "DIFEXT"}*/
+/*"PAFF" -> {"DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PAFF" -> {"OASGP"; "OAMONS"; "VSPACE"; "INS"; "OINTDOM"; "CFCAT"; "REAL"}*/
+/*"PAFF" -> {"STEP"; "PI"; "NNI"; "BOOLEAN"}*/
+
+"PAFFFF" -> "PAFF"
+"PAFF" -> "INFCLSPS"
+/*"PAFF" -> {"BLMETCT"; "GPAFF"; "PFORP"; "PACOFF"; "PROJPLPS"; "PLACESPS"}*/
+/*"PAFF" -> {"NSDPS"; "LOCPOWC"; "DIV"; "SETCATD"; "PLACESC"; "DIVCAT"}*/
+/*"PAFF" -> {"INFCLCT"; "DSTREE"; "DSTRCAT"; "PRSPCAT"; "UTSZ"; "PACFFC"}*/
+/*"PAFF" -> {"PACPERC"; "PROJPL"; "PLACES"; "INFCLSPT"; "PROJPL"; "ICP"}*/
+/*"PAFF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
+/*"PAFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"PAFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
+/*"PAFF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
+/*"PAFF" -> {"DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
+/*"PAFF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
+/*"PAFF" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
+/*"PAFF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
+/*"PAFF" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
+/*"PAFF" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "DIRPCAT"; "DIFEXT"}*/
+/*"PAFF" -> {"DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
+/*"PAFF" -> {"OASGP"; "OAMONS"; "VSPACE"; "INS"; "OINTDOM"; "CFCAT"; "REAL"}*/
+/*"PAFF" -> {"STEP"; "PI"; "NNI"; "BOOLEAN"}*/
+
+\end{chunk}
+\subsection{Order}
+The final order of the layers is determined here. The GUESS package
+is broken so we remove the layers involved until this can be resolved.
+\begin{chunk}{order}
+ORDER=\
+  ${LAYER0BOOTSTRAP}     ${LAYER0}  ${LAYER1}  ${LAYER2}  ${LAYER3}  \
+  ${LAYER4}   ${LAYER5}  ${LAYER6}  ${LAYER7}  ${LAYER8}  ${LAYER9}  \
+  ${LAYER10}  ${LAYER11} ${LAYER12} ${LAYER13} ${LAYER14} ${LAYER15} \
+  ${LAYER16}  ${LAYER17} ${LAYER18} ${LAYER19} ${LAYER20} ${LAYER21} \
+  ${LAYER22}  ${LAYER23} ${LAYER0COPY}
+\end{chunk}
+
+\begin{verbatim}
+ORDER=\
+  ${LAYER0BOOTSTRAP}     ${LAYER0}  ${LAYER1}  ${LAYER2}  ${LAYER3}  \
+  ${LAYER4}   ${LAYER5}  ${LAYER6}  ${LAYER7}  ${LAYER8}  ${LAYER9}  \
+  ${LAYER10}  ${LAYER11} ${LAYER12} ${LAYER13} ${LAYER14} ${LAYER15} \
+  ${LAYER16}  ${LAYER17} ${LAYER18} ${LAYER19} ${LAYER0COPY}
+
+\end{verbatim}
+\section{Cliques}
+The algebra code sometimes have circular references. The compiler can
+resolve these references directly if all of the required sources
+are in the same source file.
+
+So the idea to remove the BOOTSTRAP code is to cluster the spad
+sources into "cliqueN.spad" files and feed them all to the compiler
+at once.
+\begin{chunk}{newcode}
+CLIQUE1FILES = ${OUT}/MYUP.o  ${OUT}/MYEXPR.o
+
+${MID}/clique1.spad: ${CLIQUE1FILES}
+	@echo sa01 making ${OUT}/MYUP.o from ${MID}/clique1.spad
+	@echo sa02 making ${OUT}/MYEXPR.o from ${MID}/clique1.spad
+	@ (cd ${MID} ; \
+	   cat ${IN}/MYUP.spad >clique1.spad ; \
+	   cat ${IN}/MYEXPR.spad >>clique1.spad ; \
+	   if [ -z "${NOISE}" ] ; then \
+	    echo ")co clique1.spad" | ${INTERPSYS}  ; \
+           else \
+	    echo ")co clique1.spad" | ${INTERPSYS} >${TMP}/trace ; \
+	   fi )
+	@ cp ${MID}/MYUP.nrlib/code.o ${OUT}/MYUP.o
+	@ cp ${MID}/MYEXPR.nrlib/code.o ${OUT}/MYEXPR.o
+	
+\end{chunk}
+Here we have the general case where two files are co-dependent, that is,
+PAFF and PAFFFF both have to be compiled together. They also have a set
+of prerequired files that must be loaded since they are not yet in the
+new database.
+\begin{chunk}{newcode}
+CLIQUE2FILES = ${OUT}/PAFF.o ${OUT}/PAFFFF.o
+CLIQUE2DEPS  = BLMETCT GPAFF PFORP PACOFF PROJPLPS PLACESPS NSDPS LOCPOWC \
+               DIV SETCATD PLACESC DIVCAT INFCLSPS INFCLCT DSTREE DSTRCAT \
+               PRSPCAT UTSZ PACFFC PACPERC PROJPL PLACES INFCLSPT PROJPL ICP
+
+${MID}/clique2.spad: ${CLIQUE2FILES}
+	@echo sa03 making ${OUT}/PAFF.o from ${MID}/clique2.spad
+	@echo sa04 making ${OUT}/PAFFFF.o from ${MID}/clique2.spad
+	@ (cd ${MID} ; \
+	   cat ${IN}/PAFF.spad >clique2.spad ; \
+	   cat ${IN}/PAFFFF.spad >>clique2.spad ; \
+	   if [ -z "${NOISE}" ] ; then \
+	    echo -e ")lib ${CLIQUE2DEPS} \n )co clique2.spad" \
+              | ${INTERPSYS} ; \
+           else \
+	    echo -e ")lib ${CLIQUE2DEPS} \n )co clique2.spad" \
+	      | ${INTERPSYS} >${TMP}/trace ; \
+	    echo ")co clique2.spad" | ${INTERPSYS} >${TMP}/trace ; \
+	   fi )
+	@ cp ${MID}/PAFF.nrlib/code.o ${OUT}/PAFF.o
+	@ cp ${MID}/PAFFFF.nrlib/code.o ${OUT}/PAFFFF.o
+	
+\end{chunk}
+\begin{chunk}{ignore}
+EXPRDEPS  = LF
+
+${MID}/EXPR.nrlib/code.o: ${MID}/EXPR.spad
+	@echo sa05 newcode EXPR.o depends on LF.o
+	@ ( cd ${MID} ; \
+            echo -e ")lib ${EXPRDEPS} \n )co EXPR.spad" | ${INTERPSYS} )
+	@ cp ${MID}/EXPR.nrlib/code.o ${OUT}/EXPR.o
+	
+\end{chunk}
+\section{Broken Files}
+These files are Aldor files
+\begin{verbatim}
+axtimer.as Timer
+iviews.as  InventorRenderPackage IVREND
+ffrac.as   FormalFraction FORMAL
+iviews.as  InventorViewPort IVVIEW
+iviews.as  InventorDataSink IVDATA
+herm.as    PackedHermitianSequence PACKED
+nsfip.as   NagSpecialFunctionsInterfacePackage NAGSPE
+nrc.as     NagResultChecks NAGRES
+nqip.as    NagQuadratureInterfacePackage NAGQUA
+noptip.as  NagOptimizationInterfacePackage NAGOPT
+nepip.as   NagEigenInterfacePackage NAGEIG
+ndftip.as  NagDiscreteFourierTransformInterfacePackage NAGDIS
+\end{verbatim}
+
+These domains are referenced but don't exist
+\begin{verbatim}
+OBJECT
+\end{verbatim}
+
+\section{The Environment}
+\subsection{The working directories}
+We define 5 directories for this build. The{\bf IN} directory
+contains the pamphlet files for the algebra. These are expanded
+into the{\bf MID} directory as either .spad or .as files. The
+.spad files are compiled by the native spad internal compiler.
+The .as files are compiled using the Aldor compiler. The output
+of the compilation has two purposes. Part of the information is
+used to build various database files (daase files). The other
+part is executable code which is placed in the {\bf OUT}
+directory. When invoked as ``make document'' we construct
+the .dvi files in the{\bf DOC} directory.
+
+The \verb|OUTSRC=${MNT}/${SYS}/src/algebra| subdirectory contains the 
+algebra source files extracted from the pamphlet files. These sources 
+allow the end user to change the algebra if needed.
+
+\begin{chunk}{environment}
+
+IN=${SRC}/algebra
+MID=${INT}/algebra
+OUT=${MNT}/${SYS}/algebra
+DOC=${MNT}/${SYS}/doc/src/algebra
+OUTSRC=${MNT}/${SYS}/src/algebra
+INPUT=${INT}/input
+LISP=${OBJ}/${SYS}/bin/lisp
+LISPTANGLE=${OBJ}/${SYS}/bin/lisp
+BOOKSRC=${SPD}/books/bookvol5.pamphlet
+
+\end{chunk}
+\subsection{The depsys variable}
+The {\bf depsys} image is the compile-time environment for boot and lisp
+files.
+
+\begin{chunk}{environment}
+
+DEPSYS=${OBJ}/${SYS}/bin/depsys
+
+\end{chunk}
+\subsection{The interpsys variable}
+The {\bf interpsys} image is the compile-time environment for algebra
+files.
+
+\begin{chunk}{environment}
+
+INTERPSYS=${OBJ}/${SYS}/bin/interpsys
+
+\end{chunk}
+\subsection{The shell variable}
+We use the ``-e'' flag to echo which is not supported by the ``sh''
+shell but is supported by ``bash''. The ``-e'' flag to echo causes
+it to interpret special characters, in our case newlines.
+
+\begin{chunk}{environment}
+
+SHELL=bash
+
+\end{chunk}
+\section{The Makefile Stanzas}
+A spad pamphlet can contain many Axiom categories, domains, and
+packages. 
+
+For the purpose of explanation we assume that the pamphlet file is 
+named foo.spad.pamphlet. It contains the domains BAR, BAX,
+and BAZ. Thus there will be a subsection named foo.spad.
+
+Since pamphlet files (e.g. foo.spad.pamphlet contain a spad file
+e.g. foo.spad, it follows that every subsection contains a Makefile
+stanza that extract the foo.spad file using notangle.
+
+Since pamphlet files are intended as documents it follows that each
+subsection contains a Makefile stanza that extracts a dvi file
+using noweave.
+
+We could have a category, domain, or package that is in
+the ``bootstrap'' list. Bootstrap spad files contain their generated
+lisp code in special sections. The way bootstrapping works is that
+we extract the lisp code and compile it rather than extracting the
+spad code. We do this because we need the domain to exist before we
+can compile the domain. Some domains depend on themselves directly.
+Some domains depend on themselves thru a long chain of other domains.
+In either case we can't compile the domain until it exists so we
+cache the generated lisp code and, when we need to bootstrap the
+domain, we compile the raw lisp rather than the spad.
+
+This will only happen when the system is built from scratch. Once
+the system has been built the bootstrap code is no longer executed
+and these algebra files will appear as normal algebra files. That
+means that once the system has been built once only the last three
+rules will ever be executed. The first two rules happen when the
+system is built from scratch.
+
+A 5 stanza group for this case performs the following functions:
+\begin{enumerate}
+\item extract the lisp BAR.lsp from the pamphlet foo.spad.pamphlet
+\item compile and copy the bootstrap lisp to the final algebra directory
+\item extract the bootstrap BAR.lsp from the spad file foo.spad
+\item compile the extracted BAR domain
+\item copy the compiled BAR to the final algebra directory
+\end{enumerate}
+
+The subtle point here occurs in the first item. The bootstrap code
+group (in the layer0 bootstrap code chunk above) asks for the
+compiled ``.o'' files in the \verb|\${MID}| directory. Essentially this
+code group calls for intermediate compiled files. This triggers the
+bootstrap stanzas (items 1 and 2 above). All of the other layer 
+chunks ask for compiled code in the \verb|\${OUT}| directory which is
+the final algebra directory. 
+
+The bootstrap process works because first we ask for the compiled
+lisp code stanzas (the \verb|\${MID}/BAR.o| files), THEN we ask for
+the final algebra code stanzas (the \verb|\${OUT}/BAR.o| files). This
+is a very subtle point so think it through carefully. The layer0
+bootstrap list is the only file list that calls for \verb|\${MID}| files.
+All other layers ask for \verb|\${OUT}| files. Make sure you
+understand this before you change things. If you break it the
+world will no longer compile.
+
+So we have a 3 stanza group for normal files, a 3+2 (5) stanza
+group for normal files with default code, and a 3+2 (5) stanza
+group for normal files that need to be bootstrapped. There is
+another combination that occurs, namely bootstrap code that
+also contains default code which gives a 3+2+2+2 (9) stanza case.
+(see TSETCAT for an example. Be sure to read the items in reverse order).
+
+A 9 stanza group for this case performs the following functions:
+\begin{enumerate}
+\item extract the bootstrap BAR.lsp from the foo.spad.pamphlet
+\item compile the bootstrap BAR.lsp and copy to the intermediate directory
+\item extract the bootstrap BAR-.lsp from the foo.spad.pamphlet
+\item compile the bootstrap BAR-.lsp and copy to intermediate directory
+\item extract the spad BAR.spad from the pamphlet foo.spad.pamphlet
+\item compile the extracted BAR.spad domain (to get BAR.o)
+\item copy the BAR.o to the final algebra directory
+\item compile the extracted BAR.spad domain (to get BAR-.o)
+\item copy the BAR-.o to the final algebra directory
+\end{enumerate}
+
+As you can see this is just the combination of the two possible 5
+stanza case. We just have to deal with the BAR- both in regular
+and bootstrap files. The first four stanzas will only happen when
+the system is built from scratch. Once the system is built these
+four rules no longer apply and these stanzas effectively act like
+the 5 stanza rules above.
+
+I'm sure all of this seems confusing but it is very stylized code.
+Basically you need to figure out which kind of stanza group you need,
+copy an existing stanza group, and do a correct renaming of the parts.
+The decision tree looks something like:
+\begin{verbatim}
+IF (you have a regular spad domain)
+ THEN use a 3 stanza form (see YSTREAM)
+IF (you have a default spad domain (it generates ``-'' files)) AND
+   (it does not require bootstrapping)
+ THEN use the first 5 stanza form explained above (see LIECAT)
+IF (you have a normal spad domain) AND
+   (it requires bootstrapping)
+ THEN use the second 5 stanza form explained above (see VECTOR)
+IF (you have a default spad domain (it generates ``-'' files)) AND
+   (it requires bootstrapping)
+ THEN use the 9 stanza form explained above (see TSETCAT)
+\end{verbatim}
+
+\section{Generic Make Rules}
+The idea is to use generic rules to try to cut down the size of this file.
+
+This Makefile works very hard to cache
+intermediate results in order to minimize the re-build time. The cached
+files are kept in the int or obj directories. If one of these
+files disappears but the original pamphlet file is unchanged we only
+need to rebuild the intermediate file. These rule will attempt to do
+that and they succeed however these are intermediate files created by
+implicit rules so they would normally be deleted. To prevent the removal
+the nrlib directory and its contents, the files are marked as .PRECIOUS.
+
+The output of the compile step is saved in a file of the same name
+and extension .out in the \${MID} directory. These files are useful for
+deriving the dependencies by scanning the ``Loading ...'' messages.
+
+\begin{chunk}{genericDotOfiles}
+
+${OUT}/%.o: ${MID}/%.nrlib/code.o
+	@ echo sa06 copying $*.nrlib to $*.o
+	@ cp ${MID}/$*.nrlib/code.o ${OUT}/$*.o
+
+\end{chunk}
+\begin{chunk}{genericnrlibfiles}
+
+.PRECIOUS: ${MID}/%.nrlib/code.o
+${MID}/%.nrlib/code.o: ${MID}/%.spad
+	@ echo sa07 compiling $*.spad to $*.nrlib
+	@ if [ -z "${NOISE}" ] ; then \
+	   (cd ${MID} ; \
+	    echo ")co $*.spad" | ${INTERPSYS} ) ; \
+           else \
+	   (cd ${MID} ; \
+	     echo ")co $*.spad" | ${INTERPSYS} ) 1>/dev/null 2>/dev/null ; \
+	   fi 
+
+\end{chunk}
+\begin{chunk}{genericBOOTSTRAPfiles}
+
+${MID}/%.o: ${MID}/%.lsp
+	@ echo sa08 compiling $*.lsp to $*.o
+	@ (cd ${MID} ; \
+	  if [ -z "${NOISE}" ] ; then \
+	   echo '(progn (in-package (quote boot)) (compile-file "$*.lsp" :output-file "$*.o"))'\
+            | ${DEPSYS} ; \
+	  else \
+	   echo '(progn (in-package (quote boot)) (compile-file "$*.lsp" :output-file "$*.o"))'\
+           | ${DEPSYS} 1>/dev/null 2>/dev/null ; \
+	  fi )
+	@ cp ${MID}/$*.o ${OUT}/$*.o
+
+\end{chunk}
+\begin{chunk}{genericSPADfiles}
+
+${OUTSRC}/%.spad: ${IN}/%.pamphlet
+	@ echo sa09tangling $*.pamphlet to $*.spad
+	@(cd ${OUTSRC} ; \
+	 ${TANGLE} ${IN}/$*.pamphlet >$*.spad )
+
+\end{chunk}
+\begin{chunk}{genericDOCfiles}
+
+${DOC}/%.dvi: ${IN}/%.pamphlet ${DOC}/ps
+	@ echo sa10 latexing $*.pamphlet to ${DOC}/$*.dvi
+	@ (cd ${DOC} ; \
+	cp ${IN}/$*.pamphlet ${DOC} ; \
+	${DOCUMENT} ${NOISE} $* ; \
+	rm -f ${DOC}/$*.pamphlet ; \
+	rm -f ${DOC}/$*.tex ; \
+	rm -f ${DOC}/$* )
+
+\end{chunk}
+\begin{chunk}{genericRules}
+
+\getchunk{genericDotOfiles}
+\getchunk{genericnrlibfiles}
+\getchunk{genericBOOTSTRAPfiles}
+\getchunk{genericSPADfiles}
+\getchunk{genericDOCfiles}
+
+\end{chunk}
+
+\begin{chunk}{libdb.text (OUT from IN)}
+${OUT}/libdb.text: ${IN}/libdb.text
+	@ echo sa11 copying ${IN}/libdb.text to ${OUT}/libdb.text
+	@ cp ${IN}/libdb.text ${OUT}/libdb.text
+
+\end{chunk}
+\begin{chunk}{ps (DOC from SRC)}
+${DOC}/ps: ${SRC}/doc/ps
+	@echo sa12 making ${DOC}/ps from ${SRC}/doc/ps
+	@cp -pr ${SRC}/doc/ps ${DOC}
+
+\end{chunk}
+
+\section{Pamphlet file structure}
+Because the individual .spad files are grouped into higher-level
+algebra pamphlet files, the rules for extracting them are coded
+below as simple ``awk'' scripts that are called when the Makefile
+is constructed.
+
+\begin{chunk}{findAlgebraFiles}
+
+\getchunk{findSpadFiles}
+\getchunk{findBootstrapFiles}
+\end{chunk}
+
+There are, at present, 2 kinds of algebra files to be handled.
+
+There are the bootstrap files. These files live within
+their respective pamphlet files and are "captured" lisp code.
+These are necessary to create the algebra. See the 
+src/algebra/Makefile.pamphlet for details.
+
+Second, there are 3 ``types'' of algebra which are all treated 
+the same at compile time, namely the ``domain'', ``category'', and
+``package'' algebra.
+
+\subsection{Finding the algebra code}
+Step 1 is to scan all of the algebra pamphlet files for the
+chunk names which contain the string "domain", "package", or
+"category". This is done using grep -E (same as egrep, which
+means that the pattern is an extended regular expression) because
+extended regular expressions allows the use of alternatives
+written as (domain|package|category). Thus the command
+\begin{verbatim}
+  grep -E '\\begin{chunk}{(domain|package|category)\ .*}' *.pamphlet
+\end{verbatim}
+will scan the algebra files looking for special chunknames.
+Axiom's chunk names are written in a stylized form so that each
+algebra chunk name begins with one of those three symbols. Thus 
+in bookvol10.3.pamphlet the LexTriangularPackage chunkname is:
+\begin{verbatim}
+  begin{chunk}{package LEXTRIPK LexTriangularPackage}
+\end{verbatim}
+so this grep will generate an output line, prefixed by the filename
+that looks like:
+\begin{verbatim}
+bookvol10.3.pamphlet:begin{chunk}{package LEXTRIPK LexTriangularPackage}
+\end{verbatim}
+There can be many lines of output per pamphlet file, one for
+each domain, package and category cod chunk contained in the file.
+The results are sorted and made unique.
+
+Step 2 is an awk command line.
+
+\subsection{Write the Makefile stanzas for the algebra files}
+
+\begin{chunk}{findSpadFiles}
+
+grep -E 'begin{chunk}{category\ .*}' ${BOOKS}/bookvol10.2.pamphlet | sort | uniq | awk -F: '{
+  chunk=substr($1,15,length($1)-15);
+  split(chunk,part," ");
+  spadfile="${MID}/"part[2]".spad";
+  print spadfile": ${BOOKS}/bookvol10.2.pamphlet";
+  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.2.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
+  print "";
+}'
+
+grep -E 'begin{chunk}{domain\ .*}' ${BOOKS}/bookvol10.3.pamphlet | sort | uniq | awk -F: '{
+  chunk=substr($1,15,length($1)-15);
+  split(chunk,part," ");
+  spadfile="${MID}/"part[2]".spad";
+  print spadfile": ${BOOKS}/bookvol10.3.pamphlet";
+  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.3.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
+  print "";
+}'
+
+grep -E 'begin{chunk}{package\ .*}' ${BOOKS}/bookvol10.4.pamphlet | sort | uniq | awk -F: '{
+  chunk=substr($1,15,length($1)-15);
+  split(chunk,part," ");
+  spadfile="${MID}/"part[2]".spad";
+  print spadfile": ${BOOKS}/bookvol10.4.pamphlet";
+  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.4.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
+  print "";
+}'
+
+grep -E 'begin{chunk}{package\ .*}' ${BOOKS}/bookvol10.5.pamphlet | sort | uniq | awk -F: '{
+  chunk=substr($1,15,length($1)-15);
+  split(chunk,part," ");
+  spadfile="${MID}/"part[2]".spad";
+  print spadfile": ${BOOKS}/bookvol10.5.pamphlet";
+  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.5.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
+  print "";
+}'
+
+\end{chunk}
+awk processes each line of the grep output. 
+
+The awk script uses ``-F:'' which is a flag that says that a ``:'' is
+the field separator. As a result the \$1 and \$2 in the awk script
+refer to the parts of the grep output that come before and after the
+``:'' respectively.
+
+The variable ``chunk'' is assigned the actual chunk name minus
+the '\verb|\begin{chunk}{|' and '\verb|}|' delimiters. 
+In the example given above this will become
+\begin{verbatim}
+package LEXTRIPK LexTriangularPackage
+\end{verbatim}
+The call to ``split'' splits the chunk into parts separated
+by spaces. Thus
+\begin{verbatim}
+  part[1]=package
+  part[2]=LEXTRIPK
+  part[3]=LexTriangularPackage
+\end{verbatim}
+The variable ``spadfile'' in the above example is set to
+\begin{verbatim}
+${MID}/LEXTRIPK.spad
+\end{verbatim}
+Finally, in the domain example given above we print two lines.
+The first line is the Makefile stanza header which depends on the
+original ``zerodim.spad.pamphlet'' file.
+
+The second line is the body of the makefile stanza which calls 
+notangle to extract the algebra from the original pamphlet using
+the chunk name and writes it to the intermediate subdirectory. In
+the case above this would resolve to \verb|\${MID}/LEXTRIPK.spad|.
+
+For the line given above it outputs the following:
+\begin{verbatim}
+${MID}/LEXTRIPK.spad: ${IN}/bookvol10.3.pamphlet
+    echo '(tangle "bookvol10.4.pamphlet" "package LEXTRIPK LexTrianglularPackage" "LEXTRIPK.spad")' | ${LISPTANGLE}
+\end{verbatim}
+
+\subsection{Find the algebra bootstrap code}
+Step 3 works like step 1 above except that we are looking for
+chunk names that have the "BOOTSTRAP" string. The output will look like:
+\begin{verbatim}
+bookvol10.3.pamphlet:begin{chunk}{VECTOR.lsp BOOTSTRAP}
+\end{verbatim}
+This output, which can consist of many lines per input file is piped
+into ``awk''.
+
+\subsection{Write the Makefile stanzas for the bootstrap files}
+For each of the above output lines we run an ``grep'' command:
+
+\begin{chunk}{findBootstrapFiles}
+
+grep 'begin{chunk}{.*BOOTSTRAP}' ${BOOKS}/bookvol10.2.pamphlet | sort | uniq | \
+awk -F: '{
+  chunk=substr($1,15,length($1)-15);
+  split(chunk,part," ");
+  lspfile="${MID}/"part[1];
+  print lspfile": ${BOOKS}/bookvol10.2.pamphlet";
+  print "	  @echo \x27(tangle \"${BOOKS}/bookvol10.2.pamphlet\" \""chunk"\" \""lspfile"\")\x27 | ${LISPTANGLE} ";
+  print "";
+}'
+
+grep 'begin{chunk}{.*BOOTSTRAP}' ${BOOKS}/bookvol10.3.pamphlet | sort | uniq | \
+awk -F: '{
+  chunk=substr($1,15,length($1)-15);
+  split(chunk,part," ");
+  lspfile="${MID}/"part[1];
+  print lspfile": ${BOOKS}/bookvol10.3.pamphlet";
+  print "	  @echo \x27(tangle \"${BOOKS}/bookvol10.3.pamphlet\" \""chunk"\" \""lspfile"\")\x27 | ${LISPTANGLE} ";
+  print "";
+}'
+
+\end{chunk}
+
+The process is the same way as described above except that
+there are only two parts to the chunk names
+\begin{verbatim}
+  part[1]=VECTOR.lsp
+  part[2]=BOOTSTRAP
+\end{verbatim}
+The lspfile variable is assigned
+\begin{verbatim}
+${MID}/VECTOR.lsp
+\end{verbatim}
+Finally we output two lines:
+\begin{verbatim}
+${MID}/vector.spad.pamphlet: ${IN}/bookvol10.3.pamphlet
+ @echo '(tangle "${IN}/bookvol10.4.pamphlet" "VECTOR.lsp BOOTSTRAP" "VECTOR.lsp")' | ${LISPTANGLE} 
+\end{verbatim}
+
+The first line is the stanza head and creates a dependence between
+the intermediate file, in this case int/algebra/VECTOR.lsp and
+the input file src/algebra/vector.spad.pamphlet
+
+The second line calls the lisp ``tangle'' to extract the required chunk
+from the source file.
+
+\section{Stage markers}
+We output these as each stage completes.
+\begin{chunk}{stages}
+
+layer0bootstrap:
+	@ echo =====================================
+	@ echo === algebra bootstrap complete ======
+	@ echo =====================================
+
+layer0copy:
+	@ echo ==================================
+	@ echo === layer  0 copy complete  ======
+	@ echo ==================================
+
+layer0done:
+	@ echo ==================================
+	@ echo === layer  0 of 24 complete ======
+	@ echo ==================================
+
+layer1done:
+	@ echo ==================================
+	@ echo === layer  1 of 24 complete ======
+	@ echo ==================================
+
+layer2done:
+	@ echo ==================================
+	@ echo === layer  2 of 24 complete ======
+	@ echo ==================================
+
+layer3done:
+	@ echo ==================================
+	@ echo === layer  3 of 24 complete ======
+	@ echo ==================================
+
+layer4done:
+	@ echo ==================================
+	@ echo === layer  4 of 24 complete ======
+	@ echo ==================================
+
+layer5done:
+	@ echo ==================================
+	@ echo === layer  5 of 24 complete ======
+	@ echo ==================================
+
+layer6done:
+	@ echo ==================================
+	@ echo === layer  6 of 24 complete ======
+	@ echo ==================================
+
+layer7done:
+	@ echo ==================================
+	@ echo === layer  7 of 24 complete ======
+	@ echo ==================================
+
+layer8done:
+	@ echo ==================================
+	@ echo === layer  8 of 24 complete ======
+	@ echo ==================================
+
+layer9done:
+	@ echo ==================================
+	@ echo === layer 9 of 24 complete ======
+	@ echo ==================================
+
+layer10done:
+	@ echo ==================================
+	@ echo === layer 10 of 24 complete ======
+	@ echo ==================================
+
+layer11done:
+	@ echo ==================================
+	@ echo === layer 11 of 24 complete ======
+	@ echo ==================================
+
+layer12done:
+	@ echo ==================================
+	@ echo === layer 12 of 24 complete ======
+	@ echo ==================================
+
+layer13done:
+	@ echo ==================================
+	@ echo === layer 13 of 24 complete ======
+	@ echo ==================================
+
+layer14done:
+	@ echo ==================================
+	@ echo === layer 14 of 24 complete ======
+	@ echo ==================================
+
+layer15done:
+	@ echo ==================================
+	@ echo === layer 15 of 24 complete ======
+	@ echo ==================================
+
+layer16done:
+	@ echo ==================================
+	@ echo === layer 16 of 24 complete ======
+	@ echo ==================================
+
+layer17done:
+	@ echo ==================================
+	@ echo === layer 17 of 24 complete ======
+	@ echo ==================================
+
+layer18done:
+	@ echo ==================================
+	@ echo === layer 18 of 24 complete ======
+	@ echo ==================================
+
+layer19done:
+	@ echo ==================================
+	@ echo === layer 19 of 24 complete ======
+	@ echo ==================================
+
+layer20done:
+	@ echo ==================================
+	@ echo === layer 20 of 24 complete ======
+	@ echo ==================================
+
+layer21done:
+	@ echo ==================================
+	@ echo === layer 21 of 24 complete ======
+	@ echo ==================================
+
+layer22done:
+	@ echo ==================================
+	@ echo === layer 22 of 24 complete ======
+	@ echo ==================================
+
+layer23done:
+	@ echo ==================================
+	@ echo === layer 23 of 24 complete ======
+	@ echo ==================================
+
+layer24done:
+	@ echo ==================================
+	@ echo === layer 24 of 24 complete ======
+	@ echo ==================================
+
+\end{chunk}
+\subsection{Regression testing}
+
+There is a Makefile variable called REGRESS in the algebra Makefile:
+\begin{verbatim}
+REGRESS=\
+ AssociationList.regress  BalancedBinaryTree.regress \
+\end{verbatim}
+
+This is part of a Makefile that structure within the algebra Makefile.
+This Makefile gets extracted by the Makefile in the input subdirectory.
+Thus there is a connection between the two Makefiles (algebra and input).
+This algebra regression Makefile goes by the chunk name 
+{\bf algebra.regress}. It contains a list of regression files and a 
+single stanza:
+\begin{verbatim}
+%.regress: %.input
+	@ echo sa13 algebra regression testing $*
+	@ (cd ${MID} ; \
+	  rm -f $*.output ; \
+	  if [ -z "${NOISE}" ] ; then \
+           echo ')read $*.input' | ${TESTSYS} ; \
+	  else \
+           echo ')read $*.input' | ${TESTSYS} >${TMP}/trace ; \
+	  fi ; \
+	  if [ -z "${NOISE}" ] ; then \
+           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
+                | egrep -v '(Timestamp|Version)' | tee $*.regress ; \
+	  else \
+           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
+                | egrep -v '(Timestamp|Version)' > $*.regress ; \
+	  fi ; \
+	  fgrep "regression result" $*.regress )
+
+\end{verbatim}
+The input Makefile extracts {\bf algebra.regress} and then calls 
+make to process this file.
+
+This keeps the regression test list in the algebra Makefile.
+
+The algebra files contain input chunks in regress format.
+This stanza is extracted by the src/input/Makefile after
+all of the other regression tests are complete. This stanza
+is put into a int/Makefile.algebra and then executed by make.
+\begin{chunk}{algebra.regress}
+TESTSYS=  ${OBJ}/${SYS}/bin/interpsys
+
+REGRESS= \
+ AbelianGroup.regress \
+ AbelianMonoid.regress \
+ AbelianMonoidRing.regress \
+ AbelianSemiGroup.regress \
+ AdditiveValuationAttribute.regress \
+ AffineAlgebraicSetComputeWithGroebnerBasis.regress \
+ AffineAlgebraicSetComputeWithResultant.regress \
+ AffinePlane.regress \
+ AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.regress \
+ AffineSpace.regress \
+ AffineSpaceCategory.regress \
+ Aggregate.regress \
+ Algebra.regress \
+ AlgebraGivenByStructuralConstants.regress \
+ AlgebraicallyClosedField.regress \
+ AlgebraicallyClosedFunctionSpace.regress \
+ AlgebraicFunctionField.regress \
+ AlgebraicFunction.regress \
+ AlgebraicHermiteIntegration.regress \
+ AlgebraicIntegrate.regress \
+ AlgebraicIntegration.regress \
+ AlgebraicManipulations.regress \
+ AlgebraicMultFact.regress \
+ AlgebraicNumber.regress \
+ AlgebraPackage.regress \
+ AlgFactor.regress \
+ AnnaNumericalIntegrationPackage.regress \
+ AnnaNumericalOptimizationPackage.regress \
+ AnnaOrdinaryDifferentialEquationPackage.regress \
+ AnnaPartialDifferentialEquationPackage.regress \
+ AnonymousFunction.regress \
+ AntiSymm.regress \
+ Any.regress \
+ AnyFunctions1.regress \
+ ApplicationProgramInterface.regress \
+ ApplyRules.regress \
+ ApplyUnivariateSkewPolynomial.regress \
+ ApproximateAttribute.regress \
+ ArbitraryExponentAttribute.regress \
+ ArbitraryPrecisionAttribute.regress \
+ ArcHyperbolicFunctionCategory.regress \
+ ArcTrigonometricFunctionCategory.regress \
+ ArrayStack.regress \
+ Asp1.regress \
+ Asp10.regress \
+ Asp12.regress \
+ Asp19.regress \
+ Asp20.regress \
+ Asp24.regress \
+ Asp27.regress \
+ Asp28.regress \
+ Asp29.regress \
+ Asp30.regress \
+ Asp31.regress \
+ Asp33.regress \
+ Asp34.regress \
+ Asp35.regress \
+ Asp4.regress \
+ Asp41.regress \
+ Asp42.regress \
+ Asp49.regress \
+ Asp50.regress \
+ Asp55.regress \
+ Asp6.regress \
+ Asp7.regress \
+ Asp73.regress \
+ Asp74.regress \
+ Asp77.regress \
+ Asp78.regress \
+ Asp8.regress \
+ Asp80.regress \
+ Asp9.regress \
+ AssociatedEquations.regress \
+ AssociatedJordanAlgebra.regress \
+ AssociatedLieAlgebra.regress \
+ AssociationList.regress \
+ AssociationListAggregate.regress \
+ AttachPredicates.regress \
+ AttributeButtons.regress \
+ Automorphism.regress \
+ AxiomServer.regress \
+ BalancedBinaryTree.regress \
+ BalancedFactorisation.regress \
+ BalancedPAdicInteger.regress \
+ BalancedPAdicRational.regress \
+ BagAggregate.regress \
+ BasicFunctions.regress \
+ BasicOperator.regress \
+ BasicOperatorFunctions1.regress \
+ BasicStochasticDifferential.regress \
+ BasicType.regress \
+ Bezier.regress \
+ BezoutMatrix.regress \
+ BiModule.regress \
+ BinaryExpansion.regress \
+ BinaryFile.regress \
+ BinaryRecursiveAggregate.regress \
+ BinarySearchTree.regress \
+ BinaryTournament.regress \
+ BinaryTree.regress \
+ BinaryTreeCategory.regress \
+ BitAggregate.regress \
+ Bits.regress \
+ BlasLevelOne.regress \
+ BlowUpMethodCategory.regress \
+ BlowUpPackage.regress \
+ BlowUpWithHamburgerNoether.regress \
+ BlowUpWithQuadTrans.regress \
+ Boolean.regress \
+ BoundIntegerRoots.regress \
+ BrillhartTests.regress \
+ CachableSet.regress \
+ CancellationAbelianMonoid.regress \
+ CanonicalAttribute.regress \
+ CanonicalClosedAttribute.regress \
+ CanonicalUnitNormalAttribute.regress \
+ CardinalNumber.regress \
+ CartesianTensor.regress \
+ CartesianTensorFunctions2.regress \
+ CentralAttribute.regress \
+ ChangeOfVariable.regress \
+ Character.regress \
+ CharacterClass.regress \
+ CharacteristicNonZero.regress \
+ CharacteristicPolynomialInMonogenicalAlgebra.regress \
+ CharacteristicPolynomialPackage.regress \
+ CharacteristicZero.regress \
+ ChineseRemainderToolsForIntegralBases.regress \
+ CliffordAlgebra.regress \
+ CoercibleTo.regress \
+ CoerceVectorMatrixPackage.regress \
+ Collection.regress \
+ Color.regress \
+ CombinatorialFunction.regress \
+ CombinatorialFunctionCategory.regress \
+ CombinatorialOpsCategory.regress \
+ CommonDenominator.regress \
+ CommonOperators.regress \
+ CommutativeRing.regress \
+ CommutativeStarAttribute.regress \
+ Commutator.regress \
+ CommuteUnivariatePolynomialCategory.regress \
+ Comparable.regress \
+ Complex.regress \
+ ComplexCategory.regress \
+ ComplexDoubleFloatMatrix.regress \
+ ComplexDoubleFloatVector.regress \
+ ComplexFactorization.regress \
+ ComplexIntegerSolveLinearPolynomialEquation.regress \
+ ComplexFunctions2.regress \
+ ComplexPattern.regress \
+ ComplexPatternMatch.regress \
+ ComplexRootFindingPackage.regress \
+ ComplexRootPackage.regress \
+ ComplexTrigonometricManipulations.regress \
+ ConstantLODE.regress \
+ ContinuedFraction.regress \
+ ConvertibleTo.regress \
+ CoordinateSystems.regress \
+ CRApackage.regress \
+ CycleIndicators.regress \
+ CyclicStreamTools.regress \
+ CyclotomicPolynomialPackage.regress \
+ dasum.regress \
+ daxpy.regress \
+ dcabs1.regress \
+ dcopy.regress \
+ Database.regress \
+ DataList.regress \
+ DecimalExpansion.regress \
+ DefiniteIntegrationTools.regress \
+ DegreeReductionPackage.regress \
+ Dequeue.regress \
+ DequeueAggregate.regress \
+ DeRhamComplex.regress \
+ DesingTree.regress \
+ DesingTreeCategory.regress \
+ DesingTreePackage.regress \
+ Dictionary.regress \
+ DictionaryOperations.regress \
+ DifferentialExtension.regress \
+ DifferentialPolynomialCategory.regress \
+ DifferentialRing.regress \
+ DifferentialSparseMultivariatePolynomial.regress \
+ DifferentialVariableCategory.regress \
+ DiophantineSolutionPackage.regress \
+ DirectProduct.regress \
+ DirectProductCategory.regress \
+ DirectProductFunctions2.regress \
+ DirectProductMatrixModule.regress \
+ DirectProductModule.regress \
+ DirichletRing.regress \
+ DiscreteLogarithmPackage.regress \
+ DisplayPackage.regress \
+ DistributedMultivariatePolynomial.regress \
+ DistinctDegreeFactorize.regress \
+ DivisionRing.regress \
+ Divisor.regress \
+ DivisorCategory.regress \
+ DoubleFloat.regress \
+ DoubleFloatMatrix.regress \
+ DoubleFloatSpecialFunctions.regress \
+ DoubleFloatVector.regress \
+ DoubleResultantPackage.regress \
+ DoublyLinkedAggregate.regress \
+ DrawComplex.regress \
+ DrawNumericHack.regress \
+ DrawOption.regress \
+ DrawOptionFunctions0.regress \
+ DrawOptionFunctions1.regress \
+ d01AgentsPackage.regress \
+ d01ajfAnnaType.regress \
+ d01akfAnnaType.regress \
+ d01alfAnnaType.regress \
+ d01amfAnnaType.regress \
+ d01anfAnnaType.regress \
+ d01apfAnnaType.regress \
+ d01aqfAnnaType.regress \
+ d01asfAnnaType.regress \
+ d01fcfAnnaType.regress \
+ d01gbfAnnaType.regress \
+ d01TransformFunctionType.regress \
+ d01WeightsPackage.regress \
+ d02AgentsPackage.regress \
+ d02bbfAnnaType.regress \
+ d02bhfAnnaType.regress \
+ d02cjfAnnaType.regress \
+ d02ejfAnnaType.regress \
+ d03AgentsPackage.regress \
+ d03eefAnnaType.regress \
+ d03fafAnnaType.regress \
+ EigenPackage.regress \
+ ElementaryFunction.regress \
+ ElementaryFunctionCategory.regress \
+ ElementaryFunctionDefiniteIntegration.regress \
+ ElementaryFunctionLODESolver.regress \
+ ElementaryFunctionODESolver.regress \
+ ElementaryFunctionSign.regress \
+ ElementaryFunctionStructurePackage.regress \
+ ElementaryFunctionsUnivariateLaurentSeries.regress \
+ ElementaryFunctionsUnivariatePuiseuxSeries.regress \
+ ElementaryIntegration.regress \
+ ElementaryRischDE.regress \
+ ElementaryRischDESystem.regress \
+ EllipticFunctionsUnivariateTaylorSeries.regress \
+ Eltable.regress \
+ EltableAggregate.regress \
+ EntireRing.regress \
+ EqTable.regress \
+ Equation.regress \
+ EquationFunctions2.regress \
+ ErrorFunctions.regress \
+ EuclideanDomain.regress \
+ EuclideanGroebnerBasisPackage.regress \
+ EuclideanModularRing.regress \
+ Evalable.regress \
+ EvaluateCycleIndicators.regress \
+ ExpertSystemContinuityPackage.regress \
+ ExpertSystemContinuityPackage1.regress \
+ ExpertSystemToolsPackage.regress \
+ ExpertSystemToolsPackage1.regress \
+ ExpertSystemToolsPackage2.regress \
+ ExponentialExpansion.regress \
+ ExponentialOfUnivariatePuiseuxSeries.regress \
+ Export3D.regress \
+ Expression.regress \
+ ExpressionFunctions2.regress \
+ ExpressionSpace.regress \
+ ExpressionSolve.regress \
+ ExpressionSpaceFunctions1.regress \
+ ExpressionSpaceFunctions2.regress \
+ ExpressionSpaceODESolver.regress \
+ ExpressionToOpenMath.regress \
+ ExpressionToUnivariatePowerSeries.regress \
+ ExpressionTubePlot.regress \
+ ExtAlgBasis.regress \
+ ExtensibleLinearAggregate.regress \
+ ExtensionField.regress \
+ e04AgentsPackage.regress \
+ e04dgfAnnaType.regress \
+ e04fdfAnnaType.regress \
+ e04gcfAnnaType.regress \
+ e04jafAnnaType.regress \
+ e04mbfAnnaType.regress \
+ e04nafAnnaType.regress \
+ e04ucfAnnaType.regress \
+ Factored.regress \
+ FactoredFunctions.regress \
+ FactoredFunctions2.regress \
+ FactoredFunctionUtilities.regress \
+ FactoringUtilities.regress \
+ FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.regress \
+ FactorisationOverPseudoAlgebraicClosureOfRationalNumber.regress \
+ FGLMIfCanPackage.regress \
+ Field.regress \
+ FieldOfPrimeCharacteristic.regress \
+ File.regress \
+ FileCategory.regress \
+ FileName.regress \
+ FileNameCategory.regress \
+ FindOrderFinite.regress \
+ Finite.regress \
+ FiniteAbelianMonoidRing.regress \
+ FiniteAbelianMonoidRingFunctions2.regress \
+ FiniteAggregateAttribute.regress \
+ FiniteAlgebraicExtensionField.regress \
+ FiniteDivisor.regress \
+ FiniteDivisorCategory.regress \
+ FiniteDivisorFunctions2.regress \
+ FiniteField.regress \
+ FiniteFieldCategory.regress \
+ FiniteFieldCyclicGroup.regress \
+ FiniteFieldCyclicGroupExtension.regress \
+ FiniteFieldCyclicGroupExtensionByPolynomial.regress \
+ FiniteFieldExtension.regress \
+ FiniteFieldExtensionByPolynomial.regress \
+ FiniteFieldFactorization.regress \
+ FiniteFieldFactorizationWithSizeParseBySideEffect.regress \
+ FiniteFieldFunctions.regress \
+ FiniteFieldHomomorphisms.regress \
+ FiniteFieldNormalBasis.regress \
+ FiniteFieldNormalBasisExtension.regress \
+ FiniteFieldNormalBasisExtensionByPolynomial.regress \
+ FiniteFieldPolynomialPackage.regress \
+ FiniteFieldSolveLinearPolynomialEquation.regress \
+ FiniteFieldPolynomialPackage2.regress \
+ FiniteFieldSolveLinearPolynomialEquation.regress \
+ FiniteFieldSquareFreeDecomposition.regress \
+ FiniteLinearAggregate.regress \
+ FiniteLinearAggregateFunctions2.regress \
+ FiniteLinearAggregateSort.regress \
+ FiniteRankAlgebra.regress \
+ FiniteRankNonAssociativeAlgebra.regress \
+ FiniteSetAggregate.regress \
+ FiniteSetAggregateFunctions2.regress \
+ FlexibleArray.regress \
+ Float.regress \
+ FloatingComplexPackage.regress \
+ FloatingPointSystem.regress \
+ FloatingRealPackage.regress \
+ FortranCode.regress \
+ FortranCodePackage1.regress \
+ FortranExpression.regress \
+ FortranFunctionCategory.regress \
+ FortranMachineTypeCategory.regress \
+ FortranMatrixCategory.regress \
+ FortranMatrixFunctionCategory.regress \
+ FortranOutputStackPackage.regress \
+ FortranPackage.regress \
+ FortranProgram.regress \
+ FortranProgramCategory.regress \
+ FortranScalarType.regress \
+ FortranTemplate.regress \
+ FortranType.regress \
+ FortranVectorCategory.regress \
+ FortranVectorFunctionCategory.regress \
+ FourierComponent.regress \
+ FourierSeries.regress \
+ Fraction.regress \
+ FractionalIdeal.regress \
+ FractionalIdealFunctions2.regress \
+ FractionFreeFastGaussian.regress \
+ FractionFreeFastGaussianFractions.regress \
+ FractionFunctions2.regress \
+ FramedAlgebra.regress \
+ FramedModule.regress \
+ FramedNonAssociativeAlgebra.regress \
+ FramedNonAssociativeAlgebraFunctions2.regress \
+ FreeAbelianGroup.regress \
+ FreeAbelianMonoid.regress \
+ FreeAbelianMonoidCategory.regress \
+ FreeGroup.regress \
+ FreeLieAlgebra.regress \
+ FreeModuleCat.regress \
+ FreeModule.regress \
+ FreeModule1.regress \
+ FreeMonoid.regress \
+ FreeNilpotentLie.regress \
+ FullPartialFractionExpansion.regress \
+ FullyEvalableOver.regress \
+ FullyLinearlyExplicitRingOver.regress \
+ FullyPatternMatchable.regress \
+ FullyRetractableTo.regress \
+ FunctionalSpecialFunction.regress \
+ FunctionCalled.regress \
+ FunctionFieldCategory.regress \
+ FunctionFieldCategoryFunctions2.regress \
+ FunctionFieldIntegralBasis.regress \
+ FunctionSpace.regress \
+ FunctionSpaceAssertions.regress \
+ FunctionSpaceAttachPredicates.regress \
+ FunctionSpaceComplexIntegration.regress \
+ FunctionSpaceFunctions2.regress \
+ FunctionSpaceIntegration.regress \
+ FunctionSpacePrimitiveElement.regress \
+ FunctionSpaceReduce.regress \
+ FunctionSpaceSum.regress \
+ FunctionSpaceToExponentialExpansion.regress \
+ FunctionSpaceToUnivariatePowerSeries.regress \
+ FunctionSpaceUnivariatePolynomialFactor.regress \
+ GaloisGroupFactorizer.regress \
+ GaloisGroupFactorizationUtilities.regress \
+ GaloisGroupPolynomialUtilities.regress \
+ GaloisGroupUtilities.regress \
+ GaussianFactorizationPackage.regress \
+ GcdDomain.regress \
+ GeneralDistributedMultivariatePolynomial.regress \
+ GeneralHenselPackage.regress \
+ GeneralizedMultivariateFactorize.regress \
+ GeneralModulePolynomial.regress \
+ GeneralPackageForAlgebraicFunctionField.regress \
+ GeneralPolynomialGcdPackage.regress \
+ GeneralSparseTable.regress \
+ GenericNonAssociativeAlgebra.regress \
+ GeneralPolynomialSet.regress \
+ GeneralTriangularSet.regress \
+ GeneralUnivariatePowerSeries.regress \
+ GenerateUnivariatePowerSeries.regress \
+ GenExEuclid.regress \
+ GenUFactorize.regress \
+ GenusZeroIntegration.regress \
+ GnuDraw.regress \
+ GosperSummationMethod.regress \
+ GradedAlgebra.regress \
+ GradedModule.regress \
+ GraphicsDefaults.regress \
+ GraphImage.regress \
+ GrayCode.regress \
+ GroebnerFactorizationPackage.regress \
+ GroebnerInternalPackage.regress \
+ GroebnerPackage.regress \
+ GroebnerSolve.regress \
+ Group.regress \
+ Guess.regress \
+ GuessAlgebraicNumber.regress \
+ GuessFinite.regress \
+ GuessFiniteFunctions.regress \
+ GuessInteger.regress \
+ GuessOption.regress \
+ GuessOptionFunctions0.regress \
+ GuessPolynomial.regress \
+ GuessUnivariatePolynomial.regress \
+ HallBasis.regress \
+ HashTable.regress \
+ Heap.regress \
+ HeuGcd.regress \
+ HexadecimalExpansion.regress \
+ HTMLFormat.regress \
+ HomogeneousAggregate.regress \
+ HomogeneousDirectProduct.regress \
+ HomogeneousDistributedMultivariatePolynomial.regress \
+ HyperbolicFunctionCategory.regress \
+ HyperellipticFiniteDivisor.regress \
+ IdealDecompositionPackage.regress \
+ IncrementingMaps.regress \
+ IndexCard.regress \
+ IndexedAggregate.regress \
+ IndexedBits.regress \
+ IndexedDirectProductAbelianGroup.regress \
+ IndexedDirectProductAbelianMonoid.regress \
+ IndexedDirectProductCategory.regress \
+ IndexedDirectProductObject.regress \
+ IndexedDirectProductOrderedAbelianMonoid.regress \
+ IndexedDirectProductOrderedAbelianMonoidSup.regress \
+ IndexedExponents.regress \
+ IndexedFlexibleArray.regress \
+ IndexedList.regress \
+ IndexedMatrix.regress \
+ IndexedOneDimensionalArray.regress \
+ IndexedString.regress \
+ IndexedTwoDimensionalArray.regress \
+ IndexedVector.regress \
+ InfClsPt.regress \
+ InfiniteProductCharacteristicZero.regress \
+ InfiniteProductFiniteField.regress \
+ InfiniteProductPrimeField.regress \
+ InfiniteTuple.regress \
+ InfiniteTupleFunctions2.regress \
+ InfiniteTupleFunctions3.regress \
+ InfinitlyClosePoint.regress \
+ InfinitlyClosePointCategory.regress \
+ InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.regress \
+ Infinity.regress \
+ InnerAlgebraicNumber.regress \
+ InnerAlgFactor.regress \
+ InnerCommonDenominator.regress \
+ InnerEvalable.regress \
+ InnerFiniteField.regress \
+ InnerFreeAbelianMonoid.regress \
+ InnerIndexedTwoDimensionalArray.regress \
+ InnerMatrixLinearAlgebraFunctions.regress \
+ InnerMatrixQuotientFieldFunctions.regress \
+ InnerModularGcd.regress \
+ InnerMultFact.regress \
+ InnerNormalBasisFieldFunctions.regress \
+ InnerNumericEigenPackage.regress \
+ InnerNumericFloatSolvePackage.regress \
+ InnerPAdicInteger.regress \
+ InnerPolySign.regress \
+ InnerPolySum.regress \
+ InnerPrimeField.regress \
+ InnerSparseUnivariatePowerSeries.regress \
+ InnerTable.regress \
+ InnerTaylorSeries.regress \
+ InnerTrigonometricManipulations.regress \
+ InputForm.regress \
+ InputFormFunctions1.regress \
+ Integer.regress \
+ IntegerCombinatoricFunctions.regress \
+ IntegerBits.regress \
+ IntegerFactorizationPackage.regress \
+ IntegerLinearDependence.regress \
+ IntegerMod.regress \
+ IntegerNumberSystem.regress \
+ IntegerNumberTheoryFunctions.regress \
+ IntegerPrimesPackage.regress \
+ IntegerRetractions.regress \
+ IntegerRoots.regress \
+ IntegerSolveLinearPolynomialEquation.regress \
+ IntegralBasisTools.regress \
+ IntegralBasisPolynomialTools.regress \
+ IntegralDomain.regress \
+ IntegrationFunctionsTable.regress \
+ IntegrationResult.regress \
+ IntegrationResultFunctions2.regress \
+ IntegrationResultRFToFunction.regress \
+ IntegrationResultToFunction.regress \
+ IntegrationTools.regress \
+ InterfaceGroebnerPackage.regress \
+ InternalPrintPackage.regress \
+ InternalRationalUnivariateRepresentationPackage.regress \
+ InterpolateFormsPackage.regress \
+ IntersectionDivisorPackage.regress \
+ Interval.regress \
+ IntervalCategory.regress \
+ InverseLaplaceTransform.regress \
+ IrredPolyOverFiniteField.regress \
+ IrrRepSymNatPackage.regress \
+ JacobiIdentityAttribute.regress \
+ Kernel.regress \
+ KernelFunctions2.regress \
+ KeyedAccessFile.regress \
+ KeyedDictionary.regress \
+ Kovacic.regress \
+ LaplaceTransform.regress \
+ LaurentPolynomial.regress \
+ LazyRepresentationAttribute.regress \
+ LazyStreamAggregate.regress \
+ LazardSetSolvingPackage.regress \
+ LeadingCoefDetermination.regress \
+ LeftAlgebra.regress \
+ LeftModule.regress \
+ LeftUnitaryAttribute.regress \
+ LexTriangularPackage.regress \
+ Library.regress \
+ LieAlgebra.regress \
+ LieExponentials.regress \
+ LiePolynomial.regress \
+ LieSquareMatrix.regress \
+ LinearDependence.regress \
+ LinearlyExplicitRingOver.regress \
+ LinearAggregate.regress \
+ LinearOrdinaryDifferentialOperator.regress \
+ LinearOrdinaryDifferentialOperator1.regress \
+ LinearOrdinaryDifferentialOperator2.regress \
+ LinearOrdinaryDifferentialOperatorCategory.regress \
+ LinearOrdinaryDifferentialOperatorFactorizer.regress \
+ LinearOrdinaryDifferentialOperatorsOps.regress \
+ LinearPolynomialEquationByFractions.regress \
+ LinearSystemFromPowerSeriesPackage.regress \
+ LinearSystemMatrixPackage.regress \
+ LinearSystemMatrixPackage1.regress \
+ LinearSystemPolynomialPackage.regress \
+ LinesOpPack.regress \
+ LinGroebnerPackage.regress \
+ LiouvillianFunction.regress \
+ LiouvillianFunctionCategory.regress \
+ List.regress \
+ ListAggregate.regress \
+ ListFunctions2.regress \
+ ListFunctions3.regress \
+ ListMonoidOps.regress \
+ ListMultiDictionary.regress \
+ ListToMap.regress \
+ LocalAlgebra.regress \
+ Localize.regress \
+ LocalParametrizationOfSimplePointPackage.regress \
+ LocalPowerSeriesCategory.regress \
+ Logic.regress \
+ LyndonWord.regress \
+ MachineComplex.regress \
+ MachineFloat.regress \
+ MachineInteger.regress \
+ Magma.regress \
+ MakeBinaryCompiledFunction.regress \
+ MakeFloatCompiledFunction.regress \
+ MakeRecord.regress \
+ MakeUnaryCompiledFunction.regress \
+ MathMLFormat.regress \
+ MakeCachableSet.regress \
+ MakeFunction.regress \
+ MappingPackage1.regress \
+ MappingPackage2.regress \
+ MappingPackage3.regress \
+ MappingPackageInternalHacks1.regress \
+ MappingPackageInternalHacks2.regress \
+ MappingPackageInternalHacks3.regress \
+ Matrix.regress \
+ MatrixCategory.regress \
+ MatrixCategoryFunctions2.regress \
+ MatrixCommonDenominator.regress \
+ MatrixLinearAlgebraFunctions.regress \
+ MatrixManipulation.regress \
+ MergeThing.regress \
+ MeshCreationRoutinesForThreeDimensions.regress \
+ ModMonic.regress \
+ ModularDistinctDegreeFactorizer.regress \
+ ModularField.regress \
+ ModularHermitianRowReduction.regress \
+ ModularRing.regress \
+ Module.regress \
+ ModuleMonomial.regress \
+ ModuleOperator.regress \
+ MoebiusTransform.regress \
+ Monad.regress \
+ MonadWithUnit.regress \
+ MonogenicAlgebra.regress \
+ MonogenicLinearOperator.regress \
+ Monoid.regress \
+ MonoidRing.regress \
+ MonoidRingFunctions2.regress \
+ MonomialExtensionTools.regress \
+ MoreSystemCommands.regress \
+ MPolyCatFunctions2.regress \
+ MPolyCatFunctions3.regress \
+ MPolyCatPolyFactorizer.regress \
+ MPolyCatRationalFunctionFactorizer.regress \
+ MRationalFactorize.regress \
+ MultFiniteFactorize.regress \
+ MultiDictionary.regress \
+ MultipleMap.regress \
+ MultiplicativeValuationAttribute.regress \
+ Multiset.regress \
+ MultisetAggregate.regress \
+ MultiVariableCalculusFunctions.regress \
+ MultivariateFactorize.regress \
+ MultivariatePolynomial.regress \
+ MultivariateSquareFree.regress \
+ MultivariateTaylorSeriesCategory.regress \
+ MyExpression.regress \
+ MyUnivariatePolynomial.regress \
+ NAGLinkSupportPackage.regress \
+ NeitherSparseOrDensePowerSeries.regress \
+ NewSparseMultivariatePolynomial.regress \
+ NewSparseUnivariatePolynomial.regress \
+ NewSparseUnivariatePolynomialFunctions2.regress \
+ NewtonInterpolation.regress \
+ NewtonPolygon.regress \
+ NonAssociativeAlgebra.regress \
+ NonAssociativeRing.regress \
+ NonAssociativeRng.regress \
+ NonCommutativeOperatorDivision.regress \
+ None.regress \
+ NoneFunctions1.regress \
+ NonLinearFirstOrderODESolver.regress \
+ NonLinearSolvePackage.regress \
+ NonNegativeInteger.regress \
+ NormalizationPackage.regress \
+ NormalizedTriangularSetCategory.regress \
+ NormInMonogenicAlgebra.regress \
+ NormRetractPackage.regress \
+ NotherianAttribute.regress \
+ NottinghamGroup.regress \
+ NoZeroDivisorsAttribute.regress \
+ NPCoef.regress \
+ NullSquareAttribute.regress \
+ NumberFieldIntegralBasis.regress \
+ NumberFormats.regress \
+ NumberTheoreticPolynomialFunctions.regress \
+ Numeric.regress \
+ NumericalIntegrationCategory.regress \
+ NumericalIntegrationProblem.regress \
+ NumericalODEProblem.regress \
+ NumericalOptimizationCategory.regress \
+ NumericalOptimizationProblem.regress \
+ NumericalOrdinaryDifferentialEquations.regress \
+ NumericalPDEProblem.regress \
+ NumericalQuadrature.regress \
+ NumericComplexEigenPackage.regress \
+ NumericContinuedFraction.regress \
+ NumericRealEigenPackage.regress \
+ NumericTubePlot.regress \
+ Octonion.regress \
+ OctonionCategory.regress \
+ OctonionCategoryFunctions2.regress \
+ ODEIntegration.regress \
+ ODEIntensityFunctionsTable.regress \
+ ODETools.regress \
+ OneDimensionalArray.regress \
+ OneDimensionalArrayAggregate.regress \
+ OneDimensionalArrayFunctions2.regress \
+ OnePointCompletion.regress \
+ OnePointCompletionFunctions2.regress \
+ OpenMath.regress \
+ OpenMathConnection.regress \
+ OpenMathDevice.regress \
+ OpenMathEncoding.regress \
+ OpenMathError.regress \
+ OpenMathErrorKind.regress \
+ OpenMathPackage.regress \
+ OpenMathServerPackage.regress \
+ OperationsQuery.regress \
+ Operator.regress \
+ OppositeMonogenicLinearOperator.regress \
+ OrderedAbelianGroup.regress \
+ OrderedAbelianMonoid.regress \
+ OrderedAbelianMonoidSup.regress \
+ OrderedAbelianSemiGroup.regress \
+ OrderedCancellationAbelianMonoid.regress \
+ OrderedCompletion.regress \
+ OrderedCompletionFunctions2.regress \
+ OrderedDirectProduct.regress \
+ OrderedFinite.regress \
+ OrderedFreeMonoid.regress \
+ OrderedIntegralDomain.regress \
+ OrderedMonoid.regress \
+ OrderedMultisetAggregate.regress \
+ OrderedRing.regress \
+ OrderedSet.regress \
+ OrderedVariableList.regress \
+ OrderingFunctions.regress \
+ OrderlyDifferentialPolynomial.regress \
+ OrderlyDifferentialVariable.regress \
+ OrdinaryDifferentialEquationsSolverCategory.regress \
+ OrdinaryDifferentialRing.regress \
+ OrdinaryWeightedPolynomials.regress \
+ OrdSetInts.regress \
+ OrthogonalPolynomialFunctions.regress \
+ OutputForm.regress \
+ OutputPackage.regress \
+ PackageForAlgebraicFunctionField.regress \
+ PackageForAlgebraicFunctionFieldOverFiniteField.regress \
+ PackageForPoly.regress \
+ PadeApproximantPackage.regress \
+ PadeApproximants.regress \
+ PAdicInteger.regress \
+ PAdicIntegerCategory.regress \
+ PAdicRational.regress \
+ PAdicRationalConstructor.regress \
+ PAdicWildFunctionFieldIntegralBasis.regress \
+ Palette.regress \
+ ParadoxicalCombinatorsForStreams.regress \
+ ParametricLinearEquations.regress \
+ ParametricPlaneCurve.regress \
+ ParametricPlaneCurveFunctions2.regress \
+ ParametricSpaceCurve.regress \
+ ParametricSpaceCurveFunctions2.regress \
+ ParametricSurface.regress \
+ ParametricSurfaceFunctions2.regress \
+ ParametrizationPackage.regress \
+ PartialDifferentialEquationsSolverCategory.regress \
+ PartialDifferentialRing.regress \
+ PartialFraction.regress \
+ PartialFractionPackage.regress \
+ PartiallyOrderedSetAttribute.regress \
+ PartialTranscendentalFunctions.regress \
+ Partition.regress \
+ PartitionsAndPermutations.regress \
+ Pattern.regress \
+ Patternable.regress \
+ PatternFunctions1.regress \
+ PatternFunctions2.regress \
+ PatternMatch.regress \
+ PatternMatchable.regress \
+ PatternMatchAssertions.regress \
+ PatternMatchFunctionSpace.regress \
+ PatternMatchIntegerNumberSystem.regress \
+ PatternMatchIntegration.regress \
+ PatternMatchKernel.regress \
+ PatternMatchListAggregate.regress \
+ PatternMatchListResult.regress \
+ PatternMatchPolynomialCategory.regress \
+ PatternMatchPushDown.regress \
+ PatternMatchQuotientFieldCategory.regress \
+ PatternMatchResult.regress \
+ PatternMatchResultFunctions2.regress \
+ PatternMatchSymbol.regress \
+ PatternMatchTools.regress \
+ PermutationGroupExamples.regress \
+ PendantTree.regress \
+ Permanent.regress \
+ Permutation.regress \
+ PermutationCategory.regress \
+ PermutationGroup.regress \
+ Pi.regress \
+ PiCoercions.regress \
+ Places.regress \
+ PlacesCategory.regress \
+ PlacesOverPseudoAlgebraicClosureOfFiniteField.regress \
+ PlaneAlgebraicCurvePlot.regress \
+ Plcs.regress \
+ Plot.regress \
+ Plot3D.regress \
+ PlotFunctions1.regress \
+ PointFunctions2.regress \
+ PlottablePlaneCurveCategory.regress \
+ PlottableSpaceCurveCategory.regress \
+ PlotTools.regress \
+ PoincareBirkhoffWittLyndonBasis.regress \
+ Point.regress \
+ PointCategory.regress \
+ PointPackage.regress \
+ PointsOfFiniteOrder.regress \
+ PointsOfFiniteOrderRational.regress \
+ PointsOfFiniteOrderTools.regress \
+ PolToPol.regress \
+ PolyGroebner.regress \
+ Polynomial.regress \
+ PolynomialAN2Expression.regress \
+ PolynomialCategory.regress \
+ PolynomialCategoryLifting.regress \
+ PolynomialCategoryQuotientFunctions.regress \
+ PolynomialComposition.regress \
+ PolynomialDecomposition.regress \
+ PolynomialFactorizationByRecursion.regress \
+ PolynomialFactorizationByRecursionUnivariate.regress \
+ PolynomialFactorizationExplicit.regress \
+ PolynomialFunctions2.regress \
+ PolynomialGcdPackage.regress \
+ PolynomialIdeals.regress \
+ PolynomialInterpolation.regress \
+ PolynomialInterpolationAlgorithms.regress \
+ PolynomialNumberTheoryFunctions.regress \
+ PolynomialPackageForCurve.regress \
+ PolynomialRing.regress \
+ PolynomialRoots.regress \
+ PolynomialSetCategory.regress \
+ PolynomialSetUtilitiesPackage.regress \
+ PolynomialSolveByFormulas.regress \
+ PolynomialSquareFree.regress \
+ PolynomialToUnivariatePolynomial.regress \
+ PositiveInteger.regress \
+ PowerSeriesCategory.regress \
+ PowerSeriesLimitPackage.regress \
+ PrecomputedAssociatedEquations.regress \
+ PrimeField.regress \
+ PrimitiveArray.regress \
+ PrimitiveArrayFunctions2.regress \
+ PrimitiveElement.regress \
+ PrimitiveFunctionCategory.regress \
+ PrimitiveRatDE.regress \
+ PrimitiveRatRicDE.regress \
+ PrincipalIdealDomain.regress \
+ PrintPackage.regress \
+ PriorityQueueAggregate.regress \
+ Product.regress \
+ ProjectiveAlgebraicSetPackage.regress \
+ ProjectivePlane.regress \
+ ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.regress \
+ ProjectiveSpace.regress \
+ ProjectiveSpaceCategory.regress \
+ PseudoAlgebraicClosureOfAlgExtOfRationalNumber.regress \
+ PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.regress \
+ PseudoAlgebraicClosureOfFiniteField.regress \
+ PseudoAlgebraicClosureOfFiniteFieldCategory.regress \
+ PseudoAlgebraicClosureOfPerfectFieldCategory.regress \
+ PseudoAlgebraicClosureOfRationalNumber.regress \
+ PseudoAlgebraicClosureOfRationalNumberCategory.regress \
+ PseudoLinearNormalForm.regress \
+ PseudoRemainderSequence.regress \
+ PureAlgebraicIntegration.regress \
+ PureAlgebraicLODE.regress \
+ PushVariables.regress \
+ QuadraticForm.regress \
+ QuasiAlgebraicSet.regress \
+ QuasiAlgebraicSet2.regress \
+ QuasiComponentPackage.regress \
+ Quaternion.regress \
+ QuaternionCategory.regress \
+ QuaternionCategoryFunctions2.regress \
+ QueryEquation.regress \
+ Queue.regress \
+ QueueAggregate.regress \
+ QuotientFieldCategory.regress \
+ QuotientFieldCategoryFunctions2.regress \
+ RadicalCategory.regress \
+ RadicalEigenPackage.regress \
+ RadicalFunctionField.regress \
+ RadicalSolvePackage.regress \
+ RadixExpansion.regress \
+ RadixUtilities.regress \
+ RandomDistributions.regress \
+ RandomFloatDistributions.regress \
+ RandomIntegerDistributions.regress \
+ RandomNumberSource.regress \
+ RationalFactorize.regress \
+ RationalFunction.regress \
+ RationalFunctionDefiniteIntegration.regress \
+ RationalFunctionFactor.regress \
+ RationalFunctionFactorizer.regress \
+ RationalFunctionIntegration.regress \
+ RationalFunctionLimitPackage.regress \
+ RationalFunctionSign.regress \
+ RationalFunctionSum.regress \
+ RationalIntegration.regress \
+ RationalInterpolation.regress \
+ RationalLODE.regress \
+ RationalRetractions.regress \
+ RationalRicDE.regress \
+ RationalUnivariateRepresentationPackage.regress \
+ RealClosedField.regress \
+ RealClosure.regress \
+ RealConstant.regress \
+ RealNumberSystem.regress \
+ RealPolynomialUtilitiesPackage.regress \
+ RealRootCharacterizationCategory.regress \
+ RealSolvePackage.regress \
+ RealZeroPackage.regress \
+ RealZeroPackageQ.regress \
+ RectangularMatrix.regress \
+ RectangularMatrixCategory.regress \
+ RectangularMatrixCategoryFunctions2.regress \
+ RecurrenceOperator.regress \
+ RecursiveAggregate.regress \
+ RecursivePolynomialCategory.regress \
+ ReducedDivisor.regress \
+ ReduceLODE.regress \
+ ReductionOfOrder.regress \
+ Reference.regress \
+ RegularChain.regress \
+ RegularSetDecompositionPackage.regress \
+ RegularTriangularSet.regress \
+ RegularTriangularSetCategory.regress \
+ RegularTriangularSetGcdPackage.regress \
+ RepeatedDoubling.regress \
+ RepeatedSquaring.regress \
+ RepresentationPackage1.regress \
+ RepresentationPackage2.regress \
+ ResidueRing.regress \
+ ResolveLatticeCompletion.regress \
+ Result.regress \
+ RetractableTo.regress \
+ RetractSolvePackage.regress \
+ RewriteRule.regress \
+ RightModule.regress \
+ RightOpenIntervalRootCharacterization.regress \
+ RightUnitaryAttribute.regress \
+ Ring.regress \
+ Rng.regress \
+ RomanNumeral.regress \
+ RootsFindingPackage.regress \
+ RoutinesTable.regress \
+ RuleCalled.regress \
+ Ruleset.regress \
+ SAERationalFunctionAlgFactor.regress \
+ ScriptFormulaFormat.regress \
+ ScriptFormulaFormat1.regress \
+ Segment.regress \
+ SegmentBindingFunctions2.regress \
+ SegmentCategory.regress \
+ SegmentExpansionCategory.regress \
+ SegmentFunctions2.regress \
+ SemiGroup.regress \
+ Set.regress \
+ SetAggregate.regress \
+ SetCategory.regress \
+ SetCategoryWithDegree.regress \
+ SetOfMIntegersInOneToN.regress \
+ SequentialDifferentialPolynomial.regress \
+ SequentialDifferentialVariable.regress \
+ SExpression.regress \
+ SExpressionCategory.regress \
+ SExpressionOf.regress \
+ ShallowlyMutableAttribute.regress \
+ SimpleAlgebraicExtension.regress \
+ SimpleAlgebraicExtensionAlgFactor.regress \
+ SimpleFortranProgram.regress \
+ SingleInteger.regress \
+ SingletonAsOrderedSet.regress \
+ SimplifyAlgebraicNumberConvertPackage.regress \
+ SmithNormalForm.regress \
+ SortedCache.regress \
+ SortPackage.regress \
+ SparseTable.regress \
+ SparseMultivariatePolynomial.regress \
+ SparseMultivariateTaylorSeries.regress \
+ SparseUnivariateLaurentSeries.regress \
+ SparseUnivariatePolynomial.regress \
+ SparseUnivariatePolynomialExpressions.regress \
+ SparseUnivariatePolynomialFunctions2.regress \
+ SparseUnivariatePuiseuxSeries.regress \
+ SparseUnivariateSkewPolynomial.regress \
+ SparseUnivariateTaylorSeries.regress \
+ SpecialFunctionCategory.regress \
+ SpecialOutputPackage.regress \
+ SplitHomogeneousDirectProduct.regress \
+ SplittingNode.regress \
+ SplittingTree.regress \
+ SquareMatrix.regress \
+ SquareFreeNormalizedTriangularSetCategory.regress \
+ SquareFreeQuasiComponentPackage.regress \
+ SquareFreeRegularSetDecompositionPackage.regress \
+ SquareFreeRegularTriangularSet.regress \
+ SquareFreeRegularTriangularSetCategory.regress \
+ SquareFreeRegularTriangularSetGcdPackage.regress \
+ SquareMatrixCategory.regress \
+ Stack.regress \
+ StackAggregate.regress \
+ StepThrough.regress \
+ StochasticDifferential.regress \
+ StorageEfficientMatrixOperations.regress \
+ Stream.regress \
+ StreamAggregate.regress \
+ StreamFunctions1.regress \
+ StreamFunctions2.regress \
+ StreamFunctions3.regress \
+ StreamInfiniteProduct.regress \
+ StreamTaylorSeriesOperations.regress \
+ StreamTensor.regress \
+ StreamTranscendentalFunctions.regress \
+ StreamTranscendentalFunctionsNonCommutative.regress \
+ String.regress \
+ StringAggregate.regress \
+ StringCategory.regress \
+ StringTable.regress \
+ StructuralConstantsPackage.regress \
+ SturmHabichtPackage.regress \
+ SubResultantPackage.regress \
+ SubSpace.regress \
+ SubSpaceComponentProperty.regress \
+ SuchThat.regress \
+ SupFractionFactorizer.regress \
+ Switch.regress \
+ Symbol.regress \
+ SymbolTable.regress \
+ SymmetricFunctions.regress \
+ SymmetricGroupCombinatoricFunctions.regress \
+ SymmetricPolynomial.regress \
+ SystemODESolver.regress \
+ SystemSolvePackage.regress \
+ Table.regress \
+ TableAggregate.regress \
+ Tableau.regress \
+ TableauxBumpers.regress \
+ TabulatedComputationPackage.regress \
+ TangentExpansions.regress \
+ TaylorSeries.regress \
+ TaylorSolve.regress \
+ TemplateUtilities.regress \
+ TexFormat.regress \
+ TexFormat1.regress \
+ TextFile.regress \
+ TheSymbolTable.regress \
+ ThreeDimensionalMatrix.regress \
+ ThreeDimensionalViewport.regress \
+ ThreeSpace.regress \
+ ThreeSpaceCategory.regress \
+ ToolsForSign.regress \
+ TopLevelDrawFunctions.regress \
+ TopLevelDrawFunctionsForAlgebraicCurves.regress \
+ TopLevelDrawFunctionsForCompiledFunctions.regress \
+ TopLevelDrawFunctionsForPoints.regress \
+ TopLevelThreeSpace.regress \
+ TranscendentalFunctionCategory.regress \
+ TranscendentalHermiteIntegration.regress \
+ TranscendentalIntegration.regress \
+ TranscendentalManipulations.regress \
+ TranscendentalRischDE.regress \
+ TranscendentalRischDESystem.regress \
+ TransSolvePackage.regress \
+ TransSolvePackageService.regress \
+ Tree.regress \
+ TriangularSetCategory.regress \
+ TriangularMatrixOperations.regress \
+ TrigonometricFunctionCategory.regress \
+ TrigonometricManipulations.regress \
+ TubePlot.regress \
+ TubePlotTools.regress \
+ Tuple.regress \
+ TwoDimensionalArray.regress \
+ TwoDimensionalArrayCategory.regress \
+ TwoDimensionalPlotClipping.regress \
+ TwoFactorize.regress \
+ UnaryRecursiveAggregate.regress \
+ UniqueFactorizationDomain.regress \
+ UnitsKnownAttribute.regress \
+ UnivariateFactorize.regress \
+ UnivariateFormalPowerSeries.regress \
+ UnivariateFormalPowerSeriesFunctions.regress \
+ UnivariateLaurentSeries.regress \
+ UnivariateLaurentSeriesCategory.regress \
+ UnivariateLaurentSeriesConstructor.regress \
+ UnivariateLaurentSeriesConstructorCategory.regress \
+ UnivariateLaurentSeriesFunctions2.regress \
+ UnivariatePolynomial.regress \
+ UnivariatePolynomialCategory.regress \
+ UnivariatePolynomialCategoryFunctions2.regress \
+ UnivariatePolynomialCommonDenominator.regress \
+ UnivariatePolynomialDecompositionPackage.regress \
+ UnivariatePolynomialDivisionPackage.regress \
+ UnivariatePolynomialFunctions2.regress \
+ UnivariatePolynomialMultiplicationPackage.regress \
+ UnivariatePolynomialSquareFree.regress \
+ UnivariatePowerSeriesCategory.regress \
+ UnivariatePuiseuxSeries.regress \
+ UnivariatePuiseuxSeriesCategory.regress \
+ UnivariatePuiseuxSeriesConstructor.regress \
+ UnivariatePuiseuxSeriesConstructorCategory.regress \
+ UnivariatePuiseuxSeriesFunctions2.regress \
+ UnivariatePuiseuxSeriesWithExponentialSingularity.regress \
+ UnivariateSkewPolynomial.regress \
+ UnivariateSkewPolynomialCategory.regress \
+ UnivariateSkewPolynomialCategoryOps.regress \
+ UnivariateTaylorSeries.regress \
+ UnivariateTaylorSeriesCZero.regress \
+ UnivariateTaylorSeriesCategory.regress \
+ UnivariateTaylorSeriesFunctions2.regress \
+ UnivariateTaylorSeriesODESolver.regress \
+ UniversalSegment.regress \
+ UniversalSegmentFunctions2.regress \
+ UserDefinedPartialOrdering.regress \
+ UserDefinedVariableOrdering.regress \
+ UTSodetools.regress \
+ U8Matrix.regress \
+ U16Matrix.regress \
+ U32Matrix.regress \
+ U32VectorPolynomialOperations.regress \
+ U8Vector.regress \
+ U16Vector.regress \
+ U32Vector.regress \
+ Variable.regress \
+ Vector.regress \
+ VectorCategory.regress \
+ VectorFunctions2.regress \
+ VectorSpace.regress \
+ ViewDefaultsPackage.regress \
+ ViewportPackage.regress \
+ Void.regress \
+ WeightedPolynomials.regress \
+ WeierstrassPreparation.regress \
+ WildFunctionFieldIntegralBasis.regress \
+ WuWenTsunTriangularSet.regress \
+ XAlgebra.regress \
+ XDistributedPolynomial.regress \
+ XExponentialPackage.regress \
+ XFreeAlgebra.regress \
+ XPBWPolynomial.regress \
+ XPolynomial.regress \
+ XPolynomialRing.regress \
+ XPolynomialsCat.regress \
+ XRecursivePolynomial.regress \
+ ZeroDimensionalSolvePackage.regress 
+# these requires graphics
+# TwoDimensionalViewport
+
+%.regress: %.input
+	@ echo sa14 algebra regression testing $*
+	@ rm -f $*.output 
+	@ if [ -z "${NOISE}" ] ; then \
+           echo ')read $*.input' | ${TESTSYS} ; \
+	  else \
+           echo ')read $*.input' | ${TESTSYS} >${TMP}/trace ; \
+	  fi 
+	@ rm $*.input 
+	@ if [ -z "${NOISE}" ] ; then \
+           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
+                | egrep -v '(Timestamp|Version)' | tee $*.regress ; \
+	  else \
+           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
+                | egrep -v '(Timestamp|Version)' > $*.regress ; \
+	  fi 
+	@ fgrep "regression result" $*.regress 
+
+all: announce ${REGRESS}
+	@echo sa15 algebra test cases complete.
+
+announce:
+	@ echo ======================================
+	@ echo src/algebra RUNNING REGRESSION TESTING
+	@ echo ======================================
+
+\end{chunk}
+\section{The Makefile}
+
+\begin{chunk}{Makefile}
+
+\getchunk{environment}
+
+\getchunk{layer0 bootstrap}
+\getchunk{layer0 copy}
+\getchunk{layer0}
+\getchunk{layer1}
+\getchunk{layer2}
+\getchunk{layer3}
+\getchunk{layer4}
+\getchunk{layer5}
+\getchunk{layer6}
+\getchunk{layer7}
+\getchunk{layer8}
+\getchunk{layer9}
+\getchunk{layer10}
+\getchunk{layer11}
+\getchunk{layer12}
+\getchunk{layer13}
+\getchunk{layer14}
+\getchunk{layer15}
+\getchunk{layer16}
+\getchunk{layer17}
+\getchunk{layer18}
+\getchunk{layer19}
+\getchunk{layer20}
+\getchunk{layer21}
+\getchunk{layer22}
+\getchunk{layer23}
+\getchunk{order}
+
+all: fasthelp fastinput fastxhtml src ${OUT}/libdb.text \
+     ${SPADBIN}/index.html gloss
+	@ echo sa16 finished ${IN}
+
+fasthelp:
+	@ echo ======================================
+	@ echo src/algebra BUILDING HELP FILES
+	@ echo ======================================
+	@echo sa17 making .help files with lisp
+	@ echo "(makeHelpFiles)" | ${LISP}
+
+fastinput:
+	@ echo ======================================
+	@ echo src/algebra BUILDING INPUT FILES
+	@ echo ======================================
+	@echo sa18 making .input files with lisp
+	@ echo "(makeInputFiles)" | ${LISP}
+
+fastxhtml:
+	@ echo ======================================
+	@ echo src/algebra BUILDING XHTML FILES
+	@ echo ======================================
+	@echo sa19 making .xhtml files with lisp
+	@ mkdir -p ${MNT}/doc
+	@ echo "(makeXHTMLFiles)" | ${LISP}
+
+\getchunk{newcode}
+
+${SPADBIN}/index.html:
+	@ echo sa20 making ${SPADBIN}/index.html
+	@ echo "<html><head>Axiom Algebra</head><body>" >${SPADBIN}/index.html
+	@- (for i in ${IN}/*.pamphlet ; do \
+	   ${TANGLE} -R'algebra html' $$i 2>/dev/null | \
+             sed -e 's?DOC?${DOC}?g' >>${SPADBIN}/index.html ; \
+	   done)
+	@ echo "</body></html>" >>${SPADBIN}/index.html
+
+#all:	${SUBPART}
+
+gloss:
+	@ echo sa21 copying glossary files
+	@ cp ${SRC}/share/algebra/gloss.text ${MNT}/${SYS}/algebra
+	@ cp ${SRC}/share/algebra/glossdef.text ${MNT}/${SYS}/algebra
+	@ cp ${SRC}/share/algebra/glosskey.text ${MNT}/${SYS}/algebra
+
+everything: lib db cmd gloss
+	@ echo sa22 invoking make in `pwd` with parms:
+	@ echo SYS= ${SYS} LSP= ${LSP} PART= ${PART} SUBPART= ${SUBPART}
+	@ echo SPAD= ${SPAD} SRC= ${SRC} INT= ${INT}
+	@ echo OBJ= ${OBJ} MNT= ${MNT} O=${O} LISP=${LISP} BYE=${BYE}
+
+src:	announce ${ORDER}
+	@ echo sa23 Finished uilding nrlibS from spad sources
+
+announce:
+	@ echo ======================================
+	@ echo src/algebra BUILDING ALGEBRA FILES
+	@ echo ======================================
+
+\getchunk{genericRules}
+\getchunk{ps (DOC from SRC)}
+\getchunk{libdb.text (OUT from IN)}
+\getchunk{stages}
+
+clean:
+	@echo sa24 src/algebra cleaned
+
+\end{chunk}
+
 \chapter{Implementation}
 
 \section{Elementary Functions\cite{4}}
diff --git a/changelog b/changelog
index 913ad30..2be237f 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,5 @@
+20140713 tpd src/axiom-website/patches.html 20140713.01.tpd.patch
+20140713 tpd books/bookvol10 absorb src/algebra/Makefile
 20140712 tpd src/axiom-website/patches.html 20140712.01.tpd.patch
 20140712 tpd books/bookvol5  remove compression
 20140712 tpd src/interp/util.lisp remove compression
diff --git a/patch b/patch
index 314945b..8fe462b 100644
--- a/patch
+++ b/patch
@@ -1,3 +1,4 @@
-books/bookvol5, src/interp/util.lisp, *.daase
-
-remove the database compression
+books/bookvol10 absorb src/algebra/Makefile
+ 
+Volume 10 explains the algebra implementation.
+Most of these details are in the algebra Makefile.
diff --git a/src/Makefile.pamphlet b/src/Makefile.pamphlet
index f0b779d..ccd81bd 100644
--- a/src/Makefile.pamphlet
+++ b/src/Makefile.pamphlet
@@ -482,7 +482,7 @@ extracting them are derived from a simple script findAlgebraFiles which
 appends these additional rules to the Makefile.
 
 The src/algebra/Makefile is specially constructed in two
-steps. The first step uses the document command to extract
+steps. The first step uses the tangle command to extract
 the normal Makefile information.
 
 The second step is to extend the src/algebra/Makefile with
@@ -499,8 +499,6 @@ will extract input files for regression testing from the algebra pamphlets.
 
 We copy bookvol10.1 (Categories), bookvol10.2 (Domains), 
 and bookvol10.3 (Packages) to the src/algebra subdirectory. 
-Eventually we will pick this information up directly
-from the books directory.
 
 \subsection{Volume 10: Axiom Algebra book}
 \begin{chunk}{algebradir}
@@ -517,27 +515,21 @@ algebradir: ${SRC}/algebra/Makefile ${SPD}/books/bookvol10.pamphlet \
 	@mkdir -p ${INT}/input
 	@(cd algebra ; ${ENV} ${MAKE} )
 
-${SRC}/algebra/Makefile: ${SRC}/algebra/Makefile.pamphlet
+${SRC}/algebra/Makefile: ${BOOKS}/bookvol10.pamphlet
 	@echo 30 making ${SRC}/algebra/Makefile from \
-                ${SRC}/algebra/Makefile.pamphlet
-	@( cd algebra ; ${EXTRACT} Makefile ; \
-        cp Makefile.pdf ${MNT}/${SYS}/doc/src/algebra.Makefile.pdf ; \
+                ${BOOKS}/bookvol10.pamphlet
+	@( cd algebra ; \
+	${BOOKS}/tangle ${BOOKS}/bookvol10.pamphlet Makefile >Makefile ; \
 	cp ${SPD}/books/bookvol10.2.pamphlet . ; \
 	cp ${SPD}/books/bookvol10.3.pamphlet . ; \
 	cp ${SPD}/books/bookvol10.4.pamphlet . ; \
 	cp ${SPD}/books/bookvol10.5.pamphlet . ; \
-	echo 30a extracting findAlgebraFiles from \
-                 ${SRC}/algebra/Makefile.pamphlet ; \
-	${BOOKS}/tangle Makefile.pamphlet findAlgebraFiles \
-            > ${INT}/algebra/findAlgebraFiles ; \
+	echo 30a tangling findAlgebraFiles from \
+                 ${BOOKS}/bookvol10.pamphlet ; \
+	${BOOKS}/tangle ${BOOKS}/bookvol10.pamphlet \
+             findAlgebraFiles >${INT}/algebra/findAlgebraFiles ; \
 	echo 30b running ${INT}/algebra/findAlgebraFiles ; \
-	. ${INT}/algebra/findAlgebraFiles >> Makefile)
-
-algebradocument: ${SRC}/algebra/Makefile
-	@echo 31 documenting ${SRC}/algebra
-	@mkdir -p ${MNT}/${SYS}/doc/src/algebra
-	@mkdir -p ${INT}/doc/src/algebra
-	@( cd algebra ; ${ENV} ${MAKE} document )
+	. ${INT}/algebra/findAlgebraFiles >> Makefile )
 
 algebraclean: ${SRC}/algebra/Makefile
 	@echo 32 cleaning ${SRC}/algebra
diff --git a/src/algebra/Makefile.pamphlet b/src/algebra/Makefile.pamphlet
deleted file mode 100644
index ed668f4..0000000
--- a/src/algebra/Makefile.pamphlet
+++ /dev/null
@@ -1,19166 +0,0 @@
-\documentclass{article}
-\usepackage{axiom}
-\begin{document}
-\title{\$SPAD/src/algebra Makefile}
-\author{Timothy Daly}
-\maketitle
-\begin{abstract}
-\end{abstract}
-\eject
-\tableofcontents
-\eject
-\section{Adding new algebra}
-This is a complex process by its very nature. Developers and Maintainers
-who undertake the process need to understand quite a lot of detail. The
-ultimate steps to add algebra are tedious but simple. Note that only
-algebra code that gets shipped with the system needs to undergo this
-process. User code can be compiled once the distributed algebra exists
-and does not need either this Makefile or this installation process.
-
-Since understanding is the key to making correct changes to this file
-I'll work on explaining the details of why things need to exist. 
-
-The first idea that you need to understand is the overall process
-of adding algebra code. Lets assume that you have a brand new spad
-file, called bsd.spad containing a simple domain BSD. The
-steps in the process of adding this file are:
-\begin{enumerate}
-\item Find out where the algebra code lives in the lattice.
-\begin{enumerate}
-\item Start a new interpsys session. This will give you a clean build.
-\item )set mes auto on -- This will allow us to see what algebra files
-get loaded during compile
-\item )co BAR.spad       
-\item We collect all the names of the algebra files BSD loaded. Look for
-lines that say a file is loaded. Collect all of the names of those files.
-\item For each of the loaded files determine which layer contains the 
-loaded file by searching this file. For instance, if BAR.spad required
-FSAGG then look for /FSAGG.o, which resides in layer 13. 
-\item Determine the highest layer (e.g. 13) that contains the required files
-and add the new algebra file (e.g. BSD.o) in the next layer (e.g. 14).
-\item Next we need to create the graph structure information. This involves
-creating a two part stanza of information. For instance,
-\begin{verbatim}
-"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
-        shape=ellipse]
-/*"BSD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "INT"}*/
-/*"BSD" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"BSD" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "OM"; "PATMAB"}*/
-"BSD" -> "FSAGG" 
-\end{verbatim}
-\item The first part determines the color, shape of the graph node,
-and a link to the book containing the source code. The color and name
-of the book are related:
-\begin{enumerate}
-\item \#4488FF == bookvol10.2
-\item \#88FF44 == bookvol10.3
-\item \#FF4488 == bookvol10.4
-\item \#444488 == bookvol10.5
-\end{enumerate}
-\item The second part is the graph structure. All of the loaded algebra
-files are listed (currently as comments due to the size of the complete
-graph). In particular, the node that ``supports'' BSD is FSAGG so we
-make sure that the graph edge \verb|"BSD" -> "FSAGG"| is uncommented.
-\end{enumerate}
-\item Insert the documentation after the layer (e.g after layer 14).
-This documentation is used to reconstruct the full and partial graphs.
-\item Insert the \verb|${OUT}/BSD.o| file into the layer's file list. This
-will cause the algebra to build after all of the algebra it depends on is
-built.
-\item Add the algebra to the books
-\end{enumerate}
-
-\section{Adding the algebra to the proper book}
-The algebra sources are in 4 books:
-\begin{itemize}
-\item bookvol10.2 == Category
-\item bookvol10.3 == Domain
-\item bookvol10.4 == Package
-\item bookvol10.5 == Numeric
-\end{itemize}
-The algebra in these files is structured slightly differently for each
-one. Follow the directions for the kind of algebra you are adding.
-\subsection{Adding a Category}
-\subsection{Adding a Domain}
-In the Domains book we see that each domain is in alphabetic order by
-the {\bf full domain name}, not by the abbreviation. So for BSD we see
-several parts. 
-\subsubsection{The section separator}
-This gives a visual and logical separation for each domain. 
-\begin{verbatim}
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-\section{domain BSD BasicStochasticDifferential}
-\end{verbatim}
-
-\subsubsection{The input section}
-This is a standard input file format. It will be extracted from the book
-during the testing process so we can keep the test cases with the domain.
-The --R lines are the commented output of actually running the functions.
-Note that ``--'' is the comment character in Axiom. The ``regress'' function
-will run the code and then compare the actual output with the lines marked
-``--R'' and report any differences. 
-
-You can create this file by:
-\begin{itemize}
-\item Start Axiom
-\item make a bsd.input file with all of your algebra tests
-\item )co BSD -- compile your algebra to make sure it is up to date
-\item )spool BSD.output -- this will put all output into a file
-\item )read bsd -- this will read the tests and the output will be
-stored in BSD.output
-\item Modify the BSD.output file to have the same format using 
-``--S n of N'' to start the test, ``--R'' to prefix the actual output, 
-and ``--E n'' to end the test.
-\item save the test as bsdtest.input
-\item Validate the newly formatted test file (bsdtest.input):
-\begin{itemize}
-\item start a new Axiom
-\item )co BSD -- compile your new algebra
-\item )read bsdtest.input -- BE SURE to use the new test file format.
-If you did it right it will create a new file called
-BasicStochasticDifferential.output
-\item )lisp (regress "BasicStochasticDifferential.output") -- this will
-run the regress function which compares the actual output with the
-expected output and reports success or failure.
-\item fix up failures and repeat until none remain
-\item add the contents of bsdtest.input to the algebra file
-\end{itemize}
-\end{itemize}
-
-\subsubsection{The input section}
-Here we use BasicStochasticDifferential.output to create a set of test
-cases. These are automatically extracted as part of the build process
-by the function ``makeInputFiles''. This function is in the tangle.lisp file.
-\begin{verbatim}
-
-)set break resume
-)sys rm -f BasicStochasticDifferential.output
-)spool BasicStochasticDifferential.output
-)set message test on
-)set message auto off
-)clear all
---S 1 of 2
-q := D(p, x)
---R 
---R
---R                 __
---R   (6)  0.1x + 0.10
---R                                             Type: Polynomial BinaryExpansion
---E 1
-
---S 2 of 2
-g := gcd(p, q)
---R 
---R
---R              __
---R   (7)  x + 1.01
---R                                             Type: Polynomial BinaryExpansion
---E 2
-
-)spool
-)lisp (bye)
-
-\end{verbatim}
-
-\subsubsection{The help section}
-This section becomes a help file in the distributed Axiom system.
-This section is automatically extracted as part of the build process
-by the function ``makeHelpFiles''. This function is in the tangle.lisp file.
-The help section gets typed out when the user types:
-\begin{verbatim}
-)help BasicStochasticDifferential
-\end{verbatim}
-\begin{verbatim}
-begin{chunk}{BasicStochasticDifferential.help}
-====================================================================
-BasicStochasticDifferential examples
-====================================================================
-All rational numbers have repeating binary expansions.  Operations to
-access the individual bits of a binary expansion can be obtained by
-converting the value to RadixExpansion(2).  More examples of
-expansions are available with
-
-The expansion (of type BinaryExpansion) of a rational number is
-returned by the binary operation.
-
-  r := binary(22/7)
-      ___
-   11.001
-                      Type: BinaryExpansion
-
-Arithmetic is exact.
-
-  r + binary(6/7)
-   100 
-                      Type: BinaryExpansion
-
-See Also:
-o )help BasicStochasticDifferential
-o )help HexadecimalExpansion
-o )show BasicStochasticDifferential
-
-end{chunk}
-\end{verbatim}
-
-\subsubsection{The pagehead section}
-Next we create the format information for the book itself. This will
-control the display of the new algebra in the book. The ``pagehead''
-macro formats a new section for this algebra and adds it to the proper
-indexing and other housekeeping sections.
-
-The ``pagepic'' creates a graph image inline showing the subgraph
-containing this algebra from the full graph. This information is kept
-in this file (see the graph subsection below). The ``1.00'' is a 
-scaling factor for the graph.
-
-The ``pageto'' macro inserts HTML anchors into the PDF file so there
-is a way to navigate to algebra that is ``above'' this domain in the
-graph. There can be multiple pageto macros.
-
-The ``pagefrom'' macro inserts HTML anchors into the PDF file so there
-is a way to navigate to algebra that is ``below'' this domain in the
-graph. There can be multiple pagefrom macros.
-
-Together these two macros, pageto and pagefrom, allow the user to 
-follow the thread of domains in the PDF documentation.
-\begin{verbatim}
-\pagehead{BasicStochasticDifferential}{BSD}
-\pagepic{ps/v103basicstochasticdifferential.ps}{BSD}{1.00}
-{\bf See}\\
-\pageto{HexadecimalExpansion}{HEXADEC}
-\end{verbatim}
-
-\subsubsection{The Exports section}
-This shows the same information as the ``)show'' function in a running
-Axiom. The ``cross'' macro adds information to the index to cross reference
-the domain and the functions.
-\begin{verbatim}
-{\bf Exports:}\\
-\begin{tabular}{lll}
-\cross{BSD}{0} &
-\cross{BSD}{1} &
-\cross{BSD}{abs} \\
-\cross{BSD}{associates?} &
-\cross{BSD}{binary} &
-\cross{BSD}{ceiling} \\
-\cross{BSD}{characteristic} 
-\end{tabular}
-\end{verbatim}
-
-\subsubsection{The Code section}
-This is the actual algebra. Note that the ``++'' comments from the 
-description section are available at runtime using the ``)describe''
-command. They have certain format limitations so be sure to check
-this in the final system. 
-
-The signatures have comments. If the comments are broken into two
-parts and the lines of the second part of the comment start with
-``++X'' then these will be typed out as part of the output of the
-command ``)d op''. For instance, in the code below for the ``introduce!''
-function the comments read:
-\begin{verbatim}
-  introduce!: (Symbol,Symbol) -> Union(%, "failed")
-   ++ introduce!(X,dX) returns \axiom{dX} as \axiom{BSD} if it
-   ++ isn't already in \axiom{BSD}
-   ++
-   ++X introduce!(t,dt)
-\end{verbatim}
-When we type ``)d op introduce!'' in a running Axiom we will see the
-example text:
-\begin{verbatim}
-   introduce!(t,dt)
-\end{verbatim}
-\begin{verbatim}
-<domain BSD BasicStochasticDifferential>>=
-)abbrev domain BSD BasicStochasticDifferential
-++ Basic Operations: introduce!, copyBSD, copyIto, getSmgl
-++ Related Domains: StochasticDifferential(R)
-++ Also See:
-++ AMS Classifications:
-++ Keywords: stochastic differential, semimartingale.
-++ Examples:
-++ References:
-++ Ito (1975), Kendall (1991a,b; 1993a,b; 1999a,b).
-++ Description:
-++ Based on Symbol: a domain of symbols
-++ representing basic stochastic differentials, used
-++ in StochasticDifferential(R) in the underlying
-++ sparse multivariate polynomial representation.
-++
-++ We create new BSD only by coercion from Symbol
-++ using a special function introduce! first of all to 
-++ add to a private set SDset. We allow a separate 
-++ function convertIfCan which will check whether the
-++ argument has previously been declared as a BSD.
-BasicStochasticDifferential(): Category == Implementation where
- INT ==> Integer
- OF  ==> OutputForm
- Category ==> OrderedSet with
-  ConvertibleTo(Symbol)
-
-  convertIfCan: Symbol -> Union(%, "failed")
-   ++ convertIfCan(ds) transforms \axiom{dX} into a \axiom{BSD}
-   ++ if possible (if \axiom{introduce(X,dX)} has
-   ++ been invoked previously).
-
-  convert: Symbol -> %
-   ++ convert(dX) transforms \axiom{dX} into a \axiom{BSD}
-   ++ if possible and otherwise produces an error.
-
-  introduce!: (Symbol,Symbol) -> Union(%, "failed")
-   ++ introduce!(X,dX) returns \axiom{dX} as \axiom{BSD} if it
-   ++ isn't already in \axiom{BSD}
-
-  d: Symbol -> Union(%,INT)
-   ++ d(X) returns \axiom{dX} if \axiom{tableIto(X)=dX}
-   ++ and otherwise returns \axiom{0}
-
-  copyBSD:() -> List %
-   ++ copyBSD() returns \axiom{setBSD} as a list of \axiom{BSD}.
-  copyIto:() -> Table(Symbol,%)
-   ++ copyIto() returns the table relating semimartingales
-   ++ to basic stochastic differentials.
-  getSmgl: % -> Union(Symbol,"failed")
-   ++ getSmgl(bsd) returns the semimartingale \axiom{S} related
-   ++ to the basic stochastic differential \axiom{bsd} by
-   ++ \axiom{introduce!}
-
- Implementation ==> Symbol add 
-
-  Rep := Symbol
-
-  setBSD := empty()$Set(Symbol)
-  tableIto:Table(Symbol,%) := table()
-  tableBSD:Table(%,Symbol) := table()
-
-  convertIfCan(ds:Symbol):Union(%,"failed") ==
-   not(member?(ds,setBSD)) => "failed"
-   ds::%
-
-  convert(ds:Symbol):% ==
-   (du:=convertIfCan(ds)) 
-    case "failed" =>
-     print(hconcat(ds::Symbol::OF,
-       message(" is not a stochastic differential")$OF))
-     error "above causes failure in convert$BSD"
-   du
-
-  introduce!(X,dX) == 
-   member?(dX,setBSD) => "failed"
-   insert!(dX,setBSD)
-   tableBSD(dX::%) := X
-   tableIto(X) := dX::%
-
-  d(X) ==
-   search(X,tableIto) case "failed" => 0::INT
-   tableIto(X)
-
-  copyBSD() == [ds::% for ds in members(setBSD)]
-  copyIto() == tableIto
-  getSmgl(ds:%):Union(Symbol,"failed") == tableBSD(ds)
-\end{verbatim}
-
-\subsubsection{The dotabb section}
-This section is used to create the ``ps/v103basicstochasticdifferential.ps''
-graph image used above. The actual code used is kept here so we can modify
-or reproduce the result. The first line is the current domain. The second
-line is the domain, category, or package that ``supports'' this domain 
-in the previous layer. These three lines are create the subgraph of the
-main algebra graph.
-\begin{verbatim}
-<BINARY.dotabb>>=
-"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
-        shape=ellipse]
-"FSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FSAGG"]
-"BSD" -> "FSAGG"
-
-\end{chunk}
-\end{verbatim}
-In order to actually create the graph this code gets wrapped with the
-graphviz information. So you pick up the above lines and insert them
-into a file surrounded by the graphviz commands as in:
-\begin{verbatim}
-digraph pic {
- fontsize=10;
- bgcolor="#ECEA81";
- node [shape=box, color=white, style=filled];
-
-"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
-        shape=ellipse]
-"FSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FSAGG"]
-"BSD" -> "FSAGG"
-
-}
-\end{verbatim}
-Save this in a file, say bsd.dot.
-To create the correct postscript file use the command:
-\begin{verbatim}
-   dot -Teps bsd.dot >ps/v103basicstochasticdifferential.eps
-\end{verbatim}
-Notice that the output goes into a ps subdirectory. It is named
-with the v103 prefix, meaning it is intended for volume 10.3.
-
-The REGRESS table contains the names of all of the regression
-files. These are the test case files we constructed for the
-algebra. Putting a chunk name in this table will extract the test
-case, run it, and run regression testing on it looking for
-failures. The naming convention is the same as the .input file but
-uses .regress so the Makefile regression stanza is invoked. So, for
-our example, we need to add
-\begin{verbatim}
-    BasicStochasticDifferential.regress
-\end{verbatim}
-
-We must also add the domain to the \verb|$globalExposureGroupAlist|
-in the interpreter (book volume 5). This is a lisp cons structure
-where the CAR is the domain name and the CDR is the domain abbreviation.
-So we add the line:
-\begin{verbatim}
-   (|BasicStochasticDifferential| . BSD)
-\end{verbatim}
-
-\subsection{Adding a Package}
-\subsection{Adding Numerics}
-
-\section{Rebuilding the algebra from scratch}
-Compile order is important. Here we try to define the ordered lattice
-of spad file dependencies. However this is, in reality, a graph rather
-than a lattice. In order to break cycles in this graph we explicitly
-cache a few of the intermediate generated lisp code for certain files.
-These are marked throughout (both here and in the various pamphlet
-files) with the word {\bf BOOTSTRAP}.
-
-If we take a cycle such as {\bf RING} we discover that in order to
-compile the spad code we must load the compiled definition of {\bf RING}.
-In this case we must compile the cached lisp code before we try to 
-compile the spad file.
-
-The cycle for {\bf SETCAT} is longer consisting of: {\bf SETCAT} needs
-{\bf SINT} needs {\bf UFD} needs {\bf GCDDOM} needs {\bf COMRING} needs
-{\bf RING} needs {\bf RNG} needs {\bf ABELGRP} needs {\bf CABMON} needs
-{\bf ABELMON} needs {\bf ABELSG} needs {\bf SETCAT}.
-
-It is highly recommended that you try to become a developer of Axiom
-and read the archived mailing lists before you decide to change a
-cached file. In the fullness of time we will rewrite the whole algebra
-structure into a proper lattice if possible. Alternatively we'll
-reimplement the compiler to handle graphs. Or deeply adopt the
-extensible domains. Whatever we do will be much discussed (and cause
-much disgust) around the campfire. If you come up with a brilliant
-plan that gets adopted we'll even inscribe your name on a log and add
-it to the fire.
-
-In the code that follows we find the categories, packages and domains
-that compile with no dependencies and call this set ``layer 0''. Next
-we find the categories, packages and domains that will compile using
-only ``layer 0'' code and call this ``layer 1''. We walk up the
-lattice in this fashion adding layers. Note that at layer 3 this
-process runs into cycles and we create the ``layer 3 bootstrap''
-stanzas before continuing upward.
-
-\section{The Algebra Lattice Layers}
-\subsection{Layer 0 Bootstrap}
-The easiest way to find out where a spad file lives in the hierarchy
-is to create the following script (called 'show'):
-\begin{verbatim}
-  echo ")co $1" | AXIOMsys >out
-  fgrep abbreviates out
-  fgrep "Loading" out | grep -v autoload
-\end{verbatim}
-and then run it with ``./show FOO'' where the algebra source file
-is FOO.spad.
-
-Each layer is followed by a layerpic chunk which gives the graphviz
-graph information. The graphviz header information is here:
-\begin{chunk}{layerpic}
-digraph pic {
- fontsize=10;
- bgcolor="\#ECEA81";
- node [shape=box, color=white, style=filled];
- ranksep=3.0;
- /* nodsep=inches */
- /* size="x,y", size="7.5,10" fits 8.5x11 page */
- /* ratio=auto */ /* page="x,y" */ /* generates multipage layout */
- /* margin=0 */
-
-"Category" [color="\#4488FF"]
-"Category" -> "."
-
-"Domain" [color="\#88FF44"]
-"Domain" -> "."
-
-"Package" [color="\#FF4488"]
-"Package" -> "."
-
-\end{chunk}
-
-\subsubsection{Completed spad files}
-Note well that none of the algebra stanzas should include these
-files in the preconditions otherwise we have an infinite compile
-loop. These files are originally bootstrapped from lisp code
-when we build the system for the first time but they are
-forcibly recompiled at the end of the build so they reflect
-current code (just in case someone changes the spad code but
-does not re-cache the generated lisp). If you add these files
-as preconditions (note that they are all in the {\bf MID} 
-directory rather than the {\bf OUT} directory like everything
-else) then the final recompile will invalidate all of the
-rest of the algebra targets which will get rebuilt again causing
-these targets to be out of date. The rest of the loop is left
-up to the student.
-
-The bootstrap process works because first we ask for the compiled
-lisp code stanzas (the \verb|\${MID}/BAR.o| files), THEN we ask for
-the final algebra code stanzas (the \verb|\${OUT}/BAR.o| files). This
-is a very subtle point so think it through carefully. Notice that
-this is the only layer calling for \verb|\${MID}| files. All other 
-layers call for \verb|\${OUT}| files. If you break this the world
-will no longer compile so don't change it if you don't understand it.
-
-\begin{verbatim}
-LAYER0BOOTSTRAP=${OUT}/XPR.o 
-\end{verbatim}
-
-\begin{chunk}{layer0 bootstrap}
-
-LAYER0BOOTSTRAP=\
-  ${MID}/ABELGRP.o  ${MID}/ABELGRP-.o ${MID}/ABELMON.o  ${MID}/ABELMON-.o \
-  ${MID}/ABELSG.o   ${MID}/ABELSG-.o  ${MID}/ALAGG.o    ${MID}/BOOLEAN.o  \
-  ${MID}/CABMON.o   ${MID}/CHAR.o     ${MID}/CLAGG.o    ${MID}/CLAGG-.o   \
-  ${MID}/COMRING.o  ${MID}/DFLOAT.o   ${MID}/DIFRING.o  ${MID}/DIFRING-.o \
-  ${MID}/DIVRING.o  ${MID}/DIVRING-.o ${MID}/ENTIRER.o  ${MID}/ES.o       \
-  ${MID}/ES-.o      ${MID}/EUCDOM.o   ${MID}/EUCDOM-.o  ${MID}/FFIELDC.o  \
-  ${MID}/FFIELDC-.o ${MID}/FPS.o      ${MID}/FPS-.o     ${MID}/GCDDOM.o   \
-  ${MID}/GCDDOM-.o  ${MID}/HOAGG.o    ${MID}/HOAGG-.o   ${MID}/ILIST.o    \
-  ${MID}/INS.o      ${MID}/INS-.o     ${MID}/INT.o      ${MID}/INTDOM.o   \
-  ${MID}/INTDOM-.o  ${MID}/ISTRING.o  ${MID}/LIST.o     ${MID}/LNAGG.o    \
-  ${MID}/LNAGG-.o   ${MID}/LSAGG.o    ${MID}/LSAGG-.o   ${MID}/MONOID.o   \
-  ${MID}/MONOID-.o  ${MID}/MTSCAT.o   ${MID}/NNI.o      ${MID}/OINTDOM.o  \
-  ${MID}/ORDRING.o  ${MID}/ORDRING-.o ${MID}/OUTFORM.o  ${MID}/PI.o       \
-  ${MID}/PRIMARR.o  ${MID}/POLYCAT.o  ${MID}/POLYCAT-.o ${MID}/PSETCAT.o  \
-  ${MID}/PSETCAT-.o ${MID}/QFCAT.o    ${MID}/QFCAT-.o   ${MID}/RCAGG.o    \
-  ${MID}/RCAGG-.o   ${MID}/REF.o      ${MID}/RING.o     ${MID}/RING-.o    \
-  ${MID}/RNG.o      ${MID}/RNS.o      ${MID}/RNS-.o     ${MID}/SETAGG.o   \
-  ${MID}/SETAGG-.o  ${MID}/SETCAT.o   ${MID}/SETCAT-.o  ${MID}/SINT.o     \
-  ${MID}/STAGG.o    ${MID}/STAGG-.o   ${MID}/SYMBOL.o   ${MID}/TSETCAT.o  \
-  ${MID}/TSETCAT-.o ${MID}/UFD.o      ${MID}/UFD-.o     ${MID}/ULSCAT.o   \
-  ${MID}/UPOLYC.o   ${MID}/UPOLYC-.o  ${MID}/URAGG.o    ${MID}/URAGG-.o   \
-  ${MID}/VECTOR.o \
-  layer0bootstrap
-
-\end{chunk}
-\begin{chunk}{layer0 copy}
-
-LAYER0COPY=\
-  ${OUT}/ABELGRP.o  ${OUT}/ABELGRP-.o ${OUT}/ABELMON.o  ${OUT}/ABELMON-.o \
-  ${OUT}/ABELSG.o   ${OUT}/ABELSG-.o  ${OUT}/ALAGG.o    ${OUT}/BOOLEAN.o  \
-  ${OUT}/CABMON.o   ${OUT}/CHAR.o     ${OUT}/CLAGG.o    ${OUT}/CLAGG-.o   \
-  ${OUT}/COMRING.o  ${OUT}/DFLOAT.o   ${OUT}/DIFRING.o  ${OUT}/DIFRING-.o \
-  ${OUT}/DIVRING.o  ${OUT}/DIVRING-.o ${OUT}/ENTIRER.o  ${OUT}/ES.o       \
-  ${OUT}/ES-.o      ${OUT}/EUCDOM.o   ${OUT}/EUCDOM-.o  ${OUT}/FFIELDC.o  \
-  ${OUT}/FFIELDC-.o ${OUT}/FPS.o      ${OUT}/FPS-.o     ${OUT}/GCDDOM.o   \
-  ${OUT}/GCDDOM-.o  ${OUT}/HOAGG.o    ${OUT}/HOAGG-.o   ${OUT}/ILIST.o    \
-  ${OUT}/INS.o      ${OUT}/INS-.o     ${OUT}/INT.o      ${OUT}/INTDOM.o   \
-  ${OUT}/INTDOM-.o  ${OUT}/ISTRING.o  ${OUT}/LIST.o     ${OUT}/LNAGG.o    \
-  ${OUT}/LNAGG-.o   ${OUT}/LSAGG.o    ${OUT}/LSAGG-.o   ${OUT}/MONOID.o   \
-  ${OUT}/MONOID-.o  ${OUT}/MTSCAT.o   ${OUT}/NNI.o      ${OUT}/OINTDOM.o  \
-  ${OUT}/ORDRING.o  ${OUT}/ORDRING-.o ${OUT}/OUTFORM.o  ${OUT}/PI.o       \
-  ${OUT}/PRIMARR.o  ${OUT}/POLYCAT.o  ${OUT}/POLYCAT-.o ${OUT}/PSETCAT.o  \
-  ${OUT}/PSETCAT-.o ${OUT}/QFCAT.o    ${OUT}/QFCAT-.o   ${OUT}/RCAGG.o    \
-  ${OUT}/RCAGG-.o   ${OUT}/REF.o      ${OUT}/RING.o     ${OUT}/RING-.o    \
-  ${OUT}/RNG.o      ${OUT}/RNS.o      ${OUT}/RNS-.o     ${OUT}/SETAGG.o   \
-  ${OUT}/SETAGG-.o  ${OUT}/SETCAT.o   ${OUT}/SETCAT-.o  ${OUT}/SINT.o     \
-  ${OUT}/STAGG.o    ${OUT}/STAGG-.o   ${OUT}/SYMBOL.o   ${OUT}/TSETCAT.o  \
-  ${OUT}/TSETCAT-.o ${OUT}/UFD.o      ${OUT}/UFD-.o     ${OUT}/ULSCAT.o   \
-  ${OUT}/UPOLYC.o   ${OUT}/UPOLYC-.o  ${OUT}/URAGG.o    ${OUT}/URAGG-.o   \
-  ${OUT}/VECTOR.o \
-  layer0copy
-
-\end{chunk}
-\subsection{Layer 0}
-Depends on: Category Domain Package Bootstrap\\
-Used by next layer: BASTYPE CFCAT KOERCE KONVERT TYPE
-\begin{chunk}{layer0}
-
-LAYER0=\
-  ${OUT}/AHYP.o     ${OUT}/ATADDVA.o  ${OUT}/ATCENRL.o  ${OUT}/ATCS.o \
-  ${OUT}/ATAPPRO.o  ${OUT}/ATARBEX.o \
-  ${OUT}/ATARBPR.o  ${OUT}/ATCANCL.o  ${OUT}/ATCANON.o  ${OUT}/ATCUNOR.o \
-  ${OUT}/ATFINAG.o  ${OUT}/ATJACID.o  ${OUT}/ATLR.o     ${OUT}/ATLUNIT.o \
-  ${OUT}/ATMULVA.o  ${OUT}/ATNOTHR.o  ${OUT}/ATNULSQ.o \
-  ${OUT}/ATNZDIV.o  ${OUT}/ATPOSET.o \
-  ${OUT}/ATSHMUT.o \
-  ${OUT}/ATTREG.o   ${OUT}/ATUNIKN.o \
-  ${OUT}/BASTYPE.o  ${OUT}/BASTYPE-.o \
-  ${OUT}/CFCAT.o    ${OUT}/ELTAB.o    ${OUT}/ESCONT1.o ${OUT}/GRDEF.o \
-  ${OUT}/INTBIT.o   ${OUT}/KOERCE.o   ${OUT}/KONVERT.o \
-  ${OUT}/MAGCDOC.o  ${OUT}/MSYSCMD.o \
-  ${OUT}/ODEIFTBL.o ${OUT}/OM.o       ${OUT}/OMCONN.o  ${OUT}/OMDEV.o  \
-  ${OUT}/OUT.o      ${OUT}/PRIMCAT.o  ${OUT}/PRINT.o   ${OUT}/PTRANFN.o \
-  ${OUT}/RFDIST.o   ${OUT}/RIDIST.o   ${OUT}/SPFCAT.o  ${OUT}/TYPE.o \
-  layer0done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 0 */
-/* depends on: Category Domain Package Bootstrap */
-/* provides: BASTYPE CFCAT KOERCE KONVERT TYPE */
-
-"AHYP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=AHYP"]
-"AHYP" -> "Category"
-
-"ATADDVA"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATADDVA"];
-"ATADDVA" -> "Category"
-
-"ATCENRL"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCENRL"];
-"ATCENRL" -> "Category"
-
-"ATCS"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCS"];
-"ATCS" -> "Category"
-
-"ATAPPRO"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATAPPRO"];
-"ATAPPRO" -> "Category"
-
-"ATARBEX"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATARBEX"];
-"ATARBEX" -> "Category"
-
-"ATARBPR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATARBPR"];
-"ATARBPR" -> "Category"
-
-"ATCANCL"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCANCL"];
-"ATCANCL" -> "Category"
-
-"ATCANON"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCANON"];
-"ATCANON" -> "Category"
-
-"ATCUNOR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATCUNOR"];
-"ATCUNOR" -> "Category"
-
-"ATFINAG"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATFINAG"];
-"ATFINAG" -> "Category"
-
-"ATJACID"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATJACID"];
-"ATJACID" -> "Category"
-
-"ATLR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATLR"];
-"ATLR" -> "Category"
-
-"ATLUNIT"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATLUNIT"];
-"ATLUNIT" -> "Category"
-
-"ATMULVA"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATMULVA"];
-"ATMULVA" -> "Category"
-
-"ATNOTHR"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATNOTHR"];
-"ATNOTHR" -> "Category"
-
-"ATNULSQ"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATNULSQ"];
-"ATNULSQ" -> "Category"
-
-"ATNZDIV"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATNZDIV"];
-"ATNZDIV" -> "Category"
-
-"ATSHMUT"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATSHMUT"];
-"ATSHMUT" -> "Category"
-
-"ATTREG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ATTREG"]
-"ATTREG"  -> "Category"
-
-"ATUNIKN"  [color=lightblue,href="bookvol10.2.pdf#nameddest=ATUNIKN"];
-"ATUNIKN" -> "Category"
-
-/* nobody seems to go to bastype by itself */
-/* we combine these two to minimize edges in the graph */
-/* note that koerce is duplicated */
-"BASTYPE/KOERCE" [color="blue",href="bookvol10.2.pdf#nameddest=BASTYPE"]
-"BASTYPE/KOERCE" -> "Category"
-/*"BASTYPE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BASTYPE"]*/
-/*"BASTYPE" -> "Category"*/
-/*"BASTYPE" -> "BOOLEAN"*/
-"KOERCE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=KOERCE"]
-"KOERCE"  -> "Category"
-
-"BASTYPE-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BASTYPE"]
-"BASTYPE-" -> "Domain"
-/*"BASTYPE-" -> "BOOLEAN"*/
-
-"CFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CFCAT"]
-"CFCAT"  -> "Category"
-
-"ELTAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELTAB"]
-"ELTAB"  -> "Category"
-
-"ESCONT1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESCONT1"]
-"ESCONT1" -> "Package"
-/*"ESCONT1" -> "DFLOAT"*/
-/*"ESCONT1" -> "BOOLEAN"*/
-
-"GRDEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GRDEF"]
-"GRDEF" -> "Package"
-/*"GRDEF" -> "BOOLEAN"*/
-
-"INTBIT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTBIT"]
-"INTBIT" -> "Package"
-/*"INTBIT" -> "INT"*/
-
-"KONVERT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=KONVERT"]
-"KONVERT"  -> "Category"
-
-"MAGCDOC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MAGCDOC"]
-"MAGCDOC" -> "Category"
-
-"MSYSCMD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MSYSCMD"]
-"MSYSCMD" -> "Package"
-
-"ODEIFTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODEIFTBL"]
-"ODEIFTBL" -> "Domain"
-
-"OM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OM"]
-"OM"  -> "Category"
-
-"OMCONN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMCONN"]
-"OMCONN" -> "Domain"
-
-"OMDEV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMDEV"]
-"OMDEV" -> "Domain"
-
-"OUT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OUT"]
-"OUT" -> "Package"
-/* "OUT" -> {"STRING", "CHAR", "SINT", "OUTFORM", "LIST", "INT"}*/
-/* "OUT" -> {"PRIMARR", "A1AGG-", "ISTRING"} */
-
-"PRIMCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PRIMCAT"]
-"PRIMCAT"  -> "Category"
-
-"PRINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRINT"]
-"PRINT" -> "Package"
-
-"PTRANFN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PTRANFN"]
-"PTRANFN"  -> "Category"
-
-"RFDIST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFDIST"]
-"RFDIST" -> "Package"
-/*"RFDIST" -> {"INT"; "PI"; "NNI"; "BOOLEAN"; "SINT"}*/
-
-"RIDIST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RIDIST"]
-"RIDIST" -> "Package"
-/*"RIDIST" -> {"SINT"; "NNI"; "INT"}*/
-
-"SPFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SPFCAT"]
-"SPFCAT"  -> "Category"
-
-"TYPE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TYPE"]
-"TYPE"  -> "Category"
-
-\end{chunk}
-\subsection{Layer 1}
-Depends on: BASTYPE CFCAT KOERCE KONVERT TYPE\\
-Used by next layer: AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE 
-MONAD ORDSET PATMAB RETRACT RMODULE SGROUP 
-
-\begin{chunk}{layer1}
-
-LAYER1=\
-  ${OUT}/AGG.o      ${OUT}/AGG-.o     ${OUT}/ANON.o     ${OUT}/ANY1.o     \
-  ${OUT}/BLMETCT.o  \
-  ${OUT}/COLOR.o    ${OUT}/COMBOPC.o  ${OUT}/COMM.o     ${OUT}/COMPAR.o   \
-  ${OUT}/COMPPROP.o \
-  ${OUT}/DROPT1.o   ${OUT}/ELTAGG.o   ${OUT}/ELTAGG-.o  ${OUT}/EQ2.o      \
-  ${OUT}/EXIT.o     ${OUT}/FILECAT.o  ${OUT}/FINITE.o   ${OUT}/FINITE-.o  \
-  ${OUT}/FNCAT.o    \
-  ${OUT}/FORMULA1.o ${OUT}/FORTCAT.o  ${OUT}/IDPC.o     ${OUT}/IEVALAB.o  \
-  ${OUT}/IEVALAB-.o ${OUT}/ITFUN2.o   ${OUT}/ITFUN3.o   ${OUT}/ITUPLE.o   \
-  ${OUT}/LIST3.o    ${OUT}/LMODULE.o  ${OUT}/LOGIC.o    ${OUT}/LOGIC-.o   \
-  ${OUT}/MAPHACK1.o ${OUT}/MAPHACK2.o ${OUT}/MAPHACK3.o ${OUT}/MAPPKG1.o  \
-  ${OUT}/MAPPKG2.o  ${OUT}/MAPPKG3.o  ${OUT}/MKBCFUNC.o ${OUT}/MKFUNC.o   \
-  ${OUT}/MKRECORD.o ${OUT}/MKUCFUNC.o ${OUT}/MONAD.o    ${OUT}/MONAD-.o   \
-  ${OUT}/NIPROB.o   ${OUT}/NONE.o     ${OUT}/NONE1.o    ${OUT}/NUMINT.o   \
-  ${OUT}/ODECAT.o   ${OUT}/ODEPROB.o  ${OUT}/OMENC.o    ${OUT}/ONECOMP2.o \
-  ${OUT}/OPTCAT.o   ${OUT}/OPTPROB.o  ${OUT}/ORDCOMP2.o ${OUT}/ORDSET.o   \
-  ${OUT}/ORDSET-.o  ${OUT}/PALETTE.o  ${OUT}/PARPCURV.o ${OUT}/PARPC2.o   \
-  ${OUT}/PARSCURV.o ${OUT}/PARSC2.o   ${OUT}/PARSURF.o  ${OUT}/PARSU2.o   \
-  ${OUT}/PATAB.o    ${OUT}/PATMAB.o   ${OUT}/PATRES2.o  ${OUT}/PATTERN1.o \
-  ${OUT}/PDECAT.o   ${OUT}/PDEPROB.o  ${OUT}/PLOT1.o    ${OUT}/PPCURVE.o  \
-  ${OUT}/PSCURVE.o  ${OUT}/REAL.o     ${OUT}/REPDB.o    ${OUT}/REPSQ.o    \
-  ${OUT}/RESLATC.o  ${OUT}/RETRACT.o  ${OUT}/RETRACT-.o ${OUT}/RMODULE.o  \
-  ${OUT}/SEGBIND2.o ${OUT}/SEGCAT.o   ${OUT}/SETCATD.o  \
-  ${OUT}/SEXCAT.o   ${OUT}/SGROUP.o   \
-  ${OUT}/SGROUP-.o  ${OUT}/SPACEC.o   ${OUT}/SPLNODE.o  ${OUT}/STEP.o     \
-  ${OUT}/STNSR.o    \
-  ${OUT}/STREAM1.o  ${OUT}/STREAM2.o  ${OUT}/STREAM3.o  ${OUT}/SUCH.o     \
-  ${OUT}/TEX1.o     ${OUT}/UDVO.o     ${OUT}/YSTREAM.o \
-  layer1done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 1 */
-/* depends on: BASTYPE CFCAT KOERCE KONVERT TYPE */
-/* provides: FORTCAT RETRACT SEGCAT */
-
-"AGG"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=AGG"]
-"AGG" -> "TYPE"
-/*"AGG" -> "NNI"*/
-/*"AGG" -> "INT"*/
-
-"AGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AGG"]
-"AGG-" -> "TYPE"
-/*"AGG-" -> "NNI"*/
-/*"AGG-" -> "INT"*/
-
-"ANON" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ANON"]
-/*"ANON" -> "SETCAT"*/
-"ANON" -> "BASTYPE/KOERCE"
-/*"ANON" -> "KOERCE"*/
-
-"ANY1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ANY1"]
-"ANY1" -> "TYPE"
-
-"BLMETCT"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=BLMETCT"]
-"BLMETCT" -> {"SETCAT", "BASTYPE/KOERCE"}
-
-"CABMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CABMON",
-           shape=ellipse]
-/*"CABMON" -> {"ABELMON"; "ABELSG"; "SETCAT"}*/
-"CABMON" -> "BASTYPE/KOERCE"
-/*"CABMON" -> "KOERCE"*/
-
-"COLOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COLOR"]
-/*"COLOR" -> "ABELSG"*/
-/*"COLOR" -> "SETCAT"*/
-"COLOR" -> "BASTYPE/KOERCE"
-/*"COLOR" -> {"KOERCE"; "DFLOAT"; "INT"; "FPS-"; "RNS-"; "NNI"; "PI"}*/
-/*"COLOR" -> "BOOLEAN"*/
-
-"COMBOPC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMBOPC"]
-"COMBOPC" -> "CFCAT"
-
-"COMM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMM"]
-/*"COMM" -> "SETCAT"*/
-"COMM" -> "BASTYPE/KOERCE"
-/*"COMM" -> {"KOERCE"; "BOOLEAN"}*/
-
-"COMPAR" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMPAR"]
-/*"COMPAR" -> "SETCAT"*/
-"COMPAR" -> "BASTYPE/KOERCE"
-
-"COMPPROP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMPPROP"]
-/*"COMPPROP" -> "SETCAT"*/
-"COMPPROP" -> "BASTYPE/KOERCE"
-/*"COMPPROP" -> {"KOERCE"; "BOOLEAN"}*/
-
-"DROPT1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DROPT1"]
-"DROPT1" -> "TYPE"
-
-"ELTAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELTAGG"]
-/*"ELTAGG" -> "ELTAB"*/
-/*"ELTAGG" -> "SETCAT"*/
-"ELTAGG" -> "BASTYPE/KOERCE"
-/*"ELTAGG" -> "KOERCE"*/
-"ELTAGG" -> "TYPE"
-
-"ELTAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ELTAGG"]
-/*"ELTAGG-" -> {"ELTAB"; "SETCAT"}*/
-"ELTAGG-" -> "BASTYPE/KOERCE"
-/*"ELTAGG-" -> "KOERCE"*/
-"ELTAGG-" -> "TYPE"
-
-"EQ2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EQ2"]
-"EQ2" -> "TYPE"
-
-"EXIT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXIT"]
-/*"EXIT" -> "SETCAT"*/
-"EXIT" -> "BASTYPE/KOERCE"
-/*"EXIT" -> "KOERCE"*/
-
-"FILECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FILECAT"]
-/*"FILECAT" -> "SETCAT"*/
-"FILECAT" -> "BASTYPE/KOERCE"
-/*"FILECAT" -> "KOERCE"*/
-
-"FINITE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FINITE"]
-/*"FINITE" -> "SETCAT"*/
-"FINITE" -> "BASTYPE/KOERCE"
-/*"FINITE" -> "KOERCE"*/
-
-"FNCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FNCAT"]
-/*"FNCAT" -> "SETCAT"*/
-"FNCAT" -> "BASTYPE/KOERCE"
-/*"FNCAT" -> "KOERCE"*/
-
-"FORMULA1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FORMULA1"]
-/*"FORMULA1" -> "SETCAT"*/
-"FORMULA1" -> "BASTYPE/KOERCE"
-/*"FORMULA1" -> "KOERCE"*/
-
-"FORTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FORTCAT"]
-"FORTCAT" -> "TYPE"
-/*"FORTCAT" -> "KOERCE"*/
-
-"IDPC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=IDPC"]
-/*"IDPC" -> "SETCAT"*/
-"IDPC" -> "BASTYPE/KOERCE"
-/*"IDPC" -> "KOERCE"*/
-
-"IEVALAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=IEVALAB"]
-/*"IEVALAB" -> "SETCAT"*/
-"IEVALAB" -> "BASTYPE/KOERCE"
-/*"IEVALAB" -> "KOERCE"*/
-"IEVALAB" -> "TYPE"
-
-"IEVALAB-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IEVALAB"]
-/*"IEVALAB-" -> "SETCAT"*/
-"IEVALAB-" -> "BASTYPE/KOERCE"
-/*"IEVALAB-" -> "KOERCE"*/
-"IEVALAB-" -> "TYPE"
-
-"ITFUN2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ITFUN2"]
-"ITFUN2" -> "TYPE"
-
-"ITFUN3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ITFUN3"]
-"ITFUN3" -> "TYPE"
-
-"ITUPLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ITUPLE"]
-/*"ITUPLE" -> "KOERCE"*/
-"ITUPLE" -> "TYPE"
-
-"LIST3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIST3"]
-"LIST3" -> "TYPE"
-/*"LIST3" -> {"INT"; "LIST"; "ILIST"}*/
-
-"LOGIC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LOGIC"]
-"LOGIC" -> "BASTYPE/KOERCE"
-
-"LOGIC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LOGIC"]
-"LOGIC-" -> "BASTYPE/KOERCE"
-
-"MAPHACK1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPHACK1"]
-/*"MAPHACK1" -> "SETCAT"*/
-"MAPHACK1" -> "BASTYPE/KOERCE"
-/*"MAPHACK1" -> {"KOERCE"; "SINT"; "NNI"; "INT"}*/
-
-"MAPHACK2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPHACK2"]
-/*"MAPHACK2" -> "SETCAT"*/
-"MAPHACK2" -> "BASTYPE/KOERCE"
-/*"MAPHACK2" -> "KOERCE"*/
-
-"MAPHACK3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPHACK3"]
-/*"MAPHACK3" -> "SETCAT"*/
-"MAPHACK3" -> "BASTYPE/KOERCE"
-/*"MAPHACK3" -> "KOERCE"*/
-
-"MAPPKG1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG1"]
-/*"MAPPKG1" -> "SETCAT"*/
-"MAPPKG1" -> "BASTYPE/KOERCE"
-/*"MAPPKG1" -> {"KOERCE"; "SINT"; "NNI"; "INT"; "BOOLEAN"}*/
-
-"MAPPKG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG2"]
-/*"MAPPKG2" -> "SETCAT"*/
-"MAPPKG2" -> "BASTYPE/KOERCE"
-/*"MAPPKG2" -> "KOERCE"*/
-
-"MAPPKG3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG3"]
-/*"MAPPKG3" -> "SETCAT"*/
-"MAPPKG3" -> "BASTYPE/KOERCE"
-/*"MAPPKG3" -> "KOERCE"*/
-
-"MKBCFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKBCFUNC"]
-"MKBCFUNC" -> "KONVERT"
-"MKBCFUNC" -> "TYPE"
-
-"MKFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKFUNC"]
-"MKFUNC" -> "KONVERT"
-/*"MKFUNC" -> {"INT"; "LIST"}*/
-
-"MKRECORD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKRECORD"]
-"MKRECORD" -> "TYPE"
-
-"MKUCFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKUCFUNC"]
-"MKUCFUNC" -> "KONVERT"
-"MKUCFUNC" -> "TYPE"
-
-"MONAD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONAD"]
-/*"MONAD" -> "SETCAT"*/
-"MONAD" -> "BASTYPE/KOERCE"
-/*"MONAD" -> {"KOERCE"; "PI"; "NNI"; "INT"; "SINT"}*/
-
-"MONAD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONAD"]
-/*"MONAD-" -> "SETCAT"*/
-"MONAD-" -> "BASTYPE/KOERCE"
-/*"MONAD-" -> {"KOERCE"; "PI"; "NNI"; "INT"; "SINT"}*/
-
-"NIPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NIPROB"]
-/*"NIPROB" -> "SETCAT"*/
-"NIPROB" -> "BASTYPE/KOERCE"
-/*"NIPROB" -> "KOERCE"*/
-
-"NONE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NONE"]
-/*"NONE" -> "SETCAT"*/
-"NONE" -> "BASTYPE/KOERCE"
-/*"NONE" -> "KOERCE"*/
-
-"NONE1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NONE1"]
-"NONE1" -> "TYPE"
-
-"NUMINT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NUMINT"]
-/*"NUMINT" -> "SETCAT"*/
-"NUMINT" -> "BASTYPE/KOERCE"
-/*"NUMINT" -> "KOERCE"*/
-
-"ODECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ODECAT"]
-/*"ODECAT" -> "SETCAT"*/
-"ODECAT" -> "BASTYPE/KOERCE"
-/*"ODECAT" -> "KOERCE"*/
-
-"ODEPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODEPROB"]
-/*"ODEPROB" -> "SETCAT"*/
-"ODEPROB" -> "BASTYPE/KOERCE"
-/*"ODEPROB" -> "KOERCE"*/
-
-"OMENC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMENC"]
-/*"OMENC" -> "SETCAT"*/
-"OMENC" -> "BASTYPE/KOERCE"
-/*"OMENC" -> {"KOERCE"; "SINT"}*/
-
-"ONECOMP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ONECOMP2"]
-/*"ONECOMP2" -> "SETCAT"*/
-"ONECOMP2" -> "BASTYPE/KOERCE"
-/*"ONECOMP2" -> "KOERCE"*/
-
-"OPTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OPTCAT"]
-/*"OPTCAT" -> "SETCAT"*/
-"OPTCAT" -> "BASTYPE/KOERCE"
-/*"OPTCAT" -> "KOERCE"*/
-
-"OPTPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OPTPROB"]
-/*"OPTPROB" -> "SETCAT"*/
-"OPTPROB" -> "BASTYPE/KOERCE"
-/*"OPTPROB" -> "KOERCE"*/
-
-"ORDCOMP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ORDCOMP2"]
-/*"ORDCOMP2" -> "SETCAT"*/
-"ORDCOMP2" -> "BASTYPE/KOERCE"
-/*"ORDCOMP2" -> {"KOERCE"; "SINT"}*/
-
-"ORDSET" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDSET"]
-/*"ORDSET" -> "SETCAT"*/
-"ORDSET" -> "BASTYPE/KOERCE"
-/*"ORDSET" -> {"KOERCE"; "BOOLEAN"}*/
-
-"ORDSET-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ORDSET"]
-/*"ORDSET-" -> "SETCAT"*/
-"ORDSET-" -> "BASTYPE/KOERCE"
-/*"ORDSET-" -> {"KOERCE"; "BOOLEAN"}*/
-
-"PALETTE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PALETTE"]
-/*"PALETTE" -> "SETCAT"*/
-"PALETTE" -> "BASTYPE/KOERCE"
-/*"PALETTE" -> {"KOERCE"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-
-"PARPCURV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PARPCURV"]
-"PARPCURV" -> "TYPE"
-/*"PARPCURV" -> "NNI"*/
-/*"PARPCURV" -> "INT"*/
-
-"PARPC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARPC2"]
-"PARPC2" -> "TYPE"
-/*"PARPC2" -> "NNI"*/
-/*"PARPC2" -> "INT"*/
-
-"PARSCURV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PARSCURV"]
-"PARSCURV" -> "TYPE"
-/*"PARSCURV" -> "NNI"*/
-/*"PARSCURV" -> "INT"*/
-
-"PARSC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARSC2"]
-"PARSC2" -> "TYPE"
-/*"PARSC2" -> "NNI"*/
-/*"PARSC2" -> "INT"*/
-
-"PARSURF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PARSURF"]
-"PARSURF" -> "TYPE"
-/*"PARSURF" -> "NNI"*/
-/*"PARSURF" -> "INT"*/
-
-"PARSU2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARSU2"]
-"PARSU2" -> "TYPE"
-/*"PARSU2" -> "NNI"*/
-/*"PARSU2" -> "INT"*/
-
-"PATAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PATAB"]
-"PATAB" -> "KONVERT"
-
-"PATMAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PATMAB"]
-/*"PATMAB" -> "SETCAT"*/
-"PATMAB" -> "BASTYPE/KOERCE"
-/*"PATMAB" -> "KOERCE"*/
-
-"PATRES2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATRES2"]
-/*"PATRES2" -> "SETCAT"*/
-"PATRES2" -> "BASTYPE/KOERCE"
-/*"PATRES2" -> "KOERCE" */
-
-"PATTERN1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATTERN1"]
-/*"PATTERN1" -> "SETCAT"*/
-"PATTERN1" -> "BASTYPE/KOERCE"
-/*"PATTERN1" -> "KOERCE"*/
-"PATTERN1" -> "TYPE"
-/*"PATTERN1" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "BOOLEAN"}*/
-
-"PDECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PDECAT"]
-/*"PDECAT" -> "SETCAT"*/
-"PDECAT" -> "BASTYPE/KOERCE"
-/*"PDECAT" -> "KOERCE"*/
-
-"PDEPROB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PDEPROB"]
-/*"PDEPROB" -> "SETCAT"*/
-"PDEPROB" -> "BASTYPE/KOERCE"
-/*"PDEPROB" -> "KOERCE"*/
-
-"PLOT1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PLOT1"]
-"PLOT1" -> "KONVERT"
-
-"PPCURVE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PPCURVE"]
-"PPCURVE" -> "KOERCE"
-
-"REAL" [color="#4488FF",href="bookvol10.2.pdf#nameddest=REAL"]
-"REAL" -> "KONVERT"
-
-"REF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=REF",
-          shape=ellipse]
-"REF" -> "TYPE"
-/*"REF" -> "SETCAT"*/
-"REF" -> "BASTYPE/KOERCE"
-/*"REF" -> "KOERCE"*/
-
-"REPDB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REPDB"]
-/*"REPDB" -> "SETCAT"*/
-"REPDB" -> "BASTYPE/KOERCE"
-/*"REPDB" -> {"KOERCE"; "PI"; "NNI"; "INT"}*/
-
-"REPSQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REPSQ"]
-/*"REPSQ" -> "SETCAT"*/
-"REPSQ" -> "BASTYPE/KOERCE"
-/*"REPSQ" -> {"KOERCE"; "PI"; "NNI"; "INT"}*/
-
-"RESLATC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RESLATC"]
-"RESLATC" -> "TYPE"
-
-"RETRACT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RETRACT"]
-"RETRACT" -> "TYPE"
-
-"RETRACT-" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RETRACT"]
-"RETRACT-" -> "TYPE"
-
-"RMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RMODULE"]
-/*"RMODULE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-"RMODULE" -> "BASTYPE/KOERCE"
-/*"RMODULE" -> "KOERCE"*/
-
-"SEGBIND2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SEGBIND2"]
-"SEGBIND2" -> "TYPE"
-
-"SEGCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SEGCAT"]
-"SEGCAT" -> "TYPE"
-
-"SETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SETCAT",
-          shape=ellipse]
-"SETCAT" -> "BASTYPE/KOERCE"
-/*"SETCAT" -> "KOERCE"*/
-/*"SETCAT" -> "SINT"*/
-
-"SETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SETCAT",
-          shape=ellipse]
-"SETCAT-" -> "BASTYPE/KOERCE"
-/*"SETCAT-" -> {"KOERCE"; "SINT"}*/
-
-"SETCATD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SETCATD"]
-/*"SETCATD" -> "SETCAT"*/
-"SETCATD" -> "BASTYPE/KOERCE"
-
-"SEXCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SEXCAT"]
-/*"SEXCAT" -> "SETCAT"*/
-"SEXCAT" -> "BASTYPE/KOERCE"
-/*"SEXCAT" -> "KOERCE"*/
-
-/* We combine LMODULE and SGROUP to minimize edges */
-"LMODULE/SGROUP" [color="blue",href="bookvol10.2.pdf#nameddest=LMODULE"]
-"LMODULE/SGROUP" -> "BASTYPE/KOERCE"
-/*"LMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LMODULE"]*/
-/*"LMODULE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"LMODULE" -> {"BASTYPE/KOERCE"; "KOERCE"}*/
-
-"SGROUP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SGROUP"]
-/*"SGROUP" -> "SETCAT"*/
-"SGROUP" -> "BASTYPE/KOERCE"
-/*"SGROUP" -> "KOERCE"*/
-
-"SGROUP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SGROUP"]
-/*"SGROUP" -> "SETCAT"*/
-"SGROUP-" -> "BASTYPE/KOERCE"
-/*"SGROUP-" -> "KOERCE"*/
-
-"SPACEC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SPACEC"]
-/*"SPACEC" -> "SETCAT"*/
-"SPACEC" -> "BASTYPE/KOERCE"
-/*"SPACEC" -> "KOERCE"*/
-
-"SPLNODE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SPLNODE"]
-/*"SPLNODE" -> "SETCAT"*/
-"SPLNODE" -> "BASTYPE/KOERCE"
-/*"SPLNODE" -> {"KOERCE"; "AGG"}*/
-"SPLNODE" -> "TYPE"
-/*"SPLNODE" -> "BOOLEAN"*/
-
-"STEP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=STEP"]
-/*"STEP" -> "SETCAT"*/
-"STEP" -> "BASTYPE/KOERCE"
-/*"STEP" -> "KOERCE"*/
-
-"STNSR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STNSR"]
-"STNSR" -> "TYPE"
-
-"STREAM1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STREAM1"]
-"STREAM1" -> "TYPE"
-
-"STREAM2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STREAM2"]
-"STREAM2" -> "TYPE"
-
-"STREAM3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STREAM3"]
-"STREAM3" -> "TYPE"
-
-"SUCH" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUCH"]
-/*"SUCH" -> "SETCAT"*/
-"SUCH" -> "BASTYPE/KOERCE"
-/*"SUCH" -> "KOERCE"*/
-
-"TEX1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TEX1"]
-/*"TEX1" -> "SETCAT"*/
-"TEX1" -> "BASTYPE/KOERCE"
-/*"TEX1" -> "KOERCE"*/
-
-"UDVO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UDVO"]
-/*"UDVO" -> {"INT"; "LIST"; "ILIST"; "ORDSET"; "SETCAT"}*/
-"UDVO" -> "BASTYPE/KOERCE"
-/*"UDVO" -> "KOERCE"*/
-
-"YSTREAM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=YSTREAM"]
-"YSTREAM" -> "TYPE"
-/*"YSTREAM" -> {"INT"; "SINT"; "NNI"}*/
-
-\end{chunk}
-\subsection{Layer 2}
-Depends on: AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE MONAD ORDSET 
-PATMAB RETRACT RMODULE SGROUP SETCATD \\
-Used by next layer: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG 
-OASGP PDRING 
-\begin{chunk}{layer2}
-
-LAYER2=\
-  ${OUT}/AFSPCAT.o  \
-  ${OUT}/API.o      ${OUT}/ASP29.o    ${OUT}/ATRIG.o    ${OUT}/ATRIG-.o   \
-  ${OUT}/BEZIER.o   ${OUT}/BLHN.o     \
-  ${OUT}/BLQT.o     ${OUT}/BMODULE.o  ${OUT}/CACHSET.o  \
-  ${OUT}/CHARNZ.o   ${OUT}/CHARZ.o    ${OUT}/DVARCAT.o  ${OUT}/DVARCAT-.o \
-  ${OUT}/ELEMFUN.o  ${OUT}/ELEMFUN-.o ${OUT}/ESTOOLS2.o ${OUT}/EVALAB.o   \
-  ${OUT}/EVALAB-.o  ${OUT}/FAMONC.o   ${OUT}/FCOMP.o    ${OUT}/FEVALAB.o  \
-  ${OUT}/FEVALAB-.o ${OUT}/FMC.o      ${OUT}/FMFUN.o    ${OUT}/FORTFN.o   \
-  ${OUT}/FPATMAB.o  ${OUT}/FVC.o      ${OUT}/FVFUN.o    ${OUT}/GROUP.o    \
-  ${OUT}/GROUP-.o   ${OUT}/IDPAG.o    ${OUT}/IDPAM.o    ${OUT}/IDPO.o     \
-  ${OUT}/INCRMAPS.o ${OUT}/INTRET.o   ${OUT}/IXAGG.o    ${OUT}/IXAGG-.o   \
-  ${OUT}/KERNEL2.o  ${OUT}/LALG.o     ${OUT}/LALG-.o    ${OUT}/LINEXP.o   \
-  ${OUT}/MODMONOM.o ${OUT}/MONADWU.o  ${OUT}/MONADWU-.o ${OUT}/MRF2.o     \
-  ${OUT}/NARNG.o    ${OUT}/NARNG-.o   ${OUT}/NSUP2.o    ${OUT}/OASGP.o    \
-  ${OUT}/ODVAR.o    ${OUT}/OPQUERY.o  ${OUT}/ORDFIN.o   ${OUT}/ORDMON.o   \
-  ${OUT}/PATMATCH.o ${OUT}/PERMCAT.o  ${OUT}/PDRING.o   ${OUT}/PDRING-.o  \
-  ${OUT}/PLACESC.o  ${OUT}/PRSPCAT.o  \
-  ${OUT}/SDVAR.o    ${OUT}/SEGXCAT.o  ${OUT}/SUP2.o     ${OUT}/TRIGCAT.o  \
-  ${OUT}/TRIGCAT-.o ${OUT}/ULS2.o     ${OUT}/UP2.o \
-  layer2done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 2 */
-/* AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE MONAD ORDSET */
-/* PATMAB RETRACT RMODULE SEGCAT SGROUP SETCATD */
-
-"AFSPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=AFSPCAT",
-          shape=ellipse]
-"AFSPCAT" -> "SETCATD"
-/*"AFSPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"ABELGRP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ABELGRP",
-           shape=ellipse]
-/*"ABELGRP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"ABELGRP" -> {"KOERCE"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-"ABELGRP" -> "LMODULE/SGROUP"
-/*"ABELGRP" -> "INT"*/
-
-"ABELGRP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ABELGRP",
-           shape=ellipse]
-/*"ABELGRP-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"ABELGRP-" -> {"KOERCE"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-"ABELGRP-" -> "LMODULE/SGROUP"
-/*"ABELGRP-" -> "INT"*/
-
-"ABELMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ABELMON",
-           shape=ellipse]
-/*"ABELMON" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
-/*"ABELMON" -> {"ABELGRP"; "CABMON"; "SGROUP"; "MONOID"}*/
-"ABELMON" -> "LMODULE/SGROUP"
-/*"ABELMON" -> {"NNI"; "INT"}*/
-
-"ABELMON-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ABELMON",
-           shape=ellipse]
-/*"ABELMON-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
-/*"ABELMON-" -> {"ABELGRP"; "CABMON"; "SGROUP"; "MONOID"}*/
-"ABELMON-" -> "LMODULE/SGROUP"
-/*"ABELMON-" -> {"NNI"; "INT"}*/
-
-"ABELSG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ABELSG",
-           shape=ellipse]
-/*"ABELSG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ABELSG" -> {"CABMON"; "ABELMON"; "SGROUP"; "MONOID"}*/
-"ABELSG" -> "LMODULE/SGROUP"
-
-"ABELSG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ABELSG",
-           shape=ellipse]
-/*"ABELSG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ABELSG-" -> {"CABMON"; "ABELMON"; "SGROUP"; "MONOID"}*/
-"ABELSG-" -> "LMODULE/SGROUP"
-
-"API"  [color="#FF4488",href="bookvol10.4.pdf#nameddest=API"]
-/*"API" -> {"INT"; "LIST"; "ILIST"}*/
-"API" -> "ORDSET"
-/*"API" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"ATRIG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ATRIG"]
-/*"ATRIG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ATRIG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"ATRIG" -> "LMODULE/SGROUP"
-
-"ATRIG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ATRIG"]
-/*"ATRIG-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ATRIG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"ATRIG-" -> "LMODULE/SGROUP"
-
-"BEZIER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BEZIER"]
-/*"BEZIER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"BEZIER" -> {"SETCAT"; "BASTYPE"; "KOERCE" "SGROUP"; "MONOID"; "LMODULE"} */
-"BEZIER" -> "LMODULE/SGROUP"
-
-"BLQT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BLQT"]
-"BLQT" -> "BLMETCT"
-/*"BLQT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"BLQT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BLQT"]
-"BLQT" -> "BLMETCT"
-/*"BLQT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"BLQT" -> {"STAGG-"; "PI"; "NNI"}*/
-
-"BMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BMODULE"]
-/*"BMODULE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"BMODULE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"BMODULE" -> "LMODULE/SGROUP"
-"BMODULE" -> "RMODULE"
-
-"CACHSET" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CACHSET"]
-"CACHSET" -> "ORDSET"
-/*"CACHSET" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"CHARNZ" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CHARNZ"]
-/*"CHARNZ" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"CHARNZ" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"CHARNZ" -> "LMODULE/SGROUP"
-
-"CHARZ" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CHARZ"]
-/*"CHARZ" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"CHARZ" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"CHARZ" -> "LMODULE/SGROUP"
-
-"DIFRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIFRING",
-           shape=ellipse]
-/*"DIFRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DIFRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"DIFRING" -> "LMODULE/SGROUP"
-/*"DIFRING" -> {"SINT"; "NNI"; "INT"}*/
-
-"DIFRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIFRING",
-           shape=ellipse]
-/*"DIFRING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DIFRING-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"DIFRING-" -> "LMODULE/SGROUP"
-/*"DIFRING-" -> {"SINT"; "NNI"; "INT"}*/
-
-"DVARCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DVARCAT"]
-"DVARCAT" -> "ORDSET"
-/*"DVARCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"DVARCAT" -> "RETRACT"
-/*"DVARCAT" -> {"NNI"; "INT"; "BOOLEAN"}*/
-
-"DVARCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DVARCAT"]
-"DVARCAT-" -> "ORDSET"
-/*"DVARCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"DVARCAT-" -> "RETRACT"
-/*"DVARCAT-" -> {"NNI"; "INT"; "BOOLEAN"}*/
-
-"ELEMFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELEMFUN"]
-/*"ELEMFUN" -> "MONOID"*/
-"ELEMFUN" -> "SGROUP"
-/*"ELEMFUN" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"ELEMFUN-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ELEMFUN"]
-/*"ELEMFUN-" -> "MONOID"*/
-"ELEMFUN-" -> "SGROUP"
-/*"ELEMFUN-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"ESTOOLS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESTOOLS2"]
-/*"ESTOOLS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ESTOOLS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"ESTOOLS2" -> "LMODULE/SGROUP"
-
-"EVALAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=EVALAB"]
-"EVALAB" -> "IEVALAB"
-/*"EVALAB" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"EVALAB-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EVALAB"]
-"EVALAB-" -> "IEVALAB"
-/*"EVALAB-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"FAMONC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FAMONC"]
-/*"FAMONC" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"FAMONC" -> "RETRACT"
-
-"FCOMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FCOMP"]
-"FCOMP" -> "ORDSET"
-/*"FCOMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"}*/
-
-"FEVALAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FEVALAB"]
-/*"FEVALAB" -> {"ELTAB"; "EVALAB"}*/
-"FEVALAB" -> "IEVALAB"
-/*"FEVALAB" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"FEVALAB-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FEVALAB"]
-/*"FEVALAB-" -> {"ELTAB"; "EVALAB"}*/
-"FEVALAB-" -> "IEVALAB"
-/*"FEVALAB-" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"FMC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMC"]
-"FMC" -> "FORTCAT"
-/*"FMC" -> {"TYPE"; "KOERCE"}*/
-
-"FMFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMFUN"]
-"FMFUN" -> "FORTCAT"
-/*"FMFUN" -> {"TYPE"; "KOERCE"}*/
-
-"FORTFN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FORTFN"]
-"FORTFN" -> "FORTCAT"
-/*"FORTFN" -> {"TYPE"; "KOERCE"}*/
-
-"FPATMAB" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FPATMAB"]
-/*"FPATMAB" -> "TYPE"*/
-"FPATMAB" -> "PATMAB"
-/*"FPATMAB" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"FVC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FVC"]
-"FVC" -> "FORTCAT"
-/*"FVC" -> {"TYPE"; "KOERCE"}*/
-
-"FVFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FVFUN"]
-"FVFUN" -> "FORTCAT"
-/*"FVFUN" -> {"TYPE"; "KOERCE"}*/
-
-"GROUP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GROUP"]
-/*"GROUP" -> "MONOID"*/
-"GROUP" -> "SGROUP"
-/*"GROUP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"}*/
-
-"GROUP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GROUP"]
-/*"GROUP-" -> "MONOID"*/
-"GROUP-" -> "SGROUP"
-/*"GROUP-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"}*/
-
-"IDPAG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPAG"]
-/*"IDPAG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"IDPAG" -> {"BASTYPE"; "KOERCE"}*/ 
-"IDPAG" -> "IDPC"
-"IDPAG" -> "ORDSET"
-/*"IDPAG" -> {"INT"; "BOOLEAN"; "LIST"; "ILIST"}*/
-
-"IDPAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPAM"]
-/*"IDPAM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"IDPAM" -> "IDPC"
-"IDPAM" -> "ORDSET"
-/*"IDPAM" -> {"INT"; "LIST"; "ILIST"; "BOOLEAN"; "NNI"}*/
-
-"IDPO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPO"]
-"IDPO" -> "IDPC"
-/*"IDPO" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"IDPO" -> "ORDSET"
-/*"IDPO" -> {"INT"; "LIST"; "BOOLEAN"; "ILIST"}*/
-
-"INCRMAPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INCRMAPS"]
-/*"INCRMAPS" -> "MONOID"*/
-"INCRMAPS" -> "SGROUP"
-/*"INCRMAPS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELSG"}*/
-
-"INTRET" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTRET"]
-"INTRET" -> "RETRACT"
-
-"IXAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=IXAGG"]
-/*"IXAGG" -> "HOAGG"*/
-"IXAGG" -> "AGG"
-/*"IXAGG" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-"IXAGG" -> "ELTAGG"
-/*"IXAGG" -> "ELTAB"*/
-"IXAGG" -> "ORDSET"
-
-"IXAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IXAGG"]
-/*"IXAGG-" -> "HOAGG"*/
-"IXAGG-" -> "AGG"
-/*"IXAGG-" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-"IXAGG-" -> "ELTAGG"
-/*"IXAGG-" -> "ELTAB"*/
-"IXAGG-" -> "ORDSET"
-
-"KERNEL2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=KERNEL2"]
-"KERNEL2" -> "ORDSET"
-/*"KERNEL2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "NNI"}*/
-
-"LALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LALG"]
-/*"LALG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"LALG" -> "LMODULE/SGROUP"
-
-"LALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LALG"]
-/*"LALG-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LALG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"LALG-" -> "LMODULE/SGROUP"
-
-"LINEXP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LINEXP"]
-/*"LINEXP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LINEXP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"LINEXP" -> "LMODULE/SGROUP"
-
-"MODMONOM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODMONOM"]
-"MODMONOM" -> "ORDSET"
-/*"MODMONOM" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"MONADWU" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONADWU"]
-"MONADWU" -> "MONAD"
-/*"MONADWU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "SINT"}*/
-
-"MONADWU-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONADWU"]
-"MONADWU-" -> "MONAD"
-/*"MONADWU-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "SINT"}*/
-
-"MONOID" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONOID",
-          shape=ellipse]
-"MONOID" -> "SGROUP"
-/*"MONOID" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-
-"MONOID-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONOID",
-          shape=ellipse]
-"MONOID-" -> "SGROUP"
-/*"MONOID-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-
-"MRF2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MRF2"]
-/*"MRF2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"MRF2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"MRF2" -> "LMODULE/SGROUP"
-
-"NARNG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NARNG"]
-/*"NARNG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NARNG" -> {"BASTYPE"; "KOERCE"}*/
-"NARNG" -> "MONAD"
-
-"NARNG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NARNG"]
-/*"NARNG-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NARNG-" -> {"BASTYPE"; "KOERCE"}*/
-"NARNG-" -> "MONAD"
-
-"NSUP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NSUP2"]
-/*"NSUP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"NSUP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"NSUP2" -> "LMODULE/SGROUP"
-
-"OASGP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OASGP"]
-"OASGP" -> "ORDSET"
-/*"OASGP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
-
-"ODVAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODVAR"]
-/*"ODVAR" -> "DVARCAT"*/
-"ODVAR" -> "ORDSET"
-/*"ODVAR" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"ODVAR" -> "RETRACT"
-
-"OPQUERY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OPQUERY"]
-"OPQUERY" -> "ORDSET"
-/*"OPQUERY" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"ORDFIN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDFIN"]
-"ORDFIN" -> "ORDSET"
-/*"ORDFIN" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"ORDFIN" -> "FINITE"
-
-"ORDMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDMON"]
-"ORDMON" -> "ORDSET"
-/*"ORDMON" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONOID"}*/
-"ORDMON" -> "SGROUP"
-
-"PATMATCH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATMATCH"]
-/*"PATMATCH" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"PATMATCH" -> "PATMAB"
-/*"PATMATCH" -> {"KONVERT"; "BOOLEAN"}*/
-"PATMATCH" -> "RETRACT"
-/*"PATMATCH" -> {"INT"; "LIST"; "ILIST"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PATMATCH" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-"PATMATCH" -> "LMODULE/SGROUP"
-
-"PDRING"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=PDRING"]
-/*"PDRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PDRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"PDRING" -> "LMODULE/SGROUP"
-/*"PDRING" -> {"SINT"; "NNI"; "INT"}*/
-
-"PDRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PDRING"]
-/*"PDRING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PDRING-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"PDRING-" -> "LMODULE/SGROUP"
-/*"PDRING-" -> {"SINT"; "NNI"; "INT"}*/
-
-"PERMCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PERMCAT"]
-/*"PERMCAT" -> {"GROUP"; "MONOID"}*/
-"PERMCAT" -> "SGROUP"
-/*"PERMCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"PERMCAT" -> "ORDSET"
-"PERMCAT" -> "FINITE"
-
-"PI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PI",
-          shape=ellipse]
-/*"PI" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"PI" -> "ORDSET"
-/*"PI" -> "MONOID"*/
-"PI" -> "SGROUP"
-/*"PI" -> {"NNI"; "INT"}*/
-
-"RING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RING",
-          shape=ellipse]
-/*"RING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"RING" -> "LMODULE/SGROUP"
-
-"RING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RING",
-          shape=ellipse]
-/*"RING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RING-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"RING-" -> "LMODULE/SGROUP"
-
-"RNG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RNG",
-          shape=ellipse]
-/*"RNG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RNG" -> "KOERCE"*/
-"RNG" -> "SGROUP"
-
-"PLACESC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PLACESC",
-          shape=ellipse]
-"PLACESC" -> "SETCATD"
-/*"PLACESC" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"PRSPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PRSPCAT",
-          shape=ellipse]
-"PRSPCAT" -> "SETCATD"
-/*"PRSPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-
-"SDVAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SDVAR"]
-/*"SDVAR" -> "DVARCAT"*/
-"SDVAR" -> "ORDSET"
-/*"SDVAR" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"SDVAR" -> "RETRACT"
-/*"SDVAR" -> {"NNI"; "INT"}*/
-
-"SEGXCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SEGXCAT"]
-"SEGXCAT" -> "SEGCAT"
-/*"SEGXCAT" -> "TYPE"*/
-
-"SUP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUP2"]
-/*"SUP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SUP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"SUP2" -> "LMODULE/SGROUP"
-
-"TRIGCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TRIGCAT"]
-/*"TRIGCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"TRIGCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"TRIGCAT" -> "LMODULE/SGROUP"
-
-"TRIGCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TRIGCAT"]
-/*"TRIGCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"TRIGCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"TRIGCAT-" -> "LMODULE/SGROUP"
-
-"ULS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ULS2"]
-/*"ULS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ULS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"ULS2" -> "LMODULE/SGROUP"
-
-"UP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UP2"]
-/*"UP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-"UP2" -> "LMODULE/SGROUP"
-
-\end{chunk}
-\subsection{Layer 3}
-Depends on: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG 
-OASGP PDRING\\
-Used by next layer: BGAGG BRAGG ELAGG- GRMOD MODULE OAMON 
-\begin{chunk}{layer3}
-
-LAYER3=\
-  ${OUT}/AUTOMOR.o  ${OUT}/BGAGG.o   ${OUT}/BGAGG-.o   ${OUT}/BRAGG.o    \
-  ${OUT}/BRAGG-.o   ${OUT}/CARTEN2.o ${OUT}/CHARPOL.o  ${OUT}/COMPLEX2.o \
-  ${OUT}/DIFEXT.o   ${OUT}/DIFEXT-.o ${OUT}/DLAGG.o    ${OUT}/DSTRCAT.o  \
-  ${OUT}/ELAGG.o    \
-  ${OUT}/ELAGG-.o   ${OUT}/ES1.o     ${OUT}/ES2.o      ${OUT}/GRMOD.o    \
-  ${OUT}/GRMOD-.o   ${OUT}/HYPCAT.o  ${OUT}/HYPCAT-.o  ${OUT}/LORER.o    \
-  ${OUT}/MKCHSET.o  \
-  ${OUT}/MODRING.o  ${OUT}/MODULE.o  ${OUT}/MODULE-.o  ${OUT}/NASRING.o  \
-  ${OUT}/NASRING-.o ${OUT}/OAMON.o   ${OUT}/SORTPAK.o  ${OUT}/ZMOD.o \
-  layer3done
-
-\end{chunk}
-
-\begin{chunk}{layerpic}
-/* layer 3 */
-/* depends on: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG */
-/* OASGP PDRING */
-
-"AUTOMOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AUTOMOR"]
-"AUTOMOR" -> "GROUP"
-/*"AUTOMOR" -> {"MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"AUTOMOR" -> {"ELTAB"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"AUTOMOR" -> {"ABELSG"; "LMODULE"; "INT"; "SINT"; "NNI"}*/
-
-"BGAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BGAGG"]
-/*"BGAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"BGAGG" -> "EVALAB"
-/*"BGAGG" -> "IEVALAB"*/
-
-"BGAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BGAGG"]
-/*"BGAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"BGAGG-" -> "EVALAB"
-/*"BGAGG-" -> "IEVALAB"*/
-
-"BRAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BRAGG"]
-/*"BRAGG" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"BRAGG" -> "KOERCE"*/
-"BRAGG" -> "EVALAB"
-/*"BRAGG" -> {"IEVALAB"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"BRAGG" -> {"STAGG-"; "SETAGG"; "CLAGG"; "KONVERT"; "NNI"}*/
-
-"BRAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BRAGG"]
-/*"BRAGG-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"BRAGG-" -> "KOERCE"*/
-"BRAGG-" -> "EVALAB"
-/*"BRAGG-" -> {"IEVALAB"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"BRAGG-" -> {"STAGG-"; "SETAGG"; "CLAGG"; "KONVERT"; "NNI"}*/
-
-"CARTEN2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CARTEN2"]
-/*"CARTEN2" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"CARTEN2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"CARTEN2" -> {"MONOID"; "LMODULE"}*/
-"CARTEN2" -> "BMODULE"
-/*"CARTEN2" -> "RMODULE"*/
-
-"CHARPOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CHARPOL"]
-/*"CHARPOL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"CHARPOL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"CHARPOL" -> {"MONOID"; "LMODULE"}*/
-"CHARPOL" -> "BMODULE"
-/*"CHARPOL" -> {"RMODULE"; "NNI"; "INT"; "SINT"; "PI"}*/
-
-"COMPLEX2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMPLEX2"]
-/*"COMPLEX2" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"COMPLEX2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"COMPLEX2" -> {"MONOID"; "LMODULE"}*/
-"COMPLEX2" -> "BMODULE"
-/*"COMPLEX2" -> "RMODULE"*/
-
-"COMRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMRING",
-           shape=ellipse]
-/*"COMRING" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"COMRING" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"COMRING" -> {"MONOID"; "LMODULE"}*/
-"COMRING" -> "BMODULE"
-/*"COMRING" -> "RMODULE"*/
-
-"DIFEXT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIFEXT"]
-/*"DIFEXT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DIFEXT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"*}/ 
-/*"DIFEXT" -> "DIFRING"*/
-"DIFEXT" -> "PDRING"
-/*"DIFEXT" -> {"SINT"; "NNI"; "INT"}*/
-
-"DIFEXT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIFEXT"]
-/*"DIFEXT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DIFEXT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"DIFEXT-" -> {"LMODULE"; "DIFRING"}*/
-"DIFEXT-" -> "PDRING"
-/*"DIFEXT-" -> {"SINT"; "NNI"; "INT"}*/
-
-"DLAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DLAGG"]
-/*"DLAGG" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"DLAGG" -> "EVALAB"
-/*"DLAGG" -> "IEVALAB"*/
-
-"DSTRCAT"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=DSTRCAT"]
-/*"DSTRCAT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-"DSTRCAT" -> "EVALAB"
-/*"DSTRCAT" -> {"KOERCE"; "IEVALAB"}*/
-
-"ELAGG"  [color="#4488FF",href="bookvol10.2.pdf#nameddest=ELAGG"]
-/*"ELAGG" -> "LNAGG"*/
-"ELAGG" -> "IXAGG"
-/*"ELAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"ELAGG" -> "EVALAB"
-/*"ELAGG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "NNI"}*/
-/*"ELAGG" -> {"INT"; "ORDSET"}*/
-
-"ELAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ELAGG"]
-/*"ELAGG-" -> "LNAGG"*/
-"ELAGG-" -> "IXAGG"
-/*"ELAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"ELAGG-" -> "EVALAB"
-/*"ELAGG-" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "NNI"}*/
-/*"ELAGG-" -> {"INT"; "ORDSET"}*/
-
-/* Note that ENTIRER has a circular self reference */
-"ENTIRER" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ENTIRER",
-           shape=ellipse]
-/*"ENTIRER" -> {"ENTIRER"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ENTIRER" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ENTIRER" -> {"MONOID"; "LMODULE"}*/
-"ENTIRER" -> "BMODULE"
-/*"ENTIRER" -> "RMODULE"*/
-
-"ES1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ES1"]
-/*"ES1" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"ES1" -> "IEVALAB"*/
-"ES1" -> "EVALAB"
-/*"ES1" -> "TYPE"*/
-
-"ES2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ES2"]
-/*"ES2" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"ES2" -> "IEVALAB"*/
-"ES2" -> "EVALAB"
-
-"GRMOD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GRMOD"]
-/*"GRMOD" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "COMRING"; "RING"; "RNG"}*/
-/*"GRMOD" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"GRMOD" -> {"MONOID"; "LMODULE"}*/
-"GRMOD" -> "BMODULE"
-/*"GRMOD" -> "RMODULE"*/
-
-"GRMOD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GRMOD"]
-/*"GRMOD-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "COMRING"; "RING"; "RNG"}*/
-/*"GRMOD-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"GRMOD-" -> {"MONOID"; "LMODULE"}*/
-"GRMOD-" -> "BMODULE"
-/*"GRMOD-" -> "RMODULE"*/
-
-"HYPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=HYPCAT"]
-/*"HYPCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"HYPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"HYPCAT" -> "LMODULE"*/
-"HYPCAT" -> "ELEMFUN"
-
-"HYPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HYPCAT"]
-/*"HYPCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"HYPCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"HYPCAT-" -> "LMODULE"*/
-"HYPCAT-" -> "ELEMFUN"
-
-"LORER" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LORER"]
-/*"LORER" -> {"ENTIRER"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"LORER" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"LORER" -> {"MONOID"; "LMODULE"; "RMODULE"}*/
-"LORER" -> "BMODULE"
-
-"MKCHSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MKCHSET"]
-"MKCHSET" -> "CACHSET"
-/*"MKCHSET" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-
-"MODRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODRING"]
-/*"MODRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"MODRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"MODRING" -> {"LMODULE"; "COMRING"}*/
-"MODRING" -> "BMODULE"
-/*"MODRING" -> {"RMODULE"; "BOOLEAN"}*/
-
-"MODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MODULE"]
-/*"MODULE" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"MODULE" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"MODULE" -> {"MONOID"; "LMODULE"}*/
-"MODULE" -> "BMODULE"
-/*"MODULE" -> "RMODULE"*/
-
-"MODULE-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODULE"]
-/*"MODULE-" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"MODULE-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"MODULE-" -> {"MONOID"; "LMODULE"}*/
-"MODULE-" -> "BMODULE"
-/*"MODULE-" -> "RMODULE"*/
-
-"NASRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NASRING"]
-"NASRING" -> "NARNG"
-/*"NASRING" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NASRING" -> {"BASTYPE"; "KOERCE"; "MONAD"}*/
-"NASRING" -> "MONADWU"
-
-"NASRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NASRING"]
-"NASRING-" -> "NARNG"
-/*"NASRING-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NASRING-" -> {"BASTYPE"; "KOERCE"; "MONAD"}*/
-"NASRING-" -> "MONADWU"
-
-"OAMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OAMON"]
-"OAMON" -> "OASGP"
-/*"OAMON" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
-
-"SETAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SETAGG",
-          shape=ellipse]
-/*"SETAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"; "HOAGG"; "AGG"*/
-/*"SETAGG" -> "TYPE"*/
-"SETAGG" -> "EVALAB"
-/*"SETAGG" -> {"IEVALAB"; "KONVERT"}*/
-
-"SETAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SETAGG",
-          shape=ellipse]
-/*"SETAGG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"; "HOAGG"; "AGG"}*/
-/*"SETAGG-" -> "TYPE"*/
-"SETAGG-" -> "EVALAB"
-/*"SETAGG-" -> {"IEVALAB"; "KONVERT"}*/
-
-"SORTPAK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SORTPAK"]
-/*"SORTPAK" -> "TYPE"*/
-"SORTPAK" -> "IXAGG"
-/*"SORTPAK" -> {"HOAGG"; "AGG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"SORTPAK" -> "EVALAB"
-/*"SORTPAK" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "SINT"; "NNI"; "INT"}*/
-/*"SORTPAK" -> {"BOOLEAN"; "PI"; "ORDSET"; "URAGG"; "RCAGG"}*/
-
-"ZMOD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ZMOD"]
-/*"ZMOD" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ZMOD" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ZMOD" -> "LMODULE"*/
-"ZMOD" -> "BMODULE"
-/*"ZMOD" -> {"RMODULE"; "FINITE"; "KONVERT"; "STEP"; "SINT"; "INT"}*/
-/*"ZMOD" -> {"PI"; "NNI"; "INS-"; "EUCDOM-"}*/
-
-\end{chunk}
-\subsection{Layer 4}
-Depends on: BGAGG BRAGG ELAGG- GRMOD MODULE OAMON \\
-Used by next layer: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG
-\begin{chunk}{layer4}
-
-LAYER4=\
-  ${OUT}/ALGEBRA.o ${OUT}/ALGEBRA-.o ${OUT}/BTCAT.o  ${OUT}/BTCAT-.o \
-  ${OUT}/FMCAT.o   ${OUT}/IDPOAM.o   ${OUT}/IFAMON.o ${OUT}/GRALG.o  \
-  ${OUT}/GRALG-.o  ${OUT}/NAALG.o    ${OUT}/NAALG-.o ${OUT}/OCAMON.o \
-  ${OUT}/PRQAGG.o  ${OUT}/QUAGG.o    ${OUT}/SKAGG.o  \
-  layer4done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 4 */
-/* dpends on: BGAGG BRAGG GRMOD MODULE OAMON */
-
-"ALGEBRA" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ALGEBRA"]
-/*"ALGEBRA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ALGEBRA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ALGEBRA" -> "LMODULE"*/
-"ALGEBRA" -> "MODULE"
-/*"ALGEBRA" -> {"BMODULE"; "RMODULE"; "COMRING"}*/
-
-"ALGEBRA-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALGEBRA"]
-/*"ALGEBRA-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ALGEBRA-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ALGEBRA-" -> "LMODULE"*/
-"ALGEBRA-" -> "MODULE"
-/*"ALGEBRA-" -> {"BMODULE"; "RMODULE"; "COMRING"}*/
-
-"BTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BTCAT"]
-"BTCAT" -> "BRAGG"
-/*"BTCAT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"BTCAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "NNI"; "INT"}*/
-
-"BTCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTCAT"]
-"BTCAT-" -> "BRAGG"
-/*"BTCAT-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"BTCAT-" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "NNI"; "INT"}*/
-
-"FMCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMCAT"]
-/*"FMCAT" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FMCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "RETRACT"}*/
-"FMCAT" -> "MODULE"
-
-"IDPOAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPOAM"]
-"IDPOAM" -> "OAMON"
-/*"IDPOAM" -> {"OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"}*/
-/*"IDPOAM" -> {"ABELSG"; "IDPC"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
-
-"IFAMON" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IFAMON"]
-/*"IFAMON" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"IFAMON" -> {"FAMONC"; "RETRACT"; "INT"; "LIST"; "ILIST"}*/
-"IFAMON" -> "OAMON"
-/*"IFAMON" -> {"OASGP"; "ORDSET"}*/
-
-"GRALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GRALG"]
-"GRALG" -> "GRMOD"
-/*"GRALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "COMRING"; "RING"}*/
-/*"GRALG" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"GRALG" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-
-"GRALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GRALG"]
-"GRALG-" -> "GRMOD"
-/*"GRALG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "COMRING"; "RING"}*/
-/*"GRALG-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"GRALG-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-
-"NAALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NAALG"]
-/*"NAALG" -> {"NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NAALG" -> {"BASTYPE"; "KOERCE"; "MONAD"}*/
-"NAALG" -> "MODULE"
-/*"NAALG" -> {"BMODULE"; "LMODULE"; "RMODULE"; "COMRING"; "RING"; "RNG"}*/
-/*"NAALG" -> {"SGROUP"; "MONOID"; "PI"; "NNI"; "INT"}*/
-
-"NAALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NAALG"]
-/*"NAALG-" -> {"NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"NAALG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
-"NAALG-" -> "MODULE"
-/*"NAALG-" -> {"BMODULE"; "LMODULE"; "RMODULE"; "COMRING"; "RING"; "RNG"}*/
-/*"NAALG-" -> {"SGROUP"; "MONOID"; "PI"; "NNI"; "INT"}*/
-
-"OCAMON" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OCAMON"]
-"OCAMON" -> "OAMON"
-/*"OCAMON" -> {"OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"OCAMON" -> {"ABELMON"; "ABELSG"; "CABMON"}*/
-
-"PRQAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PRQAGG"]
-"PRQAGG" -> "BGAGG"
-/*"PRQAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PRQAGG" -> {"EVALAB"; "IEVALAB"}*/
-
-"QUAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=QUAGG"]
-"QUAGG" -> "BGAGG"
-/*"QUAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"QUAGG" -> {"EVALAB"; "IEVALAB"}*/
-
-"SKAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SKAGG"]
-"SKAGG" -> "BGAGG"
-/*"SKAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SKAGG" -> {"EVALAB"; "IEVALAB"}*/
-
-\end{chunk}
-\subsection{Layer 5}
-Depends on: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG\\
-Used by next layer: MLO OAGROUP OAMONS PID XALG
-
-\begin{chunk}{layer5}
-
-LAYER5=\
-  ${OUT}/BSTREE.o  ${OUT}/BTOURN.o   ${OUT}/CARD.o     ${OUT}/DRAWHACK.o \
-  ${OUT}/DQAGG.o   ${OUT}/FACTFUNC.o ${OUT}/FMTC.o     ${OUT}/FR2.o      \
-  ${OUT}/FRAC2.o   ${OUT}/FRUTIL.o   ${OUT}/ITAYLOR.o  ${OUT}/MLO.o      \
-  ${OUT}/NEWTON.o  ${OUT}/OAGROUP.o  ${OUT}/OAMONS.o   ${OUT}/OP.o       \
-  ${OUT}/PID.o     ${OUT}/RANDSRC.o  ${OUT}/UNISEG2.o  ${OUT}/XALG.o     \
-  layer5done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 5 */
-/* depends on: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG */
-
-"BSTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSTREE"]
-"BSTREE" -> "BTCAT"
-/*"BSTREE" -> {"BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"BSTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ORDSET"}*/
-/*"BSTREE" -> {"INT"; "LIST"; "ILIST"}*/
-
-"BTOURN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTOURN"]
-"BTOURN" -> "BTCAT"
-/*"BTOURN" -> {"BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"BTOURN" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ORDSET"}*/
-/*"BTOURN" -> {"INT"; "LIST"; "ILIST"}*/
-
-"CARD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CARD"]
-/*"CARD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
-/*"CARD" -> {"MONOID"; "SGROUP"; "RETRACT"; "BOOLEAN"; "INT"; "NNI"; "INS-"}*/
-/*"CARD" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-"CARD" -> "ALGEBRA-"
-/*"CARD" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-
-"DRAWHACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWHACK"]
-/*"DRAWHACK" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"DRAWHACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"DRAWHACK" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"DRAWHACK" -> "RMODULE"*/
-"DRAWHACK" -> "ALGEBRA"
-/*"DRAWHACK" -> {"MODULE"; "ENTIRER"; "KONVERT"}*/
-
-"DQAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DQAGG"]
-"DQAGG" -> "SKAGG"
-/*"DQAGG" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"DQAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"}*/
-"DQAGG" -> "QUAGG"
-
-"FACTFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACTFUNC"]
-/*"FACTFUNC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FACTFUNC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FACTFUNC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"FACTFUNC" -> "ALGEBRA"
-/*"FACTFUNC" -> {"MODULE"; "ENTIRER"; "INT"; "LIST"; "ILIST"; "INS-"}*/
-/*"FACTFUNC" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "NNI"; "LSAGG-"; "STAGG-"}*/
-/*"FACTFUNC" -> "ELAGG-"*/
-
-"FMTC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FMTC"]
-/*"FMTC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FMTC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FMTC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"FMTC" -> "ALGEBRA"
-/*"FMTC" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
-
-"FR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FR2"]
-/*"FR2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FR2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FR2" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"FR2" -> "ALGEBRA"
-/*"FR2" -> {"MODULE"; "ENTIRER"}*/
-
-"FRAC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRAC2"]
-/*"FRAC2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FRAC2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FRAC2" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"FRAC2" -> "ALGEBRA"
-/*"FRAC2" -> {"MODULE"; "ENTIRER"}*/
-
-"FRUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRUTIL"]
-/*"FRUTIL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FRUTIL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FRUTIL" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"FRUTIL" -> "ALGEBRA"
-/*"FRUTIL" -> {"MODULE"; "ENTIRER"; "INT"; "LIST"; "ILIST"; "PI"; "NNI"}*/
-/*"FRUTIL" -> {"LSAGG-"; "STAGG-"}*/
-
-"ITAYLOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ITAYLOR"]
-/*"ITAYLOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ITAYLOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ITAYLOR" -> {"LMODULE"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
-"ITAYLOR" -> "ALGEBRA"
-/*"ITAYLOR" -> {"MODULE"; "ENTIRER"; "SINT"; "NNI"; "INT"; "BOOLEAN"}*/
-
-"MLO" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MLO"]
-/*"MLO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"MLO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MLO" -> {"BMODULE"; "RMODULE"}*/
-"MLO" -> "ALGEBRA"
-/*"MLO" -> "MODULE"*/
-
-"NEWTON" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NEWTON"]
-/*"NEWTON" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"NEWTON" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"NEWTON" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"NEWTON" -> "ALGEBRA"
-/*"NEWTON" -> {"MODULE"; "ENTIRER"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-/*"NEWTON" -> {"LSAGG-"; "STAGG-"}*/
-
-/* The PID/OAGROUP node is added to the graph to simplify the layout*/
-/* Note that PID and OAGROUP also exist */
-"PID/OAGROUP" [color="blue",href="bookvol10.2.pdf#nameddest=OAGROUP"]
-"PID/OAGROUP" -> "OCAMON"
-"PID/OAGROUP" -> "ALGEBRA"
-
-"OAGROUP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OAGROUP"]
-"OAGROUP" -> "OCAMON"
-/*"OAGROUP" -> {"OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"OAGROUP" -> {"ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
-
-"PID" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PID"]
-/*"PID" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PID" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PID" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"PID" -> "ALGEBRA"
-/*"PID" -> {"MODULE"; "ENTIRER"}*/
-
-"OAMONS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OAMONS"]
-"OAMONS" -> "OCAMON"
-/*"OAMONS" -> {"OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"OAMONS" -> {"ABELMON"; "ABELSG"; "CABMON"}*/
-
-"OP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OP"]
-/*"OP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"OP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "RETRACT"}*/
-/*"OP" -> {"ELTAB"; "CHARZ"; "CHARNZ"}*/
-"OP" -> "ALGEBRA"
-/*"OP" -> {"MODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ORDSET"}*/
-
-"RANDSRC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RANDSRC"]
-/*"RANDSRC" -> {"INT"; "PI"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"RANDSRC" -> "INTDOM-"*/
-"RANDSRC" -> "ALGEBRA-"
-/*"RANDSRC" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"RANDSRC" -> "ABELMON-"*/
-
-"UNISEG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UNISEG2"]
-/*"UNISEG2" -> {"TYPE"; "ORDRING"; "OAGROUP"*/
-"UNISEG2" -> "OCAMON"
-/*"UNISEG2" -> {"OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"UNISEG2" -> {"ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"; "RING"; "RNG"}*/
-/*"UNISEG2" -> {"SGROUP"; "MONOID"; "LMODULE"}*/
-
-"XALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XALG"]
-/*"XALG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"XALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"XALG" -> {"BMODULE"; "RMODULE"}*/
-"XALG" -> "ALGEBRA"
-/*"XALG" -> "MODULE"*/
-
-\end{chunk}
-\subsection{Layer6}
-Depends on: MLO OAGROUP OAMONS PID XALG\\
-Used by next layer: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT 
-XFALG
-\begin{chunk}{layer6}
-
-LAYER6=\
-  ${OUT}/AMR.o      ${OUT}/AMR-.o     ${OUT}/DEGRED.o  ${OUT}/DIVCAT.o   \
-  ${OUT}/DLP.o      \
-  ${OUT}/EAB.o      ${OUT}/ESTOOLS1.o ${OUT}/FAGROUP.o ${OUT}/FAMONOID.o \
-  ${OUT}/FIELD.o    ${OUT}/FIELD-.o   ${OUT}/FLAGG.o   ${OUT}/FLAGG-.o   \
-  ${OUT}/FLINEXP.o  ${OUT}/FLINEXP-.o ${OUT}/FRETRCT.o ${OUT}/FRETRCT-.o \
-  ${OUT}/FSERIES.o  ${OUT}/FT.o       ${OUT}/IDPOAMS.o ${OUT}/INFINITY.o \
-  ${OUT}/LA.o       ${OUT}/MAPPKG4.o  ${OUT}/OMLO.o    ${OUT}/ORTHPOL.o  \
-  ${OUT}/PRODUCT.o  ${OUT}/PADICCT.o  ${OUT}/PMPRED.o  ${OUT}/PMASS.o   \
-  ${OUT}/PTFUNC2.o  ${OUT}/RADCAT.o   ${OUT}/RADCAT-.o ${OUT}/RATRET.o  \
-  ${OUT}/RADUTIL.o  ${OUT}/UPXS2.o    ${OUT}/XFALG.o   ${OUT}/ZLINDEP.o \
-  layer6done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 6 */
-/* MLO OAGROUP OAMONS PID XALG */
-
-"AMR" [color="#4488FF",href="bookvol10.2.pdf#nameddest=AMR"]
-/*"AMR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"AMR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"AMR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"AMR" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"AMR" -> {"INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
-"AMR" -> "PID/OAGROUP"
-/*"AMR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"}*/
-/*"AMR" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"AMR" -> "STEP"*/
-
-"AMR-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AMR"]
-/*"AMR-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"AMR-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"AMR-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"AMR-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"AMR-" -> {"INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
-"AMR-" -> "PID/OAGROUP"
-/*"AMR-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"}*/
-/*"AMR-" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"AMR-" -> "STEP"*/
-
-"DEGRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DEGRED"]
-/*"DEGRED" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DEGRED" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DEGRED" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"DEGRED" -> {"MODULE"; "ENTIRER"; "ORDSET"; "BOOLEAN"; "INT"; "LIST"}*/
-/*"DEGRED" -> {"ILIST"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-/*"DEGRED" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"DEGRED" -> {"ABELGRP-"; "ABELMON-"; "PI"; "NNI"; "INS"; "UFD"; "GCDDOM"}*/
-/*"DEGRED" -> "EUCDOM"*/
-"DEGRED" -> "PID/OAGROUP"
-/*"DEGRED" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"DEGRED" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"DEGRED" -> {"REAL"; "CHARZ"; "STEP"; "SINT"}*/
-
-"DIVCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DIVCAT"]
-/*"DIVCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"DIVCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"DIVCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DIVCAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "OINTDOM"}*/
-/*"DIVCAT" -> {"ORDRING"}*/
-"DIVCAT" -> "PID"
-"DIVCAT" -> "OAGROUP"
-/*"DIVCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"DIVCAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"DIVCAT" -> {"STEP"; "FAMONC"}*/
-
-"DLP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DLP"]
-/*"DLP" -> {"MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
-/*"DLP" -> {"INT"; "NNI"; "BOOLEAN"; "SINT"; "PI"; "ABELSG"}*/
-"DLP" -> "OAMONS"
-/*"DLP" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "ABELMON"; "CABMON"}*/
-
-"EAB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EAB"]
-/*"EAB" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"}*/
-/*"EAB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"EAB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"EAB" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"EAB" -> "PID/OAGROUP"
-/*"EAB" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"EAB" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"EAB" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "LIST"; "ILIST"}*/
-/*"EAB" -> {"BOOLEAN"; "NNI"; "SINT"}*/
-
-"ESTOOLS1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESTOOLS1"]
-/*"ESTOOLS1" -> "ORDRING"*/
-"ESTOOLS1" -> "OAGROUP"
-/*"ESTOOLS1" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-/*"ESTOOLS1" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
-/*"ESTOOLS1" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-
-"FAGROUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAGROUP"]
-/*"FAGROUP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FAGROUP" -> {"BASTYPE"; "KOERCE"; "MODULE"; "BMODULE"; "LMODULE"}*/
-/*"FAGROUP" -> {"RMODULE"; "FAMONC"; "RETRACT"; "ORDSET"; "INS"; "UFD"}*/
-/*"FAGROUP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"}*/
-/*"FAGROUP" -> {"MONOID"; "ALGEBRA"; "ENTIRER"; "EUCDOM"}*/
-"FAGROUP" -> "PID/OAGROUP"
-/*"FAGROUP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FAGROUP" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"FAGROUP" -> {"CHARZ"; "STEP"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "OM"}*/
-
-"FAMONOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAMONOID"]
-/*"FAMONOID" -> {"FAMONC"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FAMONOID" -> {"BASTYPE"; "KOERCE"; "RETRACT"}*/
-"FAMONOID" -> "OAMONS"
-/*"FAMONOID" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "NNI"; "INT"}*/
-/*"FAMONOID" -> {"MONOID"; "SGROUP"}*/
-
-"FIELD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FIELD"]
-/*"FIELD" -> "EUCDOM"*/
-"FIELD" -> "PID"
-/*"FIELD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FIELD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FIELD" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FIELD" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"FIELD" -> {"BOOLEAN"; "INT"; "NNI"}*/
-
-"FIELD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FIELD"]
-/*"FIELD-" -> "EUCDOM"*/
-"FIELD-" -> "PID"
-/*"FIELD-" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FIELD-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FIELD-" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FIELD-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "BOOLEAN"}*/
-/*"FIELD-" -> {"INT"; "NNI"}*/
-
-"FLAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FLAGG"]
-/*"FLAGG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"FLAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"FLAGG" -> {"KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"FLAGG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FLAGG" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FLAGG" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"FLAGG" -> "PID/OAGROUP"
-/*"FLAGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FLAGG" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"FLAGG" -> {"CHARZ"; "STEP"; "OM"}*/
-
-"FLAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FLAGG"]
-/*"FLAGG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"FLAGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"FLAGG-" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"}*/
-/*"FLAGG-" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FLAGG-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"FLAGG-" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FLAGG-" -> {"ENTIRER"; "EUCDOM"}*/
-"FLAGG-" -> "PID/OAGROUP"
-/*"FLAGG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FLAGG-" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"FLAGG-" -> {"CHARZ"; "STEP"; "OM"}*/
-
-"FLINEXP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FLINEXP"]
-/*"FLINEXP" -> {"LINEXP"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FLINEXP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FLINEXP" -> {"LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FLINEXP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FLINEXP" -> "EUCDOM"*/
-"FLINEXP" -> "PID/OAGROUP"
-/*"FLINEXP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FLINEXP" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "PATMAB"}*/
-/*"FLINEXP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"FLINEXP-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FLINEXP"]
-/*"FLINEXP-" -> {"LINEXP"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FLINEXP-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FLINEXP-" -> {"MONOID"; "LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"FLINEXP-" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FLINEXP-" -> {"ENTIRER"; "EUCDOM"}*/
-"FLINEXP-" -> "PID/OAGROUP"
-/*"FLINEXP-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FLINEXP-" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"FLINEXP-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"FRETRCT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FRETRCT"]
-/*"FRETRCT" -> {"RETRACT"; "TYPE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"FRETRCT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FRETRCT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FRETRCT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FRETRCT" -> {"ENTIRER"; "EUCDOM"}*/
-"FRETRCT" -> "PID/OAGROUP"
-/*"FRETRCT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FRETRCT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"FRETRCT" -> {"REAL"; "CHARZ"; "STEP"}*/
-
-"FRETRCT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRETRCT"]
-/*"FRETRCT-" -> {"RETRACT"; "TYPE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"FRETRCT-" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FRETRCT-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FRETRCT-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FRETRCT-" -> {"MODULE"; "ENTIRER"; "EUCDOM"}*/
-"FRETRCT-" -> "PID/OAGROUP"
-/*"FRETRCT-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FRETRCT-" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"}*/
-/*"FRETRCT-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"FSERIES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FSERIES"]
-/*"FSERIES" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FSERIES" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FSERIES" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"FSERIES" -> {"ORDSET"; "PI"; "NNI"; "INT"; "INS"; "UFD"; "GCDDOM"}*/
-/*"FSERIES" -> {"INTDOM"; "ENTIRER"; "EUCDOM"}*/
-"FSERIES" -> "PID/OAGROUP"
-/*"FSERIES" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FSERIES" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"FSERIES" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LIST"}*/
-
-"FT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FT"]
-/*"FT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
-/*"FT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"FT" -> "PID/OAGROUP"
-/*"FT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"FT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"; "LIST"; "ILIST"}*/
-/*"FT" -> "BOOLEAN"*/
-
-"IDPOAMS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDPOAMS"]
-"IDPOAMS" -> "OAMONS"
-/*"IDPOAMS" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-/*"IDPOAMS" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "IDPC"; "INT"}*/
-/*"IDPOAMS" -> {"LIST"; "ILIST"}*/
-
-"INFINITY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFINITY"]
-/*"INFINITY" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"INFINITY" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"INFINITY" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INFINITY" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"INFINITY" -> "EUCDOM"*/
-"INFINITY" -> "PID/OAGROUP"
-/*"INFINITY" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"INFINITY" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"INFINITY" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-/* Note that INS has a circular self reference */
-"INS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INS",
-          shape=ellipse]
-/*"INS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"INS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"INS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"INS" -> "PID/OAGROUP"
-/*"INS" -> "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"INS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"INS" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"; "INT"}*/
-/*"INS" -> {"BOOLEAN"; "DFLOAT"}*/
-
-"INS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INS",
-          shape=ellipse]
-/*"INS-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"INS-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"INS-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"INS-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"INS-" -> "PID/OAGROUP"
-/*"INS-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"INS-" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"INS-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"; "INT"}*/
-/*"INS-" -> {"BOOLEAN"; "DFLOAT"}*/
-
-"LA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LA"]
-/*"LA" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"LA" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"LA" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "ORDRING"}*/
-"LA" -> "OAGROUP"
-/*"LA" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "COMRING"}*/
-
-"LNAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LNAGG",
-          shape=ellipse]
-/*"LNAGG" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"LNAGG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"LNAGG" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"LNAGG" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"LNAGG" -> "PID/OAGROUP"
-/*"LNAGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"LNAGG" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"LNAGG" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "IXAGG"; "HOAGG"}*/
-/*"LNAGG" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"LNAGG" -> {"CLAGG"; "OM"; "INT"; "BOOLEAN"; "NNI"}*/
-
-"LNAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LNAGG",
-          shape=ellipse]
-/*"LNAGG-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"LNAGG-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"LNAGG-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"LNAGG-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"LNAGG-" -> "PID/OAGROUP"
-/*"LNAGG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"LNAGG-" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"LNAGG-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"LNAGG-" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"LNAGG-" -> {"OM"; "INT"; "BOOLEAN"; "NNI"}*/
-
-"MAPPKG4" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAPPKG4"]
-/*"MAPPKG4" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MAPPKG4" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MAPPKG4" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"MAPPKG4" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"MAPPKG4" -> "PID/OAGROUP"
-/*"MAPPKG4" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"MAPPKG4" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"MAPPKG4" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"NNI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NNI",
-          shape=ellipse]
-"NNI" -> "OAMONS"
-/*"NNI" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-/*"NNI" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "MONOID"; "SGROUP"}*/
-/*"NNI" -> {"NNI"; "INT"; "BOOLEAN"}*/
-
-"OINTDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OINTDOM",
-          shape=ellipse]
-/*"OINTDOM" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"OINTDOM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"OINTDOM" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"OINTDOM" -> {"MODULE"; "ENTIRER"; "ORDRING"}*/
-"OINTDOM" -> "OAGROUP"
-/*"OINTDOM" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-
-"OMLO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMLO"]
-"OMLO" -> "MLO"
-/*"OMLO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"OMLO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"OMLO" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "DIFRING"; "COMRING"}*/
-
-"ORDRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ORDRING",
-          shape=ellipse]
-"ORDRING" -> "OAGROUP"
-/*"ORDRING" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-/*"ORDRING" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
-/*"ORDRING" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"; "INT"}*/
-
-"ORDRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ORDRING",
-          shape=ellipse]
-"ORDRING-" -> "OAGROUP"
-/*"ORDRING-" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-/*"ORDRING-" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"; "RING"}*/
-/*"ORDRING-" -> {"RNG"; "SGROUP"; "MONOID"; "LMODULE"; "INT"}*/
-
-"ORTHPOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ORTHPOL"]
-/*"ORTHPOL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ORTHPOL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ORTHPOL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "NNI"; "INT"; "SINT"}*/
-/*"ORTHPOL" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "PI"; "INS-"}*/
-/*"ORTHPOL" -> {"ALGEBRA"; "MODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"ORTHPOL" -> {"ENTIRER"; "EUCDOM"}*/
-"ORTHPOL" -> "PID/OAGROUP"
-/*"ORTHPOL" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ORTHPOL" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"ORTHPOL" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"ORTHPOL" -> "STEP"*/
-
-"PRODUCT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PRODUCT"]
-/*"PRODUCT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"; "MONOID"}*/
-/*"PRODUCT" -> {"SGROUP"; "ABELMON"; "ABELSG"; "CABMON"; "GROUP"; {"ABELGRP"}*/
-"PRODUCT" -> "OAMONS"
-/*"PRODUCT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "BOOLEAN"; "NNI"}*/
-/*"PRODUCT" -> "INT"*/
-
-"PADICCT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PADICCT"]
-/*"PADICCT" -> "EUCDOM"*/
-"PADICCT" -> "PID"
-/*"PADICCT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PADICCT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PADICCT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PADICCT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
-
-"PMPRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPRED"]
-/*"PMPRED" -> {"TYPE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PMPRED" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PMPRED" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PMPRED" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"PMPRED" -> "PID/OAGROUP"
-/*"PMPRED" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PMPRED" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"PMPRED" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"PMASS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMASS"]
-/*"PMASS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PMASS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PMASS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PMASS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"PMASS" -> "PID/OAGROUP"
-/*"PMASS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PMASS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"PMASS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"PTFUNC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PTFUNC2"]
-/*"PTFUNC2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PTFUNC2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PTFUNC2" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"PTFUNC2" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"PTFUNC2" -> "PID/OAGROUP"
-/*"PTFUNC2" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PTFUNC2" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"PTFUNC2" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"RADCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RADCAT"]
-/*"RADCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"RADCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RADCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"RADCAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"RADCAT" -> "PID/OAGROUP"
-/*"RADCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"RADCAT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"RADCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"RADCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RADCAT"]
-/*"RADCAT-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"RADCAT-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"RADCAT-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RADCAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"RADCAT-" -> "EUCDOM"*/
-"RADCAT-" -> "PID/OAGROUP"
-/*"RADCAT-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"RADCAT-" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"RADCAT-" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"RATRET" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RATRET"]
-/*"RATRET" -> {"RETRACT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"RATRET" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RATRET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RATRET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"RATRET" -> "EUCDOM"*/
-"RATRET" -> "PID/OAGROUP"
-/*"RATRET" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"RATRET" -> {"ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"RATRET" -> {"REAL"; "CHARZ"; "STEP"}*/
-
-"RADUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RADUTIL"]
-/*"RADUTIL" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"RADUTIL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"RADUTIL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RADUTIL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"RADUTIL" -> "EUCDOM"*/
-"RADUTIL" -> "PID/OAGROUP"
-/*"RADUTIL" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"RADUTIL" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"RADUTIL" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-/* Note that SINT references itself! */
-"SINT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SINT",
-          shape=ellipse]
-/*"SINT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"SINT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SINT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SINT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"SINT" -> "PID/OAGROUP"
-/*"SINT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SINT" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"SINT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LOGIC"; "OM"; "SINT"; "INT"}*/
-
-"STAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=STAGG",
-          shape=ellipse]
-/*"STAGG" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"STAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"STAGG" -> {"ELTAB"; "CLAGG"; "KONVERT"; "BOOLEAN"; "SINT"; "NNI"; "INT"}*/
-/*"STAGG" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"STAGG" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"STAGG" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"STAGG" -> {"ENTIRER"; "EUCDOM"}*/
-"STAGG" -> "PID/OAGROUP"
-/*"STAGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"STAGG" -> {"ORDSET"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"STAGG" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "LIST"; "ILIST"}*/
-
-"STAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STAGG",
-          shape=ellipse]
-/*"STAGG-" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"STAGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"STAGG-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "BOOLEAN"; "SINT"}*/
-/*"STAGG-" -> {"NNI"; "INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"STAGG-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"STAGG-" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"STAGG-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"STAGG-" -> "PID/OAGROUP"
-/*"STAGG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"STAGG-" -> {"ORDSET"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"STAGG-" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "LIST"; "ILIST"}*/
-
-"UPXS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPXS2"]
-/*"UPXS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UPXS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UPXS2" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"UPXS2" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-"UPXS2" -> "PID/OAGROUP"
-/*"UPXS2" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"UPXS2" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"UPXS2" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"XFALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XFALG"]
-/*"XFALG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"XFALG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-"XFALG" -> "XALG"
-/*"XFALG" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "RETRACT"}*/
-
-"ZLINDEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ZLINDEP"]
-/*"ZLINDEP" -> {"LINEXP"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ZLINDEP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ZLINDEP" -> {"MONOID"; "LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"ZLINDEP" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ZLINDEP" -> {"ENTIRER"; "EUCDOM"}*/
-"ZLINDEP" -> "PID/OAGROUP"
-/*"ZLINDEP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ZLINDEP" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"ZLINDEP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-\end{chunk}
-\subsection{Layer7}
-Depends on: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT XFALG \\
-Used by next layer: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT 
-TRANFUN VSPACE XPOLYC
-\begin{chunk}{layer7}
-
-LAYER7=\
-  ${OUT}/A1AGG.o    ${OUT}/A1AGG-.o   ${OUT}/ARR2CAT.o  ${OUT}/ARR2CAT-.o \
-  ${OUT}/ASP34.o    ${OUT}/BBTREE.o   ${OUT}/BFUNCT.o   ${OUT}/BLAS1.o    \
-  ${OUT}/BPADIC.o   \
-  ${OUT}/BTREE.o    ${OUT}/CRAPACK.o  ${OUT}/DEQUEUE.o  ${OUT}/DIRRING.o  \
-  ${OUT}/DIV.o      ${OUT}/DLIST.o    \
-  ${OUT}/DRAWCX.o   ${OUT}/DRAWPT.o   ${OUT}/D01GBFA.o  ${OUT}/D02EJFA.o  \
-  ${OUT}/D03FAFA.o  ${OUT}/FAMR.o     ${OUT}/FAMR-.o    ${OUT}/FIELD.o    \
-  ${OUT}/FLASORT.o  \
-  ${OUT}/FLAGG2.o   ${OUT}/FGROUP.o   ${OUT}/FM.o       ${OUT}/FM1.o      \
-  ${OUT}/FPC.o      ${OUT}/FPC-.o     ${OUT}/FMONOID.o  ${OUT}/INDE.o     \
-  ${OUT}/IPADIC.o   ${OUT}/IROOT.o    ${OUT}/IR2.o      ${OUT}/LEXP.o     \
-  ${OUT}/LIECAT.o   ${OUT}/LIECAT-.o  ${OUT}/LIST2.o    ${OUT}/LIST2MAP.o \
-  ${OUT}/LMOPS.o    ${OUT}/LZSTAGG.o  ${OUT}/LZSTAGG-.o ${OUT}/MAGMA.o    \
-  ${OUT}/MESH.o     ${OUT}/MOEBIUS.o  ${OUT}/MODFIELD.o ${OUT}/MODOP.o    \
-  ${OUT}/MRING.o    ${OUT}/MTHING.o   ${OUT}/NCNTFRAC.o ${OUT}/NCODIV.o   \
-  ${OUT}/NUMTUBE.o  ${OUT}/ODR.o      ${OUT}/OFMONOID.o ${OUT}/ONECOMP.o  \
-  ${OUT}/ORDCOMP.o  ${OUT}/OREPCAT.o  ${OUT}/OREPCAT-.o ${OUT}/OWP.o      \
-  ${OUT}/PACPERC.o  \
-  ${OUT}/PADIC.o    ${OUT}/PATTERN2.o ${OUT}/PATLRES.o  ${OUT}/PARTPERM.o \
-  ${OUT}/PBWLB.o    ${OUT}/PENDTREE.o ${OUT}/PGE.o      ${OUT}/PGROEB.o   \
-  ${OUT}/PINTERP.o  ${OUT}/PLOTTOOL.o ${OUT}/PFR.o      ${OUT}/PMDOWN.o   \
-  ${OUT}/PMINS.o    ${OUT}/PMLSAGG.o  ${OUT}/PMTOOLS.o  ${OUT}/PRTITION.o \
-  ${OUT}/PSCAT.o    ${OUT}/PSCAT-.o   ${OUT}/QFORM.o    ${OUT}/QUEUE.o    \
-  ${OUT}/SCACHE.o   ${OUT}/SEG.o      ${OUT}/SEG2.o     ${OUT}/SEXOF.o    \
-  ${OUT}/STACK.o    ${OUT}/STTAYLOR.o ${OUT}/TABLBUMP.o ${OUT}/TABLEAU.o  \
-  ${OUT}/TOPSP.o    ${OUT}/TRANFUN.o  ${OUT}/TRANFUN-.o ${OUT}/TUBE.o     \
-  ${OUT}/UDPO.o     ${OUT}/UNISEG.o   ${OUT}/VIEW.o     ${OUT}/VSPACE.o   \
-  ${OUT}/VSPACE-.o  ${OUT}/XPOLYC.o   ${OUT}/XPR.o \
-  layer7done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 7 */
-/* depends on: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT XFALG */
-
-"A1AGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=A1AGG"]
-"A1AGG" -> "FLAGG"
-/*"A1AGG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"A1AGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"A1AGG" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"}*/
-/*"A1AGG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"A1AGG" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"A1AGG" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"A1AGG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"A1AGG" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"A1AGG" -> {"CHARZ"; "STEP"; "OM"; "BOOLEAN"; "SINT"; "INT"}*/
-/*"A1AGG" -> {"NNI"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"A1AGG" -> {"RCAGG"; "ELAGG"}*/
-
-"A1AGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=A1AGG"]
-"A1AGG-" -> "FLAGG"
-/*"A1AGG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"A1AGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"A1AGG-" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"}*/
-/*"A1AGG-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"A1AGG-" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"A1AGG-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"A1AGG-" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"A1AGG-" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"A1AGG-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-/*"A1AGG-" -> {"BOOLEAN"; "SINT"; "INT"; "NNI"; "LIST"; "ILIST"}*/
-/*"A1AGG-" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-
-"ARR2CAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ARR2CAT"]
-/*"ARR2CAT" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ARR2CAT" -> {"EVALAB"; "IEVALAB"}*/
-"ARR2CAT" -> "FLAGG"
-/*"ARR2CAT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"ARR2CAT" -> {"ORDSET"; "BOOLEAN"; "NNI"; "INT"; "SINT"; "LIST"}*/
-/*"ARR2CAT" -> {"ILIST"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ARR2CAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ARR2CAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ARR2CAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"ARR2CAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"ARR2CAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"ARR2CAT" -> {"CHARZ"; "STEP"; "OM"}*/
-
-"ARR2CAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ARR2CAT"]
-/*"ARR2CAT-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ARR2CAT-" -> {"EVALAB"; "IEVALAB"}*/
-"ARR2CAT-" -> "FLAGG"
-/*"ARR2CAT-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"ARR2CAT-" -> {"ORDSET"; "BOOLEAN"; "NNI"; "INT"; "SINT"; "LIST"; "ILIST"}*/
-/*"ARR2CAT-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"ARR2CAT-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"ARR2CAT-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ARR2CAT-" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"ARR2CAT-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ARR2CAT-" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"ARR2CAT-" -> {"REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"ASP34" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP34"]
-/*"ASP34" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "INS"; "UFD"}*/
-/*"ASP34" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ASP34" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"}*/
-/*"ASP34" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ASP34" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"ASP34" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"ASP34" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"ASP34" -> {"STEP"; "FPS"; "RNS"}*/
-"ASP34" -> "FIELD"
-/*"ASP34" -> "DIVRING"*/
-"ASP34" -> "RADCAT"
-/*"ASP34" -> {"NNI"; "INT"; "OM"}*/
-
-"BBTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BBTREE"]
-/*"BBTREE" -> {"BTCAT"; "BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"BBTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "BOOLEAN"}*/
-/*"BBTREE" -> {"LSAGG"; "STAGG"; "URAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"BBTREE" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"BBTREE" -> "FLAGG"
-/*"BBTREE" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-/*"BBTREE" -> {"SINT"; "PI"; "LSAGG-"; "STAGG-"}*/
-
-"BFUNCT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BFUNCT"]
-/*"BFUNCT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "DFLOAT"; "FPS-"}*/
-/*"BFUNCT" -> "RNS-"*/
-"BFUNCT" -> "FIELD-"
-/*"BFUNCT" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
-/*"BFUNCT" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "INT"}*/
-
-"BLAS1" [color="#444488",href="bookvol10.5.pdf#nameddest=BLAS1"]
-/*"BLAS1" -> {"FPS" "RNS"}*/ 
-"BLAS1" -> "FIELD"
-/*"BLAS1" -> {"EUCDOM" "PID" "GCDDOM" "INTDOM" "COMRING" "RING" "RNG"}*/
-/*"BLAS1" -> {"ABELGRP" "CABMON" "ABELMON" "ABELSG" "SETCAT" "BASTYPE"}*/ 
-/*"BLAS1" -> {"KOERCE" "SGROUP" "MONOID" "LMODULE" "BMODULE" "RMODULE"}*/
-/*"BLAS1" -> {"ALGEBRA" "MODULE" "ENTIRER" "UFD" "DIVRING" "ORDRING"}*/ 
-/*"BLAS1" -> {"OAGROUP" "OCAMON" "OAMON" "OASGP" "ORDSET" "REAL"}*/
-/*"BLAS1" -> {"KONVERT" "RETRACT"}*/ 
-"BLAS1" -> "RADCAT"
-/*"BLAS1" -> {"PATMAB" "CHARZ"}*/
-
-"BPADIC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BPADIC"]
-/*"BPADIC" -> "BOOLEAN"*/
-"BPADIC" -> "PADICCT"
-/*"BPADIC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"BPADIC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"BPADIC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"BPADIC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "INS"}*/
-/*"BPADIC" -> {"UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"BPADIC" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"BPADIC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-
-"BTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTREE"]
-/*"BTREE" -> {"BTCAT"; "BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"BTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"}*/
-/*"BTREE" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
-/*"BTREE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"BTREE" -> "FLAGG"
-/*"BTREE" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"CLAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=CLAGG",
-         shape=ellipse]
-/*"CLAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"CLAGG" -> {"EVALAB"; "IEVALAB"; "KONVERT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"CLAGG" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-"CLAGG" -> "FLAGG" 
-/*"CLAGG" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-/*"CLAGG" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-
-"CLAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CLAGG",
-          shape=ellipse]
-/*"CLAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"CLAGG-" -> {"EVALAB"; "IEVALAB"; "KONVERT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"CLAGG-" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-"CLAGG-" -> "FLAGG"
-/*"CLAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-/*"CLAGG-" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "ELAGG"}*/
-
-"CRAPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CRAPACK"]
-/*"CRAPACK" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"CRAPACK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"CRAPACK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CRAPACK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"CRAPACK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"CRAPACK" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"CRAPACK" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"CRAPACK" -> "FLAGG"
-/*"CRAPACK" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-
-"DEQUEUE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DEQUEUE"]
-/*"DEQUEUE" -> {"DQAGG"; "SKAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"DEQUEUE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "QUAGG"; "INT"}*/
-/*"DEQUEUE" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"DEQUEUE" -> "FLAGG-"
-/*"DEQUEUE" -> {"URAGG-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"DEQUEUE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DEQUEUE" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DEQUEUE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"DEQUEUE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"DEQUEUE" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"DEQUEUE" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "LNAGG-"; "LSAGG"; "STAGG"}*/
-/*"DEQUEUE" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"DEQUEUE" -> "CLAGG"*/
-"DEQUEUE" -> "FLAGG"
-/*"DEQUEUE" -> "ELAGG"*/
-
-"DIRRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIRRING"]
-"DIRRING" -> "FLAGG"
-/*"DIRRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DIRRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DIRRING" -> {"ELTAB"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
-/*"DIRRING" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "INT"; "INS"; "UFD"}*/
-/*"DIRRING" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"DIRRING" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"DIRRING" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"DIRRING" -> {"STEP"; "PI"; "NNI"; "BOOLEAN"; "LIST"; "ILIST"; "INS-"}*/
-/*"DIRRING" -> {"MONOID-"; "ABELSG-"; "SGROUP-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"DIRRING" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; IEVALAB"}*/
-/*"DIRRING" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "ELAGG"; "OM"; "LSAGG-"}*/
-
-"DIV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIV"]
-"DIV" -> "DIVCAT"
-"DIV" -> "FLAGG"
-/*"DIV" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"DIV" -> {"KOERCE"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "FAMONC"}*/
-/*"DIV" -> {"RETRACT"; "SETCATD"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"DIV" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "ALGEBRA"}*/
-/*"DIV" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"DIV" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"DIV" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-/*"DIV" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"DIV" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"DIV" -> {"CLAGG"; "ELAGG"; "LIST"; "ILIST"; "LSAGG-"; "BOOLEAN"; "NNI"}*/
-/*"DIV" -> {"STAGG-"; "ELAGG-"; "PI"}*/
-
-"DLIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DLIST"]
-/*"DLIST" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"DLIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"DLIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"DLIST" -> "FLAGG"
-/*"DLIST" -> {"ORDSET"; "ELAGG"; "INT"; "LIST"; "ILIST"; "INS"; "UFD"}*/
-/*"DLIST" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"DLIST" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DLIST" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"DLIST" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"DLIST" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"DLIST" -> {"REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"DRAWCX" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWCX"]
-/*"DRAWCX" -> {"DFLOAT"; "PI"; "NNI"; "INT"; "FPS"; "RNS"}*/
-"DRAWCX" -> "FIELD"
-/*"DRAWCX" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DRAWCX" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"DRAWCX" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"DRAWCX" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"DRAWCX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"DRAWCX" -> {"REAL"; "KONVERT"; "RETRACT"}*/
-"DRAWCX" -> "RADCAT"
-/*"DRAWCX" -> {"PATMAB"; "CHARZ"; "SINT"; "LIST"; "ILIST"}*/
-
-"D01GBFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01GBFA"]
-/*"D01GBFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "DFLOAT"; "PI"}*/
-/*"D01GBFA" -> {"NNI"; "INT"; "FPS"; "RNS"}*/
-"D01GBFA" -> "FIELD"
-/*"D01GBFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"D01GBFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"D01GBFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"D01GBFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"D01GBFA" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"D01GBFA" -> "RETRACT"*/
-"D01GBFA" -> "RADCAT"
-/*"D01GBFA" -> {"PATMAB"; "CHARZ"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"D01GBFA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"D01GBFA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"D01GBFA" -> "FLAGG"
-/*"D01GBFA" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"D01GBFA" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"D01GBFA" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"D01GBFA" -> "ABELMON-"*/
-
-"D02EJFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02EJFA"]
-/*"D02EJFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-/*"D02EJFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"D02EJFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"D02EJFA" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"D02EJFA" -> "FLAGG"
-/*"D02EJFA" -> {"ORDSET"; "ELAGG"; "OM"; "LIST"; "ILIST"; "DFLOAT"}*/
-/*"D02EJFA" -> {"FPS-"; "RNS-"}*/
-"D02EJFA" -> "FIELD-"
-/*"D02EJFA" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
-/*"D02EJFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "FPS"; "RNS"}*/
-"D02EJFA" -> "FIELD"
-/*"D02EJFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"D02EJFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"D02EJFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"D02EJFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"D02EJFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
-"D02EJFA" -> "RADCAT"
-/*"D02EJFA" -> {"PATMAB"; "CHARZ"; "PI"}*/
-
-"D03FAFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D03FAFA"]
-/*"D03FAFA" -> {"PDECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"}*/
-/*"D03FAFA" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"D03FAFA" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"D03FAFA" -> "KONVERT"*/
-"D03FAFA" -> "FLAGG"
-/*"D03FAFA" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-
-"DRAWPT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWPT"]
-/*"DRAWPT" -> {"FPS"; "RNS"}*/
-"DRAWPT" -> "FIELD"
-/*"DRAWPT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DRAWPT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"DRAWPT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"DRAWPT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"DRAWPT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"DRAWPT" -> {"REAL"; "KONVERT"; "RETRACT"}*/
-"DRAWPT" -> "RADCAT"
-/*"DRAWPT" -> {"PATMAB"; "CHARZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"DRAWPT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"DRAWPT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"DRAWPT" -> "FLAGG"
-/*"DRAWPT" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "INS-"; "EUCDOM-"}*/
-/*"DRAWPT" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"DRAWPT" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-/*"DRAWPT" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"; "SETCAT-"}*/
-/*"DRAWPT" -> {"RETRACT-"; "BASTYPE-"; "DFLOAT"; "PI"; "NNI"; "SINT"}*/
-/*"DRAWPT" -> {"LSAGG-"; "STAGG-"}*/
-
-"EUCDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=EUCDOM",
-          shape=ellipse]
-/*"EUCDOM" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"EUCDOM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"EUCDOM" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"EUCDOM" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"EUCDOM" -> {"BOOLEAN"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"EUCDOM" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
-/*"EUCDOM" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"EUCDOM" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"EUCDOM" -> "KONVERT"*/
-"EUCDOM" -> "FLAGG"
-/*"EUCDOM" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"EUCDOM-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EUCDOM",
-          shape=ellipse]
-/*"EUCDOM-" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"EUCDOM-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"EUCDOM-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"EUCDOM-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"EUCDOM-" -> {"BOOLEAN"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"EUCDOM-" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
-/*"EUCDOM-" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"EUCDOM-" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"EUCDOM-" -> "KONVERT"*/
-"EUCDOM-" -> "FLAGG"
-/*"EUCDOM-" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"FAMR" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FAMR"]
-"FAMR" -> "AMR"
-/*"FAMR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FAMR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FAMR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"FAMR" -> {"CHARNZ"; "INTDOM"; "ENTIRER"}*/
-"FAMR" -> "FRETRCT"
-/*"FAMR" -> {"RETRACT"; "OAMON"; "OASGP"; "ORDSET"; "NNI"; "INT"; "LIST"}*/
-/*"FAMR" -> {"ILIST"; "PI"; "BOOLEAN"}*/
-"FAMR" -> "FIELD"
-/*"FAMR" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-
-"FAMR-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAMR"]
-"FAMR-" -> "AMR"
-/*"FAMR-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FAMR-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FAMR-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"FAMR-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"}*/
-"FAMR-" -> "FRETRCT"
-/*"FAMR-" -> {"RETRACT"; "OAMON"; "OASGP"; "ORDSET"; "NNI"; "INT"; "LIST"}*/
-/*"FAMR-" -> {"ILIST"; "PI"; "BOOLEAN"}*/
-"FAMR-" -> "FIELD"
-/*"FAMR-" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-
-"FLASORT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLASORT"]
-/*"FLASORT" -> "TYPE"*/
-"FLASORT" -> "FLAGG"
-/*"FLASORT" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"; "BASTYPE"}*/
-/*"FLASORT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"FLASORT" -> {"KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"FLASORT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FLASORT" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FLASORT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"FLASORT" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FLASORT" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"FLASORT" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "INS-"; "EUCDOM-"}*/
-/*"FLASORT" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"FLASORT" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-/*"FLASORT" -> {"PI"; "NNI"; "SINT"; "BOOLEAN"}*/
-
-"FLAGG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLAGG2"]
-/*"FLAGG2" -> "TYPE"*/
-"FLAGG2" -> "FLAGG"
-/*"FLAGG2" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"; "BASTYPE"}*/
-/*"FLAGG2" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"FLAGG2" -> {"KONVERT"; "ORDSET"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"FLAGG2" -> {"ELAGG"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FLAGG2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FLAGG2" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FLAGG2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"FLAGG2" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"FLAGG2" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"FLAGG2" -> {"STEP"; "OM"; "INT"}*/
-
-"FGROUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FGROUP"]
-/*"FGROUP" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FGROUP" -> {"RETRACT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FGROUP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FGROUP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FGROUP" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"FGROUP" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"FGROUP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"}*/
-/*"FGROUP" -> {"LIST"; "ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"FGROUP" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"FGROUP" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"FGROUP" -> "FLAGG"
-/*"FGROUP" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"FGROUP" -> "FLAGG-"
-/*"FGROUP" -> "URAGG-"*/
-
-"FM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FM"]
-/*"FM" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "IDPC"; "MODULE"}*/
-/*"FM" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "ORDSET"; "ENTIRER"; "INT"}*/
-/*"FM" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"FM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"FM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"FM" -> "FLAGG"
-/*"FM" -> {"ELAGG"; "OM"; "LSAGG-"}*/
-
-"FMONOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FMONOID"]
-/*"FMONOID" -> {"MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"FMONOID" -> {"ORDSET"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ABELMON"}*/
-/*"FMONOID" -> {"ABELSG"; "CABMON"; "NNI"; "INT"; "LIST"; "ILIST"}*/
-/*"FMONOID" -> {"LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"FMONOID" -> "FLAGG-"
-/*"FMONOID" -> {"URAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"FMONOID" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"FMONOID" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"FMONOID" -> "FLAGG"
-/*"FMONOID" -> {"ELAGG"; "OM"; "BOOLEAN"}*/
-
-"FM1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FM1"]
-/*"FM1" -> {"FMCAT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FM1" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "RETRACT"}*/
-/*"FM1" -> {"MODULE"; "ORDSET"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"FM1" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"FM1" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"FM1" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"FM1" -> "FLAGG"
-/*"FM1" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"}*/
-/*"FM1" -> "LSAGG-"*/
-
-"FPC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FPC"]
-"FPC" -> "FIELD"
-/*"FPC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FPC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FPC" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FPC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
-/*"FPC" -> {"INT"; "INS-"; "NNI"}*/
-
-"FPC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FPC"]
-"FPC-" -> "FIELD"
-/*"FPC-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FPC-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FPC-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FPC-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
-/*"FPC-" -> {"INT"; "INS-"; "NNI"}*/
-
-"FPS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FPS",
-          shape=ellipse]
-/*"FPS" -> "RNS"*/
-"FPS" -> "FIELD"
-/*"FPS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FPS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FPS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"FPS" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"FPS" -> {"KONVERT"; "RETRACT"}*/
-"FPS" -> "RADCAT"
-/*"FPS" -> {"PATMAB"; "CHARZ"; "PI"; "NNI"; "INT"; "INS-"; "EUCDOM-"}*/
-/*"FPS" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"FPS" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"FPS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FPS",
-          shape=ellipse]
-/*"FPS-" -> "RNS"*/
-"FPS-" -> "FIELD"
-/*"FPS-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"FPS-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FPS-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FPS-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"FPS-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"FPS-" -> {"REAL"; "KONVERT"; "RETRACT"}*/
-"FPS-" -> "RADCAT"
-/*"FPS-" -> {"PATMAB"; "CHARZ"; "PI"; "NNI"; "INT"; "INS-"; "EUCDOM-"}*/
-/*"FPS-" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"FPS-" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"GCDDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GCDDOM",
-          shape=ellipse]
-/*"GCDDOM" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"GCDDOM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GCDDOM" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"GCDDOM" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"GCDDOM" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"GCDDOM" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"GCDDOM" -> "FLAGG" 
-/*"GCDDOM" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"GCDDOM" -> "NNI"*/
-
-"GCDDOM-" [color="#4488FF",href="bookvol10.2.pdf#nameddest=GCDDOM",
-          shape=ellipse]
-/*"GCDDOM-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"GCDDOM-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GCDDOM-" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"GCDDOM-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"GCDDOM-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"GCDDOM-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"GCDDOM-" -> "FLAGG"
-/*"GCDDOM-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"GCDDOM-" -> "NNI"*/
-
-"HOAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=HOAGG",
-          shape=ellipse]
-/*"HOAGG" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"HOAGG" -> {"IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"HOAGG" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"HOAGG" -> "FLAGG"
-/*"HOAGG" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
-/*"HOAGG" -> "NNI"*/
-
-"HOAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HOAGG",
-          shape=ellipse]
-/*"HOAGG-" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"HOAGG-" -> {"IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"HOAGG-" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"HOAGG-" -> "FLAGG"
-/*"HOAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
-/*"HOAGG-" -> "NNI"*/
-
-"INDE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INDE"]
-/*"INDE" -> {"OAMONS"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"INDE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"INDE" -> {"IDPC"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"}*/
-/*"INDE" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"INDE" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"INDE" -> "KONVERT"*/
-"INDE" -> "FLAGG"
-/*"INDE" -> {"ELAGG"; "OM"; "LSAGG-"}*/
-
-"INTDOM" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INTDOM",
-          shape=ellipse]
-/*"INTDOM" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"INTDOM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"INTDOM" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"INTDOM" -> {"MODULE"; "ENTIRER"}*/
-"INTDOM" -> "FIELD"
-/*"INTDOM" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "BOOLEAN"}*/
-
-"INTDOM-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTDOM",
-          shape=ellipse]
-/*"INTDOM-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"INTDOM-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"INTDOM-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"INTDOM-" -> {"MODULE"; "ENTIRER"}*/
-"INTDOM-" -> "FIELD"
-/*"INTDOM-" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "BOOLEAN"}*/
-
-"IPADIC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IPADIC"]
-"IPADIC" -> "PADICCT"
-/*"IPADIC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"IPADIC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"IPADIC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"IPADIC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "INT"}*/
-/*"IPADIC" -> {"NNI"; "INS-"; "SINT"; "BOOLEAN"; "PI"; "INS"; "UFD"}*/
-/*"IPADIC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"IPADIC" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"IPADIC" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"; "LIST"; "ILIST"}*/
-/*"IPADIC" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"IPADIC" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"IPADIC" -> {"ELTAB"; "CLAGG"}*/
-"IPADIC" -> "FLAGG"
-/*"IPADIC" -> {"ELAGG"; "OM"; "LSAGG-"}*/
-
-"IROOT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IROOT"]
-/*"IROOT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"IROOT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"IROOT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"IROOT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"IROOT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"IROOT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"IROOT" -> {"REAL"; "CHARZ"; "STEP"; "PI"; "NNI"; "INT"; "BOOLEAN"; "SINT"}*/
-/*"IROOT" -> {"MONOID-"; "ABELMON-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"IROOT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"IROOT" -> {"ELTAGG"; "ELTAB"; "CLAGG"}*/
-"IROOT" -> "FLAGG"
-/*"IROOT" -> {"ELAGG"; "OM"; "LIST"; "ILIST"}*/
-
-"IR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IR2"]
-"IR2" -> "FIELD"
-/*"IR2" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"IR2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"IR2" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"IR2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"LEXP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LEXP"]
-/*"LEXP" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"LEXP" -> {"ORDSET"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"LEXP" -> {"ABELMON"; "ABELSG"; "LMODULE"; "BMODULE"; "RMODULE"; "MODULE"}*/
-/*"LEXP" -> {"INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"LEXP" -> "FLAGG-"
-/*"LEXP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"LEXP" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"LEXP" -> {"CLAGG"; "KONVERT"}*/
-"LEXP" -> "FLAGG"
-/*"LEXP" -> {"ELAGG"; "OM"; "PI"}*/
-
-"LIECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LIECAT"]
-/*"LIECAT" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
-/*"LIECAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"LIECAT" -> {"RMODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-"LIECAT" -> "FIELD"
-/*"LIECAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"}*/
-/*"LIECAT" -> {"UFD"; "DIVRING"}*/
-
-"LIECAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIECAT"]
-/*"LIECAT-" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
-/*"LIECAT-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"LIECAT-" -> {"RMODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-"LIECAT-" -> "FIELD"
-/*"LIECAT-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"}*/
-/*"LIECAT-" -> {"UFD"; "DIVRING"}*/
-
-"LIST2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIST2"]
-/*"LIST2" -> {"TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"LIST2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"LIST2" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"LIST2" -> "FLAGG"
-/*"LIST2" -> {"ORDSET"; "ELAGG"}*/
-
-"LIST2MAP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIST2MAP"]
-/*"LIST2MAP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "TYPE"; "INT"; "LIST"}*/
-/*"LIST2MAP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"LIST2MAP" -> "FLAGG-"
-/*"LIST2MAP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"LIST2MAP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"LIST2MAP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"LIST2MAP" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"LIST2MAP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"LIST2MAP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"LIST2MAP" -> {"CHARZ"; "STEP"; "OM"}*/
-
-"LMOPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LMOPS"]
-/*"LMOPS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"LMOPS" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"LMOPS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"LMOPS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"LMOPS" -> "FLAGG"
-/*"LMOPS" -> {"ORDSET"; "ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"LMOPS" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "SGROUP"}*/
-/*"LMOPS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"LMOPS" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"LMOPS" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "PATMAB"}*/
-/*"LMOPS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LSAGG-"; "STAGG-"}*/
-/*"LMOPS" -> "ELAGG-"*/
-"LMOPS" -> "FLAGG-"
-/*"LMOPS" -> {"URAGG-"; "NNI"; "BOOLEAN"}*/
-
-"LSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LSAGG",
-          shape=ellipse]
-/*"LSAGG" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"LSAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"LSAGG" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"LSAGG" -> "FLAGG"
-/*"LSAGG" -> {"ORDSET"; "ELAGG"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"LSAGG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"LSAGG" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"LSAGG" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"LSAGG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"LSAGG" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"LSAGG" -> {"STEP"; "OM"; "INT"; "NNI"; "SINT"}*/
-
-"LSAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LSAGG",
-          shape=ellipse]
-/*{"LSAGG-" -> "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"LSAGG-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"LSAGG-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"LSAGG-" -> "FLAGG"
-/*"LSAGG-" -> {"ORDSET"; "ELAGG"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"}*/
-/*"LSAGG-" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"LSAGG-" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LSAGG-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LSAGG-" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"LSAGG-" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"LSAGG-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "NNI"; "SINT"}*/
-
-"LZSTAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LZSTAGG"]
-/*"LZSTAGG" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"LZSTAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"LZSTAGG" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "BOOLEAN"; "INT"}*/
-/*"LZSTAGG" -> {"LIST"; "ILIST"; "NNI"; "SINT"; "LSAGG"}*/
-"LZSTAGG" -> "FLAGG"
-/*"LZSTAGG" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"LZSTAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LZSTAGG"]
-/*"LZSTAGG-" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"LZSTAGG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"LZSTAGG-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"LZSTAGG-" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "NNI"; "SINT"; "LSAGG"}*/
-"LZSTAGG-" -> "FLAGG"
-/*"LZSTAGG-" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"MAGMA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MAGMA"]
-/*"MAGMA" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"MAGMA" -> {"BOOLEAN"; "INT"; "LIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"MAGMA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"MAGMA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"MAGMA" -> "FLAGG"
-/*"MAGMA" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"MAGMA" -> "FLAGG-"
-/*"MAGMA" -> {"PI"; "NNI"}*/
-
-"MESH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MESH"]
-/*"MESH" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"MESH" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"MESH" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"MESH" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"MESH" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"MESH" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"MESH" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "FPS"; "RNS"}*/
-"MESH" -> "FIELD"
-/*"MESH" -> "DIVRING"*/
-"MESH" -> "RADCAT"
-/*"MESH" -> {"INT"; "LIST"; "DFLOAT"; "PI"; "NNI"; "SINT"; "ILIST"}*/
-/*"MESH" -> "BOOLEAN"*/
-
-"MOEBIUS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MOEBIUS"]
-/*"MOEBIUS" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"MOEBIUS" -> "FIELD"
-/*"MOEBIUS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"MOEBIUS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "LMODULE"}*/
-/*"MOEBIUS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"MOEBIUS" -> {"DIVRING"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "LSAGG-"}*/
-/*"MOEBIUS" -> {"STAGG-"; "ELAGG-"}*/
-"MOEBIUS" -> "FLAGG-"
-/*"MOEBIUS" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-
-"MODFIELD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODFIELD"]
-"MODFIELD" -> "FIELD"
-/*"MODFIELD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"MODFIELD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"MODFIELD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MODFIELD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"MODFIELD" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"MODFIELD" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"MODFIELD" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"MODFIELD" -> "STEP"*/
-
-"MODOP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODOP"]
-/*"MODOP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"MODOP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"MODOP" -> {"LMODULE"; "RETRACT"; "ELTAB"; "CHARZ"; "CHARNZ"; "ALGEBRA"}*/
-/*"MODOP" -> {"MODULE"; "BMODULE"; "RMODULE"; "COMRING"; "LSAGG"; "STAGG"}*/
-/*"MODOP" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"MODOP" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
-"MODOP" -> "FLAGG"
-/*"MODOP" -> {"ORDSET"; "ELAGG"; "INT"; "LIST"; "ILIST"; "OM"; "LSAGG-"}*/
-/*"MODOP" -> {"STAGG-"; "ELAGG-"}*/
-"MODOP" -> "FLAGG-"
-/*"MODOP" -> {"URAGG-"; "ES"; "SINT"; "NNI"}*/
-
-"MRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MRING"]
-/*"MRING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"MRING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MRING" -> {"RETRACT"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
-/*"MRING" -> {"RMODULE"; "FINITE"; "COMRING"; "INT"; "LIST"; "ILIST"}*/
-/*"MRING" -> {"NNI"; "SINT"; "PI"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"MRING" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"MRING" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"MRING" -> "FLAGG"
-/*"MRING" -> {"ORDSET"; "ELAGG"; "OM"; "GROUP"; "LSAGG-"; "STAGG-"}*/
-/*"MRING" -> {"ELAGG-"; "ORDMON"}*/
-"MRING" -> "FLAGG-"
-
-"MTHING" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MTHING"]
-/*"MTHING" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
-/*"MTHING" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"MTHING" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"MTHING" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"MTHING" -> "FLAGG"
-/*"MTHING" -> {"ELAGG"; "OM"}*/
-
-"NCNTFRAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NCNTFRAC"]
-/*"NCNTFRAC" -> {"FPS"; "RNS"}*/
-"NCNTFRAC" -> "FIELD"
-/*"NCNTFRAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"NCNTFRAC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NCNTFRAC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"NCNTFRAC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"NCNTFRAC" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NCNTFRAC" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-"NCNTFRAC" -> "RADCAT"
-/*"NCNTFRAC" -> {"PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"NCNTFRAC" -> {"CFCAT"; "STEP"; "INT"}*/
-
-"NCODIV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NCODIV"]
-/*"NCODIV" -> {"MLO"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NCODIV" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NCODIV" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-"NCODIV" -> "FIELD"
-/*"NCODIV" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
-/*"NCODIV" -> {"UFD"; "DIVRING"; "NNI"; "INT"; "BOOLEAN"}*/
-
-"NUMTUBE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMTUBE"]
-/*"NUMTUBE" -> {"PSCURVE"; "KOERCE"; "DFLOAT"; "FPS"; "RNS"}*/
-"NUMTUBE" -> "FIELD"
-/*"NUMTUBE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"NUMTUBE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NUMTUBE" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"NUMTUBE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"NUMTUBE" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"NUMTUBE" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-"NUMTUBE" -> "RADCAT"
-/*"NUMTUBE" -> {"PATMAB"; "CHARZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"NUMTUBE" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"NUMTUBE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"NUMTUBE" -> "FLAGG"
-/*"NUMTUBE" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
-/*"NUMTUBE" -> {"STAGG-"; "ELAGG-"}*/
-"NUMTUBE" -> "FLAGG-"
-/*"NUMTUBE" -> {"URAGG-"; "PI"; "BOOLEAN"}*/
-
-"ODR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODR"]
-/*"ODR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BMODULE"; "LMODULE"}*/
-/*"ODR" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "RMODULE"}*/
-/*"ODR" -> {"DIFRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-"ODR" -> "FIELD"
-/*"ODR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ALGEBRA"}*/
-/*"ODR" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "PDRING"; "INS"}*/
-/*"ODR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ODR" -> {"ORDSET"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"ODR" -> {"REAL"; "CHARZ"; "STEP"}*/
-
-"OFMONOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OFMONOID"]
-/*"OFMONOID" -> {"ORDMON"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"OFMONOID" -> {"MONOID"; "SGROUP"; "RETRACT"; "OAMONS"; "OCAMON"}*/
-/*"OFMONOID" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "NNI"}*/
-/*"OFMONOID" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"OFMONOID" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"OFMONOID" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"OFMONOID" -> "FLAGG"
-/*"OFMONOID" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"OFMONOID" -> "FLAGG-"
-/*"OFMONOID" -> "BOOLEAN"*/
-
-"ONECOMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ONECOMP"]
-/*"ONECOMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"ONECOMP" -> "FRETRCT"
-/*"ONECOMP" -> {"RETRACT"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ONECOMP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ONECOMP" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"; "BOOLEAN"}*/
-/*"ONECOMP" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ONECOMP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ONECOMP" -> {"EUCDOM"; "PID"; "OINTDOM"; "DIFRING"; "KONVERT"; "LINEXP"}*/
-/*"ONECOMP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"ORDCOMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ORDCOMP"]
-/*"ORDCOMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"ORDCOMP" -> "FRETRCT"
-/*"ORDCOMP" -> {"RETRACT"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ORDCOMP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ORDCOMP" -> {"ORDSET"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ORDCOMP" -> {"BOOLEAN"; "SINT"; "INT"; "INS"; "UFD"; "GCDDOM"}*/
-/*"ORDCOMP" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ORDCOMP" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "DIFRING"}*/
-/*"ORDCOMP" -> {"KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"ORDCOMP" -> "STEP"*/
-
-"OREPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OREPCAT"]
-/*"OREPCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"OREPCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"OREPCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"}*/
-"OREPCAT" -> "FRETRCT"
-/*"OREPCAT" -> {"RETRACT"; "ALGEBRA"; "MODULE"; "NNI"; "INT"; "LIST"}*/
-/*"OREPCAT" -> {"ILIST"; "BOOLEAN"; "INTDOM"; "COMRING"; "ENTIRER"; "GCDDOM"}*/
-"OREPCAT" -> "FIELD"
-/*"OREPCAT" -> {"EUCDOM"; "PID"; "UFD"; "DIVRING"; "INS"; "OINTDOM"}*/
-/*"OREPCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"OREPCAT" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"OREPCAT" -> {"CHARZ"; "STEP"}*/
-
-"OREPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OREPCAT"]
-/*"OREPCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"OREPCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"OREPCAT-" -> {"LMODULE"; "BMODULE"; "RMODULE"}*/
-"OREPCAT-" -> "FRETRCT"
-/*"OREPCAT-" -> {"RETRACT"; "ALGEBRA"; "MODULE"; "NNI"; "INT"; "LIST"}*/
-/*"OREPCAT-" -> {"ILIST"; "BOOLEAN"; "INTDOM"; "COMRING"; "ENTIRER"}*/
-/*"OREPCAT-" -> "GCDDOM"*/
-"OREPCAT-" -> "FIELD"
-/*"OREPCAT-" -> {"EUCDOM"; "PID"; "UFD"; "DIVRING"; "INS"; "OINTDOM"}*/
-/*"OREPCAT-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"OREPCAT-" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"OREPCAT-" -> {"CHARZ"; "STEP"}*/
-
-"OUTFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OUTFORM",
-          shape=ellipse]
-/*"OUTFORM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "STRING"; "CHAR"; "SINT"}*/
-/*"OUTFORM" -> {"OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"OUTFORM" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "ILIST"; "LSAGG-"}*/
-/*"OUTFORM" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"OUTFORM" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"OUTFORM" -> {"BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"OUTFORM" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"OUTFORM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"OUTFORM" -> "FLAGG"
-/*"OUTFORM" -> {"ORDSET"; "ELAGG"; "OM"; "BOOLEAN"}*/
-
-"OWP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OWP"]
-/*"OWP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"OWP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"OWP" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
-"OWP" -> "FIELD"
-/*"OWP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"PACPERC" [color="#88FF44",href="bookvol10.2.pdf#nameddest=PACPERC"]
-"PACPERC" -> "FIELD"
-/*"PACPERC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PACPERC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PACPERC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PACPERC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE" }*/
-/*"PACPERC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"PADIC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PADIC"]
-/*"PADIC" -> "BOOLEAN"*/
-"PADIC" -> "PADICCT"
-/*"PADIC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PADIC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PADIC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PADIC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "INS"}*/
-/*"PADIC" -> {"UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PADIC" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"PADIC" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-
-"PATTERN2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PATTERN2"]
-/*"PATTERN2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PATTERN2" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PATTERN2" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"PATTERN2" -> "FLAGG"
-/*"PATTERN2" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-
-"PATLRES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PATLRES"]
-/*"PATLRES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PATLRES" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PATLRES" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"PATLRES" -> "FLAGG"
-/*"PATLRES" -> {"ORDSET"; "ELAGG"; "BOOLEAN"}*/
-
-"PARTPERM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARTPERM"]
-/*"PARTPERM" -> {"INT"; "LIST"; "ILIST"; "SINT"; "NNI"; "BOOLEAN"; "LSAGG"}*/
-/*"PARTPERM" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PARTPERM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"PARTPERM" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"PARTPERM" -> "FLAGG"
-/*"PARTPERM" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"PBWLB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PBWLB"]
-/*"PBWLB" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "INT"}*/
-/*"PBWLB" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"PBWLB" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"PBWLB" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"PBWLB" -> "FLAGG"
-/*"PBWLB" -> {"ELAGG"; "OM"; "LSAGG-"; "BOOLEAN"; "NNI"}*/
-
-"PENDTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PENDTREE"]
-/*"PENDTREE" -> {"BRAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"PENDTREE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"}*/
-/*"PENDTREE" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"PENDTREE" -> "FLAGG-"
-/*"PENDTREE" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"PENDTREE" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-
-"PGE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PGE"]
-/*"PGE" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PGE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PGE" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PGE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"PGE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"PGE" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"PGE" -> {"REAL"; "CHARZ"; "STEP"; "SINT"; "NNI"; "INT"}*/
-/*"PGE" -> {"LIST"; "ILIST"; "LSAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PGE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PGE" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"PGE" -> "FLAGG"
-/*"PGE" -> {"ELAGG"; "OM"; "STAGG-"; "ELAGG-"; "PI"}*/
-
-"PGROEB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PGROEB"]
-/*"PGROEB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PGROEB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PGROEB" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PGROEB" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PGROEB" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PGROEB" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"PGROEB" -> "FLAGG"
-/*"PGROEB" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-
-"PINTERP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PINTERP"]
-"PINTERP" -> "FIELD"
-/*"PINTERP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PINTERP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PINTERP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PINTERP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PINTERP" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-
-"PLOTTOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PLOTTOOL"]
-/*"PLOTTOOL" -> {"DFLOAT"; "INT"; "LIST"; "ILIST"; "FPS"; "RNS"}*/
-"PLOTTOOL" -> "FIELD"
-/*"PLOTTOOL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PLOTTOOL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PLOTTOOL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PLOTTOOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PLOTTOOL" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"PLOTTOOL" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-"PLOTTOOL" -> "RADCAT"
-/*"PLOTTOOL" -> {"PATMAB"; "CHARZ"}*/
-
-"PFR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PFR"]
-"PFR" -> "FIELD"
-/*"PFR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PFR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PFR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PFR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"PFR" -> {"INT"; "LIST"; "ILIST"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"PFR" -> "FLAGG-"
-/*"PFR" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PFR" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"PFR" -> {"CLAGG"; "KONVERT"}*/
-"PFR" -> "FLAGG"
-/*"PFR" -> {"ORDSET"; "ELAGG"; "OM"; "PI"; "NNI"; "INS"; "OINTDOM"}*/
-/*"PFR" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"PFR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"PMDOWN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMDOWN"]
-/*"PMDOWN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PATMAB"; "RETRACT"}*/
-/*"PMDOWN" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PMDOWN" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PMDOWN" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"PMDOWN" -> "FLAGG"
-/*"PMDOWN" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"PRTITION" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PRTITION"]
-/*"PRTITION" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"PRTITION" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"PRTITION" -> {"KONVERT"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"PRTITION" -> "ELAGG-"*/
-"PRTITION" -> "FLAGG-"
-/*"PRTITION" -> {"BOOLEAN"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"PRTITION" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"PRTITION" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"PRTITION" -> "FLAGG"
-/*"PRTITION" -> {"ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"PRTITION" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
-/*"PRTITION" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PRTITION" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PRTITION" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"PRTITION" -> {"CHARZ"; "STEP"; "URAGG-"; "INS-"}*/
-
-"PMINS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMINS"]
-/*"PMINS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PMINS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PMINS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PMINS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"PMINS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PMINS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"PMINS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PMINS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PMINS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"PMINS" -> "FLAGG"
-/*"PMINS" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
-/*"PMINS" -> {"STAGG-"; "ELAGG-"}*/
-"PMINS" -> "FLAGG-"
-/*"PMINS" -> "URAGG-"*/
-
-"PMLSAGG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMLSAGG"]
-/*"PMLSAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PATMAB"; "LSAGG"; "STAGG"}*/
-/*"PMLSAGG" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"PMLSAGG" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"PMLSAGG" -> "KONVERT"*/
-"PMLSAGG" -> "FLAGG"
-/*"PMLSAGG" -> {"ORDSET"; "ELAGG"; "BOOLEAN"; "INT"; "LIST"; "ILIST"}*/
-
-"PMTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMTOOLS"]
-/*"PMTOOLS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PMTOOLS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PMTOOLS" -> {"ORDSET"; "KONVERT"; "RETRACT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PMTOOLS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PMTOOLS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"PMTOOLS" -> "FLAGG"
-/*"PMTOOLS" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"PMTOOLS" -> {"ELAGG-"; "NNI"}*/
-
-"PSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PSCAT"]
-"PSCAT" -> "AMR"
-/*"PSCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PSCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PSCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
-/*"PSCAT" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"}*/
-/*"PSCAT" -> {"OASGP"; "ORDSET"; "INT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
-/*"PSCAT" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"}*/
-/*"PSCAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"PSCAT" -> "STEP"*/
-"PSCAT" -> "FIELD"
-/*"PSCAT" -> "DIVRING"*/
-
-"PSCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PSCAT"]
-"PSCAT-" -> "AMR"
-/*"PSCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PSCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PSCAT-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"PSCAT-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"PSCAT-" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"PSCAT-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "DIFRING"; "KONVERT"}*/
-/*"PSCAT-" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-"PSCAT-" -> "FIELD"
-/*"PSCAT-" -> "DIVRING"*/
-
-"QFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QFORM"]
-/*"QFORM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"QFORM" -> {"BASTYPE"; "KOERCE"}*/
-"QFORM" -> "FIELD"
-/*"QFORM" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"QFORM" -> {"RNG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"QFORM" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"QUEUE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QUEUE"]
-/*"QUEUE" -> {"QUAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"QUEUE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"}*/
-/*"QUEUE" -> {"ILIST"; "LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"QUEUE" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"QUEUE" -> "FLAGG"
-/*"QUEUE" -> {"ORDSET"; "ELAGG"; "OM"; "STAGG-"; "ELAGG-"}*/
-"QUEUE" -> "FLAGG-"
-/*"QUEUE" -> "URAGG-"*/
-
-"RCAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RCAGG",
-          shape=ellipse]
-/*"RCAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RCAGG" -> {"EVALAB"; "IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
-/*"RCAGG" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"RCAGG" -> "FLAGG"
-/*"RCAGG" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-
-"RCAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RCAGG",
-          shape=ellipse]
-/*"RCAGG-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RCAGG-" -> {"EVALAB"; "IEVALAB"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
-/*"RCAGG-" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"RCAGG-" -> "FLAGG"
-/*"RCAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-
-"RNS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RNS",
-          shape=ellipse]
-/*"RNS" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"RNS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RNS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RNS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"RNS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"RNS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"RNS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
-"RNS" -> "FIELD"
-/*"RNS" -> "DIVRING"*/
-"RNS" -> "RADCAT"
-/*"RNS" -> {"NNI"; "INT"; "PI"}*/
-
-"RNS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RNS",
-          shape=ellipse]
-/*"RNS-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"RNS-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RNS-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"RNS-" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"RNS-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"RNS-" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"RNS-" -> {"REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
-"RNS-" -> "FIELD"
-/*"RNS-" -> "DIVRING"*/
-"RNS-" -> "RADCAT"
-/*"RNS-" -> {"NNI"; "INT"; "PI"}*/
-
-"SCACHE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SCACHE"]
-/*"SCACHE" -> {"CACHSET"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"}*/
-/*"SCACHE" -> {"LIST"; "NNI"; "BOOLEAN"; "ILIST"; "LSAGG"; "STAGG"}*/
-/*"SCACHE" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"SCACHE" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"SCACHE" -> "KONVERT"*/
-"SCACHE" -> "FLAGG"
-/*"SCACHE" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "SINT"}*/
-
-"SEG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEG"]
-/*"SEG" -> {"SEGCAT"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "SEGXCAT"}*/
-/*"SEG" -> {"INT"; "BOOLEAN"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"SEG" -> {"OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"; "ABELGRP"}*/
-/*"SEG" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"; "LIST"}*/
-/*"SEG" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"SEG" -> {"AGG"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"SEG" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"SEG" -> "FLAGG"
-/*"SEG" -> {"ELAGG"; "OM"}*/
-
-"SEG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SEG2"]
-/*"SEG2" -> {"TYPE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SEG2" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
-/*"SEG2" -> {"CABMON"; "ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"SEG2" -> {"LMODULE"; "INT"; "LIST"; "BOOLEAN"; "ILIST"; "LSAGG"}*/
-/*"SEG2" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "EVALAB"}*/
-/*"SEG2" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"SEG2" -> "KONVERT"*/
-"SEG2" -> "FLAGG"
-/*"SEG2" -> {"ELAGG"; "OM"}*/
-
-"SEXOF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEXOF"]
-/*"SEXOF" -> {"SEXCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"}*/
-/*"SEXOF" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"SEXOF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"SEXOF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"SEXOF" -> "FLAGG"
-/*"SEXOF" -> {"ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"SEXOF" -> "FLAGG-"
-/*"SEXOF" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"SEXOF" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "NNI"}*/
-
-"STACK" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STACK"]
-/*"STACK" -> {"SKAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"STACK" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"; "ILIST"}*/
-/*"STACK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
-/*"STACK" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"STACK" -> "FLAGG"
-/*"STACK" -> {"ORDSET"; "ELAGG"; "OM"}*/
-
-"STTAYLOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STTAYLOR"]
-/*"STTAYLOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"STTAYLOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"STTAYLOR" -> {"LMODULE"; "SINT"; "NNI"; "INT"; "LIST"; "ILIST"}*/
-/*"STTAYLOR" -> {"LSAGG-"; "STAGG-"; "PI"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
-/*"STTAYLOR" -> {"RMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"STTAYLOR" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"STTAYLOR" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"STTAYLOR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"STTAYLOR" -> "STEP"*/
-"STTAYLOR" -> "FIELD"
-/*"STTAYLOR" -> "DIVRING"*/
-
-"TABLBUMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TABLBUMP"]
-/*"TABLBUMP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
-/*"TABLBUMP" -> {"BOOLEAN"; "ILIST"; "LSAGG-"; "STAGG-"; "PI"; "NNI"}*/
-/*"TABLBUMP" -> "ELAGG-"*/
-"TABLBUMP" -> "FLAGG-"
-/*"TABLBUMP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"TABLBUMP" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"TABLBUMP" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"TABLBUMP" -> "FLAGG"
-/*"TABLBUMP" -> "ELAGG"*/
-
-"TABLEAU" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TABLEAU"]
-/*"TABLEAU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"}*/
-/*"TABLEAU" -> {"LSAGG-"; "SINT"; "NNI"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"TABLEAU" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"TABLEAU" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"TABLEAU" -> "FLAGG"
-/*"TABLEAU" -> {"ORDSET"; "ELAGG"; "OM"; "STAGG-"}*/
-
-"TOPSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TOPSP"]
-/*"TOPSP" -> {"FPS"; "RNS"}*/
-"TOPSP" -> "FIELD"
-/*"TOPSP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"TOPSP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"TOPSP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"TOPSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"TOPSP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"TOPSP" -> {"REAL"; "KONVERT"; "RETRACT"}*/
-"TOPSP" -> "RADCAT"
-/*"TOPSP" -> {"PATMAB"; "CHARZ"}*/
-
-"TRANFUN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TRANFUN"]
-/*"TRANFUN" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RING"}*/
-/*"TRANFUN" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"TRANFUN" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"TRANFUN" -> {"PI"; "NNI"; "INT"}*/
-"TRANFUN" -> "FIELD"
-/*"TRANFUN" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"TRANFUN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"TRANFUN-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TRANFUN"]
-/*"TRANFUN-" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RING"}*/
-/*"TRANFUN-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"TRANFUN-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "PI"}*/
-/*"TRANFUN-" -> {"NNI"; "INT"}*/
-"TRANFUN-" -> "FIELD"
-/*"TRANFUN-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"TRANFUN-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"TUBE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TUBE"]
-/*"TUBE" -> {"PSCURVE"; "KOERCE"; "FPS"; "RNS"}*/
-"TUBE" -> "FIELD"
-/*"TUBE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"TUBE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"TUBE" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"TUBE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"TUBE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"TUBE" -> {"REAL"; "KONVERT"; "RETRACT"}*/
-"TUBE" -> "RADCAT"
-/*"TUBE" -> {"PATMAB"; "CHARZ"; "BOOLEAN"}*/
-
-"UDPO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UDPO"]
-/*"UDPO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"; "ILIST"}*/
-/*"UDPO" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"UDPO" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"UDPO" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"UDPO" -> "FLAGG"
-/*"UDPO" -> {"ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-
-"UFD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UFD",
-          shape=ellipse]
-/*"UFD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"UFD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"UFD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"UFD" -> {"MODULE"; "ENTIRER"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"UFD" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"UFD" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-"UFD" -> "FLAGG"
-/*"UFD" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-
-"UFD-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UFD",
-          shape=ellipse]
-/*"UFD-" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"UFD-" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"UFD-" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"UFD-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"}*/
-/*"UFD-" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"UFD-" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"UFD-" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"UFD-" -> "FLAGG"
-/*"UFD-" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-
-"UNISEG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UNISEG"]
-/*"UNISEG" -> {"SEGCAT"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "SEGXCAT"}*/
-/*"UNISEG" -> {"INT"; "BOOLEAN"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"UNISEG" -> {"OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"UNISEG" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UNISEG" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"UNISEG" -> "FLAGG-"
-/*"UNISEG" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"UNISEG" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-
-"URAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=URAGG",
-          shape=ellipse]
-/*"URAGG" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"URAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "BOOLEAN"; "INT"; "LIST"}*/
-/*"URAGG" -> {"ILIST"; "LSAGG"; "STAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"URAGG" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"URAGG" -> "FLAGG"
-/*"URAGG" -> {"ORDSET"; "ELAGG"; "OM"; "NNI"; "SINT"}*/
-
-"URAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=URAGG",
-          shape=ellipse]
-/*"URAGG-" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"URAGG-" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "BOOLEAN"; "INT"; "LIST"}*/
-/*"URAGG-" -> {"ILIST"; "LSAGG"; "STAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"URAGG-" -> {"ELTAB"; "CLAGG"; "KONVERT"}*/
-"URAGG-" -> "FLAGG"
-/*"URAGG-" -> {"ORDSET"; "ELAGG"; "OM"; "NNI"; "SINT"}*/
-
-"VIEW" [color="#FF4488",href="bookvol10.4.pdf#nameddest=VIEW"]
-/*"VIEW" -> {"INT"; "LIST"; "FPS"; "RNS"}*/
-"VIEW" -> "FIELD"
-/*"VIEW" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"VIEW" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"VIEW" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"VIEW" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"VIEW" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"VIEW" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-"VIEW" -> "RADCAT"
-/*"VIEW" -> {"PATMAB"; "CHARZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"VIEW" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"VIEW" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-"VIEW" -> "FLAGG"
-/*"VIEW" -> {"ELAGG"; "OM"; "ILIST"; "SINT"; "PI"; "NNI"}*/
-
-"VSPACE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=VSPACE"]
-"VSPACE" -> "FIELD"
-/*"VSPACE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"VSPACE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"VSPACE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"VSPACE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"VSPACE" -> {"UFD"; "DIVRING"}*/
-
-"VSPACE-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VSPACE"]
-"VSPACE-" -> "FIELD"
-/*"VSPACE-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"VSPACE-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"VSPACE-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"VSPACE-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"VSPACE-" -> {"UFD"; "DIVRING"}*/
-
-"XPOLYC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XPOLYC"]
-"XPOLYC" -> "XFALG"
-/*"XPOLYC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"XPOLYC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"XPOLYC" -> {"LMODULE"; "XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"XPOLYC" -> {"MODULE"; "RETRACT"}*/
-
-"XPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XPR"]
-/*"XPR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"XPR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"XPR" -> {"XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "FMCAT"}*/
-/*"XPR" -> {"RETRACT"; "COMRING"; "ORDMON"; "ORDSET"; "LSAGG"; "STAGG"}*/
-/*"XPR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"XPR" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"XPR" -> "KONVERT"*/
-"XPR" -> "FLAGG"
-/*"XPR" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"XPR" -> "ELAGG-"*/
-"XPR" -> "FLAGG-"
-/*"XPR" -> {"URAGG-"; "BOOLEAN"; "NNI"}*/
-"XPR" -> "FIELD"
-/*"XPR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"}*/
-/*"XPR" -> "DIVRING"*/
-
-\end{chunk}
-\subsection{Layer8}
-Depends on: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT 
-TRANFUN VSPACE XPOLYC PACPERC\\
-Used by next layer: BTAGG FLALG MATCAT SRAGG VECTCAT 
-\begin{chunk}{layer8}
-
-LAYER8=\
-  ${OUT}/AFFSP.o    \
-  ${OUT}/APPLYORE.o ${OUT}/ARRAY1.o   ${OUT}/ARRAY12.o  ${OUT}/ARRAY2.o   \
-  ${OUT}/ASTACK.o   ${OUT}/BTAGG.o    ${OUT}/BTAGG-.o   ${OUT}/COMBINAT.o \
-  ${OUT}/CSTTOOLS.o ${OUT}/D01FCFA.o  ${OUT}/E04MBFA.o  ${OUT}/FAMR2.o    \
-  ${OUT}/FARRAY.o   ${OUT}/FLALG.o    ${OUT}/GALUTIL.o  ${OUT}/HEAP.o     \
-  ${OUT}/IARRAY1.o  ${OUT}/IARRAY2.o  ${OUT}/IFARRAY.o  ${OUT}/INTCAT.o   \
-  ${OUT}/INTHEORY.o ${OUT}/IRREDFFX.o ${OUT}/LFCAT.o    ${OUT}/LODOCAT.o  \
-  ${OUT}/LODOCAT-.o ${OUT}/LWORD.o    ${OUT}/MATCAT.o   ${OUT}/MATCAT-.o  \
-  ${OUT}/MATSTOR.o  ${OUT}/ORESUP.o   ${OUT}/OREPCTO.o  ${OUT}/OREUP.o    \
-  ${OUT}/PACFFC.o   \
-  ${OUT}/PLOT3D.o   ${OUT}/POLYVEC.o \
-  ${OUT}/PR.o       ${OUT}/PREASSOC.o ${OUT}/PRIMARR2.o \
-  ${OUT}/PROJSP.o   \
-  ${OUT}/REDORDER.o ${OUT}/SRAGG.o    ${OUT}/SRAGG-.o   ${OUT}/STREAM.o   \
-  ${OUT}/SYMPOLY.o  ${OUT}/TS.o       ${OUT}/TUPLE.o    ${OUT}/UPSCAT.o   \
-  ${OUT}/UPSCAT-.o  ${OUT}/U8VEC.o    ${OUT}/U16VEC.o   ${OUT}/U32VEC.o   \
-  ${OUT}/VECTCAT.o  ${OUT}/VECTCAT-.o ${OUT}/XDPOLY.o   \
-  ${OUT}/XEXPPKG.o  ${OUT}/XF.o       ${OUT}/XF-.o      ${OUT}/XPBWPOLY.o \
-  ${OUT}/XPOLY.o    ${OUT}/XRPOLY.o \
-  layer8done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 8 */
-/* depends on: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT */
-/* TRANFUN VSPACE XPOLYC PACPREC */
-
-"AFFSP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AFFSP"]
-/*"AFFSP" -> {"AFSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
-/*"AFFSP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"AFFSP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"AFFSP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"AFFSP" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"AFFSP" -> {"PI"; "NNI"; "FFIELDC"}*/
-"AFFSP" -> "FPC"
-"AFFSP" -> "PACPERC"
-/*"AFFSP" -> {"CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "STAGG-"; "ELAGG-"}*/
-/*"AFFSP" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"AFFSP" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"AFFSP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"AFFSP" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"AFFSP" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
-/*"AFFSP" -> {"BOOLEAN"}*/
-
-"APPLYORE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=APPLYORE"]
-/*"APPLYORE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"APPLYORE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"APPLYORE" -> "LMODULE"*/
-"APPLYORE" -> "OREPCAT"
-/*"APPLYORE" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
-/*"APPLYORE" -> {"MODULE"; "SINT"; "NNI"; "INT"}*/
-
-"ARRAY1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ARRAY1"]
-"ARRAY1" -> "A1AGG"
-/*"ARRAY1" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"ARRAY1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"ARRAY1" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"; "LSAGG"}*/
-/*"ARRAY1" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
-/*"ARRAY1" -> {"NNI"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ARRAY1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ARRAY1" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ARRAY1" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"ARRAY1" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ARRAY1" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"ARRAY1" -> {"REAL"; "CHARZ"; "STEP"}*/
-
-"ARRAY12" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ARRAY12"]
-/*"ARRAY12" -> "TYPE"*/
-"ARRAY12" -> "A1AGG"
-/*"ARRAY12" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"}*/
-/*"ARRAY12" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"ARRAY12" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-
-"ARRAY2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ARRAY2"]
-"ARRAY2" -> "ARR2CAT"
-/*"ARRAY2" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ARRAY2" -> {"EVALAB"; "IEVALAB"}*/
-"ARRAY2" -> "A1AGG"
-/*"ARRAY2" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"ARRAY2" -> {"KONVERT"; "ORDSET"; "INT"}*/
-
-"ASTACK" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASTACK"]
-/*"ASTACK" -> {"SKAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"ASTACK" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "INT"}*/
-"ASTACK" -> "A1AGG"
-/*"ASTACK" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"ASTACK" -> {"KONVERT"; "ORDSET"; "ELAGG"; "LIST"; "ILIST"; "SINT"}*/
-/*"ASTACK" -> {"NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"ASTACK" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"ASTACK" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"ASTACK" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"ASTACK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"ASTACK" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ASTACK" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"ASTACK" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"ASTACK" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"ASTACK" -> {"STEP"; "OM"}*/
-
-"BTAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BTAGG"]
-/*"BTAGG" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"}*/
-"BTAGG" -> "A1AGG"
-/*"BTAGG" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"BTAGG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-
-"BTAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BTAGG"]
-/*"BTAGG-" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"}*/
-"BTAGG-" -> "A1AGG"
-/*"BTAGG-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"BTAGG-" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-
-"COMBINAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMBINAT"]
-/*"COMBINAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"COMBINAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"COMBINAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"COMBINAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"COMBINAT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"COMBINAT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"COMBINAT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"COMBINAT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"; "INT"; "OM"}*/
-"COMBINAT" -> "A1AGG"
-/*"COMBINAT" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"COMBINAT" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"COMBINAT" -> {"ELAGG"; "SINT"; "MONOID-"; "ABELMON-"; "PI"}*/
-
-"CSTTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CSTTOOLS"]
-/*"CSTTOOLS" -> "TYPE"*/
-"CSTTOOLS" -> "LZSTAGG"
-/*"CSTTOOLS" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "SETCAT"}*/
-/*"CSTTOOLS" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"CSTTOOLS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "SINT"}*/
-/*"CSTTOOLS" -> {"NNI"; "INT"}*/
-
-"D01FCFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01FCFA"]
-/*"D01FCFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"D01FCFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"D01FCFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"D01FCFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"D01FCFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"D01FCFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"D01FCFA" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
-/*"D01FCFA" -> {"PATMAB"; "CHARZ"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"D01FCFA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"D01FCFA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"D01FCFA" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
-/*"D01FCFA" -> {"STAGG-"; "DIFRING"}*/
-"D01FCFA" -> "TRANFUN"
-/*"D01FCFA" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-/*"D01FCFA" -> {"PI"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
-/*"D01FCFA" -> {"DFLOAT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-/*"D01FCFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"D01FCFA" -> "ABELGRP-"*/
-
-"E04MBFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04MBFA"]
-/*"E04MBFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"E04MBFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"E04MBFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"E04MBFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"E04MBFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"E04MBFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"E04MBFA" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
-/*"E04MBFA" -> {"PATMAB"; "CHARZ"; "DIFRING"; "OM"}*/
-"E04MBFA" -> "TRANFUN"
-/*"E04MBFA" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-/*"E04MBFA" -> {"INT"; "NNI"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"E04MBFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"E04MBFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"E04MBFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "ELAGG-"; "DFLOAT"}*/
-/*"E04MBFA" -> {"PI"; "INS-"; "MONOID-"; "ABELMON-"; "BOOLEAN"}*/
-
-"FAMR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FAMR2"]
-/*"FAMR2" -> "{OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FAMR2" -> {"ABELMON"; "ABELSG"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FAMR2" -> {"SGROUP"; "MONOID"; "LMODULE"}*/
-"FAMR2" -> "FAMR"
-/*"FAMR2" -> {"AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
-/*"FAMR2" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"FAMR2" -> {"FRETRCT"; "RETRACT"}*/
-
-"FARRAY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FARRAY"]
-/*"FARRAY" -> "INT"*/
-"FARRAY" -> "A1AGG"
-/*"FARRAY" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"FARRAY" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"FARRAY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "ELAGG"; "INS"}*/
-/*"FARRAY" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FARRAY" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"FARRAY" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FARRAY" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"FARRAY" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"FARRAY" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"FARRAY" -> {"STEP"; "OM"}*/
-
-"FLALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FLALG"]
-"FLALG" -> "LIECAT"
-/*"FLALG" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FLALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"}*/
-
-"GALUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALUTIL"]
-/*"GALUTIL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"GALUTIL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"GALUTIL" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"GALUTIL" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"GALUTIL" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"GALUTIL" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"GALUTIL" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INT"; "NNI"; "PI"}*/
-"GALUTIL" -> "A1AGG"
-/*"GALUTIL" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"GALUTIL" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "ELAGG"}*/
-
-"HEAP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HEAP"]
-/*"HEAP" -> {"PRQAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"HEAP" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ORDSET"}*/
-/*"HEAP" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
-/*"HEAP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
-/*"HEAP" -> {"OM"; "LIST"; "ILIST"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"HEAP" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"HEAP" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "PI"}*/
-"HEAP" -> "A1AGG"
-/*"HEAP" -> "SINT"*/
-
-"IARRAY1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IARRAY1"]
-"IARRAY1" -> "A1AGG"
-/*"IARRAY1" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"IARRAY1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"IARRAY1" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "SINT"; "NNI"}*/
-/*"IARRAY1" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"IARRAY1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IARRAY1" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"IARRAY1" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"IARRAY1" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"IARRAY1" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"IARRAY1" -> {"CHARZ"; "STEP"; "OM"}*/
-
-"IARRAY2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IARRAY2"]
-"IARRAY2" -> "ARR2CAT"
-/*"IARRAY2" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"IARRAY2" -> {"EVALAB"; "IEVALAB"}*/
-"IARRAY2" -> "A1AGG"
-/*"IARRAY2" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"IARRAY2" -> {"KONVERT"; "ORDSET"}*/
-
-"IFARRAY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IFARRAY"]
-"IFARRAY" -> "A1AGG"
-/*"IFARRAY" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"IFARRAY" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"IFARRAY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "ELAGG"; "BOOLEAN"}*/
-/*"IFARRAY" -> {"INT"; "PRIMARR"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"IFARRAY" -> {"OM"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"}*/
-/*"IFARRAY" -> {"SINT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-/*"IFARRAY" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"IFARRAY" -> {"ABELGRP-"; "ABELMON-"; "PI"; "INS"; "UFD"; "GCDDOM"}*/
-/*"IFARRAY" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"IFARRAY" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IFARRAY" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"IFARRAY" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"IFARRAY" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"IFARRAY" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"INTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INTCAT"]
-/*"INTCAT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTCAT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"INTCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"INTCAT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-"INTCAT" -> "TRANFUN"
-/*"INTCAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
-/*"INTCAT" -> "RETRACT"*/
-
-"INTHEORY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTHEORY"]
-/*"INTHEORY" -> {"NNI"; "INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INTHEORY" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INTHEORY" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INTHEORY" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INTHEORY" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"INTHEORY" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"INTHEORY" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"INTHEORY" -> {"REAL"; "CHARZ"; "STEP"; "SINT"; "PI"; "INS-"; "EUCDOM-"}*/
-/*"INTHEORY" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"INTHEORY" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-/*"INTHEORY" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
-"INTHEORY" -> "A1AGG"
-/*"INTHEORY" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"INTHEORY" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "ELAGG"}*/
-/*"INTHEORY" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"INTHEORY" -> "FLAGG-"*/
-
-"IRREDFFX" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRREDFFX"]
-/*"IRREDFFX" -> "FFIELDC"*/
-"IRREDFFX" -> "FPC"
-/*"IRREDFFX" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"IRREDFFX" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IRREDFFX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"IRREDFFX" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"IRREDFFX" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
-/*"IRREDFFX" -> {"DIFRING"; "INT"; "PI"; "NNI"; "BOOLEAN"; "MONOID-"}*/
-/*"IRREDFFX" -> {"ABELSG-"; "SGROUP-"}*/
-
-"LFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LFCAT"]
-/*"LFCAT" -> "PRIMCAT"*/
-"LFCAT" -> "TRANFUN"
-/*"LFCAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-
-"LODOCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LODOCAT"]
-/*"LODOCAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LODOCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"LODOCAT" -> "LMODULE"*/
-"LODOCAT" -> "OREPCAT"
-/*"LODOCAT" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
-/*"LODOCAT" -> {"MODULE"; "ELTAB"; "NNI"; "INT"; "BOOLEAN"; "FIELD"}*/
-/*"LODOCAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"LODOCAT" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-
-"LODOCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODOCAT"]
-/*"LODOCAT-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LODOCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"LODOCAT-" -> "LMODULE"*/
-"LODOCAT-" -> "OREPCAT"
-/*"LODOCAT-" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
-/*"LODOCAT-" -> {"MODULE"; "ELTAB"; "NNI"; "INT"; "BOOLEAN"; "FIELD"}*/
-/*"LODOCAT-" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"LODOCAT-" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-
-"LWORD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LWORD"]
-/*"LWORD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"LWORD" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"LWORD" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"LWORD" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
-/*"LWORD" -> {"OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"LWORD" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"LWORD" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"LWORD" -> {"NNI"; "PI"}*/
-"LWORD" -> "A1AGG"
-/*"LWORD" -> "SINT"*/
-
-"MATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MATCAT"]
-"MATCAT" -> "ARR2CAT"
-/*"MATCAT" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MATCAT" -> {"EVALAB"; "IEVALAB"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"MATCAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MATCAT" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"MATCAT" -> {"KONVERT"; "ORDSET"; "NNI"; "INT"; "BOOLEAN"; "SINT"}*/
-/*"MATCAT" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-/*"MATCAT" -> {"OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"MATCAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"MATCAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"MATCAT" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"MATCAT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "FIELD"; "DIVRING"; "INS-"}*/
-
-"MATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MATCAT"]
-"MATCAT-" -> "ARR2CAT"
-/*"MATCAT-" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MATCAT-" -> {"EVALAB"; "IEVALAB"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"MATCAT-" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MATCAT-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"MATCAT-" -> {"KONVERT"; "ORDSET"; "NNI"; "INT"; "BOOLEAN"; "SINT"}*/
-/*"MATCAT-" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"MATCAT-" -> {"ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"MATCAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"MATCAT-" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"MATCAT-" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"MATCAT-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "FIELD"; "DIVRING"; "INS-"}*/
-
-"MATSTOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MATSTOR"]
-/*"MATSTOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"MATSTOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"MATSTOR" -> {"LMODULE"; "NNI"; "INT"; "SINT"; "PRIMARR"}*/
-"MATSTOR" -> "A1AGG"
-/*"MATSTOR" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"MATSTOR" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"MATSTOR" -> "BOOLEAN"*/
-
-"MTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MTSCAT",
-          shape=ellipse]
-/*"MTSCAT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
-/*"MTSCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"MTSCAT" -> {"MTSCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"MTSCAT" -> {"MONOID"; "LMODULE"}*/
-"MTSCAT" -> "PSCAT"
-/*"MTSCAT" -> {"AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
-/*"MTSCAT" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "IEVALAB"}*/
-/*"MTSCAT" -> {"EVALAB"; "RADCAT"}*/
-"MTSCAT" -> "TRANFUN"
-/*"MTSCAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-
-"ORESUP" -> "OREPCAT"
-/*"ORESUP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ORESUP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ORESUP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
-/*"ORESUP" -> {"ALGEBRA"; "MODULE"; "INTDOM"; "COMRING"; "ENTIRER"}*/
-/*"ORESUP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"ORESUP" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ORESUP" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"}*/
-/*"ORESUP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"OREPCTO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OREPCTO"]
-/*"OREPCTO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"OREPCTO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-"OREPCTO" -> "OREPCAT"
-/*"OREPCTO" -> {"BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"; "ALGEBRA"}*/
-/*"OREPCTO" -> {"MODULE"; "BOOLEAN"; "NNI"; "INT"; "SINT"; "INTDOM"}*/
-/*"OREPCTO" -> {"COMRING"; "ENTIRER"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"OREPCTO" -> {"UFD"; "DIVRING"}*/
-
-"OREUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OREUP"]
-"OREUP" -> "OREPCAT"
-/*"OREUP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"OREUP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"OREUP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
-/*"OREUP" -> {"ALGEBRA"; "MODULE"; "NNI"; "INT"; "FIELD"; "EUCDOM"}*/
-/*"OREUP" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
-/*"OREUP" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"OREUP" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"}*/
-/*"OREUP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"PACFFC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PACFFC",
-          shape=ellipse]
-/*"PACFFC" -> {"FFIELDC"}*/
-"PACFFC" -> "FPC"
-/*"PACFFC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PACFFC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PACFFC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PACFFC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PACFFC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"PACFFC" -> {"STEP"; "DIFRING"}*/
-"PACFFC" -> "PACPERC"
-
-"PLOT3D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLOT3D"]
-/*"PLOT3D" -> {"PSCURVE"; "KOERCE"; "BOOLEAN"; "INT"; "DFLOAT"; "FPS-"}*/
-/*"PLOT3D" -> {"RNS-"; "FIELD-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
-/*"PLOT3D" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PLOT3D" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PLOT3D" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PLOT3D" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"PLOT3D" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"PLOT3D" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"PLOT3D" -> {"LIST"; "ILIST"; "NNI"; "PI"; "LSAGG-"; "STAGG-"}*/
-/*"PLOT3D" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PLOT3D" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PLOT3D" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"PLOT3D" -> {"ELAGG"; "OM"; "SINT"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"PLOT3D" -> {"DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"PLOT3D" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"}*/
-/*"PLOT3D" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "INS"; "OINTDOM"}*/
-/*"PLOT3D" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "INS-"}*/
-"PLOT3D" -> "TRANFUN"
-/*"PLOT3D" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-
-"POLYVEC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYVEC"]
-/*"POLYVEC" -> {"SINT" "NNI" "INT"}*/
-"POLYVEC" -> "A1AGG"
-/*"POLYVEC" -> {"FLAGG" "LNAGG" "IXAGG" "HOAGG" "AGG" "TYPE" "SETCAT"}*/
-/*"POLYVEC" -> {"BASTYPE" "KOERCE" "EVALAB" "IEVALAB" "ELTAGG" "ELTAB"}*/
-/*"POLYVEC" -> {"CLAGG" "KONVERT" "ORDSET" "BOOLEAN" "INS" "UFD" "GCDDOM"} */
-/*"POLYVEC" -> {"INTDOM" "COMRING" "RING" "RNG" "ABELGRP" "CABMON"}*/
-/*"POLYVEC" -> {"ABELMON" "ABELSG" "SGROUP" "MONOID" "LMODULE" "BMODULE"}*/
-/*"POLYVEC" -> {"RMODULE" "ALGEBRA" "MODULE" "ENTIRER" "EUCDOM" "PID"}*/
-/*"POLYVEC" -> {"OINTDOM" "ORDRING" "OAGROUP" "OCAMON" "OAMON" "OASGP"}*/
-/*"POLYVEC" -> {"DIFRING" "RETRACT" "LINEXP" "PATMAB" "CFCAT" "REAL"}*/
-/*"POLYVEC" -> {"CHARZ" "STEP" "INS-" "EUCDOM-" "UFD-" "GCDDOM-" "INTDOM-"}*/
-/*"POLYVEC" -> {"ALGEBRA-" "DIFRING-" "ORDRING-" "MODULE-""RING-"}*/
-/*"POLYVEC" -> {"ABELGRP-" "ABELMON-" "MONOID-" "ORDSET-" "ABELSG-"}*/
-/*"POLYVEC" -> {"SGROUP-" "SETCAT-" "RETRACT-" "BASTYPE-" "PI" "PRIMARR"}*/
-
-"PR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PR"]
-"PR" -> "FAMR"
-/*"PR" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"PR" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"PR" -> {"OAMON"; "OASGP"; "ORDSET"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"PR" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"PR" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"PR" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "BOOLEAN"; "LNAGG-"; "RCAGG-"}*/
-/*"PR" -> {"IXAGG-"; "NNI"; "PI"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PR" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PR" -> {"OCAMON"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-
-"PREASSOC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PREASSOC"]
-/*"PREASSOC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PREASSOC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PREASSOC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PREASSOC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LODOCAT"}*/
-"PREASSOC" -> "OREPCAT"
-/*"PREASSOC" -> {"FRETRCT"; "RETRACT"; "ELTAB"; "NNI"; "INT"; "PI"}*/
-/*"PREASSOC" -> {"PRIMARR"; "SINT"}*/
-"PREASSOC" -> "A1AGG"
-/*"PREASSOC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PREASSOC" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
-/*"PREASSOC" -> "ORDSET"*/
-
-"PRIMARR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PRIMARR",
-          shape=ellipse]
-"PRIMARR" -> "A1AGG"
-/*"PRIMARR" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PRIMARR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"PRIMARR" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"PRIMARR" -> {"INT"; "PRIMARR"; "SINT"; "NNI"; "INS"; "UFD"; "GCDDOM"}*/
-/*"PRIMARR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PRIMARR" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PRIMARR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PRIMARR" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PRIMARR" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"PRIMARR" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"PRIMARR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRIMARR2"]
-/*"PRIMARR2" -> "TYPE"*/
-"PRIMARR2" -> "A1AGG"
-/*"PRIMARR2" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "SETCAT"}*/
-/*"PRIMARR2" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"PRIMARR2" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-
-"PROJSP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PROJSP",
-          shape=ellipse]
-/*"PROJSP" -> {"PRSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PROJSP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"PROJSP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON";  "FFIELDC"}*/
-/*"PROJSP" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PROJSP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PROJSP" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "PI"; "NNI"}*/
-"PROJSP" -> "PACPERC"
-"PROJSP" -> "FPC"
-/*"PROJSP" -> {"CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "LSAGG-"; "STAGG-"}*/
-/*"PROJSP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"PROJSP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"PROJSP" -> {"BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"PROJSP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"PROJSP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
-/*"PROJSP" -> {"ELAGG"; "OM"; "BOOLEAN"}*/
-
-"REDORDER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REDORDER"]
-/*"REDORDER" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"REDORDER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"REDORDER" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"REDORDER" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"REDORDER" -> {"ENTIRER"; "UFD"; "DIVRING"; "LODOCAT"}*/
-"REDORDER" -> "OREPCAT"
-/*"REDORDER" -> {"FRETRCT"; "RETRACT"; "ELTAB"; "INT"; "INS-"; "PRIMARR"}*/
-/*"REDORDER" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "BOOLEAN"}*/
-/*"REDORDER" -> "NNI"*/
-"REDORDER" -> "A1AGG"
-/*"REDORDER" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"REDORDER" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
-/*"REDORDER" -> {"ORDSET"; "SINT"}*/
-
-"SRAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SRAGG"]
-"SRAGG" -> "A1AGG"
-/*"SRAGG" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"SRAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"SRAGG" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS"; "UFD"; "GCDDOM"}*/
-/*"SRAGG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SRAGG" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"SRAGG" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"SRAGG" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"SRAGG" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"SRAGG" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "NNI"; "INT"}*/
-
-"SRAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SRAGG"]
-"SRAGG-" -> "A1AGG"
-/*"SRAGG-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"SRAGG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"SRAGG-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"}*/
-/*"SRAGG-" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"SRAGG-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"SRAGG-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"SRAGG-" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"SRAGG-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SRAGG-" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"SRAGG-" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "NNI"; "INT"}*/
-
-"STREAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STREAM"]
-"STREAM" -> "LZSTAGG"
-/*"STREAM" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"STREAM" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"STREAM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "INT"; "LIST"; "ILIST"}*/
-/*"STREAM" -> {"SINT"; "NNI"; "BOOLEAN"; "LSAGG"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"STREAM" -> {"OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"STREAM" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"STREAM" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"STREAM" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"STREAM" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"STREAM" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"SYMPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMPOLY"]
-/*"SYMPOLY" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-/*"SYMPOLY" -> {"KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-"SYMPOLY" -> "FAMR"
-/*"SYMPOLY" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
-/*"SYMPOLY" -> {"LMODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
-/*"SYMPOLY" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"SYMPOLY" -> {"FRETRCT"; "RETRACT"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
-/*"SYMPOLY" -> {"KONVERT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"}*/
-/*"SYMPOLY" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "DIFRING"; "LINEXP"}*/
-/*"SYMPOLY" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"; "FIELD"; "DIVRING"}*/
-
-"TS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TS"]
-/*"TS" -> {"MTSCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"TS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"TS" -> {"MONOID"; "LMODULE"}*/
-"TS" -> "PSCAT"
-/*"TS" -> {"AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"TS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "IEVALAB"; "EVALAB"}*/
-/*"TS" -> "RADCAT"*/
-"TS" -> "TRANFUN"
-/*"TS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SINT"; "NNI"}*/
-/*"TS" -> {"INT"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"}*/
-/*"TS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"TS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"TS" -> {"CFCAT"; "REAL"; "STEP"; "FIELD"; "DIVRING"}*/
-
-"TUPLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TUPLE"]
-/*"TUPLE" -> {"KOERCE"; "SETCAT"; "BASTYPE"; "TYPE"}*/
-"TUPLE" -> "A1AGG"
-/*"TUPLE" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "EVALAB"; "IEVALAB"}*/
-/*"TUPLE" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"}*/
-/*"TUPLE" -> {"PRIMARR"; "NNI"}*/
-"TUPLE" -> "A1AGG-"
-/*"TUPLE" -> {"BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"TUPLE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"TUPLE" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"TUPLE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"TUPLE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"TUPLE" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"TUPLE" -> {"STEP"; "OM"; "FLAGG-"; "LNAGG-"}*/
-
-"UPSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPSCAT"]
-"UPSCAT" -> "PSCAT"
-/*"UPSCAT" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"UPSCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"UPSCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
-/*"UPSCAT" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"}*/
-/*"UPSCAT" -> {"DIFRING"; "PDRING"; "OAMON"; "OASGP"; "ORDSET"; "INT"}*/
-/*"UPSCAT" -> {"LIST"; "ILIST"; "LSAGG-"}*/
-
-"UPSCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPSCAT"]
-"UPSCAT-" -> "PSCAT"
-/*"UPSCAT-" -> {"AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"UPSCAT-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"UPSCAT-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"UPSCAT-" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"UPSCAT-" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "OAMON"; "OASGP"}*/
-/*"UPSCAT-" -> {"ORDSET"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-
-"U8VEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U8VEC"]
-"U8VEC" -> "A1AGG"
-/*"U8VEC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"U8VEC" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"U8VEC" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"; "INS"}*/
-/*"U8VEC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"U8VEC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"U8VEC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"U8VEC" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"U8VEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"U8VEC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"U16VEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U16VEC"]
-"U16VEC" -> "A1AGG"
-/*"U16VEC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"U16VEC" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"U16VEC" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"; "INS"}*/
-/*"U16VEC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"U16VEC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"U16VEC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"U16VEC" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"U16VEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"U16VEC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"U32VEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U32VEC"]
-"U32VEC" -> "A1AGG"
-/*"U32VEC" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"U32VEC" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"U32VEC" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"; "INS"}*/
-/*"U32VEC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"U32VEC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"U32VEC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"U32VEC" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"U32VEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"U32VEC" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"VECTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=VECTCAT"]
-"VECTCAT" -> "A1AGG"
-/*"VECTCAT" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"VECTCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"VECTCAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "ABELSG"}*/
-/*"VECTCAT" -> {"NNI"; "INT"; "ABELMON"; "ABELGRP"; "CABMON"; "MONOID"}*/
-/*"VECTCAT" -> {"SGROUP"; "RING"; "RNG"; "LMODULE"; "INS"; "UFD"; "GCDDOM"}*/
-/*"VECTCAT" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"VECTCAT" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"VECTCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"VECTCAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"VECTCAT" -> {"STEP"; "OM"; "PI"; "RADCAT"}*/
-
-"VECTCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VECTCAT"]
-"VECTCAT-" -> "A1AGG"
-/*"VECTCAT-" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"VECTCAT-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"VECTCAT-" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"VECTCAT-" -> {"ABELSG"; "NNI"; "INT"; "ABELMON"; "ABELGRP"; "CABMON"}*/
-/*"VECTCAT-" -> {"MONOID"; "SGROUP"; "RING"; "RNG"; "LMODULE"; "INS"}*/
-/*"VECTCAT-" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"VECTCAT-" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"VECTCAT-" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"VECTCAT-" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"VECTCAT-" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "PI"; "RADCAT"}*/
-
-"XDPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XDPOLY"]
-/*"XDPOLY" -> {"FMCAT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
-/*"XDPOLY" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"XDPOLY" -> {"RMODULE"; "RETRACT"; "MODULE"}*/
-"XDPOLY" -> "XPOLYC"
-/*"XDPOLY" -> {"XFALG"; "RING"; "RNG"; "SGROUP"; "MONOID"; "XALG"}*/
-/*"XDPOLY" -> {"ALGEBRA"; "ORDMON"; "ORDSET"; "INT"; "LIST"; "ILIST"}*/
-/*"XDPOLY" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "COMRING"}*/
-/*"XDPOLY" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"XDPOLY" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"XDPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"XDPOLY" -> "BOOLEAN"*/
-
-"XEXPPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=XEXPPKG"]
-/*"XEXPPKG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"XEXPPKG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"XEXPPKG" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "ORDSET"}*/
-"XEXPPKG" -> "XPOLYC"
-/*"XEXPPKG" -> {"XFALG"; "XALG"; "ALGEBRA"; "RETRACT"; "SINT"; "NNI"}*/
-/*"XEXPPKG" -> {"INT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"XEXPPKG" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"XEXPPKG" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "LINEXP"}*/
-/*"XEXPPKG" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "PI"}*/
-
-"XF" [color="#4488FF",href="bookvol10.2.pdf#nameddest=XF"]
-/*"XF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"XF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"XF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"XF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"XF" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
-"XF" -> "VSPACE"
-/*"XF" -> "CHARZ"*/
-"XF" -> "FPC"
-/*"XF" -> {"CHARNZ"; "FINITE"; "BOOLEAN"; "NNI"; "INT"}*/
-
-"XF-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XF"]
-/*"XF-" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"XF-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"XF-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"XF-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"XF-" -> {"DIVRING"; "RETRACT"}*/
-"XF-" -> "VSPACE"
-/*"XF-" -> "CHARZ"*/
-"XF-" -> "FPC"
-/*"XF-" -> {"CHARNZ"; "FINITE"; "BOOLEAN"; "NNI"; "INT"}*/
-
-"XPBWPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XPBWPOLY"]
-"XPBWPOLY" -> "XPOLYC"
-/*"XPBWPOLY" -> {"XFALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"XPBWPOLY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"XPBWPOLY" -> {"MONOID"; "LMODULE"; "XALG"; "BMODULE"; "RMODULE"}*/
-/*"XPBWPOLY" -> {"ALGEBRA"; "MODULE"; "RETRACT"; "FMCAT"; "COMRING"}*/
-/*"XPBWPOLY" -> {"ORDSET"; "INT"; "BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"XPBWPOLY" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"XPBWPOLY" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"XPBWPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"XPBWPOLY" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "INS"; "UFD"}*/
-/*"XPBWPOLY" -> {"GCDDOM"; "INTDOM"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"XPBWPOLY" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"XPBWPOLY" -> {"DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"XPBWPOLY" -> {"STEP"; "LNAGG-"; "NNI"; "SINT"}*/
-
-"XPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XPOLY"]
-"XPOLY" -> "XPOLYC"
-/*"XPOLY" -> {"XFALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"XPOLY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"XPOLY" -> {"LMODULE"; "XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"XPOLY" -> {"RETRACT"; "COMRING"}*/
-
-"XRPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=XRPOLY"]
-"XRPOLY" -> "XPOLYC"
-/*"XRPOLY" -> {"XFALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"XRPOLY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"XRPOLY" -> {"LMODULE"; "XALG"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"XRPOLY" -> {"MODULE"; "RETRACT"; "ORDSET"; "BOOLEAN"; "NNI"; "INT"}*/
-/*"XRPOLY" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"XRPOLY" -> {"COMRING"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"XRPOLY" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"XRPOLY" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"XRPOLY" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"XRPOLY" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
-
-\end{chunk}
-\subsection{Layer9}
-Depends on: BTAGG FLALG LODOCAT MATCAT SRAGG VECTCAT XF PROJSP PACFFC\\
-Used by next layer: IVECTOR PTCAT STRICAT 
-\begin{chunk}{layer9}
-
-LAYER9=\
-  ${OUT}/AFFPL.o    ${OUT}/BITS.o     ${OUT}/DFMAT.o    ${OUT}/DFVEC.o   \
-  ${OUT}/DIRPROD2.o ${OUT}/IMATRIX.o  ${OUT}/INTRVL.o  \
-  ${OUT}/IVECTOR.o  ${OUT}/LOCPOWC.o  \
-  ${OUT}/LODO1.o    ${OUT}/LODO2.o    ${OUT}/LPOLY.o   \
-  ${OUT}/LSMP.o     ${OUT}/LSMP1.o    ${OUT}/MAMA.o     ${OUT}/MATCAT2.o  \
-  ${OUT}/PROJPL.o   ${OUT}/PTCAT.o    ${OUT}/STRICAT.o  ${OUT}/TRIMAT.o  \
-  ${OUT}/U8MAT.o    ${OUT}/U16MAT.o   ${OUT}/U32MAT.o \
-  layer9done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 9 */
-/* Depends on: BTAGG FLALG INTCAT LODOCAT MATCAT SRAGG UPSCAT VECTCAT */
-/* AFFSP */
-
-"AFFPL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AFFPL"]
-"AFFPL" -> "AFFSP"
-/*"AFFPL" -> {"AFSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
-/*"AFFPL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"AFFPL" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"AFFPL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"AFFPL" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-
-"BITS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BITS"]
-"BITS" -> "BTAGG"
-/*"BITS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"; "A1AGG"}*/
-/*"BITS" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"BITS" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "INT"}*/
-/*"BITS" -> {"FINITE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"BITS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"BITS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"BITS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"BITS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"BITS" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"BITS" -> {"STEP"; "OM"}*/
-
-"DFMAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DFMAT"]
-"DFMAT" -> "MATCAT"
-"DFMAT" -> "VECTCAT"
-/*"DFMAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"DFMAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "FPS"; "RNS"; "FIELD"}*/
-/*"DFMAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"DFMAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"DFMAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"DFMAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DFMAT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"DFMAT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"DFMAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "DIFRING"; "OM"}*/
-/*"DFMAT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"DFMAT" -> {"SPFCAT"}*/
-
-"DFVEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DFVEC"]
-"DFVEC" -> "VECTCAT"
-/*"DFVEC" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"DFVEC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"DFVEC" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"; "SINT"; "NNI"}*/
-/*"DFVEC" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"DFVEC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"DFVEC" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DFVEC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"DFVEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
-/*"DFVEC" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
-/*"DFVEC" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-/*"DFVEC" -> {"INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
-
-"DIRPROD2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DIRPROD2"]
-/*"DIRPROD2" -> "TYPE"*/
-"DIRPROD2" -> "VECTCAT"
-/*"DIRPROD2" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"DIRPROD2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"DIRPROD2" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-
-"IMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IMATRIX"]
-"IMATRIX" -> "MATCAT"
-/*"IMATRIX" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"IMATRIX" -> {"KOERCE"; "EVALAB"; "IEVALAB"}*/
-"IMATRIX" -> "VECTCAT"
-/*"IMATRIX" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"IMATRIX" -> {"CLAGG"; "KONVERT"; "ORDSET"; "RING"; "RNG"; "ABELGRP"}*/
-/*"IMATRIX" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IMATRIX" -> {"INT"; "PRIMARR"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"IMATRIX" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"IMATRIX" -> {"ENTIRER"; "FIELD"; "UFD"; "DIVRING"}*/
-
-"INTRVL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTRVL"]
-"INTRVL" -> "INTCAT"
-/*"INTRVL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTRVL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INTRVL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INTRVL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "TRANFUN"}*/
-/*"INTRVL" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
-/*"INTRVL" -> {"RETRACT"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"INTRVL" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"INTRVL" -> {"OASGP"; "REAL"; "KONVERT"; "PATMAB"; "CHARZ"; "INT"}*/
-/*"INTRVL" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"INTRVL" -> {"FLAGG-"; "URAGG-"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"INTRVL" -> {"CFCAT"; "STEP"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"INTRVL" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"INTRVL" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"IVECTOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IVECTOR"]
-"IVECTOR" -> "VECTCAT"
-/*"IVECTOR" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"IVECTOR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"IVECTOR" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "RADCAT"}*/
-/*"IVECTOR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IVECTOR" -> {"SGROUP"; "MONOID"; "LMODULE"; "INS"; "UFD"; "GCDDOM"}*/
-/*"IVECTOR" -> {"INTDOM"; "COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"IVECTOR" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"IVECTOR" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"IVECTOR" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"LOCPOWC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LOCPOWC"]
-/*"LOCPOWC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"LOCPOWC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"*/
-/*"LOCPOWC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"LOCPOWC" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"LOCPOWC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"LOCPOWC" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"LOCPOWC" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"LOCPOWC" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"LOCPOWC" -> {"CHARZ"; "STEP"}*/
-"LOCPOWC" -> "UPSCAT"
-/*"LOCPOWC" -> {"PSCAT"; "AMR"; "CHARNZ"; "ELTAB"; "PDRING"}*/
-
-"LODO1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODO1"]
-/*"LODO1" -> {"DIFRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"LODO1" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"LODO1" -> "LMODULE"*/
-"LODO1" -> "LODOCAT"
-/*"LODO1" -> {"OREPCAT"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
-/*"LODO1" -> {"ALGEBRA"; "MODULE"; "ELTAB"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"LODO1" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"LODO1" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"LODO1" -> {"OASGP"; "ORDSET"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"LODO1" -> {"REAL"; "CHARZ"; "STEP"}*/
-
-"LODO2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODO2"]
-"LODO2" -> "LODOCAT"
-/*"LODO2" -> {"OREPCAT"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"LODO2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"LODO2" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
-/*"LODO2" -> {"ALGEBRA"; "MODULE"; "ELTAB"; "DIFRING"; "FIELD"; "EUCDOM"}*/
-/*"LODO2" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
-/*"LODO2" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"LODO2" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "LINEXP"}*/
-/*"LODO2" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"LPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LPOLY"]
-"LPOLY" -> "FLALG"
-/*"LPOLY" -> {"LIECAT"; "MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"}*/
-/*"LPOLY" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"LPOLY" -> {"KOERCE"; "RMODULE"; "FMCAT"; "RETRACT"; "COMRING"}*/
-/*"LPOLY" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "ORDSET"; "LSAGG"}*/
-/*"LPOLY" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"LPOLY" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"LPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
-/*"LPOLY" -> {"OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"LPOLY" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"LPOLY" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"LPOLY" -> {"BASTYPE-"; "BOOLEAN"; "NNI"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"LPOLY" -> {"GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"LSMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LSMP"]
-/*"LSMP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"LSMP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LSMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LSMP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LSMP" -> {"UFD"; "DIVRING"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"LSMP" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"LSMP" -> {"KONVERT"; "ORDSET"}*/
-"LSMP" -> "MATCAT"
-/*"LSMP" -> {"ARR2CAT"; "NNI"; "INT"; "BOOLEAN"; "PRIMARR"; "SINT"}*/
-/*"LSMP" -> {"A1AGG"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"LSMP" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"LSMP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LIST"; "ILIST"}*/
-
-"LSMP1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LSMP1"]
-/*"LSMP1" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"LSMP1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LSMP1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LSMP1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LSMP1" -> {"UFD"; "DIVRING"}*/
-"LSMP1" -> "VECTCAT"
-/*"LSMP1" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"LSMP1" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"LSMP1" -> {"KONVERT"; "ORDSET"}*/
-
-"MAMA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MAMA"]
-/*"MAMA" -> {"FIELD", "EUCDOM", "PID", "GCDDOM", "INTDOM", "COMRING"}*/
-/*"MAMA" -> {"RING", "RNG", "ABELGRP", "CABMON", "ABELMON", "ABELSG"}*/
-/*"MAMA" -> {"SETCAT", "BASTYPE", "KOERCE", "SGROUP", "MONOID"}*/
-/*"MAMA" -> {"LMODULE", "BMODULE", "RMODULE", "ALGEBRA", "MODULE"}*/
-/*"MAMA" -> {"ENTIRER", "UFD", "DIVRING", "FLAGG", "LNAGG", "IXAGG"}*/
-/*"MAMA" -> {"HOAGG", "AGG", "TYPE", "EVALAB", "IEVALAB", "ELTAGG"}*/
-/*"MAMA" -> {"ELTAB", "CLAGG", "KONVERT", "ORDSET"}*/
-"MAMA" -> "MATCAT"
-/*"MAMA" -> {"ARR2CAT", "INT", "LIST", "ILIST", "NNI", "PI", "BOOLEAN"}*/
-/*"MAMA" -> {"LSAGG", "STAGG", "URAGG", "RCAGG", "ELAGG", "OM", "LSAGG-"}*/
-/*"MAMA" -> {"SINT", "INS", "OINTDOM", "ORDRING", "OAGROUP", "OCAMON"}*/
-/*"MAMA" -> {"OAMON", "OASGP", "DIFRING", "RETRACT", "LINEXP", "PATMAB"}*/
-/*"MAMA" -> {"CFCAT", "REAL", "CHARZ", "STEP", "MONOID-", "ABELMON-"}*/
-/*"MAMA" -> {"ORDSET-", "SGROUP-", "ABELSG-", "SETCAT-", "BASTYPE-"}*/
-/*"MAMA" -> {"STAGG-"}*/
-
-"MATCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MATCAT2"]
-/*"MATCAT2" -> {"RING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"MATCAT2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"MATCAT2" -> {"LMODULE"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"MATCAT2" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"MATCAT2" -> {"KONVERT"; "ORDSET"}*/
-"MATCAT2" -> "MATCAT"
-/*"MATCAT2" -> "ARR2CAT"*/
-
-"PROJPL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PROJPL"]
-/*"PROJPL" -> {"PRSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
-"PROJPL" -> "PROJSP"
-/*"PROJPL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PROJPL" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"PROJPL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PROJPL" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-
-"PTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PTCAT"]
-"PTCAT" -> "VECTCAT"
-/*"PTCAT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PTCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"PTCAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-
-"STRICAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=STRICAT"]
-"STRICAT" -> "SRAGG"
-/*"STRICAT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"STRICAT" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"STRICAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "OM"}*/
-
-"TRIMAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TRIMAT"]
-/*"TRIMAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"TRIMAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"TRIMAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"TRIMAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"TRIMAT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"TRIMAT" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-"TRIMAT" -> "MATCAT"
-/*"TRIMAT" -> {"ARR2CAT"; "INT"; "NNI"; "PI"}*/
-
-"ULSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ULSCAT",
-          shape=ellipse]
-/*"ULSCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"ULSCAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"ULSCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ULSCAT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"ULSCAT" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ULSCAT" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"ULSCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-"ULSCAT" -> "UPSCAT"
-/*"ULSCAT" -> {"PSCAT"; "AMR"; "CHARNZ"; "ELTAB"; "PDRING"; "RADCAT"}*/
-/*"ULSCAT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"ULSCAT" -> {"ELEMFUN"; "FIELD"; "DIVRING"}*/
-
-"U8MAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U8MAT"]
-"U8MAT" -> "MATCAT"
-/*"U8MAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"U8MAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INS"; "UFD"; "GCDDOM"}*/
-/*"U8MAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"U8MAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"U8MAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"U8MAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"U8MAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"U8MAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"U8MAT" -> {"CHARZ"; "STEP"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"U8MAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "OM"; "FIELD"; "DIVRING"}*/
-
-"U16MAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U16MAT"]
-"U16MAT" -> "MATCAT"
-/*"U16MAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"U16MAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INS"; "UFD"; "GCDDOM"}*/
-/*"U16MAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"U16MAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"U16MAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"U16MAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"U16MAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"U16MAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"U16MAT" -> {"CHARZ"; "STEP"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"U16MAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "OM"; "FIELD"; "DIVRING"}*/
-
-"U32MAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=U32MAT"]
-"U32MAT" -> "MATCAT"
-/*"U32MAT" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"U32MAT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INS"; "UFD"; "GCDDOM"}*/
-/*"U32MAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"U32MAT" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"U32MAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"U32MAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"U32MAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"U32MAT" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"U32MAT" -> {"CHARZ"; "STEP"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"U32MAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "OM"; "FIELD"; "DIVRING"}*/
-
-\end{chunk}
-\subsection{Layer10}
-Depends on: IVECTOR PTCAT STRICAT LOCPOWC\\
-Used by next layer: DIRPCAT FAXF PFECAT STRING
-\begin{chunk}{layer10}
-
-LAYER10=\
-  ${OUT}/ASSOCEQ.o  ${OUT}/CARTEN.o   ${OUT}/CLIF.o     ${OUT}/CLIP.o    \
-  ${OUT}/COORDSYS.o ${OUT}/DBASE.o    ${OUT}/DHMATRIX.o ${OUT}/DIOSP.o   \
-  ${OUT}/DIRPCAT.o  ${OUT}/DIRPCAT-.o ${OUT}/D02BBFA.o  ${OUT}/D02BHFA.o \
-  ${OUT}/D02CJFA.o  ${OUT}/FAXF.o     ${OUT}/FAXF-.o    ${OUT}/FFPOLY2.o \
-  ${OUT}/FNLA.o     ${OUT}/GRAY.o     ${OUT}/HB.o       ${OUT}/INBFF.o   \
-  ${OUT}/IRSN.o     ${OUT}/LOP.o      \
-  ${OUT}/MCALCFN.o  ${OUT}/MHROWRED.o ${OUT}/NUMODE.o  \
-  ${OUT}/NUMQUAD.o  ${OUT}/ODESYS.o   ${OUT}/ODETOOLS.o ${OUT}/ORDFUNS.o \
-  ${OUT}/PERMAN.o   ${OUT}/PFECAT.o   ${OUT}/PFECAT-.o  ${OUT}/POINT.o   \
-  ${OUT}/PSEUDLIN.o ${OUT}/PTPACK.o   ${OUT}/REP2.o     ${OUT}/SETMN.o   \
-  ${OUT}/SEX.o      ${OUT}/STRING.o   ${OUT}/SYMFUNC.o  ${OUT}/VECTOR2.o \
-  layer10done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 10 */
-/* depends on: IVECTOR PTCAT STRICAT */
-
-"ASSOCEQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ASSOCEQ"]
-/*"ASSOCEQ" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ASSOCEQ" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ASSOCEQ" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ASSOCEQ" -> {"MODULE"; "ENTIRER"; "LODOCAT"; "OREPCAT"; "FRETRCT"}*/
-/*"ASSOCEQ" -> {"RETRACT"; "ELTAB"; "SINT"; "NNI"; "INT"; "VECTCAT"}*/
-/*"ASSOCEQ" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"ASSOCEQ" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"ASSOCEQ" -> {"CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"}*/
-"ASSOCEQ" -> "IVECTOR"
-/*"ASSOCEQ" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "LIST"; "ILIST"; "PI"}*/
-/*"ASSOCEQ" -> {"BOOLEAN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"ASSOCEQ" -> {"UFD"; "DIVRING"}*/
-
-"CARTEN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CARTEN"]
-/*"CARTEN" -> {"GRALG"; "GRMOD"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"CARTEN" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "ABELMON"}*/
-/*"CARTEN" -> {"ABELSG"; "CABMON"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"CARTEN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
-/*"CARTEN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"CARTEN" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"CARTEN" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"CARTEN" -> {"CHARZ"; "STEP"; "NNI"; "INT"; "MONOID-"; "ABELMON-"}*/
-/*"CARTEN" -> {"ORDSET-"; "SGROUP-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"CARTEN" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"CARTEN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"}*/
-"CARTEN" -> "IVECTOR"
-/*"CARTEN" -> {"IARRAY1"; "SINT"; "PI"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"CARTEN" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"CARTEN" -> {"MODULE-"; "RING-"; "ABELGRP-"; "BOOLEAN"; "LSAGG"}*/
-/*"CARTEN" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"}*/
-/*"CARTEN" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"CARTEN" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "AGG-"}*/
-/*"CARTEN" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-
-"CLIF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CLIF"]
-/*"CLIF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"CLIF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CLIF" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "VSPACE"}*/
-/*"CLIF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"CLIF" -> {"COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "SINT"; "PI"}*/
-/*"CLIF" -> {"NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"; "PRIMARR"}*/
-/*"CLIF" -> {"BOOLEAN"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"CLIF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"CLIF" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INS-"; "LIST"; "ILIST"}*/
-/*"CLIF" -> {"LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"CLIF" -> {"ELAGG"; "OM"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"CLIF" -> {"RCAGG-"; "IXAGG-"; "VECTOR"; "VECTCAT"}*/
-"CLIF" -> "IVECTOR"
-/*"CLIF" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
-
-"CLIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CLIP"]
-/*"CLIP" -> {"DFLOAT"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"}*/
-/*"CLIP" -> {"GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"CLIP" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-/*"CLIP" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"; "TRANFUN-"}*/
-/*"CLIP" -> {"SETCAT-"; "ELEMFUN-"; "HYPCAT-"; "ATRIG-"; "TRIGCAT-"}*/
-/*"CLIP" -> {"RADCAT-"; "RETRACT-"; "BASTYPE-"; "FPS"; "RNS"}*/
-/*"CLIP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"CLIP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"CLIP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"CLIP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"CLIP" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"CLIP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"CLIP" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-"CLIP" -> "PTCAT"
-/*"CLIP" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"CLIP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"CLIP" -> {"CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
-/*"CLIP" -> {"STEP"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"CLIP" -> {"STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-/*"CLIP" -> {"ELAGG-"; "FLAGG-"; "INS-"; "PI"; "NNI"; "SINT"}*/
-/*"CLIP" -> {"BOOLEAN"; "URAGG-"}*/
-
-"COORDSYS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COORDSYS"]
-/*"COORDSYS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"COORDSYS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"COORDSYS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"COORDSYS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"COORDSYS" -> {"ENTIRER"; "UFD"; "DIVRING"; "TRANFUN"; "TRIGCAT"}*/
-/*"COORDSYS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
-/*"COORDSYS" -> {"INT"; "PI"; "NNI"}*/
-"COORDSYS" -> "PTCAT"
-/*"COORDSYS" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"COORDSYS" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"COORDSYS" -> {"CLAGG"; "KONVERT"; "ORDSET"}*/
-
-"DBASE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DBASE"]
-/*"DBASE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"}*/
-"DBASE" -> "STRICAT"
-/*"DBASE" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"DBASE" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"DBASE" -> {"CLAGG"; "KONVERT"; "OM"; "INT"; "LIST"; "ILIST"}*/
-/*"DBASE" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "LSAGG"; "STAGG"}*/
-/*"DBASE" -> {"URAGG"; "RCAGG"; "ELAGG"; "NNI"; "SINT"; "PI"}*/
-
-"DHMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DHMATRIX"]
-/*"DHMATRIX" -> {"MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"DHMATRIX" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "FIELD"}*/
-/*"DHMATRIX" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DHMATRIX" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"DHMATRIX" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"DHMATRIX" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "VECTCAT"; "A1AGG"}*/
-/*"DHMATRIX" -> {"FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"DHMATRIX" -> {"KONVERT"; "ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"DHMATRIX" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "VECTOR"}*/
-"DHMATRIX" -> "IVECTOR"
-/*"DHMATRIX" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"DIOSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DIOSP"]
-/*"DIOSP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"DIOSP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"DIOSP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"DIOSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"DIOSP" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"DIOSP" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"DIOSP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"}*/
-/*"DIOSP" -> {"INT"; "LIST"; "ILIST"; "OAMONS"; "VECTOR"}*/
-"DIOSP" -> "IVECTOR"
-/*"DIOSP" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
-/*"DIOSP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"DIOSP" -> {"BASTYPE-"; "BOOLEAN"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"DIOSP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"DIOSP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "SINT"; "OM"}*/
-
-"DIRPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIRPCAT"]
-/*"DIRPCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DIRPCAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"DIRPCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DIRPCAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"DIRPCAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DIRPCAT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"DIRPCAT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"DIRPCAT" -> {"STEP"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"DIRPCAT" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "DIFEXT"; "PDRING"}*/
-/*"DIRPCAT" -> {"FLINEXP"; "FINITE"; "OAMONS"; "VSPACE"; "FIELD"; "DIVRING"}*/
-/*"DIRPCAT" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "CLAGG"; "INT"}*/
-/*"DIRPCAT" -> "VECTOR"*/
-"DIRPCAT" -> "IVECTOR"
-/*"DIRPCAT" -> {"IARRAY1"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"DIRPCAT" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "VECTCAT-"}*/
-/*"DIRPCAT" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"DIRPCAT" -> {"ORDSET-"; "AGG-"}*/
-
-"DIRPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIRPCAT"]
-/*"DIRPCAT-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DIRPCAT-" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"DIRPCAT-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DIRPCAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"DIRPCAT-" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"DIRPCAT-" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"DIRPCAT-" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"DIRPCAT-" -> {"REAL"; "CHARZ"; "STEP"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"DIRPCAT-" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"}*/
-/*"DIRPCAT-" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "FINITE"; "OAMONS"; "VSPACE"}*/
-/*"DIRPCAT-" -> {"FIELD"; "DIVRING"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"DIRPCAT-" -> {"CLAGG"; "INT"; "VECTOR"}*/
-"DIRPCAT-" -> "IVECTOR"
-/*"DIRPCAT-" -> {"IARRAY1"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"DIRPCAT-" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "VECTCAT-"}*/
-/*"DIRPCAT-" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"DIRPCAT-" -> "ORDSET-"; "AGG-"}*/
-
-"D02BBFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02BBFA"]
-/*"D02BBFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-/*"D02BBFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"D02BBFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"D02BBFA" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"D02BBFA" -> {"OM"; "LIST"; "ILIST"; "DFLOAT"; "FPS-"; "RNS-"}*/
-/*"D02BBFA" -> {"FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"}*/
-/*"D02BBFA" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "FPS"; "RNS"}*/
-/*"D02BBFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"D02BBFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"D02BBFA" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"D02BBFA" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"D02BBFA" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"D02BBFA" -> {"REAL"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "VECTCAT"}*/
-/*"D02BBFA" -> {"A1AGG"; "VECTOR"}*/
-"D02BBFA" -> "IVECTOR"
-/*"D02BBFA" -> {"IARRAY1"; "PI"}*/
-
-"D02BHFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02BHFA"]
-/*"D02BHFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-/*"D02BHFA" -> {"DFLOAT"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"}*/
-/*"D02BHFA" -> {"GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"D02BHFA" -> {"ORDRING-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"D02BHFA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"D02BHFA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"D02BHFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"D02BHFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"D02BHFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"D02BHFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"D02BHFA" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"D02BHFA" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"}*/
-"D02BHFA" -> "IVECTOR"
-/*"D02BHFA" -> {"IARRAY1"; "PI"}*/
-
-"D02CJFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D02CJFA"]
-/*"D02CJFA" -> {"ODECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
-/*"D02CJFA" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"D02CJFA" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"D02CJFA" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
-/*"D02CJFA" -> {"ELAGG"; "OM"; "DFLOAT"; "FPS-"; "RNS-"; "FIELD-"}*/
-/*"D02CJFA" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
-/*"D02CJFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "FPS"; "RNS"; "FIELD"}*/
-/*"D02CJFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"D02CJFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"D02CJFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"D02CJFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"D02CJFA" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"; "RADCAT"}*/
-/*"D02CJFA" -> {"PATMAB"; "CHARZ"; "VECTCAT"; "A1AGG"; "VECTOR"}*/
-"D02CJFA" -> "IVECTOR"
-/*"D02CJFA" -> "IARRAY1"*/
-
-"FAXF" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FAXF"]
-/*"FAXF" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FAXF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FAXF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FAXF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"FAXF" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
-/*"FAXF" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "SINT"; "PI"}*/
-/*"FAXF" -> {"NNI"; "INT"; "VECTOR"}*/
-"FAXF" -> "IVECTOR"
-/*"FAXF" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"FAXF" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"FAXF" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"; "OINTDOM"}*/
-/*"FAXF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "LINEXP"}*/
-/*"FAXF" -> {"PATMAB"; "CFCAT"; "REAL"; "OM"; "BOOLEAN"; "VECTCAT-"}*/
-/*"FAXF" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "LIST"; "ILIST"}*/
-/*"FAXF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "MONOID-"; "ABELMON-"}*/
-/*"FAXF" -> {"ORDSET-"; "SGROUP-"; "INS-"}*/
-
-"FAXF-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FAXF"]
-/*"FAXF-" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FAXF-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FAXF-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FAXF-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"FAXF-" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
-/*"FAXF-" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "SINT"; "PI"}*/
-/*"FAXF-" -> {"NNI"; "INT"; "VECTOR"}*/
-"FAXF-" -> "IVECTOR"
-/*"FAXF-" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"FAXF-" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"FAXF-" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INS"; "OINTDOM"}*/
-/*"FAXF-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "LINEXP"}*/
-/*"FAXF-" -> {"PATMAB"; "CFCAT"; "REAL"; "OM"; "BOOLEAN"; "VECTCAT-"}*/
-/*"FAXF-" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "LIST"; "ILIST"}*/
-/*"FAXF-" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
-/*"FAXF-" -> {"SGROUP-"; "INS-"}*/
-
-"FFPOLY2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFPOLY2"]
-/*"FFPOLY2" -> {"FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFPOLY2" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFPOLY2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFPOLY2" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFPOLY2" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FFIELDC"; "FINITE"}*/
-/*"FFPOLY2" -> {"STEP"; "DIFRING"; "NNI"; "INT"; "PI"; "VECTOR"}*/
-"FFPOLY2" -> "IVECTOR"
-/*"FFPOLY2" -> {"IARRAY1"; "PRIMARR"; "SINT"; "MONOID-"; "ABELMON-"}*/
-
-"FNLA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FNLA"]
-/*"FNLA" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FNLA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"; "MODULE"; "BMODULE"}*/
-/*"FNLA" -> {"LMODULE"; "RMODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"}*/
-/*"FNLA" -> {"MONOID"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"FNLA" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"FNLA" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"; "VECTOR"}*/
-"FNLA" -> "IVECTOR"
-/*"FNLA" -> {"IARRAY1"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "PI"; "NNI"}*/
-
-"GRAY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GRAY"]
-/*"GRAY" -> {"INT"; "VECTOR"}*/
-"GRAY" -> "IVECTOR"
-/*"GRAY" -> {"IARRAY1"; "PI"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"GRAY" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"GRAY" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"GRAY" -> {"CLAGG"; "KONVERT"; "ORDSET"; "SINT"}*/
-
-"HB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=HB"]
-/*"HB" -> {"INT"; "SINT"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"HB" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
-/*"HB" -> {"RING-"; "ABELGRP-"; "BOOLEAN"; "VECTOR"}*/
-"HB" -> "IVECTOR"
-/*"HB" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"HB" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"HB" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"HB" -> {"ORDSET"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-
-"INBFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INBFF"]
-/*"INBFF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"INBFF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"INBFF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"INBFF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"INBFF" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"INBFF" -> {"STEP"; "DIFRING"; "NNI"; "INT"; "LIST"; "VECTOR"}*/
-"INBFF" -> "IVECTOR"
-/*"INBFF" -> {"IARRAY1"; "SINT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"INBFF" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"INBFF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "PI"}*/
-/*"INBFF" -> {"VECTCAT-"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
-/*"INBFF" -> {"A1AGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "BOOLEAN"; "INS-"}*/
-/*"INBFF" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"INBFF" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"INBFF" -> {"ELAGG-"; "FLAGG-"; "URAGG-"}*/
-
-"IRSN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRSN"]
-/*"IRSN" -> {"INT"; "LIST"; "NNI"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"IRSN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"IRSN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"IRSN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"IRSN" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"IRSN" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"IRSN" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"IRSN" -> {"STEP"; "SINT"; "PI"; "OM"; "ILIST"; "LSAGG"}*/
-/*"IRSN" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"IRSN" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"IRSN" -> {"CLAGG"; "FLAGG"; "ELAGG"; "LSAGG-"; "STAGG-"; "BOOLEAN"}*/
-/*"IRSN" -> "VECTOR"*/
-"IRSN" -> "IVECTOR"
-/*"IRSN" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FINITE"; "LOGIC"; "VECTCAT-"}*/
-/*"IRSN" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"IRSN" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-
-"LOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LOP"]
-/*"LOP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"LOP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"LOP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"LOP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"LOP" -> {"PACPERC"; "INT"; "LIST"; "ILIST"; "VECTOR"}*/
-"LOP" -> "IVECTOR"
-/*"LOP" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
-/*"LOP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"LOP" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"LOP" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "LSAGG-"}*/
-/*"LOP" -> {"BOOLEAN"; "STAGG-"; "NNI"; "SINT"}*/
-
-"MCALCFN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MCALCFN"]
-/*"MCALCFN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PDRING"; "RING"; "RNG"}*/
-/*"MCALCFN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"MCALCFN" -> {"LMODULE"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"MCALCFN" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"MCALCFN" -> {"KONVERT"; "ORDSET"; "INT"; "VECTOR"; "LSAGG"; "STAGG"}*/
-/*"MCALCFN" -> {"URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
-/*"MCALCFN" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"MCALCFN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"MCALCFN" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"MCALCFN" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"MCALCFN" -> {"REAL"; "CHARZ"; "STEP"}*/
-"MCALCFN" -> "IVECTOR"
-/*"MCALCFN" -> {"IARRAY1"; "NNI"; "SINT"; "PI"; "LSAGG-"; "STAGG-"}*/
-
-"MHROWRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MHROWRED"]
-/*"MHROWRED" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"MHROWRED" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"MHROWRED" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MHROWRED" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"MHROWRED" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"MHROWRED" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"MHROWRED" -> {"CLAGG"; "KONVERT"; "ORDSET"; "INT"; "VECTOR"}*/
-"MHROWRED" -> "IVECTOR"
-/*"MHROWRED" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "BOOLEAN"; "INS"; "UFD"}*/
-/*"MHROWRED" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"MHROWRED" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"MHROWRED" -> {"CHARZ"; "STEP"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"MHROWRED" -> {"RCAGG"; "ELAGG"; "LIST"; "ILIST"; "SINT"; "NNI"}*/
-/*"MHROWRED" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "INS-"; "PI"; "FIELD"}*/
-/*"MHROWRED" -> "DIVRING"*/
-
-"NUMODE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMODE"]
-/*"NUMODE" -> {"NNI"; "INT"; "VECTOR"}*/
-"NUMODE" -> "IVECTOR"
-/*"NUMODE" -> {"IARRAY1"; "PI"; "SINT"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"NUMODE" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"NUMODE" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"NUMODE" -> {"CLAGG"; "KONVERT"; "ORDSET"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"NUMODE" -> {"RCAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"NUMODE" -> {"STAGG-"; "VECTCAT-"; "A1AGG-"}*/
-
-"NUMQUAD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMQUAD"]
-/*"NUMQUAD" -> "NNI"*/
-/*"NUMQUAD" -> {"PI"; "BOOLEAN"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"NUMQUAD" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"NUMQUAD" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"NUMQUAD" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"NUMQUAD" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "VECTOR"}*/
-"NUMQUAD" -> "IVECTOR"
-/*"NUMQUAD" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"NUMQUAD" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"NUMQUAD" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "VECTCAT-"}*/
-/*"NUMQUAD" -> "A1AGG-"*/
-
-"ODESYS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODESYS"]
-/*"ODESYS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODESYS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODESYS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ODESYS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ODESYS" -> {"UFD"; "DIVRING"; "LODOCAT"; "OREPCAT"; "FRETRCT"; "RETRACT"}*/
-/*"ODESYS" -> {"ELTAB"; "INT"; "LIST"; "ILIST"; "NNI"; "VECTOR"}*/
-"ODESYS" -> "IVECTOR"
-/*"ODESYS" -> {"IARRAY1"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"ODESYS" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"ODESYS" -> {"ELTAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"ODESYS" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"ODESYS" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "VECTCAT"; "A1AGG"}*/
-/*"ODESYS" -> {"SINT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ODESYS" -> {"OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"ODESYS" -> {"REAL"; "CHARZ"; "STEP"; "BOOLEAN"; "VECTCAT-"; "A1AGG-"}*/
-
-"ODETOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODETOOLS"]
-/*"ODETOOLS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODETOOLS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODETOOLS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ODETOOLS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ODETOOLS" -> {"ENTIRER"; "UFD"; "DIVRING"; "LODOCAT"; "OREPCAT"}*/
-/*"ODETOOLS" -> {"FRETRCT"; "RETRACT"; "ELTAB"; "LSAGG"; "STAGG"}*/
-/*"ODETOOLS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"ODETOOLS" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
-/*"ODETOOLS" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"ODETOOLS" -> {"ILIST"; "VECTOR"; "VECTCAT"; "A1AGG"}*/
-"ODETOOLS" -> "IVECTOR"
-/*"ODETOOLS" -> {"IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"ODETOOLS" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "PATMAB"}*/
-/*"ODETOOLS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"ORDFUNS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ORDFUNS"]
-/*"ORDFUNS" -> {"OAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-/*"ORDFUNS" -> {"KOERCE"; "ABELMON"; "ABELSG"; "SINT"; "NNI"; "INT"}*/
-/*"ORDFUNS" -> "VECTOR"*/
-"ORDFUNS" -> "IVECTOR"
-/*"ORDFUNS" -> {"IARRAY1"; "BOOLEAN"}*/
-
-"PERMAN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PERMAN"]
-/*"PERMAN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PERMAN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PERMAN" -> {"LMODULE"; "INT"; "VECTOR"}*/
-"PERMAN" -> "IVECTOR"
-/*"PERMAN" -> {"IARRAY1"; "PI"; "NNI"; "BOOLEAN"; "SINT"; "VECTCAT"}*/
-/*"PERMAN" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PERMAN" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"PERMAN" -> {"ORDSET"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
-/*"PERMAN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"}*/
-
-"PFECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PFECAT"]
-/*"PFECAT" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PFECAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PFECAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PFECAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PFECAT" -> {"CHARNZ"; "INT"; "VECTOR"}*/
-"PFECAT" -> "IVECTOR"
-/*"PFECAT" -> {"IARRAY1"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-
-"PFECAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PFECAT"]
-/*"PFECAT-" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"-"; "RNG"}*/
-/*"PFECAT-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PFECAT-" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PFECAT-" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PFECAT-" -> {"CHARNZ"; "INT"; "VECTOR"}*/
-"PFECAT-" -> "IVECTOR"
-/*"PFECAT-" -> {"IARRAY1"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-
-"POINT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=POINT"]
-"POINT" -> "PTCAT"
-/*"POINT" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"POINT" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"POINT" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"POINT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"POINT" -> {"SGROUP"; "MONOID"; "LMODULE"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"POINT" -> {"RCAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-/*"POINT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"POINT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"POINT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"POINT" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"POINT" -> {"CHARZ"; "STEP"; "NNI"; "PI"; "RADCAT"}*/
-
-"PSEUDLIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PSEUDLIN"]
-/*"PSEUDLIN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PSEUDLIN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PSEUDLIN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PSEUDLIN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PSEUDLIN" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"}*/
-/*"PSEUDLIN" -> {"ILIST"; "BOOLEAN"; "NNI"; "VECTOR"}*/
-"PSEUDLIN" -> "IVECTOR"
-/*"PSEUDLIN" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"PSEUDLIN" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PSEUDLIN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "SINT"}*/
-
-"PTPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PTPACK"]
-/*"PTPACK" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PTPACK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PTPACK" -> {"LMODULE"; "INT"}*/
-"PTPACK" -> "PTCAT"
-/*"PTPACK" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"PTPACK" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"PTPACK" -> {"CLAGG"; "KONVERT"; "ORDSET"; "NNI"}*/
-
-"REP2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REP2"]
-/*"REP2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"REP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"REP2" -> {"SINT"; "NNI"; "INT"; "PI"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"REP2" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"REP2" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"}*/
-"REP2" -> "IVECTOR"
-/*"REP2" -> {"IARRAY1"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"REP2" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "EUCDOM"}*/
-/*"REP2" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
-/*"REP2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "VECTCAT-"; "A1AGG-"; "FLAGG-"}*/
-/*"REP2" -> {"LNAGG-"; "IXAGG-"; "INS"; "UFD"; "OINTDOM"; "ORDRING"}*/
-/*"REP2" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"REP2" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"REP2" -> {"ELAGG-"; "URAGG-"; "FIELD"; "DIVRING"; "MATCAT"; "ARR2CAT"}*/
-/*"REP2" -> "FINITE"*/
-
-"SETMN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SETMN"]
-/*"SETMN" -> {"FINITE"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "VECTOR"}*/
-"SETMN" -> "IVECTOR"
-/*"SETMN" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
-/*"SETMN" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"SETMN" -> {"BASTYPE-"; "NNI"; "PI"; "SINT"; "LIST"; "ILIST"}*/
-/*"SETMN" -> {"BOOLEAN"; "BTAGG"; "ORDSET"; "LOGIC"; "A1AGG"; "FLAGG"}*/
-/*"SETMN" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"SETMN" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "LSAGG"}*/
-/*"SETMN" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
-
-"SEX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEX"]
-/*"SEX" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
-/*"SEX" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SEX" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"SEX" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"SEX" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SEX" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"SEX" -> {"REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"; "FIELD"}*/
-/*"SEX" -> {"DIVRING"; "RADCAT"; "SEXCAT"}*/
-"SEX" -> "STRICAT"
-/*"SEX" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"SEX" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"SEX" -> {"CLAGG"; "OM"}*/
-
-"STRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STRING"]
-"STRING" -> "STRICAT"
-/*"STRING" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"STRING" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"STRING" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"STRING" -> {"OM"; "INT"; "ORDFIN"; "FINITE"; "INS"; "UFD"}*/
-/*"STRING" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"STRING" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"STRING" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"STRING" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"STRING" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"STRING" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"SYMBOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMBOL",
-          shape=ellipse]
-/*"SYMBOL" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "OM"}*/
-/*"SYMBOL" -> {"PATMAB"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"SYMBOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SYMBOL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SYMBOL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"SYMBOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SYMBOL" -> {"DIFRING"; "RETRACT"; "LINEXP"; "CFCAT"; "REAL"}*/
-/*"SYMBOL" -> {"CHARZ"; "STEP"; "FPS"; "RNS"; "FIELD"; "DIVRING"}*/
-/*"SYMBOL" -> {"RADCAT"; "INT"; "PRIMARR"; "A1AGG-"; "SYMBOL"; "REF"}*/
-/*"SYMBOL" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"SYMBOL" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-"SYMBOL" -> "STRICAT"
-/*"SYMBOL" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"SYMBOL" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"SYMBOL" -> {"CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-/*"SYMBOL" -> {"ILIST"; "NNI"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ORDFIN"}*/
-/*"SYMBOL" -> {"FINITE"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"SYMBOL" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"SYMBOL" -> "BASTYPE-"*/
-
-"SYMFUNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SYMFUNC"]
-/*"SYMFUNC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SYMFUNC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"SYMFUNC" -> {"PI"; "NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"SYMFUNC" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"SYMFUNC" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"SYMFUNC" -> {"ORDSET"; "ELAGG"; "OM"; "LIST"; "ILIST"; "INS"}*/
-/*"SYMFUNC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"; "RMODULE"}*/
-/*"SYMFUNC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"SYMFUNC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SYMFUNC" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"SYMFUNC" -> {"CHARZ"; "STEP"; "VECTOR"}*/
-"SYMFUNC" -> "IVECTOR"
-/*"SYMFUNC" -> {"IARRAY1"; "SINT"; "VECTCAT"; "A1AGG"; "MONOID-"}*/
-/*"SYMFUNC" -> {"ABELMON-"; "VECTCAT-"; "A1AGG-"}*/
-
-"UPOLYC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPOLYC",
-          shape=ellipse]
-/*"UPOLYC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UPOLYC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UPOLYC" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"UPOLYC" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"UPOLYC" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"UPOLYC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"UPOLYC" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
-/*"UPOLYC" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-/*"UPOLYC" -> {"NNI"; "INT"; "LIST"; "ILIST"; "VECTOR"}*/
-"UPOLYC" -> "IVECTOR"
-/*"UPOLYC" -> {"IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"UPOLYC" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "VECTCAT"}*/
-/*"UPOLYC" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"UPOLYC" -> {"TYPE"; "ELTAGG"; "CLAGG"; "PI"; "BOOLEAN"}*/
-
-"UPOLYC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPOLYC",
-          shape=ellipse]
-/*"UPOLYC-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UPOLYC-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"UPOLYC-" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"UPOLYC-" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"UPOLYC-" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"UPOLYC-" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"UPOLYC-" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
-/*"UPOLYC-" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"UPOLYC-" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "NNI"; "INT"}*/
-/*"UPOLYC-" -> {"LIST"; "ILIST"; "VECTOR"}*/
-"UPOLYC-" -> "IVECTOR"
-/*"UPOLYC-" -> {"IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"UPOLYC-" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"}*/
-/*"UPOLYC-" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"UPOLYC-" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "PI"; "BOOLEAN"}*/
-
-"VECTOR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=VECTOR2"]
-/*"VECTOR2" -> {"TYPE"; "TYPE"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"VECTOR2" -> {"IXAGG"; "HOAGG"; "AGG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"VECTOR2" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"VECTOR2" -> {"ORDSET"; "INT"; "VECTOR"}*/
-"VECTOR2" -> "IVECTOR"
-/*"VECTOR2" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"VECTOR2" -> {"IXAGG-"; "LIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"VECTOR2" -> {"ELAGG"; "OM"; "ILIST"}*/
-
-\end{chunk}
-\subsection{Layer11}
-Depends on: DIRPCAT FAXF PFECAT STRING LOP\\
-Used by next layer: DIOPS DPOLCAT FINRALG FRAC RMATCAT RRCC UPXSCAT
-\begin{chunk}{layer11}
-
-LAYER11=\
-  ${OUT}/ASP1.o     ${OUT}/ASP10.o    ${OUT}/ASP24.o    ${OUT}/ASP4.o     \
-  ${OUT}/ASP50.o    ${OUT}/ASP6.o     ${OUT}/ASP73.o    ${OUT}/AXSERV.o   \
-  ${OUT}/BALFACT.o  ${OUT}/BEZOUT.o   ${OUT}/BINARY.o   ${OUT}/BINFILE.o  \
-  ${OUT}/BOUNDZRO.o ${OUT}/BPADICRT.o ${OUT}/BRILL.o    ${OUT}/CDEN.o     \
-  ${OUT}/CHVAR.o    ${OUT}/COMMUPC.o  ${OUT}/CONTFRAC.o ${OUT}/CVMP.o     \
-  ${OUT}/CYCLOTOM.o ${OUT}/CYCLES.o   ${OUT}/DDFACT.o   ${OUT}/DECIMAL.o  \
-  ${OUT}/DIOPS.o    ${OUT}/DIOPS-.o   ${OUT}/DIRPROD.o  ${OUT}/DISPLAY.o  \
-  ${OUT}/DMP.o      ${OUT}/DPMO.o     ${OUT}/DPOLCAT.o  ${OUT}/DPOLCAT-.o \
-  ${OUT}/DSTREE.o   \
-  ${OUT}/D01AJFA.o  ${OUT}/D01AKFA.o  ${OUT}/D01ALFA.o  ${OUT}/D01AMFA.o  \
-  ${OUT}/D01APFA.o  ${OUT}/D01AQFA.o  ${OUT}/EMR.o      ${OUT}/EQ.o       \
-  ${OUT}/ERROR.o    ${OUT}/EVALCYC.o  ${OUT}/EXP3D.o    \
-  ${OUT}/E04DGFA.o  ${OUT}/E04FDFA.o  \
-  ${OUT}/E04GCFA.o  ${OUT}/E04JAFA.o  ${OUT}/E04UCFA.o  ${OUT}/FACUTIL.o  \
-  ${OUT}/FF.o       ${OUT}/FFFACTOR.o  \
-  ${OUT}/FFCG.o     ${OUT}/FFCGX.o    ${OUT}/FFFG.o     \
-  ${OUT}/FFFGF.o    ${OUT}/FFHOM.o    ${OUT}/FFNB.o     ${OUT}/FFNBX.o    \
-  ${OUT}/FFPOLY.o   ${OUT}/FFSQFR.o  \
-  ${OUT}/FFX.o      ${OUT}/FFSLPE.o   ${OUT}/FGLMICPK.o \
-  ${OUT}/FILE.o     ${OUT}/FINAALG.o  ${OUT}/FINAALG-.o ${OUT}/FINRALG.o  \
-  ${OUT}/FINRALG-.o ${OUT}/FFF.o      ${OUT}/FLOATRP.o  ${OUT}/FNAME.o    \
-  ${OUT}/FOP.o      ${OUT}/FORMULA.o  ${OUT}/FORT.o     ${OUT}/FRAC.o     \
-  ${OUT}/FTEM.o     ${OUT}/GENEEZ.o   ${OUT}/GENMFACT.o ${OUT}/GENPGCD.o  \
-  ${OUT}/GALFACTU.o ${OUT}/GALPOLYU.o ${OUT}/GB.o       ${OUT}/GBEUCLID.o \
-  ${OUT}/GBF.o      ${OUT}/GBINTERN.o ${OUT}/GHENSEL.o  ${OUT}/GMODPOL.o  \
-  ${OUT}/GOSPER.o   ${OUT}/GRIMAGE.o  ${OUT}/GROEBSOL.o ${OUT}/HDMP.o     \
-  ${OUT}/HDP.o      ${OUT}/HEXADEC.o  ${OUT}/HEUGCD.o   ${OUT}/HTMLFORM.o \
-  ${OUT}/IBPTOOLS.o \
-  ${OUT}/IFF.o      ${OUT}/IBITS.o    ${OUT}/ICARD.o    ${OUT}/ICDEN.o    \
-  ${OUT}/IDECOMP.o  ${OUT}/IIARRAY2.o ${OUT}/IMATLIN.o  ${OUT}/IMATQF.o   \
-  ${OUT}/INMODGCD.o ${OUT}/INNMFACT.o ${OUT}/INPSIGN.o  ${OUT}/INTERGB.o  \
-  ${OUT}/INTHERTR.o \
-  ${OUT}/INTRAT.o   ${OUT}/INTRF.o    ${OUT}/INTSLPE.o  ${OUT}/INTTR.o    \
-  ${OUT}/ISUMP.o    ${OUT}/LAUPOL.o   ${OUT}/LEADCDET.o ${OUT}/LGROBP.o   \
-  ${OUT}/LIMITRF.o  ${OUT}/LINDEP.o   ${OUT}/LISYSER.o  \
-  ${OUT}/LO.o       ${OUT}/LPEFRAC.o  \
-  ${OUT}/LSPP.o     ${OUT}/MATLIN.o   ${OUT}/MCDEN.o    ${OUT}/MDDFACT.o  \
-  ${OUT}/MFINFACT.o ${OUT}/MFLOAT.o   ${OUT}/MINT.o     ${OUT}/MLIFT.o    \
-  ${OUT}/MMAP.o     ${OUT}/MODMON.o   ${OUT}/MONOTOOL.o ${OUT}/MPCPF.o    \
-  ${OUT}/MPC2.o     ${OUT}/MPC3.o     ${OUT}/MPOLY.o    ${OUT}/MPRFF.o    \
-  ${OUT}/MRATFAC.o  ${OUT}/MULTSQFR.o ${OUT}/NORMRETR.o ${OUT}/NPCOEF.o   \
-  ${OUT}/NSUP.o     ${OUT}/NTPOLFN.o  ${OUT}/ODP.o      ${OUT}/ODEPRIM.o  \
-  ${OUT}/ODEPRRIC.o ${OUT}/OMPKG.o    ${OUT}/OMSERVER.o ${OUT}/PACRATC.o  \
-  ${OUT}/PADEPAC.o   \
-  ${OUT}/PADICRAT.o ${OUT}/PADICRC.o  ${OUT}/PARAMP.o \
-  ${OUT}/PCOMP.o    ${OUT}/PDECOMP.o  \
-  ${OUT}/PF.o       ${OUT}/PFBR.o     ${OUT}/PFBRU.o    ${OUT}/PFORP.o    \
-  ${OUT}/PFOTOOLS.o \
-  ${OUT}/PFRPAC.o   ${OUT}/PGCD.o     ${OUT}/PINTERPA.o ${OUT}/PLEQN.o    \
-  ${OUT}/PLPKCRV.o  \
-  ${OUT}/PMPLCAT.o  ${OUT}/PMQFCAT.o  ${OUT}/PNTHEORY.o ${OUT}/POLUTIL.o  \
-  ${OUT}/POLTOPOL.o ${OUT}/POLYCATQ.o ${OUT}/POLYLIFT.o ${OUT}/POLYROOT.o \
-  ${OUT}/POLY2.o    ${OUT}/POLY2UP.o  ${OUT}/PRS.o      ${OUT}/PSQFR.o    \
-  ${OUT}/PUSHVAR.o  ${OUT}/QALGSET.o  ${OUT}/QFCAT2.o   ${OUT}/RADIX.o    \
-  ${OUT}/RATFACT.o  ${OUT}/RCFIELD.o  ${OUT}/RCFIELD-.o ${OUT}/RDETR.o    \
-  ${OUT}/RDETRS.o   ${OUT}/REAL0.o    ${OUT}/REAL0Q.o   ${OUT}/REALSOLV.o \
-  ${OUT}/RESRING.o  ${OUT}/RETSOL.o   ${OUT}/RF.o       ${OUT}/RFFACTOR.o \
-  ${OUT}/RINTERP.o  ${OUT}/RMATCAT.o  ${OUT}/RMATCAT-.o ${OUT}/RRCC.o     \
-  ${OUT}/RRCC-.o    ${OUT}/SCPKG.o    ${OUT}/SHDP.o     ${OUT}/SHP.o      \
-  ${OUT}/SIGNRF.o   ${OUT}/SMITH.o    ${OUT}/SMP.o      ${OUT}/SMTS.o     \
-  ${OUT}/SOLVEFOR.o ${OUT}/SPLTREE.o  ${OUT}/STINPROD.o ${OUT}/STTF.o     \
-  ${OUT}/STTFNC.o   ${OUT}/SUBRESP.o  ${OUT}/SUBSPACE.o ${OUT}/SUMRF.o    \
-  ${OUT}/SUP.o      ${OUT}/SUPEXPR.o  ${OUT}/SUPFRACF.o ${OUT}/TANEXP.o   \
-  ${OUT}/TEMUTL.o   ${OUT}/TEX.o      ${OUT}/TEXTFILE.o ${OUT}/TREE.o     \
-  ${OUT}/TWOFACT.o  ${OUT}/UNIFACT.o  ${OUT}/UP.o       ${OUT}/UPCDEN.o   \
-  ${OUT}/UPDECOMP.o ${OUT}/UPDIVP.o   ${OUT}/UPMP.o     ${OUT}/UPOLYC2.o  \
-  ${OUT}/UPXSCAT.o  ${OUT}/UPSQFREE.o ${OUT}/VIEWDEF.o  ${OUT}/VIEW2D.o   \
-  ${OUT}/VOID.o     ${OUT}/WEIER.o    ${OUT}/WP.o \
-  layer11done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 11 */
-/* depends on: DIRPCAT FAXF PFECAT STRING */
-
-"ASP1" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP1"]
-/*"ASP1" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"; "FIELD"}*/
-/*"ASP1" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"ASP1" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"ASP1" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ASP1" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"ASP1" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"ASP1" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "FMTC"}*/
-/*"ASP1" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-/*"ASP1" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"ASP1" -> {"EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"ASP1" -> "PFECAT"
-
-"ASP10" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP10"]
-/*"ASP10" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"ASP10" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP10" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP10" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP10" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"ASP10" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ASP10" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"ASP10" -> {"FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
-/*"ASP10" -> {"STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP10" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"ASP10" -> "PFECAT"
-/*"ASP10" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"ASP10" -> {"AGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "VECTOR"; "IVECTOR"}*/
-/*"ASP10" -> {"IARRAY1"; "NNI"; "PI"}*/
-
-"ASP24" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP24"]
-/*"ASP24" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
-/*"ASP24" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP24" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP24" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP24" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"ASP24" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ASP24" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"ASP24" -> {"FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
-/*"ASP24" -> {"STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP24" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"ASP24" -> "PFECAT"
-
-"ASP4" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP4"]
-/*"ASP4" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
-/*"ASP4" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP4" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP4" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP4" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP4" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP4" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP4" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP4" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"ASP4" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"ASP4" -> "PFECAT"
-
-"ASP50" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP50"]
-/*"ASP50" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
-/*"ASP50" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP50" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP50" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP50" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ASP50" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ASP50" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
-/*"ASP50" -> {"PATMAB"; "CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"ASP50" -> {"LINEXP"; "CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"ASP50" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"ASP50" -> "PFECAT"
-
-"ASP6" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP6"]
-/*"ASP6" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
-/*"ASP6" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP6" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP6" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP6" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP6" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP6" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP6" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP6" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"ASP6" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"ASP6" -> "PFECAT"
-
-"ASP73" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP73"]
-/*"ASP73" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"ASP73" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP73" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP73" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP73" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP73" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ASP73" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
-/*"ASP73" -> {"PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP73" -> {"CFCAT"; "STEP"; "OM"; "INT"; "VECTOR"; "IVECTOR"}*/
-/*"ASP73" -> {"IARRAY1"; "PI"; "NNI"; "FMTC"; "POLYCAT"; "PDRING"}*/
-/*"ASP73" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
-/*"ASP73" -> "FLINEXP"*/
-"ASP73" -> "PFECAT"
-
-"AXSERV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AXSERV"]
-"AXSERV" -> "STRING"
-/*"AXSERV" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"AXSERV" -> {"A1AGG-"; "ISTRING"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"AXSERV" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"AXSERV" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"AXSERV" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"AXSERV" -> {"OM"; "ILIST"; "NNI"; "SRAGG-"; "LSAGG-"; "STAGG-"}*/
-/*"AXSERV" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "PI"; "STRICAT"; "SRAGG"}*/
-/*"AXSERV" -> {"A1AGG"; "ORDFIN"; "FINITE"}*/
-
-"BALFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BALFACT"]
-/*"BALFACT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"BALFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"BALFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"BALFACT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
-/*"BALFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"BALFACT" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"BALFACT" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"BALFACT" -> "PFECAT"
-/*"BALFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"BALFACT" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "LIST"; "ILIST"}*/
-/*"BALFACT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"BALFACT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
-/*"BALFACT" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-
-"BEZOUT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BEZOUT"]
-/*"BEZOUT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"BEZOUT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"BEZOUT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"BEZOUT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"BEZOUT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"BEZOUT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"BEZOUT" -> {"PATMAB"; "GCDDOM"}*/
-"BEZOUT" -> "PFECAT"
-/*"BEZOUT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"BEZOUT" -> {"PID"; "FIELD"; "DIVRING"; "MATCAT"; "ARR2CAT"; "HOAGG"}*/
-/*"BEZOUT" -> {"AGG"; "TYPE"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"BEZOUT" -> {"NNI"; "INT"; "BOOLEAN"; "SINT"; "PI"}*/
-
-"BINARY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BINARY"]
-/*"BINARY" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"BINARY" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"BINARY" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"BINARY" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"BINARY" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
-/*"BINARY" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
-/*"BINARY" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"}*/
-/*"BINARY" -> {"FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"}*/
-/*"BINARY" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"BINARY" -> {"CHARZ"; "CHARNZ"}*/
-"BINARY" -> "PFECAT"
-/*"BINARY" -> {"INS"; "CFCAT"; "OM"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
-/*"BINARY" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
-
-"BINFILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BINFILE"]
-/*"BINFILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"; "INS"}*/
-/*"BINFILE" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"BINFILE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"BINFILE" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"BINFILE" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"BINFILE" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"BINFILE" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"BINFILE" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-"BINFILE" -> "STRING"
-/*"BINFILE" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"BINFILE" -> {"A1AGG-"; "ISTRING"}*/
-
-"BOUNDZRO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BOUNDZRO"]
-/*"BOUNDZRO" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"BOUNDZRO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"BOUNDZRO" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"BOUNDZRO" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"BOUNDZRO" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "UPOLYC"}*/
-/*"BOUNDZRO" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"BOUNDZRO" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"BOUNDZRO" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
-"BOUNDZRO" -> "PFECAT"
-/*"BOUNDZRO" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INS"; "OINTDOM"}*/
-/*"BOUNDZRO" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
-/*"BOUNDZRO" -> {"REAL"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"BOUNDZRO" -> {"INT"; "ES"; "OM"}*/
-
-"BPADICRT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BPADICRT"]
-/*"BPADICRT" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"BPADICRT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"BPADICRT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"BPADICRT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"BPADICRT" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"}*/
-/*"BPADICRT" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"BPADICRT" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"BPADICRT" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
-/*"BPADICRT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"BPADICRT" -> {"CHARZ"; "CHARNZ"}*/
-"BPADICRT" -> "PFECAT"
-/*"BPADICRT" -> {"PADICCT"; "FPS"; "RNS"; "RADCAT"; "INS"; "CFCAT"}*/
-/*"BPADICRT" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
-
-"BRILL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BRILL"]
-/*"BRILL" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"BRILL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"BRILL" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"BRILL" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"BRILL" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"BRILL" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"BRILL" -> "GCDDOM"*/
-"BRILL" -> "PFECAT"
-/*"BRILL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"BRILL" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "BOOLEAN"}*/
-/*"BRILL" -> {"INS-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"BRILL" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "FPS"; "RNS"; "RADCAT"}*/
-/*"BRILL" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"BRILL" -> {"ELEMFUN"; "PI"}*/
-
-"CDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CDEN"]
-/*"CDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"CDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"CDEN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"CDEN" -> {"MODULE"; "ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"CDEN" -> {"GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
-/*"CDEN" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"CDEN" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"CDEN" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
-/*"CDEN" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"CDEN" -> {"CHARZ"; "CHARNZ"}*/
-"CDEN" -> "PFECAT"
-/*"CDEN" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
-
-"CHVAR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CHVAR"]
-/*"CHVAR" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"CHVAR" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"CHVAR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CHVAR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"CHVAR" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"CHVAR" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"CHVAR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"CHVAR" -> "PFECAT"
-/*"CHVAR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"CHVAR" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "BOOLEAN"; "PI"; "INS"}*/
-/*"CHVAR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"CHVAR" -> {"CFCAT"; "REAL"; "OM"; "QFCAT"; "FEVALAB"; "PATAB"}*/
-/*"CHVAR" -> {"FPATMAB"; "TYPE"; "SINT"}*/
-
-"COMMUPC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMMUPC"]
-/*"COMMUPC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"COMMUPC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"COMMUPC" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"COMMUPC" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"COMMUPC" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"COMMUPC" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"COMMUPC" -> {"PATMAB"; "GCDDOM"}*/
-"COMMUPC" -> "PFECAT"
-/*"COMMUPC" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"COMMUPC" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"}*/
-
-"CONTFRAC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CONTFRAC"]
-/*"CONTFRAC" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"CONTFRAC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"CONTFRAC" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"}*/
-/*"CONTFRAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
-/*"CONTFRAC" -> {"UFD"; "DIVRING"; "QFCAT"; "RETRACT"; "FEVALAB"; "ELTAB"}*/
-/*"CONTFRAC" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"CONTFRAC" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"CONTFRAC" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"CONTFRAC" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"CONTFRAC" -> "PFECAT"
-/*"CONTFRAC" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"}*/
-/*"CONTFRAC" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"CONTFRAC" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
-/*"CONTFRAC" -> {"NNI"; "LSAGG-"; "INS"; "CFCAT"}*/
-
-"CVMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CVMP"]
-/*"CVMP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"CVMP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"CVMP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "POLYCAT"; "PDRING"}*/
-/*"CVMP" -> {"FAMR"; "AMR"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"CVMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"CVMP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"CVMP" -> "PFECAT"
-/*"CVMP" -> {"UFD"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"CVMP" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "VECTCAT"; "A1AGG"}*/
-/*"CVMP" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"CVMP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "LIST"; "ILIST"; "QFCAT"}*/
-/*"CVMP" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"; "DIFEXT"}*/
-/*"CVMP" -> {"DIFRING"; "PATAB"; "FPATMAB"; "STEP"; "OINTDOM"; "ORDRING"}*/
-/*"CVMP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-
-"CYCLOTOM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CYCLOTOM"]
-/*"CYCLOTOM" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"CYCLOTOM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"CYCLOTOM" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CYCLOTOM" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"CYCLOTOM" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"CYCLOTOM" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"CYCLOTOM" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"CYCLOTOM" -> {"STEP"; "INT"; "NNI"; "SINT"; "LIST"; "UPOLYC"}*/
-/*"CYCLOTOM" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"CYCLOTOM" -> {"EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"CYCLOTOM" -> "PFECAT"
-/*"CYCLOTOM" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"}*/
-
-"CYCLES" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CYCLES"]
-/*"CYCLES" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"CYCLES" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"CYCLES" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"CYCLES" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"CYCLES" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"CYCLES" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"CYCLES" -> {"REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"; "DIVRING"}*/
-/*"CYCLES" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"}*/
-/*"CYCLES" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
-"CYCLES" -> "PFECAT"
-/*"CYCLES" -> {"INT"; "INS-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"CYCLES" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"CYCLES" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "SINT"; "NNI"}*/
-/*"CYCLES" -> {"PI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"CYCLES" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "FAMR"; "AMR"; "FRETRCT"}*/
-
-"DDFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DDFACT"]
-/*"DDFACT" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"DDFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DDFACT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DDFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DDFACT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
-/*"DDFACT" -> {"FINITE"; "STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"DDFACT" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"DDFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"DDFACT" -> "PFECAT"
-/*"DDFACT" -> {"ELTAB"; "DIFEXT"; "NNI"; "INT"; "SINT"; "PI"; "LIST"}*/
-/*"DDFACT" -> {"ILIST"; "BOOLEAN"; "MONOID-"; "ABELMON-"; "INS"; "OINTDOM"}*/
-/*"DDFACT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
-/*"DDFACT" -> "REAL"*/
-
-"DECIMAL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DECIMAL"]
-/*"DECIMAL" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"DECIMAL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"DECIMAL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"DECIMAL" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"DECIMAL" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"DECIMAL" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"DECIMAL" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"DECIMAL" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"}*/
-/*"DECIMAL" -> {"ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DECIMAL" -> {"OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"DECIMAL" -> "PFECAT"
-/*"DECIMAL" -> {"INS"; "CFCAT"; "OM"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
-/*"DECIMAL" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
-
-"DIOPS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIOPS"]
-/*"DIOPS" -> {"BGAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"DIOPS" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
-"DIOPS" -> "STRING"
-/*"DIOPS" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"DIOPS" -> {"A1AGG-"; "ISTRING"}*/
-
-"DIOPS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIOPS"]
-/*"DIOPS-" -> {"BGAGG"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"DIOPS-" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"DIOPS-" -> "KONVERT"*/
-"DIOPS-" -> "STRING"
-/*"DIOPS-" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"DIOPS-" -> {"A1AGG-"; "ISTRING"}*/
-
-"DIRPROD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIRPROD"]
-"DIRPROD" -> "DIRPCAT"
-/*"DIRPROD" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"DIRPROD" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"DIRPROD" -> {"FRETRCT"; "RETRACT"; "BMODULE"; "LMODULE"; "ABELGRP"}*/
-/*"DIRPROD" -> {"CABMON"; "ABELMON"; "ABELSG"; "RMODULE"; "DIFEXT"}*/
-/*"DIRPROD" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "DIFRING"; "PDRING"}*/
-/*"DIRPROD" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"; "MODULE"}*/
-/*"DIRPROD" -> {"COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"DIRPROD" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"}*/
-/*"DIRPROD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"}*/
-/*"DIRPROD" -> {"DIVRING"; "INS"; "OINTDOM"; "KONVERT"; "PATMAB"; "CFCAT"}*/
-/*"DIRPROD" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "VECTOR"}*/
-/*"DIRPROD" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "SINT"; "NNI"}*/
-/*"DIRPROD" -> {"BOOLEAN"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "CLAGG"}*/
-/*"DIRPROD" -> "PI"*/
-
-"DISPLAY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DISPLAY"]
-/*"DISPLAY" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-"DISPLAY" -> "STRING"
-/*"DISPLAY" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"DISPLAY" -> {"STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"DISPLAY" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DISPLAY" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"DISPLAY" -> {"KONVERT"; "ORDSET"; "OM"}*/
-
-"DIVRING" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIVRING",
-           shape=ellipse]
-/*"DIVRING" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DIVRING" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"DIVRING" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DIVRING" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"DIVRING" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"DIVRING" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"DIVRING" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"DIVRING" -> {"REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"}*/
-/*"DIVRING" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
-/*"DIVRING" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"DIVRING" -> {"TYPE"; "CHARNZ"}*/
-"DIVRING" -> "PFECAT"
-/*"DIVRING" -> "INT"*/
-
-"DIVRING-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIVRING",
-           shape=ellipse]
-/*"DIVRING-" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"DIVRING-" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"DIVRING-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"DIVRING-" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"DIVRING-" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"DIVRING-" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"DIVRING-" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"DIVRING-" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"DIVRING-" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
-/*"DIVRING-" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"}*/
-/*"DIVRING-" -> {"PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
-"DIVRING-" -> "PFECAT"
-/*"DIVRING-" -> "INT"*/
-
-"DMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DMP"]
-/*"DMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"DMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"DMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"DMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"DMP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"DMP" -> "GCDDOM"*/
-"DMP" -> "PFECAT"
-/*"DMP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"DMP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"DMP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-"DMP" -> "DIRPCAT"
-/*"DMP" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DMP" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"DMP" -> {"PID"; "DIVRING"; "ORDFIN"; "FPS"; "RNS"; "REAL"; "RADCAT"}*/
-/*"DMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"}*/
-
-"DPMO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DPMO"]
-"DPMO" -> "DIRPCAT"
-/*"DPMO" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"DPMO" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"}*/
-/*"DPMO" -> {"RETRACT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
-/*"DPMO" -> {"ABELMON"; "ABELSG"; "RMODULE"; "DIFEXT"; "RING"}*/
-/*"DPMO" -> {"RNG"; "SGROUP"; "MONOID"; "DIFRING"; "PDRING"; "FLINEXP"}*/
-/*"DPMO" -> {"LINEXP"; "FINITE"; "ALGEBRA"; "MODULE"; "COMRING"}*/
-/*"DPMO" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"DPMO" -> {"ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"DPMO" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"DPMO" -> {"SINT"; "NNI"; "INT"; "INS"; "OINTDOM"; "KONVERT"}*/
-/*"DPMO" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"DPOLCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DPOLCAT"]
-/*"DPOLCAT" -> {"DVARCAT"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DPOLCAT" -> {"RETRACT"; "POLYCAT"; "PDRING"; "RING"; "RNG"}*/
-/*"DPOLCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"DPOLCAT" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"DPOLCAT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"DPOLCAT" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "EVALAB"}*/
-/*"DPOLCAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"DPOLCAT" -> "GCDDOM"*/
-"DPOLCAT" -> "PFECAT"
-/*"DPOLCAT" -> {"UFD"; "DIFEXT"; "DIFRING"; "OAMONS"; "OCAMON"}*/
-/*"DPOLCAT" -> {"OAMON"; "OASGP"; "NNI"; "INT"; "LIST"}*/
-/*"DPOLCAT" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"}*/
-/*"DPOLCAT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"DPOLCAT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"DPOLCAT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "FLAGG-"}*/
-/*"DPOLCAT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"DPOLCAT" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"DPOLCAT" -> {"BASTYPE-"; "SINT"; "INS"; "EUCDOM"; "PID"}*/
-/*"DPOLCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "CFCAT"; "REAL"; "STEP"}*/
-
-"DPOLCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DPOLCAT"]
-/*"DPOLCAT-" -> {"DVARCAT"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DPOLCAT-" -> {"RETRACT"; "POLYCAT"; "PDRING"; "RING"; "RNG"}*/
-/*"DPOLCAT-" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"DPOLCAT-" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"DPOLCAT-" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"DPOLCAT-" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "EVALAB"}*/
-/*"DPOLCAT-" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"DPOLCAT-" -> "GCDDOM"*/
-"DPOLCAT-" -> "PFECAT"
-/*"DPOLCAT-" -> {"UFD"; "DIFEXT"; "DIFRING"; "OAMONS"; "OCAMON"}*/
-/*"DPOLCAT-" -> {"OAMON"; "OASGP"; "NNI"; "INT"; "LIST"; "ILIST"}*/
-/*"DPOLCAT-" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"; "STAGG"}*/
-/*"DPOLCAT-" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"DPOLCAT-" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"DPOLCAT-" -> {"FLAGG"; "ELAGG"; "OM"; "FLAGG-"; "URAGG-"}*/
-/*"DPOLCAT-" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"DPOLCAT-" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"DPOLCAT-" -> {"SINT"; "INS"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"DPOLCAT-" -> {"ORDRING"; "OAGROUP"; "CFCAT"; "REAL"; "STEP"}*/
-
-"DSTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DSTREE"]
-/*"DSTREE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"DSTREE" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"; "ILIST"}*/
-/*"DSTREE" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"DSTREE" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"DSTREE" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "BOOLEAN"}*/
-"DSTREE" -> "STRING"
-/*"DSTREE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-
-"D01AJFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AJFA"]
-/*"D01AJFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "PI"; "NNI"; "INT"}*/
-"D01AJFA" -> "STRING"
-/*"D01AJFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"D01AJFA" -> {"ISTRING"; "SRAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
-/*"D01AJFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"D01AJFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"D01AJFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"D01AJFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"D01AJFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"D01AJFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"; "INS-"; "EUCDOM-"}*/
-/*"D01AJFA" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"D01AJFA" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"D01AKFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AKFA"]
-/*"D01AKFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-"D01AKFA" -> "STRING"
-/*"D01AKFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"D01AKFA" -> {"ISTRING"; "SRAGG-"; "PI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
-/*"D01AKFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"D01AKFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"D01AKFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"D01AKFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"D01AKFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"D01AKFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"; "INS-"; "EUCDOM-"}*/
-/*"D01AKFA" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"D01AKFA" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"D01ALFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01ALFA"]
-/*"D01ALFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "STRICAT"}*/
-/*"D01ALFA" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"D01ALFA" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"D01ALFA" -> {"CLAGG"; "KONVERT"; "ORDSET"; "OM"; "INT"; "LIST"}*/
-/*"D01ALFA" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-/*"D01ALFA" -> {"NNI"; "INS-"}*/
-"D01ALFA" -> "STRING"
-/*"D01ALFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"D01ALFA" -> {"SRAGG-"; "PI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
-/*"D01ALFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"D01ALFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"D01ALFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"D01ALFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"D01ALFA" -> {"OAMON"; "OASGP"; "REAL"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"D01ALFA" -> {"CHARZ"; "DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"D01ALFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"D01ALFA" -> {"DFLOAT"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-/*"D01ALFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"D01ALFA" -> {"ABELGRP-"; "ABELMON-"}*/
-
-"D01AMFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AMFA"]
-/*"D01AMFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-"D01AMFA" -> "STRING"
-/*"D01AMFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"D01AMFA" -> {"ISTRING"; "SRAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"}*/
-/*"D01AMFA" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"D01AMFA" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"D01AMFA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"D01AMFA" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"D01AMFA" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"D01AMFA" -> {"RADCAT"; "PATMAB"; "CHARZ"; "PI"; "INS-"; "EUCDOM-"}*/
-/*"D01AMFA" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"D01AMFA" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-/*"D01AMFA" -> "DFLOAT"*/
-
-"D01APFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01APFA"]
-/*"D01APFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "DFLOAT"; "INT"}*/
-/*"D01APFA" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "PI"; "NNI"}*/
-"D01APFA" -> "STRING"
-/*"D01APFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"D01APFA" -> {"SRAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"D01APFA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"D01APFA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"D01APFA" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"D01APFA" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"D01APFA" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
-/*"D01APFA" -> {"PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"}*/
-/*"D01APFA" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "ELAGG-"}*/
-/*"D01APFA" -> {"FLAGG-"; "URAGG-"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"D01APFA" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
-/*"D01APFA" -> {"RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"D01AQFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01AQFA"]
-/*"D01AQFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"D01AQFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"D01AQFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"D01AQFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"D01AQFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"D01AQFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"D01AQFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"}*/
-/*"D01AQFA" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"D01AQFA" -> {"ELEMFUN"; "SPFCAT"; "INT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"D01AQFA" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"D01AQFA" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"D01AQFA" -> {"ELAGG"; "LIST"; "ILIST"; "NNI"; "PI"}*/
-"D01AQFA" -> "STRING"
-/*"D01AQFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"D01AQFA" -> {"SRAGG-"; "INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
-/*"D01AQFA" -> {"QFCAT"; "FEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
-/*"D01AQFA" -> {"FPATMAB"; "CHARNZ"}*/
-"D01AQFA" -> "PFECAT"
-/*"D01AQFA" -> {"DFLOAT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-/*"D01AQFA" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"D01AQFA" -> {"ABELGRP-"; "ABELMON-"}*/
-
-"EMR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EMR"]
-/*"EMR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"EMR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"EMR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"EMR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
-/*"EMR" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"EMR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"EMR" -> {"KONVERT"; "PATMAB"}*/
-"EMR" -> "PFECAT"
-/*"EMR" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
-/*"EMR" -> {"DIVRING"; "INT"; "NNI"; "BOOLEAN"}*/
-
-"EQ" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EQ"]
-/*"EQ" -> {"TYPE"; "IEVALAB"; "SETCAT"; "BASTYPE"; "KOERCE"; "ABELSG"}*/
-/*"EQ" -> {"ABELGRP"; "CABMON"; "ABELMON"; "SGROUP"; "MONOID"; "GROUP"}*/
-/*"EQ" -> {"RING"; "RNG"; "LMODULE"; "BMODULE"; "RMODULE"; "MODULE"}*/
-/*"EQ" -> {"PDRING"; "VSPACE"; "COMRING"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"EQ" -> {"GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"EQ" -> {"EVALAB"; "BOOLEAN"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"EQ" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"EQ" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"EQ" -> {"STEP"; "POLYCAT"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
-"EQ" -> "PFECAT"
-/*"EQ" -> "ES"*/
-
-"ERROR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ERROR"]
-/*"ERROR" -> {"INT"; "LIST"}*/
-"ERROR" -> "STRING"
-/*"ERROR" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-
-"EVALCYC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EVALCYC"]
-/*"EVALCYC" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"EVALCYC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"EVALCYC" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "INS"}*/
-/*"EVALCYC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "EUCDOM"}*/
-/*"EVALCYC" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"EVALCYC" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"EVALCYC" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"}*/
-/*"EVALCYC" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
-/*"EVALCYC" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"EVALCYC" -> "CHARNZ"*/
-"EVALCYC" -> "PFECAT"
-
-"EXP3D" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXP3D"]
-"EXP3D" -> "STRING"
-/*"EXP3D" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; }*/
-/*"EXP3D" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"EXP3D" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"EXP3D" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"EXP3D" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"EXP3D" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"EXP3D" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INT"; "LIST"; "ILIST"; "CHAR"}*/
-/*"EXP3D" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "LSAGG"}*/
-/*"EXP3D" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"EXP3D" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"EXP3D" -> {"FLAGG"; "ELAGG"; "OM"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"EXP3D" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"EXP3D" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"EXP3D" -> {"DFLOAT"; "PTCAT"; "VECTCAT"; "A1AGG"; "PI"}*/
-
-"E04DGFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04DGFA"]
-/*"E04DGFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"E04DGFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"E04DGFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"E04DGFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"E04DGFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"E04DGFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"E04DGFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "LSAGG"}*/
-/*"E04DGFA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"E04DGFA" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"E04DGFA" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"E04DGFA" -> {"ILIST"; "NNI"; "INS-"}*/
-"E04DGFA" -> "STRING"
-/*"E04DGFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"E04DGFA" -> {"DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"E04DGFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "DFLOAT"; "MONOID-"; "ABELMON-"}*/
-/*"E04DGFA" -> {"PI"; "BOOLEAN"}*/
-
-"E04FDFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04FDFA"]
-/*"E04FDFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"E04FDFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"E04FDFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"E04FDFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"E04FDFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"E04FDFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"E04FDFA" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"E04FDFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"E04FDFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"E04FDFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
-/*"E04FDFA" -> {"LIST"; "ILIST"; "NNI"; "INS-"}*/
-"E04FDFA" -> "STRING"
-/*"E04FDFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"E04FDFA" -> {"DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"E04FDFA" -> {"ELEMFUN"; "SPFCAT"; "PI"; "VECTOR"; "EUCDOM-"; "UFD-"}*/
-/*"E04FDFA" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"E04FDFA" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"E04GCFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04GCFA"]
-/*"E04GCFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"E04GCFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"E04GCFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"E04GCFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"E04GCFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"E04GCFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"E04GCFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"E04GCFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"E04GCFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"E04GCFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
-/*"E04GCFA" -> {"LIST"; "ILIST"; "NNI"; "INS-"}*/
-"E04GCFA" -> "STRING"
-/*"E04GCFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"E04GCFA" -> {"DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"E04GCFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "PI"; "DFLOAT"; "VECTOR"}*/
-/*"E04GCFA" -> {"MONOID-"; "ABELMON-"}*/
-
-"E04JAFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04JAFA"]
-/*"E04JAFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "LIST"}*/
-/*"E04JAFA" -> {"ILIST"; "LSAGG-"; "STAGG-"; "FPS"; "RNS"; "FIELD"}*/
-/*"E04JAFA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"E04JAFA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"E04JAFA" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"E04JAFA" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"E04JAFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"E04JAFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "LSAGG"}*/
-/*"E04JAFA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"E04JAFA" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"E04JAFA" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "DIFRING"}*/
-/*"E04JAFA" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"E04JAFA" -> {"SPFCAT"; "INS-"}*/
-"E04JAFA" -> "STRING"
-/*"E04JAFA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"E04JAFA" -> {"STRICAT"; "SRAGG"; "A1AGG"; "NNI"; "EUCDOM-"; "UFD-"}*/
-/*"E04JAFA" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"E04JAFA" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "PI"; "DFLOAT"}*/
-
-"E04UCFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04UCFA"]
-/*"E04UCFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"E04UCFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"E04UCFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"E04UCFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"E04UCFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"E04UCFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"E04UCFA" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"E04UCFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"E04UCFA" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"E04UCFA" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
-/*"E04UCFA" -> {"LIST"; "ILIST"; "NNI"; "DIFRING"; "TRANFUN"; "TRIGCAT"}*/
-/*"E04UCFA" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "LSAGG-"}*/
-/*"E04UCFA" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "DFLOAT"; "PI"; "MONOID-"}*/
-/*"E04UCFA" -> {"ABELMON-"; "INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
-/*"E04UCFA" -> {"INS-"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"E04UCFA" -> {"FRETRCT"; "FLINEXP"}*/
-"E04UCFA" -> "PFECAT"
-/*"E04UCFA" -> {"QFCAT"; "FEVALAB"; "DIFEXT"; "PATAB"; "FPATMAB"; "VECTOR"}*/
-/*"E04UCFA" -> "BOOLEAN"*/
-
-"FACUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACUTIL"]
-/*"FACUTIL" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"FACUTIL" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
-/*"FACUTIL" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "POLYCAT"}*/
-/*"FACUTIL" -> {"PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"FACUTIL" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"FACUTIL" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"FACUTIL" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"FACUTIL" -> "PFECAT"
-/*"FACUTIL" -> {"UFD"; "NNI"; "INT"; "LIST"; "FFIELDC"; "FPC"; "FIELD"}*/
-/*"FACUTIL" -> {"EUCDOM"; "PID"; "DIVRING"; "FINITE"; "STEP"; "DIFRING"}*/
-/*"FACUTIL" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"FACUTIL" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"FACUTIL" -> {"ABELMON-"; "PI"; "BOOLEAN"}*/
-
-"FF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FF"]
-"FF" -> "FAXF"
-/*"FF" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"FF" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
-/*"FF" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "KONVERT"; "OAMONS"}*/
-/*"FF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"}*/
-/*"FF" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-
-"FFFFACTOR"  [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFFACTOR"]
-/*"FFFACTOR" -> {"FFIELDC", "FPC", "FIELD", "EUCDOM", "PID", "GCDDOM"}*/
-/*"FFFACTOR" -> {"INTDOM", "COMRING", "RING", "RNG", "ABELGRP", "CABMON"}*/
-/*"FFFACTOR" -> {"ABELMON", "ABELSG", "SETCAT", "BASTYPE", "KOERCE","SGROUP"}*/
-/*"FFFACTOR" -> {"MONOID", "LMODULE", "BMODULE", "RMODULE", "ALGEBRA"}*/
-/*"FFFACTOR" -> {"MODULE", "ENTIRER", "UFD", "DIVRING", "CHARNZ", "FINITE"}*/
-/*"FFFACTOR" -> {"STEP", "DIFRING", "UPOLYC", "POLYCAT", "PDRING", "FAMR"}*/
-/*"FFFACTOR" -> {"AMR", "CHARZ", "FRETRCT", "RETRACT", "EVALAB", "IEVALAB"}*/
-/*"FFFACTOR" -> {"FLINEXP", "LINEXP", "ORDSET", "KONVERT", "PATMAB"}*/
-"FFFACTOR" -> "PFECAT"
-/*"FFFACTOR" -> {"ELTAB", "DIFEXT", "NNI", "INT", "PI", "PRIMARR", "A1AGG"}*/
-/*"FFFACTOR" -> {"FLAGG", "LNAGG", "IXAGG", "HOAGG", "AGG", "TYPE", "ELTAGG"}*/
-/*"FFFACTOR" -> {"CLAGG", "BOOLEAN", "SINT", "LIST", "ILIST", "LSAGG-"}*/
-/*"FFFACTOR" -> {"STAGG-", "INS-", "INS", "OINTDOM", "ORDRING", "OAGROUP"}*/
-/*"FFFACTOR" -> {"OCAMON", "OAMON", "OASGP", "CFCAT", "REAL"}*/
-
-"FFCG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCG"]
-"FFCG" -> "FAXF"
-/*"FFCG" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFCG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFCG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFCG" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFCG" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
-/*"FFCG" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
-/*"FFCG" -> {"KONVERT"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"FFCG" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "LINEXP"}*/
-/*"FFCG" -> {"PATMAB"; "CFCAT"; "REAL"}*/
-
-"FFCGX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCGX"]
-"FFCGX" -> "FAXF"
-/*"FFCGX" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FFCGX" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FFCGX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FFCGX" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"FFCGX" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
-/*"FFCGX" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "OAMONS"; "OCAMON"}*/
-/*"FFCGX" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"FFCGX" -> {"OAGROUP"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-
-"FFFG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFG"]
-/*"FFFG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FFFG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FFFG" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FFFG" -> {"MODULE"; "ENTIRER"; "GCDDOM"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"FFFG" -> {"NNI"; "INT"; "SINT"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"FFFG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"FFFG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"FFFG" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"FFFG" -> {"FAMR"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-"FFFG" -> "PFECAT"
-/*"FFFG" -> {"UFD"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
-/*"FFFG" -> {"DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-/*"FFFG" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"FFFG" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"FFFG" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"FFFG" -> {"MONOID-"; "ABELMON-"; "SGROUP-"; "ABELSG-"; "PI"; "OAMONS"}*/
-/*"FFFG" -> {"OCAMON"; "OAMON"; "OASGP"; "VECTCAT-"; "A1AGG-"; "BOOLEAN"}*/
-
-"FFHOM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFHOM"]
-"FFHOM" -> "FAXF"
-/*"FFHOM" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFHOM" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFHOM" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFHOM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFHOM" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
-/*"FFHOM" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
-/*"FFHOM" -> {"NNI"; "INT"; "BOOLEAN"; "SINT"; "PI"; "PRIMARR"}*/
-/*"FFHOM" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"}*/
-/*"FFHOM" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FFHOM" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"FFHOM" -> "ORDSET"*/
-
-"FFNB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFNB"]
-"FFNB" -> "FAXF"
-/*"FFNB" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFNB" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFNB" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFNB" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFNB" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
-/*"FFNB" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
-/*"FFNB" -> {"KONVERT"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"FFNB" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"}*/
-/*"FFNB" -> {"CFCAT"; "REAL"}*/
-
-"FFNBX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFNBX"]
-"FFNBX" -> "FAXF"
-/*"FFNBX" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFNBX" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFNBX" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFNBX" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFNBX" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
-/*"FFNBX" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
-/*"FFNBX" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"}*/
-/*"FFNBX" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "KONVERT"; "LINEXP"}*/
-/*"FFNBX" -> {"PATMAB"; "CFCAT"; "REAL"}*/
-
-"FFPOLY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFPOLY"]
-/*"FFPOLY" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FFPOLY" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FFPOLY" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FFPOLY" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FFPOLY" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"FFPOLY" -> {"STEP"; "DIFRING"; "INT"; "LIST"; "ILIST"; "PI"}*/
-/*"FFPOLY" -> {"NNI"; "PRIMARR"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"FFPOLY" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"FFPOLY" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "SINT"; "BOOLEAN"}*/
-/*"FFPOLY" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
-/*"FFPOLY" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"FFPOLY" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
-/*"FFPOLY" -> {"LINEXP"; "PATMAB"}*/
-"FFPOLY" -> "PFECAT"
-/*"FFPOLY" -> {"DIFEXT"; "LSAGG-"; "STAGG-"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
-/*"FFPOLY" -> {"INS-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FFPOLY" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"FFPOLY" -> {"RCAGG"; "ELAGG"; "OM"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
-/*"FFPOLY" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"FFPOLY" -> {"SETCAT-"; "BASTYPE-"}*/
-
-"FFSQFR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFSQFR"]
-/*"FFSQFR" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FFSQFR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FFSQFR" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FFSQFR" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/ 
-/*"FFSQFR" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"FFSQFR" -> {"STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"FFSQFR" -> {"AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"FFSQFR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"FFSQFR" -> "PFECAT" 
-/*"FFSQFR" -> {"ELTAB"; "DIFEXT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"FFSQFR" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "SINT"; "NNI"}*/
-/*"FFSQFR" -> {"INT"; "BOOLEAN"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"FFSQFR" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
-/*"FFSQFR" -> {"RING-"; "ABELGRP-"}*/
-
-"FFX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFX"]
-"FFX" -> "FAXF"
-/*"FFX" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FFX" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FFX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FFX" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FFX" -> {"UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
-/*"FFX" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "OAMONS"; "OCAMON"}*/
-/*"FFX" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"FFX" -> {"OAGROUP"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-
-"FFSLPE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFSLPE"]
-/*"FFSLPE" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FFSLPE" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FFSLPE" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FFSLPE" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FFSLPE" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"FFSLPE" -> {"STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"FFSLPE" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"FFSLPE" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"FFSLPE" -> "PATMAB"*/
-"FFSLPE" -> "PFECAT"
-/*"FFSLPE" -> {"ELTAB"; "DIFEXT"; "NNI"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
-
-"FGLMICPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FGLMICPK"]
-/*"FGLMICPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FGLMICPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FGLMICPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FGLMICPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"}*/
-/*"FGLMICPK" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"FGLMICPK" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"FGLMICPK" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"FGLMICPK" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-"FGLMICPK" -> "DIRPCAT"
-/*"FGLMICPK" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"FGLMICPK" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"}*/
-/*"FGLMICPK" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
-/*"FGLMICPK" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
-/*"FGLMICPK" -> {"ORDFIN"; "BOOLEAN"; "NNI"; "POLYCAT"; "FAMR"}*/
-/*"FGLMICPK" -> {"AMR"; "CHARZ"; "CHARNZ"; "PATMAB"}*/
-"FGLMICPK" -> "PFECAT"
-/*"FGLMICPK" -> {"LSAGG-"; "STAGG-"; "ELAGG-"}*/
-
-"FILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FILE"]
-/*"FILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"}*/
-"FILE" -> "STRING"
-/*"FILE" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"FILE" -> {"A1AGG-"; "ISTRING"}*/
-
-"FINAALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FINAALG"]
-/*"FINAALG" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FINAALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
-/*"FINAALG" -> {"MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "COMRING"}*/
-/*"FINAALG" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "UPOLYC"}*/
-/*"FINAALG" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "ALGEBRA"}*/
-/*"FINAALG" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"FINAALG" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"FINAALG" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"FINAALG" -> "PFECAT"
-/*"FINAALG" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"FINAALG" -> {"PID"; "FIELD"; "DIVRING"; "SINT"; "PI"; "NNI"; "INT"}*/
-/*"FINAALG" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "BOOLEAN"}*/
-"FINAALG" -> "STRING"
-/*"FINAALG" -> {"CHAR"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"FINAALG" -> {"SRAGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FINAALG" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "ILIST"; "VECTCAT"}*/
-/*"FINAALG" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"FINAALG" -> {"TYPE"; "ELTAGG"; "CLAGG"; "VECTCAT-"; "MONOID-"; "ABELSG-"}*/
-/*"FINAALG" -> "SGROUP-"*/
-
-"FINAALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FINAALG"]
-/*"FINAALG-" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FINAALG-" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
-/*"FINAALG-" -> {"MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "COMRING"}*/
-/*"FINAALG-" -> {"RING"; "RNG"; "SGROUP"; "MONOID"; "UPOLYC"}*/
-/*"FINAALG-" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "ALGEBRA"}*/
-/*"FINAALG-" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"FINAALG-" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"FINAALG-" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"FINAALG-" -> "PFECAT"
-/*"FINAALG-" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"FINAALG-" -> {"PID"; "FIELD"; "DIVRING"; "SINT"; "PI"; "NNI"}*/
-/*"FINAALG-" -> {"INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "BOOLEAN"}*/
-"FINAALG-" -> "STRING"
-/*"FINAALG-" -> {"CHAR"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"FINAALG-" -> {"ISTRING"; "SRAGG-"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"FINAALG-" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
-/*"FINAALG-" -> {"REAL"; "OM"; "ILIST"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"FINAALG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"FINAALG-" -> {"CLAGG"; "VECTCAT-"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
-
-"FINRALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FINRALG"]
-/*"FINRALG" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FINRALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FINRALG" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "CHARZ"; "CHARNZ"}*/
-/*"FINRALG" -> {"COMRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"FINRALG" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"FINRALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"FINRALG" -> {"PATMAB"; "GCDDOM"}*/
-"FINRALG" -> "PFECAT"
-/*"FINRALG" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"FINRALG" -> {"PID"; "FIELD"; "DIVRING"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"FINRALG" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"FINRALG" -> {"CLAGG"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"}*/
-/*"FINRALG" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FINRALG" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "SINT"; "PI"; "NNI"}*/
-/*"FINRALG" -> {"VECTCAT-"; "A1AGG-"}*/
-
-"FINRALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FINRALG"]
-/*"FINRALG-" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FINRALG-" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FINRALG-" -> {"SGROUP"; "MONOID"; "LMODULE"; "MODULE"; "BMODULE"}*/
-/*"FINRALG-" -> {"RMODULE"; "CHARZ"; "CHARNZ"; "COMRING"; "UPOLYC"}*/
-/*"FINRALG-" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "INTDOM"}*/
-/*"FINRALG-" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"FINRALG-" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"FINRALG-" -> "GCDDOM"*/
-"FINRALG-" -> "PFECAT"
-/*"FINRALG-" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"FINRALG-" -> {"PID"; "FIELD"; "DIVRING"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"FINRALG-" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"FINRALG-" -> {"CLAGG"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"}*/
-/*"FINRALG-" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FINRALG-" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "SINT"; "PI"}*/
-/*"FINRALG-" -> {"NNI"; "VECTCAT-"; "A1AGG-"}*/
-
-"FFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFF"]
-/*"FFF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FFF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FFF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FFF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFF" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
-/*"FFF" -> {"DIFRING"; "NNI"; "INT"; "SINT"; "PI"; "INS-"; "INS"; "OINTDOM"}*/
-/*"FFF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"FFF" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"FFF" -> {"CHARZ"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"FFF" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"FFF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"FFF" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"FFF" -> {"ELAGG"; "PRIMARR"; "BOOLEAN"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
-/*"FFF" -> {"SGROUP-"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"FFF" -> {"FRETRCT"; "FLINEXP"}*/
-"FFF" -> "PFECAT"
-/*"FFF" -> "DIFEXT"*/
-
-"FFFGF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFGF"]
-/*"FFFGF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FFFGF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FFFGF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FFFGF" -> {"MODULE"; "ENTIRER"; "GCDDOM"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"FFFGF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"FFFGF" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"FFFGF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"}*/
-/*"FFFGF" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"; "NNI"; "UPOLYC"}*/
-/*"FFFGF" -> {"POLYCAT"; "PDRING"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-"FFFGF" -> "PFECAT"
-/*"FFFGF" -> {"UFD"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
-/*"FFFGF" -> {"DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-/*"FFFGF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "QFCAT"; "FEVALAB"}*/
-/*"FFFGF" -> {"PATAB"; "FPATMAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"}*/
-
-"FLOATRP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLOATRP"]
-/*"FLOATRP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"FLOATRP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"}*/
-/*"FLOATRP" -> {"CABMON"; "ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"FLOATRP" -> {"LMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FLOATRP" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FLOATRP" -> {"ENTIRER"; "UFD"; "DIVRING"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"FLOATRP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"FLOATRP" -> {"CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"FLOATRP" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"FLOATRP" -> "PFECAT"
-/*"FLOATRP" -> {"BOOLEAN"; "OM"; "INT"; "LIST"; "ILIST"}*/
-
-"FNAME" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FNAME"]
-/*"FNAME" -> {"FNCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"FNAME" -> "STRING"
-/*"FNAME" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"FNAME" -> {"A1AGG-"; "ISTRING"}*/
-
-"FOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FOP"]
-"FOP" -> "STRING"
-/*"FOP" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
-/*"FOP" -> {"ISTRING"}*/
-
-"FORMULA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FORMULA"]
-/*"FORMULA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"; "LIST"}*/
-"FORMULA" -> "STRING"
-/*"FORMULA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ILIST"}*/
-/*"FORMULA" -> {"LSAGG-"; "STAGG-"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
-/*"FORMULA" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"FORMULA" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"FORMULA" -> {"OM"; "ISTRING"; "PI"; "ELAGG-"; "FLAGG-"; "LSAGG"}*/
-/*"FORMULA" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-
-"FORT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FORT"]
-/*"FORT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FORT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"FORT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"FORT" -> {"ORDSET"; "ELAGG"; "OM"; "STRICAT"; "SRAGG"; "A1AGG"}*/
-/*"FORT" -> {"INT"; "LIST"; "ILIST"}*/
-"FORT" -> "STRING"
-/*"FORT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"FORT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FORT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"FORT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FORT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FORT" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"FORT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"FRAC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRAC"]
-/*"FRAC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FRAC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FRAC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FRAC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FRAC" -> {"UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"FRAC" -> {"IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"FRAC" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"}*/
-/*"FRAC" -> {"ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FRAC" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"FRAC" -> "PFECAT"
-/*"FRAC" -> {"OM"; "INS"; "CFCAT"; "BOOLEAN"; "NNI"; "INT"; "PI"; "SINT"}*/
-/*"FRAC" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"FRAC" -> {"ELTAGG"; "CLAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"; "UPOLYC"}*/
-/*"FRAC" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "LIST"; "ILIST"; "FPS"}*/
-/*"FRAC" -> {"RNS"; "RADCAT"}*/
-
-"FTEM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FTEM"]
-/*"FTEM" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"}*/
-"FTEM" -> "STRING"
-/*"FTEM" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
-/*"FTEM" -> {"ISTRING"; "BOOLEAN"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"FTEM" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FTEM" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FTEM" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"FTEM" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"FTEM" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"FTEM" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"FTEM" -> {"STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"FTEM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"FTEM" -> {"ELTAB"; "CLAGG"}*/
-
-"GENEEZ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENEEZ"]
-/*"GENEEZ" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"GENEEZ" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"GENEEZ" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"GENEEZ" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"}*/
-/*"GENEEZ" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"GENEEZ" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"GENEEZ" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"GENEEZ" -> "PFECAT"
-/*"GENEEZ" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
-/*"GENEEZ" -> {"DIVRING"; "NNI"; "INT"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
-/*"GENEEZ" -> {"SGROUP-"; "PI"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"GENEEZ" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "VECTOR"}*/
-/*"GENEEZ" -> {"IVECTOR"; "IARRAY1"; "SINT"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
-/*"GENEEZ" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"GENEEZ" -> {"CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
-/*"GENEEZ" -> {"LIST"; "ILIST"}*/
-
-"GENMFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENMFACT"]
-/*"GENMFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
-/*"GENMFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"GENMFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"GENMFACT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"GENMFACT" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"GENMFACT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"GENMFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"GENMFACT" -> "GCDDOM"*/
-"GENMFACT" -> "PFECAT"
-/*"GENMFACT" -> {"UFD"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"GENMFACT" -> {"DIVRING"; "FINITE"; "STEP"; "DIFRING"}*/
-
-"GENPGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENPGCD"]
-/*"GENPGCD" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"GENPGCD" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-"GENPGCD" -> "PFECAT"
-/*"GENPGCD" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"GENPGCD" -> {"ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"GENPGCD" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
-/*"GENPGCD" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"GENPGCD" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"GENPGCD" -> {"KONVERT"; "PATMAB"; "NNI"; "INT"; "LIST"; "LSAGG"}*/
-/*"GENPGCD" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"GENPGCD" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"GENPGCD" -> {"OM"; "ILIST"; "STEP"; "BOOLEAN"; "PI"; "SINT"; "LSAGG-"}*/
-/*"GENPGCD" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-
-"GALFACTU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALFACTU"]
-/*"GALFACTU" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"GALFACTU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"GALFACTU" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"GALFACTU" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"GALFACTU" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"GALFACTU" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"GALFACTU" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"GALFACTU" -> "PFECAT"
-/*"GALFACTU" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"GALFACTU" -> {"PID"; "FIELD"; "DIVRING"; "FPS"; "RNS"; "ORDRING"}*/
-/*"GALFACTU" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
-/*"GALFACTU" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"GALFACTU" -> {"PI"; "NNI"; "INT"; "MONOID-"; "ABELMON-"; "INS"}*/
-/*"GALFACTU" -> {"OINTDOM"; "CFCAT"; "SINT"; "INS-"}*/
-
-"GALPOLYU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALPOLYU"]
-/*"GALPOLYU" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"GALPOLYU" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"GALPOLYU" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"GALPOLYU" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"GALPOLYU" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"GALPOLYU" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"GALPOLYU" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"GALPOLYU" -> "PFECAT"
-/*"GALPOLYU" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"GALPOLYU" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-/*"GALPOLYU" -> {"SINT"; "PI"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"GALPOLYU" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"GALPOLYU" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "VECTOR"; "IVECTOR"}*/
-/*"GALPOLYU" -> "IARRAY1"*/
-
-"GB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GB"]
-/*"GB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"GB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GB" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"GB" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"GB" -> {"ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"GB" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"GB" -> {"KONVERT"; "PATMAB"}*/
-"GB" -> "PFECAT"
-/*"GB" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "INT"; "LIST"}*/
-/*"GB" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"GB" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "BOOLEAN"}*/
-"GB" -> "STRING"
-/*"GB" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"GB" -> {"PI"; "NNI"}*/
-
-"GBEUCLID" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GBEUCLID"]
-/*"GBEUCLID" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"GBEUCLID" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"GBEUCLID" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"GBEUCLID" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"GBEUCLID" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "POLYCAT"}*/
-/*"GBEUCLID" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"GBEUCLID" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"GBEUCLID" -> {"KONVERT"; "PATMAB"}*/
-"GBEUCLID" -> "PFECAT"
-/*"GBEUCLID" -> {"UFD"; "INT"}*/
-"GBEUCLID" -> "STRING"
-/*"GBEUCLID" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"GBEUCLID" -> {"ISTRING"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"GBEUCLID" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"GBEUCLID" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"GBEUCLID" -> {"FLAGG"; "ELAGG"; "OM"; "NNI"}*/
-
-"GBF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GBF"]
-/*"GBF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"GBF" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"GBF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"GBF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "OAMONS"; "OCAMON"}*/
-/*"GBF" -> {"OAMON"; "OASGP"; "ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"GBF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"GBF" -> {"LINEXP"; "KONVERT"; "PATMAB"}*/
-"GBF" -> "PFECAT"
-/*"GBF" -> {"UFD"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
-/*"GBF" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"GBF" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"GBF" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-
-"GBINTERN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GBINTERN"]
-/*"GBINTERN" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"GBINTERN" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"GBINTERN" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"GBINTERN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
-/*"GBINTERN" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "POLYCAT"; "PDRING"}*/
-/*"GBINTERN" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"GBINTERN" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
-/*"GBINTERN" -> "PATMAB"*/
-"GBINTERN" -> "PFECAT"
-/*"GBINTERN" -> {"UFD"; "NNI"; "INT"; "BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"GBINTERN" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"GBINTERN" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
-/*"GBINTERN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
-/*"GBINTERN" -> "PI"*/
-
-"GHENSEL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GHENSEL"]
-/*"GHENSEL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"GHENSEL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"GHENSEL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"GHENSEL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"GHENSEL" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"GHENSEL" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"GHENSEL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"GHENSEL" -> "PFECAT"
-/*"GHENSEL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
-/*"GHENSEL" -> {"DIVRING"; "INT"; "INS-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"GHENSEL" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"GHENSEL" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"}*/
-
-"GMODPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GMODPOL"]
-/*"GMODPOL" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
-/*"GMODPOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GMODPOL" -> {"RMODULE"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "SGROUP"}*/
-/*"GMODPOL" -> {"MONOID"; "FAMR"; "AMR"; "COMRING"; "ALGEBRA"; "CHARZ"}*/
-/*"GMODPOL" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"GMODPOL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"GMODPOL" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"GMODPOL" -> "PFECAT"
-/*"GMODPOL" -> "UFD"*/
-"GMODPOL" -> "DIRPCAT"
-/*"GMODPOL" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "ELTAB"}*/
-/*"GMODPOL" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
-/*"GMODPOL" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
-/*"GMODPOL" -> {"EUCDOM"; "PID"; "DIVRING"}*/
-
-"GOSPER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GOSPER"]
-/*"GOSPER" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"GOSPER" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "INTDOM"}*/
-/*"GOSPER" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
-/*"GOSPER" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"GOSPER" -> {"ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"GOSPER" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"GOSPER" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"GOSPER" -> "PFECAT"
-/*"GOSPER" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "INS"; "OINTDOM"}*/
-/*"GOSPER" -> {"ORDRING"; "OAGROUP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
-/*"GOSPER" -> {"QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"; "FPATMAB"}*/
-/*"GOSPER" -> {"TYPE"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"GOSPER" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"GOSPER" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"GOSPER" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "SINT"}*/
-/*"GOSPER" -> {"NNI"; "PI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "BOOLEAN"}*/
-/*"GOSPER" -> {"VECTCAT"; "A1AGG"}*/
-
-"GRIMAGE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GRIMAGE"]
-/*"GRIMAGE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
-/*"GRIMAGE" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"GRIMAGE" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"GRIMAGE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"GRIMAGE" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"GRIMAGE" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"GRIMAGE" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-/*"GRIMAGE" -> {"FPS"; "RNS"; "FIELD"; "DIVRING"; "RADCAT"; "INT"; "LSAGG"}*/
-/*"GRIMAGE" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"GRIMAGE" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"GRIMAGE" -> {"FLAGG"; "ELAGG"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"}*/
-/*"GRIMAGE" -> {"PI"; "DFLOAT"; "PTCAT"; "VECTCAT"; "A1AGG"; "FPS-"; "RNS-"}*/
-"GRIMAGE" -> "STRING"
-/*"GRIMAGE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "STRICAT"}*/
-/*"GRIMAGE" -> {"SRAGG"; "ISTRING"; "FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"GRIMAGE" -> {"DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"GRIMAGE" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"}*/
-/*"GRIMAGE" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "TRANFUN-"; "SETCAT-"}*/
-/*"GRIMAGE" -> {"ELEMFUN-"; "HYPCAT-"; "ATRIG-"; "TRIGCAT-"; "RADCAT-"}*/
-/*"GRIMAGE" -> {"RETRACT-"; "BASTYPE-"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"GRIMAGE" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "BOOLEAN"; "ELAGG-"}*/
-/*"GRIMAGE" -> {"FLAGG-"; "URAGG-"}*/
-
-"GROEBSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GROEBSOL"]
-/*"GROEBSOL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"GROEBSOL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"GROEBSOL" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"GROEBSOL" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LSAGG"}*/
-/*"GROEBSOL" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"GROEBSOL" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"GROEBSOL" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"}*/
-/*"GROEBSOL" -> {"LIST"; "ILIST"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"GROEBSOL" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
-/*"GROEBSOL" -> {"LINEXP"; "PATMAB"}*/
-"GROEBSOL" -> "PFECAT"
-/*"GROEBSOL" -> {"UFD"; "NNI"}*/
-"GROEBSOL" -> "DIRPCAT"
-/*"GROEBSOL" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
-/*"GROEBSOL" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
-/*"GROEBSOL" -> {"EUCDOM"; "PID"; "DIVRING"; "ORDFIN"; "SINT"; "BOOLEAN"}*/
-/*"GROEBSOL" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-
-"HDMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HDMP"]
-/*"HDMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"HDMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"HDMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"HDMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"HDMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"HDMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"HDMP" -> "PFECAT"
-/*"HDMP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"HDMP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"HDMP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-"HDMP" -> "DIRPCAT"
-/*"HDMP" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"HDMP" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"HDMP" -> {"PID"; "DIVRING"; "ORDFIN"; "FPS"; "RNS"; "REAL"; "RADCAT"}*/
-/*"HDMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"}*/
-
-"HDP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HDP"]
-"HDP" -> "DIRPCAT"
-/*"HDP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"HDP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"}*/
-/*"HDP" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"HDP" -> {"RMODULE"; "DIFEXT"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"HDP" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"}*/
-/*"HDP" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"HDP" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"HDP" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "SINT"}*/
-/*"HDP" -> {"NNI"; "INT"; "BOOLEAN"; "INS"; "OINTDOM"; "KONVERT"; "PATMAB"}*/
-/*"HDP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"HEXADEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HEXADEC"]
-/*"HEXADEC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"HEXADEC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"HEXADEC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"HEXADEC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"HEXADEC" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"}*/
-/*"HEXADEC" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"HEXADEC" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"HEXADEC" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"HEXADEC" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"HEXADEC" -> "PFECAT"
-/*"HEXADEC" -> {"INS"; "CFCAT"; "OM"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
-/*"HEXADEC" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
-
-"HEUGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=HEUGCD"]
-/*"HEUGCD" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"HEUGCD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"HEUGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"HEUGCD" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"HEUGCD" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"HEUGCD" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"HEUGCD" -> {"PATMAB"; "GCDDOM"}*/
-"HEUGCD" -> "PFECAT"
-/*"HEUGCD" -> {"UFD"; "ELTAB"}*/
-/*"HEUGCD" -> {"DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
-/*"HEUGCD" -> {"DIVRING"; "INT"; "NNI"; "BOOLEAN"; "PI"; "SINT"; "LIST"}*/
-/*"HEUGCD" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"HEUGCD" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"HEUGCD" -> {"OM"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"HEUGCD" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "LSAGG-"; "STAGG-"}*/
-/*"HEUGCD" -> {"ELAGG-"; "FLAGG-"; "OAMONS"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"HEUGCD" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"HEUGCD" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"}*/
-/*"HEUGCD" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "SETCAT-"; "RETRACT-"}*/
-/*"HEUGCD" -> "BASTYPE-"*/
-
-"HTMLFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HTMLFORM"]
-"HTMLFORM" -> "STRING"
-/*"HTMLFORM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"; "STRICAT"}*/
-/*"HTMLFORM" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"HTMLFORM" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"HTMLFORM" -> {"KONVERT"; "ORDSET"; "OM"; "RCAGG"; "BOOLEAN"; "CHAR"}*/
-/*"HTMLFORM" -> {"SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"HTMLFORM" -> {"SRAGG-"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "ELAGG"}*/
-/*"HTMLFORM" -> {"LSAGG-"; "ORDFIN"; "FINITE"; "STAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"HTMLFORM" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"HTMLFORM" -> {"SETCAT-"; "BASTYPE-"; "ELAGG-"; "URAGG-"; "INS-"; "PI"}*/
-/*"HTMLFORM" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"HTMLFORM" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"HTMLFORM" -> {"ABELMON-"; "MONOID-"; "ABELSG-"; "SGROUP-"; "RETRACT-"}*/
-
-"IBPTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IBPTOOLS"]
-/*"IBPTOOLS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IBPTOOLS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"IBPTOOLS" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"IBPTOOLS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"IBPTOOLS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"IBPTOOLS" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"IBPTOOLS" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"IBPTOOLS" -> "PFECAT"
-/*"IBPTOOLS" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"IBPTOOLS" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"; "SINT"; "NNI"; "INT"}*/
-
-"IBITS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IBITS"]
-/*"IBITS" -> {"BTAGG"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "LOGIC"}*/
-/*"IBITS" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"IBITS" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"IBITS" -> "INT"*/
-"IBITS" -> "STRING"
-/*"IBITS" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"IBITS" -> {"ISTRING"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"IBITS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IBITS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"IBITS" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"IBITS" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"}*/
-/*"IBITS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-/*"IBITS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "STRICAT"; "SRAGG"; "FINITE"}*/
-
-"ICARD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ICARD"]
-/*"ICARD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "ORDFIN"; "FINITE"}*/
-"ICARD" -> "STRING"
-/*"ICARD" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"ICARD" -> {"A1AGG-"; "ISTRING"; "PI"; "NNI"}*/
-
-"ICDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ICDEN"]
-/*"ICDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ICDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ICDEN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ICDEN" -> {"ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"ICDEN" -> {"UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"ICDEN" -> {"IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"ICDEN" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"}*/
-/*"ICDEN" -> {"ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ICDEN" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"ICDEN" -> "PFECAT"
-/*"ICDEN" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
-
-"IDECOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IDECOMP"]
-/*"IDECOMP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"IDECOMP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"IDECOMP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IDECOMP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"IDECOMP" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"IDECOMP" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"IDECOMP" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"IDECOMP" -> {"STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"IDECOMP" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"IDECOMP" -> "PFECAT"
-/*"IDECOMP" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
-/*"IDECOMP" -> {"PATAB"; "FPATMAB"; "TYPE"}*/
-"IDECOMP" -> "DIRPCAT"
-/*"IDECOMP" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "FINITE"; "OAMONS"}*/
-/*"IDECOMP" -> {"VSPACE"; "ORDFIN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"IDECOMP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"IDECOMP" -> {"ILIST"; "NNI"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"IDECOMP" -> {"FLAGG-"; "URAGG-"}*/
-
-"IFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IFF"]
-"IFF" -> "FAXF"
-/*"IFF" -> {"XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"IFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IFF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"IFF" -> {"DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
-/*"IFF" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "KONVERT"; "OAMONS"}*/
-/*"IFF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"}*/
-/*"IFF" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-
-"IIARRAY2" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IIARRAY2"]
-/*"IIARRAY2" -> {"ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"IIARRAY2" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"IIARRAY2" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "INT"}*/
-/*"IIARRAY2" -> {"PRIMARR"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"IIARRAY2" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "NNI"; "INS"; "UFD"; "GCDDOM"}*/
-/*"IIARRAY2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"IIARRAY2" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IIARRAY2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"IIARRAY2" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"IIARRAY2" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"IIARRAY2" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "A1AGG"}*/
-"IIARRAY2" -> "STRING"
-/*"IIARRAY2" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "ISTRING"}*/
-
-/* Note that ILIST has a circular self reference */
-"ILIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ILIST",
-          shape=ellipse]
-/*"ILIST" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"ILIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"ILIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"ILIST" -> {"ORDSET"; "ELAGG"; "SINT"; "NNI"; "INT"; "BOOLEAN"; "LIST"}*/
-/*"ILIST" -> {"ILIST"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-"ILIST" -> "STRING"
-/*"ILIST" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "INS"}*/
-/*"ILIST" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"ILIST" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"ILIST" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ILIST" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"ILIST" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"ILIST" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"IMATLIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IMATLIN"]
-/*"IMATLIN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"IMATLIN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IMATLIN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"IMATLIN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"IMATLIN" -> {"ENTIRER"; "UFD"; "DIVRING"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"IMATLIN" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"IMATLIN" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"; "ARR2CAT"}*/
-/*"IMATLIN" -> {"BOOLEAN"; "INT"; "SINT"; "NNI"; "LIST"; "A1AGG"; "PI"}*/
-/*"IMATLIN" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"IMATLIN" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"IMATLIN" -> "PATMAB"*/
-"IMATLIN" -> "PFECAT"
-/*"IMATLIN" -> {"DIFRING"; "DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "PATAB"}*/
-/*"IMATLIN" -> {"FPATMAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"IMATLIN" -> {"OAMON"; "OASGP"; "REAL"; "VECTCAT"; "OM"}*/
-
-"IMATQF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IMATQF"]
-/*"IMATQF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"IMATQF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"IMATQF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"IMATQF" -> {"MODULE"; "ENTIRER"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"IMATQF" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"IMATQF" -> {"CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"; "ARR2CAT"; "QFCAT"}*/
-/*"IMATQF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"IMATQF" -> {"RETRACT"; "FEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"IMATQF" -> {"FLINEXP"; "LINEXP"; "PATAB"; "FPATMAB"; "PATMAB"; "STEP"}*/
-/*"IMATQF" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"IMATQF" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"IMATQF" -> "PFECAT"
-
-"INMODGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INMODGCD"]
-/*"INMODGCD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"INMODGCD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"INMODGCD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INMODGCD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"INMODGCD" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"INMODGCD" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"INMODGCD" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"INMODGCD" -> "PFECAT"
-/*"INMODGCD" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
-/*"INMODGCD" -> {"DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"INMODGCD" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "INT"}*/
-/*"INMODGCD" -> {"LIST"; "ILIST"; "BOOLEAN"; "NNI"; "LSAGG-"; "STAGG-"}*/
-/*"INMODGCD" -> {"ELAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"INMODGCD" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"INMODGCD" -> {"FLAGG"; "ELAGG"; "OM"; "OAMONS"; "FLAGG-"; "PI"}*/
-/*"INMODGCD" -> {"MONOID-"; "ABELMON-"}*/
-
-"INNMFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INNMFACT"]
-/*"INNMFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
-/*"INNMFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"INNMFACT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"INNMFACT" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"INNMFACT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
-/*"INNMFACT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"INNMFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"INNMFACT" -> {"KONVERT"; "PATMAB"}*/
-"INNMFACT" -> "PFECAT"
-/*"INNMFACT" -> {"UFD"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"}*/
-/*"INNMFACT" -> {"SGROUP-"; "LIST"; "ILIST"; "UPOLYC"; "ELTAB"; "DIFRING"}*/
-/*"INNMFACT" -> {"DIFEXT"; "STEP"; "FIELD"; "DIVRING"; "BOOLEAN"; "LSAGG-"}*/
-/*"INNMFACT" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "SINT"; "LSAGG"; "STAGG"}*/
-/*"INNMFACT" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
-/*"INNMFACT" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ABELMON-"}*/
-/*"INNMFACT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-
-"INPSIGN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INPSIGN"]
-/*"INPSIGN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INPSIGN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INPSIGN" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"INPSIGN" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"INPSIGN" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"INPSIGN" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"INPSIGN" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"INPSIGN" -> "PFECAT"
-/*"INPSIGN" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"INPSIGN" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "INS-"}*/
-
-"INTERGB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTERGB"]
-/*"INTERGB" -> {
-/*"INTERGB" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INTERGB" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INTERGB" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INTERGB" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INTERGB" -> {"ENTIRER"; "UFD"; "DIVRING"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"INTERGB" -> {"OASGP"; "ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"INTERGB" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"INTERGB" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-"INTERGB" -> "PFECAT"
-/*"INTERGB" -> {"FFIELDC"; "FPC"; "FINITE"; "STEP"; "DIFRING"; "NNI"; "INT"}*/
-
-"INT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INT",
-          shape=ellipse]
-/*"INT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"INT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"INT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"INT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"INT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"INT" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "INT"; "NNI"; "DFLOAT"}*/
-"INT" -> "STRING"
-/*"INT" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"INT" -> {"ISTRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"INT" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"INT" -> "PFECAT"
-/*"INT" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"; "INS-"}*/
-
-"INTHERTR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTHERTR"]
-/*"INTHERTR" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INTHERTR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INTHERTR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INTHERTR" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INTHERTR" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"INTHERTR" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"INTHERTR" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"INTHERTR" -> {"KONVERT"; "PATMAB"}*/
-"INTHERTR" -> "PFECAT"
-/*"INTHERTR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"; "INT"}*/
-
-"INTRAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTRAT"]
-/*"INTRAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INTRAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INTRAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INTRAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"INTRAT" -> {"DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"INTRAT" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
-/*"INTRAT" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"INTRAT" -> "PFECAT"
-/*"INTRAT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"}*/
-/*"INTRAT" -> {"PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"INTRAT" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-
-"INTRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTRF"]
-/*"INTRF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"INTRF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INTRF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INTRF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "CHARZ"}*/
-/*"INTRF" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"INTRF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"INTRF" -> {"PATMAB"; "GCDDOM"}*/
-"INTRF" -> "PFECAT"
-/*"INTRF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-/*"INTRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
-/*"INTRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"INTRF" -> {"OAMON"; "OASGP"; "REAL"; "UPOLYC"}*/
-
-"INTSLPE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTSLPE"]
-/*"INTSLPE" -> {"INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"; "UFD"}*/
-/*"INTSLPE" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTSLPE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"INTSLPE" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"INTSLPE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"INTSLPE" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"INTSLPE" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"INTSLPE" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"INTSLPE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"INTSLPE" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"INTSLPE" -> "PFECAT"
-/*"INTSLPE" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"; "LIST"; "ILIST"}*/
-/*"INTSLPE" -> "NNI"*/
-
-"INTTR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTTR"]
-/*"INTTR" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INTTR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INTTR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INTTR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"INTTR" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"INTTR" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"INTTR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"INTTR" -> "PFECAT"
-/*"INTTR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"}*/
-/*"INTTR" -> {"PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"INTTR" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "BOOLEAN"; "NNI"; "INT"}*/
-/*"INTTR" -> {"PRIMARR"; "INS"; "CFCAT"; "LIST"; "ILIST"; "PI"; "LSAGG-"}*/
-/*"INTTR" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
-/*"INTTR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"INTTR" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
-
-"ISUMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ISUMP"]
-/*"ISUMP" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"ISUMP" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "INTDOM"}*/
-/*"ISUMP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"}*/
-/*"ISUMP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ISUMP" -> {"ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"ISUMP" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"ISUMP" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"ISUMP" -> "PFECAT"
-/*"ISUMP" -> {"UFD"; "INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"ISUMP" -> {"OAGROUP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"}*/
-/*"ISUMP" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"}*/
-/*"ISUMP" -> {"FPATMAB"; "TYPE"; "INT"; "LIST"; "BOOLEAN"; "NNI"; "ILIST"}*/
-/*"ISUMP" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-
-"LAUPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LAUPOL"]
-/*"LAUPOL" -> {"DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"LAUPOL" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"LAUPOL" -> {"LMODULE"; "DIFRING"; "PDRING"; "INTDOM"; "COMRING"}*/
-/*"LAUPOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LAUPOL" -> {"KONVERT"; "FRETRCT"; "RETRACT"; "CHARZ"; "CHARNZ"}*/
-/*"LAUPOL" -> {"EUCDOM"; "PID"; "GCDDOM"; "FIELD"; "UFD"; "DIVRING"}*/
-/*"LAUPOL" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "EVALAB"; "IEVALAB"}*/
-/*"LAUPOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "PATMAB"}*/
-"LAUPOL" -> "PFECAT"
-/*"LAUPOL" -> {"ELTAB"; "STEP"; "INT"; "BOOLEAN"; "NNI"; "LIST"; "ILIST"}*/
-/*"LAUPOL" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"LAUPOL" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"LAUPOL" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"LAUPOL" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-
-"LEADCDET" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LEADCDET"]
-/*"LEADCDET" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
-/*"LEADCDET" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
-/*"LEADCDET" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"LEADCDET" -> {"ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"LEADCDET" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
-/*"LEADCDET" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"LEADCDET" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"LEADCDET" -> {"KONVERT"; "PATMAB"}*/
-"LEADCDET" -> "PFECAT"
-/*"LEADCDET" -> {"UFD"; "SINT"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"LEADCDET" -> {"STAGG-"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"LEADCDET" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"LEADCDET" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "PI"}*/
-
-"LGROBP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LGROBP"]
-/*"LGROBP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"LGROBP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"LGROBP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"LGROBP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "VECTCAT"}*/
-/*"LGROBP" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"LGROBP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"LGROBP" -> {"ORDSET"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"}*/
-/*"LGROBP" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
-/*"LGROBP" -> {"LIST"; "ILIST"}*/
-"LGROBP" -> "DIRPCAT"
-/*"LGROBP" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"LGROBP" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"}*/
-/*"LGROBP" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
-/*"LGROBP" -> {"EUCDOM"; "PID"; "UFD"; "DIVRING"; "ORDFIN"; "PI"; "BOOLEAN"}*/
-/*"LGROBP" -> {"VECTCAT-"; "LSAGG-"; "STAGG-"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"LGROBP" -> {"CHARZ"; "CHARNZ"; "PATMAB"}*/
-"LGROBP" -> "PFECAT"
-/*"LGROBP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"}*/
-
-"LIMITRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIMITRF"]
-/*"LIMITRF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"LIMITRF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"LIMITRF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"LIMITRF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
-/*"LIMITRF" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"LIMITRF" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"LIMITRF" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
-"LIMITRF" -> "PFECAT"
-/*"LIMITRF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-/*"LIMITRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
-/*"LIMITRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"LIMITRF" -> {"OAMON"; "OASGP"; "REAL"; "INT"; "OM"; "UPOLYC"; "SINT"}*/
-/*"LIMITRF" -> "NNI"*/
-
-"LINDEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LINDEP"]
-/*"LINDEP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"LINDEP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"LINDEP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"LINDEP" -> {"MODULE"; "ENTIRER"; "LINEXP"; "INT"; "LIST"; "ILIST"}*/
-/*"LINDEP" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"LINDEP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"LINDEP" -> {"CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"LINDEP" -> {"VECTCAT-"; "A1AGG-"; "NNI"; "BOOLEAN"; "INS"; "UFD"}*/
-/*"LINDEP" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"LINDEP" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "PATMAB"}*/
-/*"LINDEP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "INS-"; "FIELD"}*/
-/*"LINDEP" -> {"DIVRING"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"LINDEP" -> {"ORDSET-"; "AGG-"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PDRING"}*/
-/*"LINDEP" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "CHARNZ"}*/
-"LINDEP" -> "PFECAT"
-
-"LISYSER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LISYSER"]
-/*"LISYSER" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"LISYSER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LISYSER" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LISYSER" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"LISYSER" -> {"DIVRING"}*/
-"LISYSER" -> "LOCPOWC"
-/*"LISYSER" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
-/*"LISYSER" -> {"DIFRING"; "PDRING"; "INT"; "LIST"; "ILIST"; "LSAGG"}*/
-/*"LISYSER" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"LISYSER" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
-/*"LISYSER" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "NNI"; "STAGG-"}*/
-
-"LO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LO"]
-/*"LO" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"LO" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "OAGROUP"}*/
-/*"LO" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "COMRING"; "RING"; "RNG"}*/
-/*"LO" -> {"SGROUP"; "MONOID"}*/
-"LO" -> "STRING"
-/*"LO" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"LO" -> {"A1AGG-"; "ISTRING"}*/
-
-"LPEFRAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LPEFRAC"]
-"LPEFRAC" -> "PFECAT"
-/*"LPEFRAC" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"LPEFRAC" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"LPEFRAC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LPEFRAC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LPEFRAC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "RETRACT"}*/
-/*"LPEFRAC" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
-/*"LPEFRAC" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"LPEFRAC" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
-/*"LPEFRAC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"}*/
-/*"LPEFRAC" -> "CHARNZ"*/
-
-"LSPP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LSPP"]
-/*"LSPP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"LSPP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"LSPP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"LSPP" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"LSPP" -> {"ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"LSPP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"LSPP" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"LSPP" -> "PFECAT"
-/*"LSPP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"LSPP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"LSPP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "VECTOR"; "IVECTOR"}*/
-/*"LSPP" -> {"IARRAY1"; "SINT"; "NNI"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
-/*"LSPP" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"}*/
-/*"LSPP" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "STEP"; "OINTDOM"}*/
-/*"LSPP" -> {"ORDRING"; "OAGROUP"; "REAL"}*/
-
-"MATLIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MATLIN"]
-/*"MATLIN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"MATLIN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"MATLIN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"MATLIN" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"MATLIN" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"; "ARR2CAT"}*/
-/*"MATLIN" -> {"BOOLEAN"; "INT"; "PRIMARR"; "LIST"; "ILIST"; "PI"; "NNI"}*/
-/*"MATLIN" -> {"A1AGG"; "SINT"; "INTDOM"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"MATLIN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"MATLIN" -> {"VECTCAT"; "QFCAT"; "RETRACT"; "FEVALAB"; "DIFEXT"}*/
-/*"MATLIN" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "FPATMAB"}*/
-/*"MATLIN" -> {"PATMAB"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"MATLIN" -> {"OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"MATLIN" -> "PFECAT"
-/*"MATLIN" -> {"INS"; "CFCAT"}*/
-
-"MCDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MCDEN"]
-/*"MCDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"MCDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MCDEN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"MCDEN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"}*/
-/*"MCDEN" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
-/*"MCDEN" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"MCDEN" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"MCDEN" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"MCDEN" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"MCDEN" -> "PFECAT"
-/*"MCDEN" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"MCDEN" -> {"AGG"; "ELTAGG"; "CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"MCDEN" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-
-"MDDFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MDDFACT"]
-/*"MDDFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MDDFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MDDFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"MDDFACT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"MDDFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"MDDFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"MDDFACT" -> {"PATMAB"; "GCDDOM"}*/
-"MDDFACT" -> "PFECAT"
-/*"MDDFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"MDDFACT" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "INS-"; "EUCDOM-"; "INS"}*/
-/*"MDDFACT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"MDDFACT" -> {"CFCAT"; "REAL"; "LIST"; "NNI"; "SINT"; "PI"; "ILIST"}*/
-
-"MFINFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MFINFACT"]
-/*"MFINFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
-/*"MFINFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"MFINFACT" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"MFINFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"MFINFACT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"MFINFACT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"MFINFACT" -> {"STEP"; "DIFRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"MFINFACT" -> {"CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"MFINFACT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-"MFINFACT" -> "PFECAT"
-/*"MFINFACT" -> {"UPOLYC"; "ELTAB"; "DIFEXT"; "INT"; "LIST"; "ILIST"}*/
-/*"MFINFACT" -> {"NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "BOOLEAN"}*/
-/*"MFINFACT" -> {"PI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"MFINFACT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
-/*"MFINFACT" -> {"ELAGG"; "OM"; "SINT"}*/
-
-"MFLOAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MFLOAT"]
-/*"MFLOAT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"MFLOAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"MFLOAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"MFLOAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"MFLOAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"MFLOAT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"MFLOAT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "FMTC"; "INS"; "OINTDOM"}*/
-/*"MFLOAT" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "INT"; "PI"; "NNI"}*/
-/*"MFLOAT" -> {"MONOID-"; "ABELSG-"; "SGROUP-"; "INS-"; "OM"; "EUCDOM-"}*/
-/*"MFLOAT" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"MFLOAT" -> "ORDRING-"*/
-"MFLOAT" -> "STRING"
-/*"MFLOAT" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"MFLOAT" -> {"ISTRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"MFLOAT" -> {"AHYP"; "ELEMFUN"; "BOOLEAN"}*/
-
-"MINT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MINT"]
-/*"MINT" -> {"FMTC"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MINT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"MINT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"MINT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"MINT" -> {"RETRACT"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"MINT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"MINT" -> {"KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"MINT" -> {"STEP"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
-"MINT" -> "STRING"
-/*"MINT" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"MINT" -> "ISTRING"*/
-
-"MLIFT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MLIFT"]
-/*"MLIFT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"MLIFT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
-/*"MLIFT" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MLIFT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"MLIFT" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"MLIFT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"MLIFT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-"MLIFT" -> "PFECAT"
-/*"MLIFT" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"MLIFT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"MLIFT" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"; "SINT"}*/
-/*"MLIFT" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "PI"}*/
-
-"MMAP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MMAP"]
-/*"MMAP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"MMAP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"MMAP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"MMAP" -> {"ENTIRER"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"MMAP" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"MMAP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"MMAP" -> "PFECAT"
-/*"MMAP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"MMAP" -> {"FIELD"; "DIVRING"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
-/*"MMAP" -> {"TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"MMAP" -> {"OASGP"; "REAL"}*/
-
-"MODMON" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MODMON"]
-/*"MODMON" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MODMON" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MODMON" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"MODMON" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"MODMON" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"MODMON" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"MODMON" -> {"PATMAB"; "GCDDOM"}*/
-"MODMON" -> "PFECAT"
-/*"MODMON" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"MODMON" -> {"PID"; "FIELD"; "DIVRING"; "FINITE"; "NNI"; "INT"; "MONOID-"}*/
-/*"MODMON" -> {"ABELMON-"; "PI"; "FFIELDC"; "FPC"; "PRIMARR"; "A1AGG-"}*/
-/*"MODMON" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
-/*"MODMON" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "BOOLEAN"}*/
-/*"MODMON" -> {"SINT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"MODMON" -> {"TYPE"; "ELTAGG"; "CLAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"MODMON" -> {"FPS"; "RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"MODMON" -> {"OASGP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
-
-"MONOTOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MONOTOOL"]
-/*"MONOTOOL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"MONOTOOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"MONOTOOL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"MONOTOOL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"MONOTOOL" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
-/*"MONOTOOL" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"MONOTOOL" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"MONOTOOL" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
-"MONOTOOL" -> "PFECAT"
-/*"MONOTOOL" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"; "INT"}*/
-
-"MPCPF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPCPF"]
-/*"MPCPF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"MPCPF" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"MPCPF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"MPCPF" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"MPCPF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
-/*"MPCPF" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"MPCPF" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"MPCPF" -> {"KONVERT"; "PATMAB"}*/
-"MPCPF" -> "PFECAT"
-/*"MPCPF" -> {"UFD"; "INT"; "OM"}*/
-
-"MPC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPC2"]
-/*"MPC2" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
-/*"MPC2" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
-/*"MPC2" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "POLYCAT"}*/
-/*"MPC2" -> {"PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"MPC2" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"MPC2" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"MPC2" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"MPC2" -> "PFECAT"
-/*"MPC2" -> {"UFD"; "NNI"; "INT"}*/
-
-"MPC3" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPC3"]
-/*"MPC3" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
-/*"MPC3" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
-/*"MPC3" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "POLYCAT"}*/
-/*"MPC3" -> {"PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"MPC3" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"MPC3" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"MPC3" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"MPC3" -> "PFECAT"
-/*"MPC3" -> {"UFD"; "BOOLEAN"}*/
-
-"MPOLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MPOLY"]
-/*"MPOLY" -> {"ORDFIN"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
-/*"MPOLY" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"MPOLY" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MPOLY" -> {"FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"}*/
-/*"MPOLY" -> {"MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"MPOLY" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"MPOLY" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"MPOLY" -> "PFECAT"
-/*"MPOLY" -> {"UFD"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-/*"MPOLY" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"MPOLY" -> {"RADCAT"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"; "STEP"}*/
-/*"MPOLY" -> {"UPOLYC"; "ELTAB"; "DIFEXT"}*/
-
-"MPRFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MPRFF"]
-/*"MPRFF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"MPRFF" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"MPRFF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"MPRFF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"MPRFF" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"MPRFF" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"MPRFF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"MPRFF" -> "PFECAT"
-/*"MPRFF" -> {"UFD"; "INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"MPRFF" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"; "FIELD"}*/
-/*"MPRFF" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"; "FPATMAB"}*/
-/*"MPRFF" -> {"TYPE"; "FFIELDC"; "FPC"; "FINITE"; "BOOLEAN"; "NNI"; "INT"}*/
-
-"MRATFAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MRATFAC"]
-/*"MRATFAC" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"MRATFAC" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"MRATFAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"MRATFAC" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"MRATFAC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
-/*"MRATFAC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"MRATFAC" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"MRATFAC" -> {"KONVERT"; "PATMAB"}*/
-"MRATFAC" -> "PFECAT"
-/*"MRATFAC" -> {"UFD"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
-/*"MRATFAC" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
-/*"MRATFAC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"; "PI"; "NNI"}*/
-/*"MRATFAC" -> {"INT"; "INS"; "CFCAT"}*/
-
-"MULTSQFR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MULTSQFR"]
-/*"MULTSQFR" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"MULTSQFR" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"MULTSQFR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"MULTSQFR" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"MULTSQFR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"}*/
-/*"MULTSQFR" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"MULTSQFR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"MULTSQFR" -> {"KONVERT"; "PATMAB"}*/
-"MULTSQFR" -> "PFECAT"
-/*"MULTSQFR" -> {"UFD"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
-/*"MULTSQFR" -> {"BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"MULTSQFR" -> {"FLAGG-"; "UPOLYC"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"MULTSQFR" -> {"FIELD"; "DIVRING"; "SINT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"MULTSQFR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
-/*"MULTSQFR" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INS-"}*/
-/*"MULTSQFR" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"MULTSQFR" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"MULTSQFR" -> "ABELMON-"*/
-
-"NORMRETR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NORMRETR"]
-/*"NORMRETR" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"NORMRETR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"NORMRETR" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"NORMRETR" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"NORMRETR" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
-/*"NORMRETR" -> {"FINITE"; "STEP"; "DIFRING"}*/
-"NORMRETR" -> "FAXF"
-/*"NORMRETR" -> {"XF"; "RETRACT"; "VSPACE"; "CHARZ"; "UPOLYC"; "POLYCAT"}*/
-/*"NORMRETR" -> {"PDRING"; "FAMR"; "AMR"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
-/*"NORMRETR" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"NORMRETR" -> "PFECAT"
-/*"NORMRETR" -> {"ELTAB"; "DIFEXT"; "SINT"; "PI"; "NNI"; "INT"; "LSAGG"}*/
-/*"NORMRETR" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"NORMRETR" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"NORMRETR" -> {"LIST"; "ILIST"; "BOOLEAN"}*/
-
-"NPCOEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NPCOEF"]
-/*"NPCOEF" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NPCOEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"NPCOEF" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"NPCOEF" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"NPCOEF" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"NPCOEF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"NPCOEF" -> {"PATMAB"; "GCDDOM"}*/
-"NPCOEF" -> "PFECAT"
-/*"NPCOEF" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"NPCOEF" -> {"FIELD"; "DIVRING"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"NPCOEF" -> {"INT"; "LIST"; "ILIST"; "SINT"; "NNI"; "VECTOR"; "LSAGG"}*/
-/*"NPCOEF" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"NPCOEF" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "BOOLEAN"}*/
-/*"NPCOEF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "PI"; "IVECTOR"}*/
-/*"NPCOEF" -> {"IARRAY1"; "VECTCAT"; "A1AGG"}*/
-
-"NSUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NSUP"]
-/*"NSUP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NSUP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"NSUP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"NSUP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"NSUP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"NSUP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"NSUP" -> "PFECAT"
-/*"NSUP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"NSUP" -> {"FIELD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"; "FPS"}*/
-/*"NSUP" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"NSUP" -> {"REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
-
-"NTPOLFN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NTPOLFN"]
-/*"NTPOLFN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NTPOLFN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NTPOLFN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "INS"; "UFD"; "GCDDOM"}*/
-/*"NTPOLFN" -> {"INTDOM"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"NTPOLFN" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"NTPOLFN" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"NTPOLFN" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"NTPOLFN" -> {"NNI"; "INT"; "BOOLEAN"; "QFCAT"; "FIELD"; "DIVRING"}*/
-/*"NTPOLFN" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"NTPOLFN" -> {"PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
-"NTPOLFN" -> "PFECAT"
-
-"ODP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODP"]
-"ODP" -> "DIRPCAT"
-/*"ODP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ODP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"}*/
-/*"ODP" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODP" -> {"RMODULE"; "DIFEXT"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"ODP" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"}*/
-/*"ODP" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ODP" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"ODP" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "INS"}*/
-/*"ODP" -> {"OINTDOM"; "KONVERT"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"ODP" -> {"STEP"; "OM"}*/
-
-"ODEPRIM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPRIM"]
-/*"ODEPRIM" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODEPRIM" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODEPRIM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ODEPRIM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ODEPRIM" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
-/*"ODEPRIM" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"ODEPRIM" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"ODEPRIM" -> {"KONVERT"; "PATMAB"}*/
-"ODEPRIM" -> "PFECAT"
-/*"ODEPRIM" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LODOCAT"; "OREPCAT"}*/
-/*"ODEPRIM" -> {"NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"ODEPRIM" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"ODEPRIM" -> {"FLAGG"; "ELAGG"; "BOOLEAN"; "LIST"; "ILIST"; "SINT"; "PI"}*/
-
-"ODEPRRIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPRRIC"]
-/*"ODEPRRIC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODEPRRIC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODEPRRIC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ODEPRRIC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ODEPRRIC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
-/*"ODEPRRIC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"ODEPRRIC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"ODEPRRIC" -> {"KONVERT"; "PATMAB"}*/
-"ODEPRRIC" -> "PFECAT"
-/*"ODEPRRIC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LODOCAT"; "OREPCAT"}*/
-/*"ODEPRRIC" -> {"SINT"; "INT"; "NNI"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"ODEPRRIC" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ODEPRRIC" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "BOOLEAN"; "PI"; "LSAGG"}*/
-/*"ODEPRRIC" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"ODEPRRIC" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OAMONS"}*/
-/*"ODEPRRIC" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"ODEPRRIC" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-
-"OMPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OMPKG"]
-"OMPKG" -> "STRING"
-/*"OMPKG" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"OMPKG" -> {"A1AGG-"; "ISTRING"; "BOOLEAN"}*/
-
-"OMSERVER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OMSERVER"]
-/*"OMSERVER" -> {"BOOLEAN"; "INT"; "DFLOAT"}*/
-"OMSERVER" -> "STRING"
-/*"OMSERVER" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-
-"PACRATC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PACRATC"]
-"PACRATC" -> "XF"
-/*"PACRATC" -> {"VSPACE"; "FPC"; "FINITE"; "PACPERC"}*/
-
-"PADEPAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PADEPAC"]
-/*"PADEPAC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PADEPAC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PADEPAC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PADEPAC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PADEPAC" -> {"ENTIRER"; "UFD"; "DIVRING"; "NNI"; "INT"; "UPOLYC"}*/
-/*"PADEPAC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"PADEPAC" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"PADEPAC" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"PADEPAC" -> "PFECAT"
-/*"PADEPAC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-
-"PADICRAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PADICRAT"]
-/*"PADICRAT" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"PADICRAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PADICRAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"PADICRAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PADICRAT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"PADICRAT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"PADICRAT" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"PADICRAT" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
-/*"PADICRAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PADICRAT" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"PADICRAT" -> "PFECAT"
-/*"PADICRAT" -> {"PADICCT"; "FPS"; "RNS"; "RADCAT"; "INS"; "CFCAT"}*/
-/*"PADICRAT" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
-
-"PADICRC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PADICRC"]
-/*"PADICRC" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"PADICRC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PADICRC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"PADICRC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PADICRC" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"PADICRC" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"PADICRC" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"PADICRC" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
-/*"PADICRC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PADICRC" -> {"OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"PADICRC" -> "PFECAT"
-/*"PADICRC" -> {"PADICCT"; "INT"; "INS"; "CFCAT"; "BOOLEAN"; "INS-"}*/
-/*"PADICRC" -> {"LIST"; "ILIST"; "SINT"; "NNI"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PADICRC" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"PADICRC" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "FPS"; "RNS"}*/
-/*"PADICRC" -> {"RADCAT"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"}*/
-
-"PARAMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PARAMP"]
-"PARAMP" -> "PFECAT"
-"PARAMP" -> "DIRPCAT"
-/*"PARAMP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "FIELD"; "EUCDOM"}*/
-/*"PARAMP" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PARAMP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PARAMP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PARAMP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"PARAMP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"PARAMP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"PARAMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "IXAGG"; "HOAGG"}*/
-/*"PARAMP" -> {"AGG"; "TYPE"; "ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"}*/
-/*"PARAMP" -> {"FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PARAMP" -> {"OAMONS"; "VSPACE"; "UPSCAT"; "PSCAT"; "INT"; "LIST"; "ILIST"}*/
-/*"PARAMP" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"}*/
-/*"PARAMP" -> {"ELAGG"; "OM"; "NNI"; "OUTFORM"; "LSAGG-"}*/
-
-"PCOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PCOMP"]
-/*"PCOMP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PCOMP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PCOMP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"PCOMP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"PCOMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"PCOMP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"PCOMP" -> {"PATMAB"; "GCDDOM"}*/
-"PCOMP" -> "PFECAT"
-/*"PCOMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"PCOMP" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"}*/
-
-"PDECOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PDECOMP"]
-/*"PDECOMP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PDECOMP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PDECOMP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"PDECOMP" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"PDECOMP" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"PDECOMP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"PDECOMP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"PDECOMP" -> "PFECAT"
-/*"PDECOMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"PDECOMP" -> {"PID"; "FIELD"; "DIVRING"; "SINT"; "NNI"; "INT"; "BOOLEAN"}*/
-/*"PDECOMP" -> "LIST"*/
-
-"PF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PF"]
-/*"PF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"PF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PF" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PF" -> {"UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"}*/
-"PF" -> "FAXF"
-/*"PF" -> {"XF"; "RETRACT"; "VSPACE"; "CHARZ"; "KONVERT"; "OAMONS"}*/
-/*"PF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"}*/
-/*"PF" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-
-"PFBR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFBR"]
-"PFBR" -> "PFECAT"
-/*"PFBR" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PFBR" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PFBR" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PFBR" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"PFBR" -> {"OASGP"; "ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"PFBR" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PFBR" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "INT"; "PI"; "NNI"}*/
-/*"PFBR" -> {"LIST"; "ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PFBR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"PFBR" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "UPOLYC"; "DIFRING"}*/
-/*"PFBR" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-/*"PFBR" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FFIELDC"; "FPC"; "FINITE"}*/
-
-"PFBRU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFBRU"]
-"PFBRU" -> "PFECAT"
-/*"PFBRU" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PFBRU" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PFBRU" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PFBRU" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"}*/
-/*"PFBRU" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"PFBRU" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"PFBRU" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "ELTAB"; "DIFRING"}*/
-/*"PFBRU" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"; "NNI"}*/
-/*"PFBRU" -> {"INT"; "SINT"; "PI"; "LIST"; "ILIST"; "BOOLEAN"; "LSAGG"}*/
-/*"PFBRU" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"PFBRU" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"}*/
-/*"PFBRU" -> {"STAGG-"; "ELAGG-"}*/
-
-"PFORP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFORP"]
-/*"PFORP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PFORP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"PFORP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"PFORP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"PFORP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-"PFORP" -> "DIRPCAT"
-/*"PFORP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"PFORP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"PFORP" -> {"FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PFORP" -> {"ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"PFORP" -> {"GCDDOM"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-/*"PFORP" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"PFORP" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"PFORP" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PFORP" -> {"RCAGG"; "LNAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"PFORP" -> {"VECTOR"; "SINT"; "PI"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
-/*"PFORP" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
-
-"PFOTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFOTOOLS"]
-/*"PFOTOOLS" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PFOTOOLS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PFOTOOLS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"PFOTOOLS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"PFOTOOLS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"PFOTOOLS" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"PFOTOOLS" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"PFOTOOLS" -> "PFECAT"
-/*"PFOTOOLS" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"PFOTOOLS" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "INS-"; "EUCDOM-"}*/
-/*"PFOTOOLS" -> {"UFD-"; "GCDDOM-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PFOTOOLS" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "QFCAT"}*/
-/*"PFOTOOLS" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OM"}*/
-
-"PFRPAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFRPAC"]
-/*"PFRPAC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PFRPAC" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PFRPAC" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PFRPAC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PFRPAC" -> {"CHARZ"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"PFRPAC" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"PFRPAC" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"PFRPAC" -> "PFECAT"
-/*"PFRPAC" -> {"UFD"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
-/*"PFRPAC" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
-/*"PFRPAC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PFRPAC" -> {"REAL"; "UPOLYC"}*/
-
-"PGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PGCD"]
-/*"PGCD" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"PGCD" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
-/*"PGCD" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PGCD" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"PGCD" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PGCD" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-"PGCD" -> "PFECAT"
-/*"PGCD" -> {"UFD"; "PI"; "NNI"; "INT"; "MONOID-"; "ABELSG-"; "SGROUP-"}*/
-/*"PGCD" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"PGCD" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"PGCD" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "INS-"; "EUCDOM-"}*/
-/*"PGCD" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"PGCD" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-/*"PGCD" -> {"SINT"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "UPOLYC"}*/
-/*"PGCD" -> {"DIFRING"; "DIFEXT"; "STEP"; "FIELD"; "DIVRING"}*/
-
-"PINTERPA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PINTERPA"]
-/*"PINTERPA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PINTERPA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PINTERPA" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PINTERPA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PINTERPA" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"PINTERPA" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"PINTERPA" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"PINTERPA" -> {"KONVERT"; "PATMAB"}*/
-"PINTERPA" -> "PFECAT"
-/*"PINTERPA" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"; "STAGG"}*/
-/*"PINTERPA" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"PINTERPA" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"PINTERPA" -> {"INT"; "LIST"; "ILIST"; "NNI"; "SINT"; "BOOLEAN"}*/
-
-"PLEQN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PLEQN"]
-/*"PLEQN" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PLEQN" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PLEQN" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PLEQN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "ORDSET"}*/
-/*"PLEQN" -> {"KONVERT"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "POLYCAT"}*/
-/*"PLEQN" -> {"PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"PLEQN" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-"PLEQN" -> "PFECAT"
-/*"PLEQN" -> {"UFD"; "BOOLEAN"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"}*/
-/*"PLEQN" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"PLEQN" -> {"STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"; "NNI"}*/
-/*"PLEQN" -> {"INT"; "INS"; "CFCAT"; "OM"; "LIST"; "VECTOR"; "IVECTOR"}*/
-/*"PLEQN" -> {"IARRAY1"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"PLEQN" -> {"HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "SINT"; "ILIST"; "LSAGG-"}*/
-/*"PLEQN" -> {"STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"}*/
-/*"PLEQN" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"PLEQN" -> "PI"*/
-
-"PMPLCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPLCAT"]
-/*"PLPKCRV" -> {"SETCATD"; "PRSPCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PLPKCRV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PLPKCRV" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"PLPKCRV" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PLPKCRV" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "FAMR"; "AMR"}*/
-/*"PLPKCRV" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-"PLPKCRV" -> "DIRPCAT"
-/*"PLPKCRV" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PLPKCRV" -> {"ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"}*/
-/*"PLPKCRV" -> {"LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"PLPKCRV" -> {"OAMON"; "OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "BOOLEAN"}*/
-/*"PLPKCRV" -> {"NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"PLPKCRV" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
-/*"PLPKCRV" -> {"ILIST"; "LSAGG-"}*/
-
-"PMPLCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPLCAT"]
-/*"PMPLCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"PMPLCAT" -> {"OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"; "RING"}*/
-/*"PMPLCAT" -> {"RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "PATMAB"}*/
-/*"PMPLCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"PMPLCAT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"PMPLCAT" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PMPLCAT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "GCDDOM"}*/
-"PMPLCAT" -> "PFECAT"
-/*"PMPLCAT" -> {"UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"PMPLCAT" -> {"ELAGG-"; "FLAGG-"; "URAGG-"}*/
-
-"PMQFCAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMQFCAT"]
-/*"PMQFCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PMQFCAT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"PMQFCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PMQFCAT" -> {"MODULE"; "ENTIRER"; "PATMAB"; "KONVERT"; "QFCAT"; "FIELD"}*/
-/*"PMQFCAT" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"PMQFCAT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"PMQFCAT" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"PMQFCAT" -> {"FPATMAB"; "TYPE"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
-/*"PMQFCAT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"}*/
-/*"PMQFCAT" -> "CHARNZ"*/
-"PMQFCAT" -> "PFECAT"
-
-"PNTHEORY" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PNTHEORY"]
-/*"PNTHEORY" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PNTHEORY" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PNTHEORY" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PNTHEORY" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PNTHEORY" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PNTHEORY" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"PNTHEORY" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"PNTHEORY" -> {"REAL"; "CHARZ"; "STEP"; "INT"; "NNI"; "QFCAT"; "FIELD"}*/
-/*"PNTHEORY" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
-/*"PNTHEORY" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"PNTHEORY" -> {"TYPE"; "CHARNZ"}*/
-"PNTHEORY" -> "PFECAT"
-/*"PNTHEORY" -> {"BOOLEAN"; "OM"; "PI"; "SINT"; "INS-"; "EUCDOM-"}*/
-/*"PNTHEORY" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"PNTHEORY" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-/*"PNTHEORY" -> {"MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
-
-"POLTOPOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLTOPOL"]
-/*"POLTOPOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"POLTOPOL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"POLTOPOL" -> {"LMODULE"; "ORDFIN"; "ORDSET"; "FINITE"; "LSAGG"}*/
-/*"POLTOPOL" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"POLTOPOL" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"POLTOPOL" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"POLTOPOL" -> "ILIST"*/
-"POLTOPOL" -> "DIRPCAT"
-/*"POLTOPOL" -> {"FRETRCT"; "RETRACT"; "BMODULE"; "RMODULE"; "DIFEXT"}*/
-/*"POLTOPOL" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "ALGEBRA"}*/
-/*"POLTOPOL" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"POLTOPOL" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"POLTOPOL" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"POLUTIL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLUTIL"]
-/*"POLUTIL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"POLUTIL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"POLUTIL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"POLUTIL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"POLUTIL" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"POLUTIL" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"POLUTIL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"POLUTIL" -> {"KONVERT"; "PATMAB"}*/
-"POLUTIL" -> "PFECAT"
-/*"POLUTIL" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "BOOLEAN"; "INT"}*/
-/*"POLUTIL" -> {"LIST"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"POLUTIL" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
-/*"POLUTIL" -> {"ELAGG"; "OM"; "ILIST"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"POLUTIL" -> {"OAMON"; "OASGP"; "LSAGG-"; "STAGG-"}*/
-
-"POLYCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=POLYCAT",
-          shape=ellipse]
-/*"POLYCAT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
-/*"POLYCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"POLYCAT" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"POLYCAT" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"POLYCAT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"POLYCAT" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"POLYCAT" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"POLYCAT" -> "PFECAT"
-/*"POLYCAT" -> {"UFD"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "NNI"; "LSAGG"}*/
-/*"POLYCAT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"POLYCAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"POLYCAT" -> {"OM"; "LSAGG-"; "STAGG-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"POLYCAT" -> {"INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"POLYCAT" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "VECTCAT"; "A1AGG"}*/
-/*"POLYCAT" -> {"VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
-/*"POLYCAT" -> {"UPOLYC"; "DIFEXT"; "FIELD"; "DIVRING"; "FPS"; "RNS"}*/
-/*"POLYCAT" -> {"RADCAT"; "SEXCAT"}*/
-
-"POLYCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=POLYCAT",
-          shape=ellipse]
-/*"POLYCAT-" -> {"ORDSET";  "SETCAT";  "BASTYPE";  "KOERCE";  "OAMONS"}*/
-/*"POLYCAT-" -> {"OCAMON";  "OAMON";  "OASGP";  "ABELMON";  "ABELSG"}*/
-/*"POLYCAT-" -> {"CABMON";  "POLYCAT";  "PDRING";  "RING";  "RNG"}*/
-/*"POLYCAT-" -> {"ABELGRP";  "SGROUP";  "MONOID";  "LMODULE";  "FAMR"}*/
-/*"POLYCAT-" -> {"AMR";  "BMODULE";  "RMODULE";  "COMRING";  "ALGEBRA"}*/
-/*"POLYCAT-" -> {"MODULE";  "CHARZ";  "CHARNZ";  "INTDOM";  "ENTIRER"}*/
-/*"POLYCAT-" -> {"FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP"}*/
-/*"POLYCAT-" -> {"LINEXP";  "KONVERT";  "PATMAB";  "GCDDOM"}*/
-"POLYCAT-" -> "PFECAT"
-/*"POLYCAT-" -> {"UFD";  "INT";  "LIST";  "ILIST";  "BOOLEAN";  "NNI"}*/
-/*"POLYCAT-" -> {"LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "HOAGG";  "AGG"}*/
-/*"POLYCAT-" -> {"TYPE";  "LNAGG";  "IXAGG";  "ELTAGG";  "ELTAB";  "CLAGG"}*/
-/*"POLYCAT-" -> {"FLAGG";  "ELAGG";  "OM";  "LSAGG-";  "STAGG-";  "VECTOR"}*/
-/*"POLYCAT-" -> {"IVECTOR";  "IARRAY1";  "INS";  "EUCDOM";  "PID"}*/
-/*"POLYCAT-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "DIFRING";  "CFCAT"}*/
-/*"POLYCAT-" -> {"REAL";  "STEP";  "VECTCAT";  "A1AGG";  "VECTCAT-"}*/
-/*"POLYCAT-" -> {"A1AGG-";  "FLAGG-";  "LNAGG-";  "IXAGG-";  "UPOLYC"}*/
-/*"POLYCAT-" -> {"DIFEXT";  "FIELD";  "DIVRING";  "FPS";  "RNS";  "RADCAT"}*/
-/*"POLYCAT-" -> "SEXCAT"*/
-
-/* Note that this depends on POLYCAT in this layer but POLYCAT is */
-/* part of the layer0 clique and thus guaranteed to be compiled. */
-"POLYCATQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYCATQ"]
-/*"POLYCATQ" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"POLYCATQ" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"POLYCATQ" -> {"RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"POLYCATQ" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"POLYCATQ" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"POLYCATQ" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"POLYCATQ" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"POLYCATQ" -> "GCDDOM"*/
-"POLYCATQ" -> "PFECAT"
-/*"POLYCATQ" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "UPOLYC"}*/
-/*"POLYCATQ" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LIST"}*/
-/*"POLYCATQ" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-
-"POLYLIFT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYLIFT"]
-/*"POLYLIFT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"POLYLIFT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"POLYLIFT" -> {"RING"; "RNG"; "ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"POLYLIFT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"POLYLIFT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"POLYLIFT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"POLYLIFT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"POLYLIFT" -> "GCDDOM"*/
-"POLYLIFT" -> "PFECAT"
-/*"POLYLIFT" -> {"UFD"; "BOOLEAN"}*/
-
-"POLYROOT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLYROOT"]
-/*"POLYROOT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"POLYROOT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"POLYROOT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"POLYROOT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"POLYROOT" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"POLYROOT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"POLYROOT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"POLYROOT" -> "GCDDOM"*/
-"POLYROOT" -> "PFECAT"
-/*"POLYROOT" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "INT"; "NNI"}*/
-/*"POLYROOT" -> {"INS-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "DIFRING"}*/
-/*"POLYROOT" -> {"CFCAT"; "REAL"; "STEP"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-
-"POLY2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLY2"]
-/*"POLY2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"POLY2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"POLY2" -> {"LMODULE"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"POLY2" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"POLY2" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"POLY2" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"POLY2" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"POLY2" -> "PFECAT"
-/*"POLY2" -> "UFD"*/
-
-"POLY2UP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=POLY2UP"]
-/*"POLY2UP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"POLY2UP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"POLY2UP" -> {"LMODULE"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"POLY2UP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"POLY2UP" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"POLY2UP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"POLY2UP" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"POLY2UP" -> "PFECAT"
-/*"POLY2UP" -> "UFD"*/
-
-"PRS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRS"]
-/*"PRS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PRS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"PRS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PRS" -> {"ENTIRER"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"PRS" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PRS" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"PRS" -> "PFECAT"
-/*"PRS" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"PRS" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "VECTOR"; "IVECTOR"}*/
-/*"PRS" -> {"IARRAY1"; "VECTCAT-"; "BOOLEAN"; "PI"; "MONOID-"; "ABELMON-"}*/
-/*"PRS" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"PRS" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "FINITE"; "A1AGG-"; "LIST"}*/
-/*"PRS" -> {"ILIST"; "LSAGG-"; "STAGG-"}*/
-
-"PSQFR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PSQFR"]
-/*"PSQFR" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
-/*"PSQFR" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "GCDDOM"}*/
-/*"PSQFR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"PSQFR" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PSQFR" -> {"MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"PSQFR" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PSQFR" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-"PSQFR" -> "PFECAT"
-/*"PSQFR" -> {"UFD"; "INT"; "LIST"; "ILIST"; "BOOLEAN"; "UPOLYC"; "ELTAB"}*/
-/*"PSQFR" -> {"DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
-/*"PSQFR" -> {"DIVRING"; "NNI"}*/
-
-"PUSHVAR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PUSHVAR"]
-/*"PUSHVAR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PUSHVAR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"PUSHVAR" -> {"LMODULE"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"PUSHVAR" -> {"ORDSET"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"PUSHVAR" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"PUSHVAR" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"PUSHVAR" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
-/*"PUSHVAR" -> {"PATMAB"; "GCDDOM"}*/
-"PUSHVAR" -> "PFECAT"
-/*"PUSHVAR" -> {"UFD"; "NNI"; "INT"; "BOOLEAN"}*/
-
-"QALGSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QALGSET"]
-/*"QALGSET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "GCDDOM"; "INTDOM"}*/
-/*"QALGSET" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"QALGSET" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"QALGSET" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"QALGSET" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "POLYCAT"; "PDRING"}*/
-/*"QALGSET" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"QALGSET" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
-/*"QALGSET" -> "PATMAB"*/
-"QALGSET" -> "PFECAT"
-/*"QALGSET" -> {"UFD"; "EUCDOM"; "PID"; "INT"; "LIST"; "LSAGG"; "STAGG"}*/
-/*"QALGSET" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"QALGSET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"QALGSET" -> {"OM"; "ILIST"; "NNI"; "BOOLEAN"; "LSAGG-"; "STAGG-"}*/
-/*"QALGSET" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"QALGSET" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"QALGSET" -> {"SETCAT-"; "BASTYPE-"}*/
-
-"QFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=QFCAT",
-          shape=ellipse]
-/*"QFCAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"QFCAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"QFCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"QFCAT" -> {"MODULE"; "ENTIRER"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"QFCAT" -> {"UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"QFCAT" -> {"IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"}*/
-/*"QFCAT" -> {"LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
-/*"QFCAT" -> {"STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"QFCAT" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"QFCAT" -> "PFECAT"
-/*"QFCAT" -> {"DFLOAT"; "INS"; "CFCAT"; "FPS"; "RNS"; "RADCAT"; "INT"}*/
-
-"QFCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QFCAT",
-          shape=ellipse]
-/*"QFCAT-" -> {"INTDOM";  "COMRING";  "RING";  "RNG";  "ABELGRP"}*/
-/*"QFCAT-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
-/*"QFCAT-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
-/*"QFCAT-" -> {"RMODULE";  "ALGEBRA";  "MODULE";  "ENTIRER";  "FIELD"}*/
-/*"QFCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "UFD";  "DIVRING";  "RETRACT"}*/
-/*"QFCAT-" -> {"FEVALAB";  "ELTAB";  "EVALAB";  "IEVALAB";  "DIFEXT"}*/
-/*"QFCAT-" -> {"DIFRING";  "PDRING";  "FLINEXP";  "LINEXP";  "PATAB"}*/
-/*"QFCAT-" -> {"KONVERT";  "FPATMAB";  "TYPE";  "PATMAB";  "STEP"}*/
-/*"QFCAT-" -> {"ORDSET";  "OINTDOM";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
-/*"QFCAT-" -> {"OAMON";  "OASGP";  "REAL";  "CHARZ";  "CHARNZ"}*/
-"QFCAT-" -> "PFECAT"
-/*"QFCAT-" -> {"DFLOAT";  "INS";  "CFCAT";  "FPS";  "RNS";  "RADCAT";  "INT"}*/
-
-/* Note that QFCAT2 depends on QFCAT in the same layer but QFCAT is */
-/* part of the bootstrap clique so it is guaranteed to be compiled */
-"QFCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QFCAT2"]
-/*"QFCAT2" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"QFCAT2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"QFCAT2" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"QFCAT2" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "QFCAT"; "FIELD"}*/
-/*"QFCAT2" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"QFCAT2" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
-/*"QFCAT2" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"QFCAT2" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
-/*"QFCAT2" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"}*/
-/*"QFCAT2" -> "CHARNZ"*/
-"QFCAT2" -> "PFECAT"
-
-"RADIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RADIX"]
-/*"RADIX" -> {"QFCAT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"RADIX" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"RADIX" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"RADIX" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"RADIX" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
-/*"RADIX" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"RADIX" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"RADIX" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"RADIX" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"RADIX" -> "PFECAT"
-/*"RADIX" -> {"INS"; "CFCAT"; "INT"; "NNI"; "LIST"; "OM"; "ILIST"}*/
-/*"RADIX" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"RADIX" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"RADIX" -> "PI"*/
-"RADIX" -> "STRING"
-/*"RADIX" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"RADIX" -> {"FPS"; "RNS"; "RADCAT"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"RADIX" -> "FRETRCT"*/
-
-"RATFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RATFACT"]
-/*"RATFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"RATFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RATFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"RATFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"RATFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"RATFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"RATFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"RATFACT" -> "PFECAT"
-/*"RATFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"RATFACT" -> {"PID"; "FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"RATFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"RATFACT" -> {"INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "QFCAT"}*/
-/*"RATFACT" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "BOOLEAN"}*/
-
-"RCFIELD" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RCFIELD"]
-/*"RCFIELD" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"RCFIELD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"RCFIELD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RCFIELD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"RCFIELD" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"RCFIELD" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"RCFIELD" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"RCFIELD" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"RCFIELD" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"RCFIELD" -> {"TYPE"; "CHARNZ"}*/
-"RCFIELD" -> "PFECAT"
-/*"RCFIELD" -> {"FRETRCT"; "RADCAT"; "NNI"; "INT"; "LSAGG"; "STAGG"}*/
-/*"RCFIELD" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"RCFIELD" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
-/*"RCFIELD" -> {"ILIST"; "LSAGG-"; "STAGG-"; "PI"}*/
-
-"RCFIELD-" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RCFIELD"]
-/*"RCFIELD-" -> {"INS";  "UFD";  "GCDDOM";  "INTDOM";  "COMRING";  "RING"}*/
-/*"RCFIELD-" -> {"RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
-/*"RCFIELD-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP";  "MONOID"}*/
-/*"RCFIELD-" -> {"LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
-/*"RCFIELD-" -> {"ENTIRER";  "EUCDOM";  "PID";  "OINTDOM";  "ORDRING"}*/
-/*"RCFIELD-" -> {"OAGROUP";  "OCAMON";  "OAMON";  "OASGP";  "ORDSET"}*/
-/*"RCFIELD-" -> {"DIFRING";  "KONVERT";  "RETRACT";  "LINEXP";  "PATMAB"}*/
-/*"RCFIELD-" -> {"CFCAT";  "REAL";  "CHARZ";  "STEP";  "QFCAT";  "FIELD"}*/
-/*"RCFIELD-" -> {"DIVRING";  "FEVALAB";  "ELTAB";  "EVALAB";  "IEVALAB"}*/
-/*"RCFIELD-" -> {"DIFEXT";  "PDRING";  "FLINEXP";  "PATAB";  "FPATMAB"}*/
-/*"RCFIELD-" -> {"TYPE";  "CHARNZ"}*/
-"RCFIELD-" -> "PFECAT"
-/*"RCFIELD-" -> {"FRETRCT";  "RADCAT";  "NNI";  "INT";  "LSAGG";  "STAGG"}*/
-/*"RCFIELD-" -> {"URAGG";  "RCAGG";  "HOAGG";  "AGG";  "LNAGG";  "IXAGG"}*/
-/*"RCFIELD-" -> {"ELTAGG";  "CLAGG";  "FLAGG";  "ELAGG";  "OM";  "LIST"}*/
-/*"RCFIELD-" -> {"ILIST";  "LSAGG-";  "STAGG-";  "PI"}*/
-
-"RDETR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDETR"]
-/*"RDETR" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"RDETR" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RDETR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"RDETR" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"RDETR" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
-/*"RDETR" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"RDETR" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"RDETR" -> {"KONVERT"; "PATMAB"}*/
-"RDETR" -> "PFECAT"
-/*"RDETR" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "BOOLEAN"; "NNI"}*/
-/*"RDETR" -> {"INT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"RDETR" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-
-"RDETRS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDETRS"]
-/*"RDETRS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"RDETRS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RDETRS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RDETRS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"RDETRS" -> {"DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"RDETRS" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"}*/
-/*"RDETRS" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-"RDETRS" -> "PFECAT"
-/*"RDETRS" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LIST"}*/
-/*"RDETRS" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"RDETRS" -> {"VECTOR"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"RDETRS" -> {"HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "IVECTOR"}*/
-/*"RDETRS" -> {"IARRAY1"; "PI"; "NNI"}*/
-
-"REAL0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REAL0"]
-/*"REAL0" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"REAL0" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"REAL0" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"REAL0" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"REAL0" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"REAL0" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"REAL0" -> {"PATMAB"; "GCDDOM"}*/
-"REAL0" -> "PFECAT"
-/*"REAL0" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"REAL0" -> {"PID"; "FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"REAL0" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"REAL0" -> {"INT"; "OM"; "NNI"; "LIST"; "ILIST"; "PI"; "BOOLEAN"}*/
-/*"REAL0" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"REAL0" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"REAL0" -> {"ABELMON-"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"}*/
-/*"REAL0" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"REAL0" -> {"ELTAGG"; "CLAGG"}*/
-
-"REAL0Q" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REAL0Q"]
-/*"REAL0Q" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"REAL0Q" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"REAL0Q" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"REAL0Q" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"REAL0Q" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"REAL0Q" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"REAL0Q" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"REAL0Q" -> "PFECAT"
-/*"REAL0Q" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"REAL0Q" -> {"PID"; "FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"REAL0Q" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"REAL0Q" -> {"INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "QFCAT"}*/
-/*"REAL0Q" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-
-"REALSOLV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REALSOLV"]
-/*"REALSOLV" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"REALSOLV" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"REALSOLV" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"REALSOLV" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"REALSOLV" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"REALSOLV" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"REALSOLV" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"REALSOLV" -> {"REAL"; "CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"REALSOLV" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-"REALSOLV" -> "PFECAT"
-/*"REALSOLV" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
-/*"REALSOLV" -> {"PATAB"; "FPATMAB"; "TYPE"; "FPS"; "RNS"; "RADCAT"}*/
-
-"RESRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RESRING"]
-/*"RESRING" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"RESRING" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RESRING" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"RESRING" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"RESRING" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"RESRING" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"RESRING" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"RESRING" -> "PFECAT"
-/*"RESRING" -> {"UFD"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "OAMONS"}*/
-/*"RESRING" -> {"OCAMON"; "OAMON"; "OASGP"; "INT"; "LIST"; "ILIST"}*/
-
-"RETSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RETSOL"]
-/*"RETSOL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"RETSOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RETSOL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"RETSOL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "POLYCAT"}*/
-/*"RETSOL" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"RETSOL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"RETSOL" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"RETSOL" -> "PFECAT"
-/*"RETSOL" -> {"UFD"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
-
-"RF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RF"]
-/*"RF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"RF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"RF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"RF" -> {"ENTIRER"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"RF" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"RF" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"RF" -> "PFECAT"
-/*"RF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"}*/
-/*"RF" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"RF" -> {"STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"RF" -> {"OASGP"; "REAL"; "UPOLYC"}*/
-
-"RFFACTOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFFACTOR"]
-/*"RFFACTOR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"RFFACTOR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"RFFACTOR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RFFACTOR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"RFFACTOR" -> {"INS"; "UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"RFFACTOR" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"RFFACTOR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"RFFACTOR" -> {"STEP"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
-/*"RFFACTOR" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"}*/
-/*"RFFACTOR" -> {"PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
-"RFFACTOR" -> "PFECAT"
-/*"RFFACTOR" -> {"POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "FFIELDC"; "FPC"}*/
-/*"RFFACTOR" -> "FINITE"*/
-
-"RINTERP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RINTERP"]
-/*"RINTERP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"RINTERP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RINTERP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"RINTERP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"RINTERP" -> {"ENTIRER"; "UFD"; "DIVRING"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"RINTERP" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"RINTERP" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"RINTERP" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-/*"RINTERP" -> {"NNI"; "SINT"; "LSAGG-"; "STAGG-"; "POLYCAT"; "PDRING"}*/
-/*"RINTERP" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"RINTERP" -> {"FLINEXP"; "LINEXP"; "PATMAB"}*/
-"RINTERP" -> "PFECAT" 
-/*"RINTERP" -> {"PI"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
-/*"RINTERP" -> {"ABELSG-"; "SETCAT-"; "BASTYPE-"; "VECTOR"; "IVECTOR"}*/
-/*"RINTERP" -> "IARRAY1"*/
-
-"RMATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RMATCAT"]
-/*"RMATCAT" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"RMATCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"}*/
-/*"RMATCAT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "MODULE"}*/
-/*"RMATCAT" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-"RMATCAT" -> "DIRPCAT"
-/*"RMATCAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"; "DIFEXT"}*/
-/*"RMATCAT" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"}*/
-/*"RMATCAT" -> {"ALGEBRA"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"RMATCAT" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"RMATCAT" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"RMATCAT" -> {"NNI"; "INT"; "BOOLEAN"; "SINT"}*/
-
-"RMATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RMATCAT"]
-/*"RMATCAT-" -> {"BMODULE";  "LMODULE";  "ABELGRP";  "CABMON";  "ABELMON"}*/
-/*"RMATCAT-" -> {"ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE";  "RMODULE"}*/
-/*"RMATCAT-" -> {"HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB";  "MODULE"}*/
-/*"RMATCAT-" -> {"COMRING";  "RING";  "RNG";  "SGROUP";  "MONOID"}*/
-"RMATCAT-" -> "DIRPCAT"
-/*"RMATCAT-" -> {"IXAGG";  "ELTAGG";  "ELTAB";  "FRETRCT";  "RETRACT"}*/
-/*"RMATCAT-" -> {"DIFEXT";  "DIFRING";  "PDRING";  "FLINEXP";  "LINEXP"}*/
-/*"RMATCAT-" -> {"FINITE";  "ALGEBRA";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
-/*"RMATCAT-" -> {"OAMON";  "OASGP";  "ORDSET";  "OAMONS";  "VSPACE"}*/
-/*"RMATCAT-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
-/*"RMATCAT-" -> {"ENTIRER";  "UFD";  "DIVRING";  "NNI";  "INT";  "BOOLEAN"}*/
-/*"RMATCAT-" -> "SINT"*/
-
-"RRCC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RRCC"]
-/*"RRCC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"RRCC" -> {"OAMON"; "OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"RRCC" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RRCC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"RRCC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"RRCC" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"RRCC" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"RRCC" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-"RRCC" -> "PFECAT"
-/*"RRCC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LSAGG"; "STAGG"}*/
-/*"RRCC" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
-/*"RRCC" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
-/*"RRCC" -> {"NNI"; "LSAGG-"; "STAGG-"}*/
-
-"RRCC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RRCC"]
-/*"RRCC-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "ORDRING";  "OAGROUP"}*/
-/*"RRCC-" -> {"OCAMON";  "OAMON";  "OASGP";  "ORDSET";  "ABELMON";  "ABELSG"}*/
-/*"RRCC-" -> {"CABMON";  "ABELGRP";  "RING";  "RNG";  "SGROUP";  "MONOID"}*/
-/*"RRCC-" -> {"LMODULE";  "FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
-/*"RRCC-" -> {"COMRING";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
-/*"RRCC-" -> {"ENTIRER";  "UFD";  "DIVRING";  "UPOLYC";  "POLYCAT"}*/
-/*"RRCC-" -> {"PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ";  "FRETRCT"}*/
-/*"RRCC-" -> {"RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP";  "LINEXP"}*/
-/*"RRCC-" -> {"KONVERT";  "PATMAB"}*/
-"RRCC-" -> "PFECAT"
-/*"RRCC-" -> {"ELTAB";  "DIFRING";  "DIFEXT";  "STEP";  "INT";  "LSAGG"}*/
-/*"RRCC-" -> {"STAGG";  "URAGG";  "RCAGG";  "HOAGG";  "AGG";  "TYPE"}*/
-/*"RRCC-" -> {"LNAGG";  "IXAGG";  "ELTAGG";  "CLAGG";  "FLAGG";  "ELAGG"}*/
-/*"RRCC-" -> {"OM";  "LIST";  "ILIST";  "NNI";  "LSAGG-";  "STAGG-"}*/
-
-"SCPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SCPKG"]
-/*"SCPKG" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"SCPKG" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SCPKG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"SCPKG" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"SCPKG" -> {"DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"SCPKG" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"SCPKG" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
-/*"SCPKG" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "VECTOR"}*/
-/*"SCPKG" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "INS"; "OINTDOM"}*/
-/*"SCPKG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"SCPKG" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"SCPKG" -> {"STEP"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"SCPKG" -> {"NNI"; "SINT"; "VECTCAT"; "A1AGG"; "POLYCAT"; "PDRING"}*/
-/*"SCPKG" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
-"SCPKG" -> "PFECAT"
-/*"SCPKG" -> {"BOOLEAN"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PATAB"; "FPATMAB"}*/
-
-"SHDP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SHDP"]
-"SHDP" -> "DIRPCAT"
-/*"SHDP" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SHDP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"}*/
-/*"SHDP" -> {"BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SHDP" -> {"RMODULE"; "DIFEXT"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"SHDP" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"; "ALGEBRA"}*/
-/*"SHDP" -> {"MODULE"; "COMRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"SHDP" -> {"OASGP"; "ORDSET"; "OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"}*/
-/*"SHDP" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"SHDP" -> {"BOOLEAN"; "NNI"; "INT"; "SINT"; "INS"; "OINTDOM"; "KONVERT"}*/
-/*"SHDP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"SHP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SHP"]
-/*"SHP" -> {"OINTDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SHP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SHP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"SHP" -> {"MODULE"; "ENTIRER"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"SHP" -> {"OASGP"; "ORDSET"; "NNI"; "INT"; "LIST"; "PI"; "ILIST"}*/
-/*"SHP" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "SINT"}*/
-/*"SHP" -> {"BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"SHP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"SHP" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "INS"}*/
-/*"SHP" -> {"UFD"; "GCDDOM"; "EUCDOM"; "PID"; "DIFRING"; "RETRACT"}*/
-/*"SHP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "UPOLYC"}*/
-/*"SHP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"SHP" -> "FLINEXP"*/
-"SHP" -> "PFECAT"
-/*"SHP" -> {"DIFEXT"; "FIELD"; "DIVRING"}*/
-
-"SIGNRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SIGNRF"]
-/*"SIGNRF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SIGNRF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SIGNRF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SIGNRF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"}*/
-/*"SIGNRF" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"SIGNRF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"SIGNRF" -> {"KONVERT"; "PATMAB"}*/
-"SIGNRF" -> "PFECAT"
-/*"SIGNRF" -> {"UFD"; "INT"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-/*"SIGNRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
-/*"SIGNRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"SIGNRF" -> {"OAMON"; "OASGP"; "REAL"; "UPOLYC"; "LIST"; "ILIST"}*/
-
-"SMITH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SMITH"]
-/*"SMITH" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"SMITH" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"SMITH" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"SMITH" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "FLAGG"; "LNAGG"}*/
-/*"SMITH" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"SMITH" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "MATCAT"}*/
-/*"SMITH" -> {"ARR2CAT"; "NNI"; "INT"; "SINT"; "BOOLEAN"; "PI"; "QFCAT"}*/
-/*"SMITH" -> {"FIELD"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"; "DIFEXT"}*/
-/*"SMITH" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "FPATMAB"}*/
-/*"SMITH" -> {"PATMAB"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"SMITH" -> {"OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"SMITH" -> "PFECAT"
-/*"SMITH" -> {"VECTCAT"; "A1AGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"}*/
-
-"SMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SMP"]
-/*"SMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"SMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"SMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"SMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"SMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"SMP" -> "PFECAT"
-/*"SMP" -> {"UFD"; "BOOLEAN"; "NNI"; "INT"; "PI"; "LSAGG"; "STAGG"}*/
-/*"SMP" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
-/*"SMP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
-/*"SMP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"SMP" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
-/*"SMP" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "FIELD"; "EUCDOM"}*/
-/*"SMP" -> {"PID"; "DIVRING"; "FPS"; "RNS"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"SMP" -> {"OAMON"; "OASGP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"SMP" -> {"CFCAT"; "STEP"; "UPOLYC"; "DIFEXT"}*/
-
-"SMTS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SMTS"]
-/*"SMTS" -> {"MTSCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SMTS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"SMTS" -> {"MONOID"; "LMODULE"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"SMTS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"SMTS" -> {"ENTIRER"; "IEVALAB"; "EVALAB"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"SMTS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "ORDSET"; "POLYCAT"}*/
-/*"SMTS" -> {"FAMR"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
-/*"SMTS" -> {"PATMAB"; "GCDDOM"}*/
-"SMTS" -> "PFECAT"
-/*"SMTS" -> {"UFD"; "NNI"; "INT"; "BOOLEAN"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"SMTS" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"SMTS" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"SMTS" -> {"SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"SMTS" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"SMTS" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INS"; "EUCDOM"; "PID"}*/
-/*"SMTS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SMTS" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "PI"; "SINT"; "FIELD"}*/
-/*"SMTS" -> "DIVRING"*/
-
-"SOLVEFOR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVEFOR"]
-/*"SOLVEFOR" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SOLVEFOR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SOLVEFOR" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"SOLVEFOR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"SOLVEFOR" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"SOLVEFOR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"SOLVEFOR" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"SOLVEFOR" -> "PFECAT"
-/*"SOLVEFOR" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"SOLVEFOR" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"; "INT"; "LIST"}*/
-/*"SOLVEFOR" -> {"ILIST"; "LSAGG-"; "STAGG-"; "NNI"; "PI"; "SINT"; "INS"}*/
-/*"SOLVEFOR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"SOLVEFOR" -> {"OASGP"; "CFCAT"; "REAL"}*/
-
-"SPLTREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SPLTREE"]
-/*"SPLTREE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"SPLTREE" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "INT"; "LIST"; "ILIST"}*/
-/*"SPLTREE" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"SPLTREE" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"SPLTREE" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "BOOLEAN"; "LSAGG"}*/
-/*"SPLTREE" -> {"STAGG"; "URAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"SPLTREE" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "NNI"}*/
-"SPLTREE" -> "STRING"
-/*"SPLTREE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-
-"STINPROD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STINPROD"]
-/*"STINPROD" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"STINPROD" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"STINPROD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"STINPROD" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "FIELD"; "EUCDOM"}*/
-/*"STINPROD" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "QFCAT"; "RETRACT"}*/
-/*"STINPROD" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"STINPROD" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"STINPROD" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
-/*"STINPROD" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"STINPROD" -> {"OASGP"; "REAL"; "CHARNZ"}*/
-"STINPROD" -> "PFECAT"
-
-"STTF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STTF"]
-/*"STTF" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"STTF" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"STTF" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "TRANFUN"; "TRIGCAT"}*/
-/*"STTF" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"STTF" -> "STRING"
-/*"STTF" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
-/*"STTF" -> {"ISTRING"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"STTF" -> {"URAGG-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"STTF" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"STTF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"STTF" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"STTF" -> {"STEP"; "NNI"; "PI"}*/
-
-"STTFNC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=STTFNC"]
-/*"STTFNC" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"STTFNC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"STTFNC" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "INT"}*/
-"STTFNC" -> "STRING"
-/*"STTFNC" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"STTFNC" -> "ISTRING"*/
-
-"SUBRESP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUBRESP"]
-/*"SUBRESP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SUBRESP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SUBRESP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SUBRESP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
-/*"SUBRESP" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"SUBRESP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"SUBRESP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"SUBRESP" -> "PFECAT"
-/*"SUBRESP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"SUBRESP" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "PRIMARR"}*/
-/*"SUBRESP" -> {"LIST"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"SUBRESP" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "PI"; "ILIST"; "BOOLEAN"}*/
-
-"SUBSPACE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUBSPACE"]
-/*"SUBSPACE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SUBSPACE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"SUBSPACE" -> {"LMODULE"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"SUBSPACE" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"SUBSPACE" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"SUBSPACE" -> {"BASTYPE-"; "NNI"; "BOOLEAN"; "PI"}*/
-"SUBSPACE" -> "STRING"
-/*"SUBSPACE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"SUBSPACE" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"SUBSPACE" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"SUBSPACE" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
-
-"SUMRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUMRF"]
-/*"SUMRF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SUMRF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"SUMRF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"SUMRF" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "POLYCAT"}*/
-/*"SUMRF" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"SUMRF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
-/*"SUMRF" -> {"PATMAB"; "GCDDOM"}*/
-"SUMRF" -> "PFECAT"
-/*"SUMRF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-/*"SUMRF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
-/*"SUMRF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"SUMRF" -> {"OAMON"; "OASGP"; "REAL"}*/
-
-"SUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUP"]
-/*"SUP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SUP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SUP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"SUP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"SUP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"SUP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"SUP" -> "PFECAT"
-/*"SUP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"SUP" -> {"FIELD"; "DIVRING"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SUP" -> {"FPC"; "INT"; "LIST"; "NNI"; "PI"; "ILIST"; "BOOLEAN"}*/
-/*"SUP" -> {"FFIELDC"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"SUP" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"SUP" -> {"FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "FPS"; "RNS"; "ORDRING"}*/
-/*"SUP" -> {"OAGROUP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
-
-"SUPEXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUPEXPR"]
-/*"SUPEXPR" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SUPEXPR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SUPEXPR" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"SUPEXPR" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"SUPEXPR" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"SUPEXPR" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"SUPEXPR" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"SUPEXPR" -> "PFECAT"
-/*"SUPEXPR" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"SUPEXPR" -> {"PID"; "FIELD"; "DIVRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"SUPEXPR" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FPS"; "RNS"; "ORDRING"}*/
-/*"SUPEXPR" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
-/*"SUPEXPR" -> {"INS"; "OINTDOM"; "CFCAT"}*/
-
-"SUPFRACF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUPFRACF"]
-/*"SUPFRACF" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"SUPFRACF" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"SUPFRACF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SUPFRACF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SUPFRACF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"}*/
-/*"SUPFRACF" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"SUPFRACF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"}*/
-/*"SUPFRACF" -> "PATMAB"*/
-"SUPFRACF" -> "PFECAT"
-/*"SUPFRACF" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-/*"SUPFRACF" -> {"FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"}*/
-/*"SUPFRACF" -> {"TYPE"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "REAL"}*/
-/*"SUPFRACF" -> "UPOLYC"*/
-
-"TANEXP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TANEXP"]
-/*"TANEXP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"TANEXP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"TANEXP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"TANEXP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"TANEXP" -> {"UFD"; "DIVRING"; "INT"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"TANEXP" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"TANEXP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"TANEXP" -> {"KONVERT"; "PATMAB"}*/
-"TANEXP" -> "PFECAT"
-/*"TANEXP" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INS"; "OINTDOM"}*/
-/*"TANEXP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
-/*"TANEXP" -> {"REAL"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"}*/
-/*"TANEXP" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"TANEXP" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "NNI"; "PI"; "MONOID-"}*/
-/*"TANEXP" -> "ABELMON-"*/
-
-"TEMUTL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TEMUTL"]
-/*"TEMUTL" -> "INT"*/
-"TEMUTL" -> "STRING"
-/*"TEMUTL" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"TEMUTL" -> {"ISTRING"; "SRAGG-"}*/
-
-"TEX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TEX"]
-/*"TEX" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"}*/
-"TEX" -> "STRING"
-/*"TEX" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"TEX" -> {"ISTRING"; "ILIST"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
-/*"TEX" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"TEX" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "OM"; "PI"}*/
-/*"TEX" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"TEX" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "ORDFIN"}*/
-/*"TEX" -> {"FINITE"; "SRAGG-"}*/
-
-"TEXTFILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TEXTFILE"]
-/*"TEXTFILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FNCAT"}*/
-/*"TEXTFILE" -> {"STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"TEXTFILE" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"TEXTFILE" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "OM"}*/
-"TEXTFILE" -> "STRING"
-/*"TEXTFILE" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"TEXTFILE" -> {"A1AGG-"; "ISTRING"; "BOOLEAN"}*/
-
-"TREE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TREE"]
-/*"TREE" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"TREE" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "NNI"; "INT"; "LIST"}*/
-/*"TREE" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "LNAGG"}*/
-/*"TREE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"TREE" -> {"ORDSET"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"TREE" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"TREE" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"TREE" -> "PI"*/
-"TREE" -> "STRING"
-/*"TREE" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-
-"TWOFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TWOFACT"]
-/*"TWOFACT" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"TWOFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"TWOFACT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"TWOFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"TWOFACT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"TWOFACT" -> {"CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "UPOLYC"}*/
-/*"TWOFACT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "FRETRCT"}*/
-/*"TWOFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"TWOFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"}*/
-"TWOFACT" -> "PFECAT"
-/*"TWOFACT" -> {"ELTAB"; "DIFEXT"; "INT"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"TWOFACT" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"TWOFACT" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "PI"; "NNI"}*/
-/*"TWOFACT" -> {"LIST"; "ILIST"; "BOOLEAN"}*/
-"TWOFACT" -> "FAXF"
-/*"TWOFACT" -> {"XF"; "VSPACE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"TWOFACT" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"TWOFACT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-
-"UNIFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UNIFACT"]
-/*"UNIFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"UNIFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"UNIFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"UNIFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"UNIFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"UNIFACT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"UNIFACT" -> {"KONVERT"; "PATMAB"; "GCDDOM"}*/
-"UNIFACT" -> "PFECAT"
-/*"UNIFACT" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"UNIFACT" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"; "INT"; "LIST"}*/
-/*"UNIFACT" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"UNIFACT" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "INS-"; "NNI"}*/
-/*"UNIFACT" -> {"SINT"; "PI"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-/*"UNIFACT" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"UNIFACT" -> {"ABELGRP-"; "ABELMON-"; "MONOID-"; "ORDSET-"; "ABELSG-"}*/
-/*"UNIFACT" -> {"SGROUP-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"UNIFACT" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"UNIFACT" -> {"FLAGG"; "ELAGG"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"UNIFACT" -> {"FLAGG-"; "URAGG-"}*/
-
-"UP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UP"]
-/*"UP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"UP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"UP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"UP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"UP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"UP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"UP" -> "PFECAT"
-/*"UP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"UP" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "FPS"; "RNS"; "ORDRING"}*/
-/*"UP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
-/*"UP" -> {"INS"; "OINTDOM"; "CFCAT"}*/
-
-"UPCDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPCDEN"]
-/*"UPCDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"UPCDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"UPCDEN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"UPCDEN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "QFCAT"; "FIELD"; "EUCDOM"}*/
-/*"UPCDEN" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
-/*"UPCDEN" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"UPCDEN" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"UPCDEN" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"UPCDEN" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARZ"; "CHARNZ"}*/
-"UPCDEN" -> "PFECAT"
-/*"UPCDEN" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "LSAGG"}*/
-/*"UPCDEN" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"UPCDEN" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-
-"UPDECOMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPDECOMP"]
-/*"UPDECOMP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"UPDECOMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"UPDECOMP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"UPDECOMP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "UPOLYC"}*/
-/*"UPDECOMP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"UPDECOMP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"UPDECOMP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"UPDECOMP" -> "PFECAT"
-/*"UPDECOMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"UPDECOMP" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "SINT"}*/
-/*"UPDECOMP" -> {"BOOLEAN"; "LIST"}*/
-
-"UPDIVP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPDIVP"]
-/*"UPDIVP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"UPDIVP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"UPDIVP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"UPDIVP" -> {"MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"UPDIVP" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"UPDIVP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"UPDIVP" -> "PATMAB"; "GCDDOM"}*/
-"UPDIVP" -> "PFECAT"
-/*"UPDIVP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"UPDIVP" -> {"PID"; "FIELD"; "DIVRING"; "NNI"; "BOOLEAN"}*/
-
-"UPMP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPMP"]
-/*"UPMP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UPMP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UPMP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"UPMP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"UPMP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"UPMP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"UPMP" -> {"PATMAB"; "GCDDOM"}*/
-"UPMP" -> "PFECAT"
-/*"UPMP" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"UPMP" -> {"FIELD"; "DIVRING"; "NNI"; "INT"; "LIST"; "ILIST"; "MONOID-"}*/
-/*"UPMP" -> "ABELMON-"*/
-
-"UPOLYC2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPOLYC2"]
-/*"UPOLYC2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UPOLYC2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"UPOLYC2" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"UPOLYC2" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"UPOLYC2" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"UPOLYC2" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"UPOLYC2" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"UPOLYC2" -> "PFECAT"
-/*"UPOLYC2" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"UPOLYC2" -> {"PID"; "FIELD"; "DIVRING"; "BOOLEAN"}*/
-
-"UPXSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPXSCAT"]
-/*"UPXSCAT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"UPXSCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"UPXSCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UPXSCAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"UPXSCAT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"UPXSCAT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"UPXSCAT" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"UPXSCAT" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"UPXSCAT" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
-/*"UPXSCAT" -> {"FPATMAB"; "TYPE"; "CHARNZ"}*/
-"UPXSCAT" -> "PFECAT"
-/*"UPXSCAT" -> {"UPSCAT"; "PSCAT"; "AMR"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"UPXSCAT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-
-"UPSQFREE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UPSQFREE"]
-/*"UPSQFREE" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"UPSQFREE" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"UPSQFREE" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"UPSQFREE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
-/*"UPSQFREE" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"UPSQFREE" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"UPSQFREE" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-"UPSQFREE" -> "PFECAT"
-/*"UPSQFREE" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"UPSQFREE" -> {"PID"; "FIELD"; "DIVRING"; "FFIELDC"; "FPC"; "FINITE"}*/
-/*"UPSQFREE" -> {"INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"}*/
-/*"UPSQFREE" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"UPSQFREE" -> {"ABELGRP-"; "NNI"; "BOOLEAN"; "LIST"; "PI"}*/
-
-"VECTOR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VECTOR",
-          shape=ellipse]
-/*"VECTOR" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"VECTOR" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"VECTOR" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"VECTOR" -> {"INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"}*/
-/*"VECTOR" -> {"SYMBOL"; "REF"; "ALIST"; "LIST"}*/
-"VECTOR" -> "STRING"
-/*"VECTOR" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
-/*"VECTOR" -> {"FLAGG-"; "LNAGG-"; "RADCAT"; "RING"; "RNG"; "ABELGRP"}*/
-/*"VECTOR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"VECTOR" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"VECTOR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"VECTOR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"VECTOR" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"VECTOR" -> {"CHARZ"; "STEP"; "OM"}*/
-
-"VIEWDEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=VIEWDEF"]
-/*"VIEWDEF" -> {"NNI"; "INT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"VIEWDEF" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"VIEWDEF" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"VIEWDEF" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"VIEWDEF" -> {"OM"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"VIEWDEF" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"VIEWDEF" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"VIEWDEF" -> "BASTYPE-"*/
-"VIEWDEF" -> "STRING"
-/*"VIEWDEF" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"VIEWDEF" -> {"SRAGG-"; "STRICAT"; "SRAGG"; "A1AGG"}*/
-
-"VIEW2D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VIEW2D"]
-/*"VIEW2D" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "DFLOAT"; "INT"; "BOOLEAN"}*/
-/*"VIEW2D" -> {"PI"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"VIEW2D" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"VIEW2D" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTOR"; "IVECTOR"}*/
-/*"VIEW2D" -> {"IARRAY1"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "SINT"}*/
-"VIEW2D" -> "STRING"
-/*"VIEW2D" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "INS"}*/
-/*"VIEW2D" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"VIEW2D" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"VIEW2D" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"VIEW2D" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"VIEW2D" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"VIEW2D" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "SRAGG-"}*/
-/*"VIEW2D" -> {"STRICAT"; "SRAGG"; "ELAGG-"; "FLAGG-"; "FPS"; "RNS"}*/
-/*"VIEW2D" -> {"FIELD"; "DIVRING"; "RADCAT"}*/
-
-"VOID" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VOID"]
-"VOID" -> "STRING"
-/*"VOID" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"VOID" -> {"A1AGG-"; "ISTRING"}*/
-
-"WEIER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=WEIER"]
-/*"WEIER" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"WEIER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"WEIER" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"WEIER" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"WEIER" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "NNI"; "POLYCAT"}*/
-/*"WEIER" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"WEIER" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"WEIER" -> {"KONVERT"; "PATMAB"}*/
-"WEIER" -> "PFECAT"
-/*"WEIER" -> {"MTSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"WEIER" -> {"HYPCAT"; "AHYP"; "ELEMFUN"}*/
-
-"WP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=WP"]
-/*"WP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
-/*"WP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"WP" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "OAMONS"; "OCAMON"}*/
-/*"WP" -> {"OAMON"; "OASGP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "COMRING"}*/
-/*"WP" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"WP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"WP" -> "GCDDOM"*/
-"WP" -> "PFECAT"
-/*"WP" -> {"UFD"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"WP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"WP" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"WP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"WP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"WP" -> {"BASTYPE-"; "NNI"; "BOOLEAN"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
-
-\end{chunk}
-\subsection{Layer12}
-Depends on: DIOPS DPOLCAT FINRALG FRAC RMATCAT RRCC UPXSCAT FFSQFR PACRATC
-PLPKCRV\\
-Used by next layer: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA
-\begin{chunk}{layer12}
-
-LAYER12=\
-  ${OUT}/DIAGG.o   ${OUT}/DIAGG-.o   ${OUT}/DSMP.o     ${OUT}/EXPUPXS.o \
-  ${OUT}/FACTRN.o  ${OUT}/FFFACTSE.o \
-  ${OUT}/FRAMALG.o ${OUT}/FRAMALG-.o ${OUT}/INTFRSP.o  ${OUT}/LPARSPT.o  \
-  ${OUT}/MDAGG.o   ${OUT}/NPOLYGON.o \
-  ${OUT}/ODPOL.o   ${OUT}/PLOT.o     ${OUT}/RFP.o     \
-  ${OUT}/RMCAT2.o  ${OUT}/ROIRC.o    ${OUT}/SDPOL.o   \
-  ${OUT}/SMATCAT.o ${OUT}/SMATCAT-.o ${OUT}/TUBETOOL.o ${OUT}/UPXSCCA.o \
-  ${OUT}/UPXSCCA-.o \
-  layer12done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 12 */
-/* depends on: DIOPS DPOLCAT FFSQFR FINRALG FRAC RMATCAT RRCC UPXSCAT */
-/*             PLPKCRV */
-
-"DFLOAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DFLOAT",
-          shape=ellipse]
-/*"DFLOAT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"DFLOAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DFLOAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DFLOAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DFLOAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"DFLOAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"DFLOAT" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"DFLOAT" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"DFLOAT" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "DFLOAT"; "INT"; "PI"; "NNI"}*/
-/*"DFLOAT" -> {"FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"DFLOAT" -> {"DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"DFLOAT" -> "MODULE-"*/
-"DFLOAT" -> "FRAC"
-/*"DFLOAT" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "INS"; "OINTDOM"; "LINEXP"}*/
-/*"DFLOAT" -> {"CFCAT"; "STEP"; "INS"}*/
-
-"DIAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=DIAGG"]
-"DIAGG" -> "DIOPS"
-/*"DIAGG" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"DIAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
-/*"DIAGG" -> {"BOOLEAN"; "NNI"; "INT"}*/
-
-"DIAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DIAGG"]
-"DIAGG-" -> "DIOPS"
-/*"DIAGG-" -> {"BGAGG";  "HOAGG";  "AGG";  "TYPE";  "SETCAT";  "BASTYPE"}*/
-/*"DIAGG-" -> {"KOERCE";  "EVALAB";  "IEVALAB";  "CLAGG";  "KONVERT"}*/
-/*"DIAGG-" -> {"BOOLEAN";  "NNI";  "INT"}*/
-
-"DSMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DSMP"]
-"DSMP" -> "DPOLCAT"
-/*"DSMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DSMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"DSMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"DSMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"DSMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"DSMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
-/*"DSMP" -> {"UFD"; "DIFEXT"; "DIFRING"; "DVARCAT"; "NNI"; "INT"; "FPS"}*/
-/*"DSMP" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"}*/
-/*"DSMP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
-/*"DSMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"; "ELTAB"}*/
-
-"EXPUPXS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXPUPXS"]
-/*"EXPUPXS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"EXPUPXS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"EXPUPXS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"EXPUPXS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"EXPUPXS" -> {"UFD"; "DIVRING"; "ORDSET"}*/
-"EXPUPXS" -> "UPXSCAT"
-/*"EXPUPXS" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
-/*"EXPUPXS" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"EXPUPXS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "OAMON"; "OASGP"}*/
-/*"EXPUPXS" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "KONVERT"}*/
-/*"EXPUPXS" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-/*"EXPUPXS" -> {"INT"; "LIST"; "ILIST"; "BOOLEAN"; "OM"; "QFCAT"; "FEVALAB"}*/
-/*"EXPUPXS" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"EXPUPXS" -> {"TYPE"; "PFECAT"}*/
-
-"FACTRN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACTRN"]
-"FACTRN" -> "PACRATC"
-/*"FACTRN" -> {"PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FACTRN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FACTRN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FACTRN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FACTRN" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"}*/
-/*"FACTRN" -> {"XF"; "VSPACE"; "FPC"; "CHARNZ"; "FINITE"; "UPOLYC"}*/
-/*"FACTRN" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "FRETRCT"; "EVALAB"}*/
-/*"FACTRN" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"FACTRN" -> {"PFECAT"}*/
-/*"FACTRN" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"; "STAGG"}*/
-/*"FACTRN" -> {"URAGG" "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
-/*"FACTRN" -> {"ELTAGG" "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"} */
-/*"FACTRN" -> {"ILIST" "LSAGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"FACTRN" -> {"OCAMON" "OAMON"; "OASGP"; "CFCAT"; "REAL"; "QFCAT"}*/
-/*"FACTRN" -> {"FEVALAB""PATAB"; "FPATMAB"}*/
-
-"FFFACTSE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFFACTSE"]
-/*"FFFACTSE" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"FFFACTSE" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FFFACTSE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FFFACTSE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FFFACTSE" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FFFACTSE" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/ 
-/*"FFFACTSE" -> {"DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"}*/
-/*"FFFACTSE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"FFFACTSE" -> {"CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"FFFACTSE" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"FFFACTSE" -> {"KONVERT"; "PATMAB"}*/
-"FFFACTSE" -> "PFECAT"
-"FFFACTSE" -> "FFSQFR"
-/*"FFFACTSE" -> {"ELTAB"; "DIFEXT"}*/
-/*"FFFACTSE" -> {"NNI"; "INT"; "PI"; "PRIMARR"; "A1AGG"; "FLAGG"}*/
-/*"FFFACTSE" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FFFACTSE" -> {"ELTAGG"; "CLAGG"; "BOOLEAN"; "SINT"; "LIST"}*/
-/*"FFFACTSE" -> {"ILIST"; "LSAGG-"; "STAGG-"; "INS-"; "INS"}*/
-/*"FFFACTSE" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FFFACTSE" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-
-"FRAMALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FRAMALG"]
-"FRAMALG" -> "FINRALG"
-/*"FRAMALG" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FRAMALG" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FRAMALG" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "CHARZ"; "CHARNZ"}*/
-/*"FRAMALG" -> {"COMRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"FRAMALG" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"FRAMALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"FRAMALG" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
-/*"FRAMALG" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-/*"FRAMALG" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"FRAMALG" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "INT"; "VECTOR"}*/
-/*"FRAMALG" -> {"IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"FRAMALG" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"FRAMALG" -> {"OM"; "NNI"; "PI"; "SINT"; "LIST"; "ILIST"}*/
-
-"FRAMALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRAMALG"]
-"FRAMALG-" -> "FINRALG"
-/*"FRAMALG-" -> {"ALGEBRA";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
-/*"FRAMALG-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
-/*"FRAMALG-" -> {"SGROUP";  "MONOID";  "LMODULE";  "MODULE";  "BMODULE"}*/
-/*"FRAMALG-" -> {"RMODULE";  "CHARZ";  "CHARNZ";  "COMRING";  "UPOLYC"}*/
-/*"FRAMALG-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "INTDOM"}*/
-/*"FRAMALG-" -> {"ENTIRER";  "FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB"}*/
-/*"FRAMALG-" -> {"FLINEXP";  "LINEXP";  "ORDSET";  "KONVERT";  "PATMAB"}*/
-/*"FRAMALG-" -> {"GCDDOM";  "PFECAT";  "UFD";  "ELTAB";  "DIFRING"}*/
-/*"FRAMALG-" -> {"DIFEXT";  "STEP";  "EUCDOM";  "PID";  "FIELD";  "DIVRING"}*/
-/*"FRAMALG-" -> {"VECTCAT";  "A1AGG";  "FLAGG";  "LNAGG";  "IXAGG";  "HOAGG"}*/
-/*"FRAMALG-" -> {"AGG";  "TYPE";  "ELTAGG";  "CLAGG";  "INT";  "VECTOR"}*/
-/*"FRAMALG-" -> {"IVECTOR";  "IARRAY1";  "INS";  "OINTDOM";  "ORDRING"}*/
-/*"FRAMALG-" -> {"OAGROUP";  "OCAMON";  "OAMON";  "OASGP";  "CFCAT";  "REAL"}*/
-/*"FRAMALG-" -> {"OM";  "NNI";  "PI";  "SINT";  "LIST";  "ILIST"}*/
-
-"INTFRSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTFRSP"]
-"INTFRSP" -> "PFORP"
-"INTFRSP" -> "PARAMP"
-"INTFRSP" -> "LISYSER"
-/*"INTFRSP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"}*/
-/*"INTFRSP" -> {"DIVCAT"; "LOP"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"INTFRSP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTFRSP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"INTFRSP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"INTFRSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"INTFRSP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"INTFRSP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"INTFRSP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"INTFRSP" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"INTFRSP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
-/*"INTFRSP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"}*/
-/*"INTFRSP" -> {"VSPACE"; "UPSCAT"; "PSCAT"; "FAMONC"; "INT"; "LIST"}*/
-/*"INTFRSP" -> {"ILIST"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"INTFRSP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "VECTOR"}*/
-/*"INTFRSP" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"}*/
-/*"INTFRSP" -> {"LNAGG-"; "IXAGG-"; "LSAGG-"; "SINT"; "PI"; "STAGG-"}*/
-/*"INTFRSP" -> {"ELAGG-"; "OUTFORM"}*/
-
-"LPARSPT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LPARSPT"]
-"LPARSPT" -> "PLPKCRV"
-/*"LPARSPT" -> {"PFECAT"; "DIRPCAT"}*/
-/*"LPARSPT" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "FIELD"}*/
-/*"LPARSPT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"LPARSPT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"LPARSPT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LPARSPT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LPARSPT" -> {"UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"LPARSPT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"LPARSPT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"LPARSPT" -> {"PATMAB"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"LPARSPT" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
-/*"LPARSPT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"}*/
-/*"LPARSPT" -> {"VSPACE"; "UPSCAT"; "PSCAT"; "SINT"; "INT"; "LSAGG"}*/
-/*"LPARSPT" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"}*/
-/*"LPARSPT" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"; "STEP"}*/
-/*"LPARSPT" -> {"UPOLYC"; "PI"; "LSAGG-"; "STAGG-"; "OUTFORM"; "ELAGG-"}*/
-
-"MDAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MDAGG"]
-"MDAGG" -> "DIOPS"
-/*"MDAGG" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"MDAGG" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
-
-"NPOLYGON" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NPOLYGON"]
-/*"NPOLYGON" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"NPOLYGON" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NPOLYGON" -> {"LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"NPOLYGON" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"NPOLYGON" -> {"ENTIRER"; "FRETRCT"; "RETRACT"}*/
-"NPOLYGON" -> "DIRPCAT"
-/*"NPOLYGON" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"NPOLYGON" -> {"ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"NPOLYGON" -> {"FLINEXP"; "LINEXP"; "FINITE"; "ORDRING"; "OAGROUP"}*/
-/*"NPOLYGON" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "OAMONS"; "VSPACE"}*/
-/*"NPOLYGON" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "INT"}*/
-/*"NPOLYGON" -> {"PI"; "NNI"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"NPOLYGON" -> {"RCAGG"; "LNAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
-/*"NPOLYGON" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"NPOLYGON" -> {"BOOLEAN"}*/
-
-"ODPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ODPOL"]
-"ODPOL" -> "DPOLCAT"
-/*"ODPOL" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ODPOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ODPOL" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"ODPOL" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"ODPOL" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"ODPOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-/*"ODPOL" -> {"PFECAT"; "UFD"; "DIFEXT"; "DIFRING"; "DVARCAT"; "FPS"; "RNS"}*/
-/*"ODPOL" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"ODPOL" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"; "INS"; "OINTDOM"}*/
-/*"ODPOL" -> {"CFCAT"; "STEP"; "UPOLYC"; "ELTAB"}*/
-
-"PLOT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLOT"]
-/*"PLOT" -> {"PPCURVE"; "KOERCE"; "BOOLEAN"; "INT"; "DFLOAT"; "FPS-"}*/
-/*"PLOT" -> {"RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"}*/
-/*"PLOT" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
-/*"PLOT" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"; "ORDSET-"}*/
-/*"PLOT" -> {"ABELSG-"; "SGROUP-"; "TRANFUN-"; "SETCAT-"; "ELEMFUN-"}*/
-/*"PLOT" -> {"HYPCAT-"; "ATRIG-"; "TRIGCAT-"; "RADCAT-"; "RETRACT-"}*/
-/*"PLOT" -> {"BASTYPE-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PLOT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PLOT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"}*/
-/*"PLOT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PLOT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"PLOT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"PLOT" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "PTCAT"; "VECTCAT"}*/
-/*"PLOT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PLOT" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "LIST"}*/
-/*"PLOT" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"}*/
-/*"PLOT" -> {"NNI"; "PI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"PLOT" -> {"SINT"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
-/*"PLOT" -> {"STEP"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"PLOT" -> {"ELEMFUN"; "SPFCAT"}*/
-"PLOT" -> "FRAC"
-
-"RFP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFP"]
-/*"RFP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"RFP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"RFP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RFP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"RFP" -> {"INT"; "LIST"; "ILIST"; "PACPERC"; "FFIELDC"; "FPC"; "CHARNZ"}*/
-/*"RFP" -> {"FINITE"; "STEP"; "DIFRING"; "PACFFC"; "UPOLYC"; "POLYCAT"}*/
-/*"RFP" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"RFP" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"RFP" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"RFP" -> {"GCDDOM-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"RFP" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"RFP" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "QFCAT"; "FEVALAB"; "PATAB"}*/
-/*"RFP" -> {"FPATMAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"RFP" -> {"OASGP"; "REAL"; "INS"; "CFCAT"}*/
-"RFP" -> "PACRATC"
-/*"RFP" -> {"XF"; "VSPACE"; "BOOLEAN"; "NNI"; "FLAGG-"; "URAGG-"}*/
-
-"RMCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RMCAT2"]
-/*"RMCAT2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RMCAT2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RMCAT2" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"RMCAT2" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "FRETRCT"; "RETRACT"; "BMODULE"}*/
-/*"RMCAT2" -> {"RMODULE"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"RMCAT2" -> {"FINITE"; "ALGEBRA"; "MODULE"; "COMRING"; "ORDRING"}*/
-/*"RMCAT2" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "OAMONS"}*/
-/*"RMCAT2" -> {"VSPACE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"RMCAT2" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-"RMCAT2" -> "RMATCAT"
-/*"RMCAT2" -> {"NNI"; "INT"}*/
-
-"ROIRC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ROIRC"]
-"ROIRC" -> "RRCC"
-/*"ROIRC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ROIRC" -> {"OAMON"; "OASGP"; "ORDSET"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"ROIRC" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ROIRC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ROIRC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ROIRC" -> {"UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"ROIRC" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"ROIRC" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"ROIRC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"; "INT"; "LIST"}*/
-/*"ROIRC" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"ROIRC" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"ROIRC" -> {"ILIST"; "PI"; "BOOLEAN"; "INS"; "OINTDOM"; "CFCAT"; "REAL"}*/
-
-"SDPOL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SDPOL"]
-"SDPOL" -> "DPOLCAT"
-/*"SDPOL" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SDPOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"SDPOL" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"SDPOL" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"SDPOL" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"SDPOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"SDPOL" -> {"GCDDOM"; "PFECAT"; "UFD"; "DIFEXT"; "DIFRING"; "DVARCAT"}*/
-/*"SDPOL" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"}*/
-/*"SDPOL" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
-/*"SDPOL" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"; "ELTAB"}*/
-
-"SMATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SMATCAT"]
-/*"SMATCAT" -> {"DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"SMATCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"SMATCAT" -> {"MONOID"; "LMODULE"; "DIFRING"; "PDRING"; "BMODULE"}*/
-/*"SMATCAT" -> "RMODULE"*/
-"SMATCAT" -> "RMATCAT"
-/*"SMATCAT" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "MODULE"}*/
-/*"SMATCAT" -> {"COMRING"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"SMATCAT" -> {"ALGEBRA"; "DIRPCAT"; "IXAGG"; "ELTAGG"; "ELTAB"; "FINITE"}*/
-/*"SMATCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"SMATCAT" -> {"OAMONS"; "VSPACE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"SMATCAT" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "NNI"; "INT"}*/
-/*"SMATCAT" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "KONVERT"}*/
-/*"SMATCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "VECTCAT"}*/
-/*"SMATCAT" -> {"A1AGG"; "FLAGG"; "LNAGG"; "CLAGG"; "LSAGG"; "STAGG"}*/
-/*"SMATCAT" -> {"URAGG"; "RCAGG"; "ELAGG"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"SMATCAT" -> {"VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"SMATCAT" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "INS-"}*/
-
-"SMATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SMATCAT"]
-/*"SMATCAT-" -> {"DIFEXT";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
-/*"SMATCAT-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
-/*"SMATCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "DIFRING";  "PDRING"}*/
-/*"SMATCAT-" -> {"BMODULE";  "RMODULE"}*/
-"SMATCAT-" -> "RMATCAT"
-/*"SMATCAT-" -> {"HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB";  "MODULE"}*/
-/*"SMATCAT-" -> {"COMRING";  "FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP"}*/
-/*"SMATCAT-" -> {"ALGEBRA";  "DIRPCAT";  "IXAGG";  "ELTAGG";  "ELTAB"}*/
-/*"SMATCAT-" -> {"FINITE";  "ORDRING";  "OAGROUP";  "OCAMON";  "OAMON"}*/
-/*"SMATCAT-" -> {"OASGP";  "ORDSET";  "OAMONS";  "VSPACE";  "FIELD"}*/
-/*"SMATCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "ENTIRER"}*/
-/*"SMATCAT-" -> {"UFD";  "DIVRING";  "NNI";  "INT";  "VECTOR";  "IVECTOR"}*/
-/*"SMATCAT-" -> {"IARRAY1";  "INS";  "OINTDOM";  "KONVERT";  "PATMAB"}*/
-/*"SMATCAT-" -> {"CFCAT";  "REAL";  "CHARZ";  "STEP";  "OM";  "VECTCAT"}*/
-/*"SMATCAT-" -> {"A1AGG";  "FLAGG";  "LNAGG";  "CLAGG";  "LSAGG";  "STAGG"}*/
-/*"SMATCAT-" -> {"URAGG";  "RCAGG";  "ELAGG";  "LIST";  "ILIST";  "LSAGG-"}*/
-/*"SMATCAT-" -> {"VECTCAT-";  "A1AGG-";  "FLAGG-";  "LNAGG-";  "IXAGG-"}*/
-/*"SMATCAT-" -> {"CLAGG-";  "HOAGG-";  "ORDSET-";  "AGG-";  "INS-"}*/
-
-"TUBETOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TUBETOOL"]
-/*"TUBETOOL" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"TUBETOOL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"TUBETOOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"TUBETOOL" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"TUBETOOL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"TUBETOOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"TUBETOOL" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"TUBETOOL" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-/*"TUBETOOL" -> {"OM"; "INT"; "DFLOAT"; "FPS-"; "RNS-"; "FIELD-"; "LIST"}*/
-/*"TUBETOOL" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"}*/
-/*"TUBETOOL" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
-"TUBETOOL" -> "FRAC"
-/*"TUBETOOL" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "SINT"; "PI"; "NNI"}*/
-/*"TUBETOOL" -> {"ILIST"; "BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"TUBETOOL" -> "URAGG-"*/
-
-"UPXSCCA" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UPXSCCA"]
-"UPXSCCA" -> "UPXSCAT"
-/*"UPXSCCA" -> {"UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"}*/
-/*"UPXSCCA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"UPXSCCA" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"UPXSCCA" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"UPXSCCA" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
-/*"UPXSCCA" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"UPXSCCA" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"UPXSCCA" -> {"GCDDOM"; "UFD"; "DIVRING"; "RETRACT"; "ULSCAT"}*/
-
-"UPXSCCA-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXSCCA"]
-"UPXSCCA-" -> "UPXSCAT"
-/*"UPXSCCA-" -> {"UPSCAT";  "PSCAT";  "AMR";  "RING";  "RNG";  "ABELGRP"}*/
-/*"UPXSCCA-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
-/*"UPXSCCA-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
-/*"UPXSCCA-" -> {"RMODULE";  "COMRING";  "ALGEBRA";  "MODULE";  "CHARZ"}*/
-/*"UPXSCCA-" -> {"CHARNZ";  "INTDOM";  "ENTIRER";  "ELTAB";  "DIFRING"}*/
-/*"UPXSCCA-" -> {"PDRING";  "RADCAT";  "TRANFUN";  "TRIGCAT";  "ATRIG"}*/
-/*"UPXSCCA-" -> {"HYPCAT";  "AHYP";  "ELEMFUN";  "FIELD";  "EUCDOM";  "PID"}*/
-/*"UPXSCCA-" -> {"GCDDOM";  "UFD";  "DIVRING";  "RETRACT";  "ULSCAT"}*/
-
-\end{chunk}
-\subsection{Layer13}
-Depends on: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA RFP\\
-Used by next layer: FSAGG KDAGG MSETAGG MONOGEN
-\begin{chunk}{layer13}
-
-LAYER13=\
-  ${OUT}/AFALGGRO.o ${OUT}/AFALGRES.o \
-  ${OUT}/DPMM.o     ${OUT}/EFUPXS.o  ${OUT}/FFINTBAS.o ${OUT}/FRIDEAL.o  \
-  ${OUT}/FRIDEAL2.o ${OUT}/FRMOD.o   ${OUT}/FSAGG.o    ${OUT}/FSAGG-.o   \
-  ${OUT}/IBATOOL.o  ${OUT}/INTFACT.o ${OUT}/KDAGG.o    ${OUT}/KDAGG-.o   \
-  ${OUT}/MSETAGG.o  ${OUT}/MONOGEN.o ${OUT}/MONOGEN-.o ${OUT}/NFINTBAS.o \
-  layer13done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 13 */
-/* depends on: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA RFP*/
-
-"AFALGGRO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AFALGGRO"]
-"AFALGGRO" -> "DIRPCAT"
-"AFALGGRO" -> "PFECAT"
-/*"AFALGGRO" -> {"PRSPCAT"; "SETCATD"; "PACFFC"; "PACPERC"; "FIELD"}*/
-/*"AFALGGRO" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"AFALGGRO" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"AFALGGRO" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"AFALGGRO" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"AFALGGRO" -> {"UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"AFALGGRO" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"AFALGGRO" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"AFALGGRO" -> {"PATMAB"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"AFALGGRO" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
-/*"AFALGGRO" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
-/*"AFALGGRO" -> {"SINT"; "OUTFORM"; "INT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"AFALGGRO" -> {"RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"}*/
-/*"AFALGGRO" -> {"ILIST"; "NNI"; "FFIELDC"; "FPC"; "STEP"; "PI"; "VECTOR"}*/
-/*"AFALGGRO" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "ORDFIN"}*/
-/*"AFALGGRO" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "INS-"}*/
-/*"AFALGGRO" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-
-"AFALGRES" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AFALGRES"]
-"AFALGRES" -> "RFP" 
-/*"AFALGRES" -> {"PRSPCAT"; "LOCPOWC"; "SETCATD"; "PACFFC"; "CHARZ"}*/
-/*"AFALGRES" -> {"PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"AFALGRES" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"AFALGRES" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"AFALGRES" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"AFALGRES" -> {"UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"AFALGRES" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"AFALGRES" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"AFALGRES" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "ELTAB"}*/
-/*"AFALGRES" -> {"DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"AFALGRES" -> {"OASGP"; "OAMONS"; "VSPACE"; "UPOLYC"; "STEP"; "NNI"; "INT"}*/
-/*"AFALGRES" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "FFIELDC"; "FPC"; "PI"}*/
-/*"AFALGRES" -> {"VECTOR"; "OUTFORM"; "MONOID-"; "ABELMON-"; "ORDSET-"}*/
-/*"AFALGRES" -> {"SGROUP-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"AFALGRES" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "FLAGG-"}*/
-/*"AFALGRES" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "ENTIRER"; "FLINEXP"}*/
-/*"AFALGRES" -> {"URAGG-"; "DIRPCAT"; "DIFEXT"; "OAMON"}*/
-
-"DPMM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DPMM"]
-/*"DPMM" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"DPMM" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"DPMM" -> {"FRETRCT"; "RETRACT"; "BMODULE"; "LMODULE"; "ABELGRP"}*/
-/*"DPMM" -> {"CABMON"; "ABELMON"; "ABELSG"; "RMODULE"; "DIFEXT"; "RING"}*/
-/*"DPMM" -> {"RNG"; "SGROUP"; "MONOID"; "DIFRING"; "PDRING"; "FLINEXP"}*/
-/*"DPMM" -> {"LINEXP"; "FINITE"; "ALGEBRA"; "MODULE"; "COMRING"; "ORDRING"}*/
-/*"DPMM" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "OAMONS"}*/
-/*"DPMM" -> {"VSPACE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"DPMM" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-"DPMM" -> "SMATCAT"
-/*"DPMM" -> {"RMATCAT"; "SINT"; "PI"; "NNI"; "INT"; "INS"; "OINTDOM"}*/
-/*"DPMM" -> {"KONVERT"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-
-"EFUPXS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EFUPXS"]
-/*"EFUPXS" -> "PTRANFN"*/
-"EFUPXS" -> "UPXSCCA"
-/*"EFUPXS" -> {"UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"}*/
-/*"EFUPXS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"EFUPXS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"EFUPXS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"EFUPXS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
-/*"EFUPXS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"}*/
-/*"EFUPXS" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"EFUPXS" -> {"ULSCAT"; "NNI"; "INT"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"EFUPXS" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"}*/
-/*"EFUPXS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "OM"; "PI"}*/
-/*"EFUPXS" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
-/*"EFUPXS" -> {"A1AGG-"; "ISTRING"}*/
-
-"FFINTBAS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFINTBAS"]
-/*"FFINTBAS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"FFINTBAS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FFINTBAS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FFINTBAS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FFINTBAS" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"FFINTBAS" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"FFINTBAS" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"FFINTBAS" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"FFINTBAS" -> {"FIELD"; "DIVRING"}*/
-"FFINTBAS" -> "FRAMALG"
-/*"FFINTBAS" -> {"FINRALG"; "INT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"FFINTBAS" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "NNI"}*/
-
-"FRIDEAL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRIDEAL"]
-/*"FRIDEAL" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"}*/
-/*"FRIDEAL" -> {"KOERCE"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FRIDEAL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FRIDEAL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FRIDEAL" -> {"ENTIRER"; "QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"FRIDEAL" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"FRIDEAL" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"FRIDEAL" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
-/*"FRIDEAL" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FRIDEAL" -> {"REAL"; "CHARZ"; "CHARNZ"; "PFECAT"; "UPOLYC"; "POLYCAT"}*/
-/*"FRIDEAL" -> {"FAMR"; "AMR"; "FRETRCT"}*/
-"FRIDEAL" -> "FRAMALG"
-/*"FRIDEAL" -> {"FINRALG"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"FRIDEAL" -> {"HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "INT"; "VECTOR"}*/
-/*"FRIDEAL" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "BOOLEAN"}*/
-/*"FRIDEAL" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "OM"; "LIST"}*/
-/*"FRIDEAL" -> {"ILIST"; "LSAGG-"; "SINT"; "NNI"; "MONOID-"; "ABELMON-"}*/
-/*"FRIDEAL" -> {"INS"; "CFCAT"; "STAGG-"; "ELAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"FRIDEAL" -> {"FINITE"; "PI"}*/
-
-"FRIDEAL2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRIDEAL2"]
-/*"FRIDEAL2" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"FRIDEAL2" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FRIDEAL2" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FRIDEAL2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FRIDEAL2" -> {"QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
-/*"FRIDEAL2" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
-/*"FRIDEAL2" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"}*/
-/*"FRIDEAL2" -> {"FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"}*/
-/*"FRIDEAL2" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"FRIDEAL2" -> {"CHARZ"; "CHARNZ"; "PFECAT"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"FRIDEAL2" -> {"AMR"; "FRETRCT"}*/
-"FRIDEAL2" -> "FRAMALG"
-/*"FRIDEAL2" -> {"FINRALG"; "INS"; "CFCAT"; "OM"; "INT"; "VECTOR"; "IVECTOR"}*/
-/*"FRIDEAL2" -> "IARRAY1"*/
-
-"FRMOD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRMOD"]
-"FRMOD" -> "FRAMALG"
-/*"FRMOD" -> {"FINRALG"; "ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FRMOD" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FRMOD" -> {"MONOID"; "LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "CHARZ"}*/
-/*"FRMOD" -> {"CHARNZ"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FRMOD" -> {"ENTIRER"; "QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"FRMOD" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "DIFRING"}*/
-/*"FRMOD" -> {"PDRING"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"FRMOD" -> {"TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"}*/
-/*"FRMOD" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "PFECAT"}*/
-/*"FRMOD" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "FRETRCT"; "BOOLEAN"}*/
-/*"FRMOD" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"FRMOD" -> {"AGG"; "ELTAGG"; "CLAGG"; "INT"; "VECTOR"; "IVECTOR"}*/
-/*"FRMOD" -> {"IARRAY1"; "INS"; "CFCAT"; "OM"; "VECTCAT-"; "A1AGG-"; "NNI"}*/
-/*"FRMOD" -> "PI"*/
-
-"FSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FSAGG"]
-"FSAGG" -> "DIAGG"
-/*"FSAGG" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"FSAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
-/*"FSAGG" -> {"SETAGG"; "FINITE"; "NNI"; "INT"; "BOOLEAN"; "SINT"; "PI"}*/
-/*"FSAGG" -> {"INS-"; "ORDSET"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"FSAGG" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"}*/
-/*"FSAGG" -> {"ELAGG"; "OM"; "LSAGG-"}*/
-
-"FSAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FSAGG"]
-"FSAGG-" -> "DIAGG"
-/*"FSAGG-" -> {"DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE";  "SETCAT"}*/
-/*"FSAGG-" -> {"BASTYPE";  "KOERCE";  "EVALAB";  "IEVALAB";  "CLAGG"}*/
-/*"FSAGG-" -> {"KONVERT";  "SETAGG";  "FINITE";  "NNI";  "INT";  "BOOLEAN"}*/
-/*"FSAGG-" -> {"SINT";  "PI";  "INS-";  "ORDSET";  "LIST";  "ILIST"}*/
-/*"FSAGG-" -> {"LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "LNAGG";  "IXAGG"}*/
-/*"FSAGG-" -> {"ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG";  "OM";  "LSAGG-"}*/
-
-"IBATOOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IBATOOL"]
-/*"IBATOOL" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"IBATOOL" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"IBATOOL" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IBATOOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"IBATOOL" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"IBATOOL" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"IBATOOL" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"IBATOOL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "FIELD"}*/
-/*"IBATOOL" -> "DIVRING"*/
-"IBATOOL" -> "FRAMALG"
-/*"IBATOOL" -> {"FINRALG"; "SINT"; "NNI"; "INT"; "PI"; "INS"; "OINTDOM"}*/
-/*"IBATOOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
-/*"IBATOOL" -> {"REAL"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"}*/
-/*"IBATOOL" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"IBATOOL" -> {"TYPE"; "ELTAGG"; "CLAGG"}*/
-
-"INTFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTFACT"]
-/*"INTFACT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"INTFACT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"INTFACT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INTFACT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"INTFACT" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"INTFACT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"INTFACT" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"}*/
-/*"INTFACT" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"INTFACT" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"INTFACT" -> {"ABELMON-"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"INTFACT" -> {"PI"; "NNI"; "SINT"; "BOOLEAN"}*/
-"INTFACT" -> "MDAGG"
-/*"INTFACT" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"INTFACT" -> {"IEVALAB"; "CLAGG"}*/
-
-"KDAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=KDAGG"]
-"KDAGG" -> "DIAGG"
-/*"KDAGG" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"KDAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
-/*"KDAGG" -> "BOOLEAN"*/
-
-"KDAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=KDAGG"]
-"KDAGG-" -> "DIAGG"
-/*"KDAGG-" -> {"DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE";  "SETCAT"}*/
-/*"KDAGG-" -> {"BASTYPE";  "KOERCE";  "EVALAB";  "IEVALAB";  "CLAGG"}*/
-/*"KDAGG-" -> {"KONVERT";  "BOOLEAN"}*/
-
-"MSETAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MSETAGG"]
-"MSETAGG" -> "MDAGG"
-/*"MSETAGG" -> {"DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"MSETAGG" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"MSETAGG" -> {"KONVERT"; "SETAGG"}*/
-
-"MONOGEN" [color="#4488FF",href="bookvol10.2.pdf#nameddest=MONOGEN"]
-/*"MONOGEN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"MONOGEN" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"MONOGEN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"MONOGEN" -> "FRAMALG"
-/*"MONOGEN" -> {"FINRALG"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"MONOGEN" -> {"KONVERT"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"MONOGEN" -> {"FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"MONOGEN" -> {"ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"MONOGEN" -> {"FFIELDC"; "FPC"; "STEP"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"MONOGEN" -> {"AMR"; "EVALAB"; "IEVALAB"; "ORDSET"; "PATMAB"; "PFECAT"}*/
-/*"MONOGEN" -> {"ELTAB"; "NNI"; "INT"; "SINT"; "MONOID-"; "ABELMON-"}*/
-/*"MONOGEN" -> {"ORDSET-"; "SGROUP-"; "PI"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"MONOGEN" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"MONOGEN" -> {"OASGP"; "CFCAT"; "REAL"}*/
-
-"MONOGEN-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MONOGEN"]
-/*"MONOGEN-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
-/*"MONOGEN-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
-/*"MONOGEN-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
-"MONOGEN-" -> "FRAMALG"
-/*"MONOGEN-" -> {"FINRALG";  "ALGEBRA";  "MODULE";  "CHARZ";  "CHARNZ"}*/
-/*"MONOGEN-" -> {"KONVERT";  "FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP"}*/
-/*"MONOGEN-" -> {"FINITE";  "FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
-/*"MONOGEN-" -> {"ENTIRER";  "UFD";  "DIVRING";  "DIFEXT";  "DIFRING"}*/
-/*"MONOGEN-" -> {"PDRING";  "FFIELDC";  "FPC";  "STEP";  "UPOLYC"}*/
-/*"MONOGEN-" -> {"POLYCAT";  "FAMR";  "AMR";  "EVALAB";  "IEVALAB"}*/
-/*"MONOGEN-" -> {"ORDSET";  "PATMAB";  "PFECAT";  "ELTAB";  "NNI";  "INT"}*/
-/*"MONOGEN-" -> {"SINT";  "MONOID-";  "ABELMON-";  "ORDSET-";  "SGROUP-"}*/
-/*"MONOGEN-" -> {"PI";  "VECTOR";  "IVECTOR";  "IARRAY1";  "INS";  "OINTDOM"}*/
-/*"MONOGEN-" -> {"ORDRING";  "OAGROUP";  "OCAMON";  "OAMON";  "OASGP"}*/
-/*"MONOGEN-" -> {"CFCAT";  "REAL"}*/
-
-"NFINTBAS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NFINTBAS"]
-/*"NFINTBAS" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NFINTBAS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"NFINTBAS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"NFINTBAS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"NFINTBAS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"NFINTBAS" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"NFINTBAS" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
-/*"NFINTBAS" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"NFINTBAS" -> {"FIELD"; "DIVRING"}*/
-"NFINTBAS" -> "FRAMALG"
-/*"NFINTBAS" -> {"FINRALG"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "INS"}*/
-/*"NFINTBAS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"NFINTBAS" -> {"OASGP"; "CFCAT"; "REAL"; "OM"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"NFINTBAS" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"NFINTBAS" -> {"CLAGG"; "LIST"; "ILIST"; "PI"; "NNI"; "INS-"; "EUCDOM-"}*/
-
-\end{chunk}
-\subsection{Layer14}
-Depends on: FSAGG KDAGG MSETAGG MONOGEN\\
-Used by next layer: TBAGG
-\begin{chunk}{layer14}
-
-LAYER14=\
-  ${OUT}/BSD.o \
-  ${OUT}/CCLASS.o   ${OUT}/CPIMA.o   ${OUT}/FSAGG2.o   ${OUT}/GALFACT.o  \
-  ${OUT}/IALGFACT.o ${OUT}/IBACHIN.o  ${OUT}/MMLFORM.o ${OUT}/NORMMA.o   \
-  ${OUT}/ODERED.o   ${OUT}/OMSAGG.o   ${OUT}/PERM.o    ${OUT}/PERMGRP.o  \
-  ${OUT}/PRIMES.o   ${OUT}/PRJALGPK.o \
-  ${OUT}/PWFFINTB.o ${OUT}/RDIST.o   ${OUT}/SAE.o      \
-  ${OUT}/SAEFACT.o  ${OUT}/SAERFFC.o  ${OUT}/SGCF.o    ${OUT}/SPACE3.o   \
-  ${OUT}/TBAGG.o    ${OUT}/TBAGG-.o   ${OUT}/VIEW3D.o  ${OUT}/WFFINTBS.o \
-  layer14done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 14 */
-/* depends on: FSAGG KDAGG MSETAGG MONOGEN */
-
-"BSD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BSD",
-        shape=ellipse]
-/*"BSD" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "INT"}*/
-/*"BSD" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"BSD" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "OM"; "PATMAB"}*/
-"BSD" -> "FSAGG" 
-
-"CHAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CHAR",
-        shape=ellipse]
-/*"CHAR" -> {"ORDFIN"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
-/*"CHAR" -> {"SINT"; "INT"; "NNI"; "PRIMARR"; "A1AGG-"; "INS"; "UFD"}*/
-/*"CHAR" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"CHAR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CHAR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"CHAR" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"CHAR" -> {"OASGP"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"CHAR" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "PI"}*/
-"CHAR" -> "FSAGG" 
-/*"CHAR" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"CHAR" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "STRING"; "CHAR"; "OUTFORM"}*/
-/*"CHAR" -> {"LIST"; "ISTRING"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
-/*"CHAR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-
-"CCLASS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CCLASS"]
-/*"CCLASS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"}*/
-"CCLASS" -> "FSAGG"
-/*"CCLASS" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"CCLASS" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "ORDFIN"; "ORDSET"}*/
-/*"CCLASS" -> {"INT"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
-/*"CCLASS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "NNI"; "BOOLEAN"; "INS"; "UFD"}*/
-/*"CCLASS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"CCLASS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CCLASS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"CCLASS" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"CCLASS" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"CCLASS" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "FLAGG-"; "LNAGG-"}*/
-/*"CCLASS" -> {"BTAGG"; "LOGIC"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"CCLASS" -> {"ELTAGG"; "ELTAB"}*/
-
-"CPIMA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CPIMA"]
-/*"CPIMA" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"CPIMA" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"CPIMA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "UPOLYC"; "POLYCAT"}*/
-/*"CPIMA" -> {"PDRING"; "FAMR"; "AMR"; "ALGEBRA"; "MODULE"; "CHARZ"}*/
-/*"CPIMA" -> {"CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"CPIMA" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"CPIMA" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
-/*"CPIMA" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-"CPIMA" -> "MONOGEN"
-/*"CPIMA" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "NNI"; "INT"}*/
-
-"FSAGG2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSAGG2"]
-/*"FSAGG2" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"FSAGG2" -> "FSAGG"
-/*"FSAGG2" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FSAGG2" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "SETAGG"; "FINITE"}*/
-
-"GALFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GALFACT"]
-/*"GALFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"GALFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"GALFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"GALFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"GALFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"GALFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"GALFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
-/*"GALFACT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"GALFACT" -> {"FIELD"; "DIVRING"; "BOOLEAN"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"GALFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"GALFACT" -> {"OM"; "INT"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"GALFACT" -> {"INTDOM-"; "PI"; "NNI"; "OAMONS"}*/
-"GALFACT" -> "FSAGG"
-/*"GALFACT" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "CLAGG"}*/
-/*"GALFACT" -> {"SETAGG"; "FINITE"; "SINT"; "LIST"; "ILIST"; "ALGEBRA-"}*/
-/*"GALFACT" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"GALFACT" -> {"ABELMON-"; "FPS"; "RNS"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"GALFACT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "LSAGG"; "STAGG"}*/
-/*"GALFACT" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "FLAGG"}*/
-/*"GALFACT" -> {"ELAGG"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"GALFACT" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "MONOID-"; "ORDSET-"}*/
-/*"GALFACT" -> {"ABELSG-"; "SGROUP-"; "CLAGG-"; "HOAGG-"; "AGG-"; "ELTAGG-"}*/
-/*"GALFACT" -> {"SETCAT-"; "BASTYPE-"}*/
-
-"IALGFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IALGFACT"]
-/*"IALGFACT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"IALGFACT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IALGFACT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"IALGFACT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"IALGFACT" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
-/*"IALGFACT" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"IALGFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"IALGFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
-/*"IALGFACT" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
-"IALGFACT" -> "MONOGEN"
-/*"IALGFACT" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "NNI"}*/
-/*"IALGFACT" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"IALGFACT" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"IALGFACT" -> {"FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
-
-"IBACHIN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IBACHIN"]
-/*"IBACHIN" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"IBACHIN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"IBACHIN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"IBACHIN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"IBACHIN" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"IBACHIN" -> {"STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"IBACHIN" -> {"AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"IBACHIN" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"IBACHIN" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "SINT"; "NNI"; "INT"; "LIST"}*/
-/*"IBACHIN" -> {"ILIST"; "LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"IBACHIN" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"IBACHIN" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "PI"}*/
-"IBACHIN" -> "MONOGEN"
-/*"IBACHIN" -> {"FRAMALG"; "FINRALG"; "BOOLEAN"; "STAGG-"; "VECTCAT"}*/
-/*"IBACHIN" -> "A1AGG"*/
-
-"ISTRING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ISTRING",
-          shape=ellipse]
-/*"ISTRING" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"ISTRING" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"ISTRING" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"ISTRING" -> {"INT"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
-/*"ISTRING" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "INS"; "UFD"; "GCDDOM"}*/
-/*"ISTRING" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ISTRING" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ISTRING" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ISTRING" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ISTRING" -> {"OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"ISTRING" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "NNI"; "BOOLEAN"}*/
-"ISTRING" -> "FSAGG"
-/*"ISTRING" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "ORDFIN"}*/
-/*"ISTRING" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"ISTRING" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
-/*"ISTRING" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"}*/
-/*"ISTRING" -> {"URAGG"; "RCAGG"; "ELAGG"}*/
-
-"MMLFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MMLFORM"]
-/*"MMLFORM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "NNI"; "STRING"}*/
-/*"MMLFORM" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"}*/
-/*"MMLFORM" -> {"ISTRING"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"MMLFORM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"MMLFORM" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"MMLFORM" -> {"ORDSET"; "ELAGG"; "OM"; "STRICAT"; "SRAGG"; "A1AGG"; "PI"}*/
-"MMLFORM" -> "FSAGG"
-/*"MMLFORM" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "ORDFIN"}*/
-/*"MMLFORM" -> {"BOOLEAN"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"MMLFORM" -> "SRAGG-"*/
-
-"NORMMA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NORMMA"]
-/*"NORMMA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NORMMA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"NORMMA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"NORMMA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UPOLYC"; "POLYCAT"}*/
-/*"NORMMA" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"NORMMA" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"NORMMA" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "ELTAB"}*/
-/*"NORMMA" -> {"DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"}*/
-/*"NORMMA" -> "DIVRING"*/
-"NORMMA" -> "MONOGEN"
-/*"NORMMA" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-
-"ODERED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODERED"]
-/*"ODERED" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODERED" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODERED" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ODERED" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ODERED" -> {"DIVRING"; "LODOCAT"; "OREPCAT"; "FRETRCT"; "RETRACT"}*/
-/*"ODERED" -> {"ELTAB"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"ODERED" -> {"CHARZ"; "CHARNZ"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"ODERED" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "DIFRING"; "DIFEXT"}*/
-/*"ODERED" -> "STEP"*/
-"ODERED" -> "MONOGEN"
-/*"ODERED" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "VECTCAT"}*/
-/*"ODERED" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"ODERED" -> {"ELTAGG"; "CLAGG"; "NNI"; "INT"; "SINT"; "PI"}*/
-
-"OMSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OMSAGG"]
-/*"OMSAGG" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"OMSAGG" -> "MSETAGG"
-/*"OMSAGG" -> {"MDAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"OMSAGG" -> {"IEVALAB"; "CLAGG"; "KONVERT"; "SETAGG"; "PRQAGG"}*/
-
-"PERM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PERM"]
-/*"PERM" -> {"PERMCAT"; "GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"}*/
-/*"PERM" -> {"KOERCE"; "ORDSET"; "FINITE"; "INT"; "BOOLEAN"; "LIST"}*/
-/*"PERM" -> {"ILIST"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PERM" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PERM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PERM" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"PERM" -> {"OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"PERM" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LSAGG-"}*/
-/*"PERM" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "SINT"}*/
-/*"PERM" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PERM" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"PERM" -> {"CLAGG"; "FLAGG"; "ELAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-"PERM" -> "FSAGG"
-/*"PERM" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "NNI"; "INS-"; "EUCDOM-"}*/
-/*"PERM" -> {"UFD-"; "GCDDOM-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"PERM" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT-"}*/
-/*"PERM" -> {"A1AGG-"; "PI"}*/
-
-"PERMGRP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PERMGRP"]
-/*"PERMGRP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "BOOLEAN"}*/
-/*"PERMGRP" -> {"LIST"; "ILIST"; "SINT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"PERMGRP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PERMGRP" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PERMGRP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"PERMGRP" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PERMGRP" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"PERMGRP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LSAGG-"}*/
-/*"PERMGRP" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "LSAGG"}*/
-/*"PERMGRP" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"PERMGRP" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"PERMGRP" -> {"FLAGG"; "ELAGG"; "OAMONS"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"PERMGRP" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"PERMGRP" -> {"BASTYPE-"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"PERMGRP" -> {"A1AGG-"; "VECTCAT"; "A1AGG"}*/
-"PERMGRP" -> "FSAGG"
-/*"PERMGRP" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "PI"}*/
-/*"PERMGRP" -> {"PERMCAT"; "GROUP"}*/
-
-"PRIMES" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRIMES"]
-/*"PRIMES" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PRIMES" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PRIMES" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PRIMES" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"PRIMES" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"PRIMES" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"PRIMES" -> {"REAL"; "CHARZ"; "STEP"; "PI"; "NNI"; "INT"; "MONOID-"}*/
-/*"PRIMES" -> {"ABELSG-"; "SGROUP-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"PRIMES" -> {"VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"PRIMES" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"PRIMES" -> {"LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"PRIMES" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"PRIMES" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SINT"}*/
-/*"PRIMES" -> {"BOOLEAN"; "VECTCAT"; "A1AGG"}*/
-"PRIMES" -> "FSAGG"
-/*"PRIMES" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"; "LSAGG-"}*/
-/*"PRIMES" -> "STAGG-"*/
-
-"PRJALGPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRJALGPK"]
-"PRJALGPK" -> "AFALGGRO"
-/*"PRJALGPK" -> {"PRSPCAT"; "LOCPOWC"; "SETCATD"; "PACFFC"; "PACPERC"; "RFP"}*/
-/*"PRJALGPK" -> {"PLPKCRV"; "INTERGB"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PRJALGPK" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PRJALGPK" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PRJALGPK" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PRJALGPK" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"PRJALGPK" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"PRJALGPK" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"PRJALGPK" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"PRJALGPK" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"PRJALGPK" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
-/*"PRJALGPK" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
-/*"PRJALGPK" -> {"SINT"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"PRJALGPK" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
-/*"PRJALGPK" -> {"NNI"; "PI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"PRJALGPK" -> {"LSAGG-"; "STAGG-"; "FFIELDC"; "FPC"; "STEP"; "MONOID-"}*/
-/*"PRJALGPK" -> {"ABELMON-"; "ORDSET-"; "SGROUP-"; "ELAGG-"; "FLAGG-"}*/
-/*"PRJALGPK" -> {"URAGG-"; "OUTFORM"}*/
-
-"PWFFINTB" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PWFFINTB"]
-/*"PWFFINTB" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PWFFINTB" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PWFFINTB" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PWFFINTB" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PWFFINTB" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
-/*"PWFFINTB" -> {"FINITE"; "STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"PWFFINTB" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"PWFFINTB" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"PWFFINTB" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFEXT"}*/
-"PWFFINTB" -> "MONOGEN"
-/*"PWFFINTB" -> {"FRAMALG"; "FINRALG"; "QFCAT"; "FEVALAB"; "PATAB"}*/
-/*"PWFFINTB" -> {"FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PWFFINTB" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "OM"; "INT"; "LIST"}*/
-/*"PWFFINTB" -> {"ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PWFFINTB" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"PWFFINTB" -> {"CLAGG"; "FLAGG"; "ELAGG"; "PI"; "NNI"; "INS"; "CFCAT"}*/
-/*"PWFFINTB" -> {"VECTCAT"; "A1AGG"}*/
-
-"RDIST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDIST"]
-/*"RDIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INS"; "UFD"; "GCDDOM"}*/
-/*"RDIST" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"RDIST" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RDIST" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"RDIST" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"RDIST" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"RDIST" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"RDIST" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"RDIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"RDIST" -> {"VECTCAT"; "A1AGG"}*/
-"RDIST" -> "FSAGG"
-/*"RDIST" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"}*/
-
-"SAE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SAE"]
-/*"SAE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SAE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SAE" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"SAE" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"SAE" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"SAE" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-/*"SAE" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"SAE" -> {"PID"; "FIELD"; "DIVRING"}*/
-"SAE" -> "MONOGEN"
-/*"SAE" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "NNI"; "INT"}*/
-/*"SAE" -> {"BOOLEAN"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"SAE" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"SAE" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT"}*/
-/*"SAE" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"SAE" -> {"ELTAGG"; "CLAGG"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
-/*"SAE" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SAE" -> {"REAL"; "PI"; "INS"; "CFCAT"; "OAMONS"}*/
-
-"SAEFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SAEFACT"]
-/*"SAEFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SAEFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SAEFACT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"SAEFACT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"SAEFACT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"SAEFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"SAEFACT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
-/*"SAEFACT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"SAEFACT" -> {"FIELD"; "DIVRING"}*/
-"SAEFACT" -> "MONOGEN"
-/*"SAEFACT" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "INS"}*/
-/*"SAEFACT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SAEFACT" -> {"CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
-/*"SAEFACT" -> "TYPE"*/
-
-"SAERFFC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SAERFFC"]
-/*"SAERFFC" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SAERFFC" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SAERFFC" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"SAERFFC" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"SAERFFC" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"SAERFFC" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"SAERFFC" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
-/*"SAERFFC" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"SAERFFC" -> {"FIELD"; "DIVRING"}*/
-"SAERFFC" -> "MONOGEN"
-/*"SAERFFC" -> {"FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"; "INS"}*/
-/*"SAERFFC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"SAERFFC" -> {"OASGP"; "CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"}*/
-/*"SAERFFC" -> {"FPATMAB"; "TYPE"}*/
-
-"SGCF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SGCF"]
-/*"SGCF" -> {"INT"; "SINT"; "NNI"; "LIST"; "ILIST"; "LSAGG-"; "VECTOR"}*/
-/*"SGCF" -> {"IVECTOR"; "IARRAY1"; "BOOLEAN"; "STAGG-"; "VECTCAT"}*/
-/*"SGCF" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"SGCF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"SGCF" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTCAT-"; "A1AGG-"}*/
-/*"SGCF" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"SGCF" -> {"RCAGG"; "ELAGG"; "OM"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"SGCF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"SGCF" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SGCF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"SGCF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"SGCF" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"SGCF" -> {"STEP"; "ELAGG-"; "URAGG-"}*/
-"SGCF" -> "FSAGG"
-/*"SGCF" -> {"DIAGG"; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"}*/
-
-"SPACE3" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SPACE3"]
-/*"SPACE3" -> {"SPACEC"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
-/*"SPACE3" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"SPACE3" -> {"MONOID"; "LMODULE"; "BOOLEAN"; "INT"; "LIST"; "LSAGG"}*/
-/*"SPACE3" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"SPACE3" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"SPACE3" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
-/*"SPACE3" -> {"ILIST"; "NNI"; "PI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"SPACE3" -> {"URAGG-"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-"SPACE3" -> "FSAGG"
-/*"SPACE3" -> {"DIAGG" ; "DIOPS"; "BGAGG"; "SETAGG"; "FINITE"}*/
-
-"TBAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TBAGG"]
-"TBAGG" -> "KDAGG"
-/*"TBAGG" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"TBAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"TBAGG" -> {"CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"TBAGG" -> {"BOOLEAN"; "NNI"; "INT"; "LIST"; "ILIST"}*/
-
-"TBAGG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TBAGG"]
-"TBAGG-" -> "KDAGG"
-/*"TBAGG-" -> {"DIAGG";  "DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE"}*/
-/*"TBAGG-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "EVALAB";  "IEVALAB"}*/
-/*"TBAGG-" -> {"CLAGG";  "KONVERT";  "IXAGG";  "ELTAGG";  "ELTAB"}*/
-/*"TBAGG-" -> {"BOOLEAN";  "NNI";  "INT";  "LIST";  "ILIST"}*/
-
-"VIEW3D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VIEW3D"]
-/*"VIEW3D" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"; "DFLOAT"}*/
-/*"VIEW3D" -> {"BOOLEAN"; "PI"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"; "UFD-"}*/
-/*"VIEW3D" -> {"GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"VIEW3D" -> {"ORDRING-"; "MODULE-"; "FRAC"; "RING-"; "ABELGRP-"}*/
-/*"VIEW3D" -> {"ABELMON-"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
-/*"VIEW3D" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"VIEW3D" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"VIEW3D" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"VIEW3D" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"VIEW3D" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"VIEW3D" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"VIEW3D" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"}*/
-/*"VIEW3D" -> "OM"*/
-"VIEW3D" -> "FSAGG"
-/*"VIEW3D" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"VIEW3D" -> {"IEVALAB"; "CLAGG"; "SETAGG"; "FINITE"; "LSAGG"; "STAGG"}*/
-/*"VIEW3D" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"VIEW3D" -> {"FLAGG"; "ELAGG"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"VIEW3D" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"VIEW3D" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "INS"; "OINTDOM"}*/
-/*"VIEW3D" -> {"LINEXP"; "CFCAT"; "STEP"; "SRAGG-"; "STRICAT"; "SRAGG"}*/
-/*"VIEW3D" -> "A1AGG"*/
-
-"WFFINTBS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=WFFINTBS"]
-/*"WFFINTBS" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"WFFINTBS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"WFFINTBS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"WFFINTBS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"WFFINTBS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
-/*"WFFINTBS" -> {"FINITE"; "STEP"; "DIFRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"WFFINTBS" -> {"FAMR"; "AMR"; "CHARZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"WFFINTBS" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"WFFINTBS" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFEXT"; "FRAMALG"}*/
-/*"WFFINTBS" -> {"FINRALG"; "INT"; "LIST"; "ILIST"; "SINT"; "PI"; "NNI"}*/
-/*"WFFINTBS" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"}*/
-/*"WFFINTBS" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"WFFINTBS" -> {"ELTAGG"; "CLAGG"}*/
-"WFFINTBS" -> "MONOGEN"
-
-\end{chunk}
-\subsection{Layer15}
-Depends on: TBAGG\\
-Used by next layer: ALIST
-\begin{chunk}{layer15}
-
-LAYER15=\
-  ${OUT}/ALIST.o   ${OUT}/EQTBL.o   ${OUT}/GSTBL.o   ${OUT}/HASHTBL.o \
-  ${OUT}/INTABL.o  ${OUT}/INTFTBL.o ${OUT}/INTPACK.o ${OUT}/IPF.o     \
-  ${OUT}/KAFILE.o  ${OUT}/PATRES.o  ${OUT}/PDEPACK.o ${OUT}/STBL.o    \
-  ${OUT}/STRTBL.o  ${OUT}/TABLE.o   ${OUT}/TBCMPPK.o  \
-  layer15done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 15 */
-/* depends on: TBAGG */
-
-"ALAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ALAGG",
-         shape=ellipse]
-"ALAGG" -> "TBAGG"
-/*"ALAGG" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"ALAGG" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"ALAGG" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "LSAGG"; "STAGG"}*/
-/*"ALAGG" -> {"URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-
-"ALIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALIST"]
-/*"ALIST" -> "ALAGG"*/
-"ALIST" -> "TBAGG"
-/*"ALIST" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"ALIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"ALIST" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "LSAGG"; "STAGG"}*/
-/*"ALIST" -> {"URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"ALIST" -> {"INT"; "LIST"; "ILIST"; "OM"; "INS"; "UFD"; "GCDDOM"}*/
-/*"ALIST" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ALIST" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ALIST" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"ALIST" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ALIST" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"ALIST" -> {"CHARZ"; "STEP"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"ALIST" -> {"URAGG-"; "LNAGG-"; "BOOLEAN"; "STRING"; "CHAR"; "SINT"}*/
-/*"ALIST" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-
-"EQTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EQTBL"]
-"EQTBL" -> "TBAGG"
-/*"EQTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"EQTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"EQTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
-
-"FFIELDC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FFIELDC",
-          shape=ellipse]
-/*"FFIELDC" -> {"FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFIELDC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFIELDC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFIELDC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFIELDC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
-/*"FFIELDC" -> {"DIFRING"; "PI"; "NNI"; "INT"; "LIST"; "ILIST"; "VECTCAT"}*/
-/*"FFIELDC" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FFIELDC" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"FFIELDC" -> {"ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"FFIELDC" -> {"A1AGG-"; "BOOLEAN"; "SINT"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"FFIELDC" -> "OASGP"*/
-"FFIELDC" -> "TBAGG"
-/*"FFIELDC" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "INS-"; "INS"; "OINTDOM"}*/
-/*"FFIELDC" -> {"ORDRING"; "OAGROUP"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"FFIELDC" -> {"REAL"; "CHARZ"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"FFIELDC" -> {"AMR"; "FRETRCT"; "FLINEXP"; "PFECAT"; "DIFEXT"}*/
-
-"FFIELDC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFIELDC",
-          shape=ellipse]
-/*"FFIELDC-" -> {"FPC";  "FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM"}*/
-/*"FFIELDC-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
-/*"FFIELDC-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
-/*"FFIELDC-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
-/*"FFIELDC-" -> {"ALGEBRA";  "MODULE";  "ENTIRER";  "UFD";  "DIVRING"}*/
-/*"FFIELDC-" -> {"CHARNZ";  "FINITE";  "STEP";  "DIFRING";  "PI";  "NNI"}*/
-/*"FFIELDC-" -> {"INT";  "LIST";  "ILIST";  "VECTCAT";  "A1AGG";  "FLAGG"}*/
-/*"FFIELDC-" -> {"LNAGG";  "IXAGG";  "HOAGG";  "AGG";  "TYPE";  "EVALAB"}*/
-/*"FFIELDC-" -> {"IEVALAB";  "ELTAGG";  "ELTAB";  "CLAGG";  "KONVERT"}*/
-/*"FFIELDC-" -> {"ORDSET";  "VECTOR";  "IVECTOR";  "IARRAY1";  "VECTCAT-"}*/
-/*"FFIELDC-" -> {"A1AGG-";  "BOOLEAN";  "SINT";  "OAMONS";  "OCAMON"}*/
-/*"FFIELDC-" -> {"OAMON";  "OASGP"}*/
-"FFIELDC-" -> "TBAGG"
-/*"FFIELDC-" -> {"KDAGG";  "DIAGG";  "DIOPS";  "BGAGG";  "INS-";  "INS"}*/
-/*"FFIELDC-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "RETRACT";  "LINEXP"}*/
-/*"FFIELDC-" -> {"PATMAB";  "CFCAT";  "REAL";  "CHARZ";  "UPOLYC"}*/
-/*"FFIELDC-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "FRETRCT"}*/
-/*"FFIELDC-" -> {"FLINEXP";  "PFECAT";  "DIFEXT"}*/
-
-"GSTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GSTBL"]
-/*"GSTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"GSTBL" -> "TBAGG"
-/*"GSTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"GSTBL" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
-/*"GSTBL" -> {"ELTAB"; "ORDSET"}*/
-
-"HASHTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HASHTBL"]
-"HASHTBL" -> "TBAGG"
-/*"HASHTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"HASHTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"HASHTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
-
-"INTABL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTABL"]
-"INTABL" -> "TBAGG"
-/*"INTABL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"INTABL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"INTABL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
-
-"INTFTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INTFTBL"]
-"INTFTBL" -> "TBAGG"
-/*"INTFTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"INTFTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"INTFTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-
-"INTPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTPACK"]
-/*"INTPACK" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"INTPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"INTPACK" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INTPACK" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INTPACK" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"INTPACK" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"INTPACK" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
-/*"INTPACK" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "LSAGG"}*/
-/*"INTPACK" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"INTPACK" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"INTPACK" -> {"FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "DFLOAT"}*/
-/*"INTPACK" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"INTPACK" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"INTPACK" -> {"FLAGG-"; "LNAGG-"; "BOOLEAN"; "STAGG-"}*/
-"INTPACK" -> "TBAGG"
-/*"INTPACK" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "NNI"; "INS-"; "PI"}*/
-/*"INTPACK" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "ABELSG-"}*/
-/*"INTPACK" -> {"SETCAT-"; "BASTYPE-"; "STRICAT"; "SRAGG"; "A1AGG"}*/
-/*"INTPACK" -> "SPFCAT"*/
-
-"IPF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IPF"]
-/*"IPF" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"IPF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"IPF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"IPF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"IPF" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
-/*"IPF" -> {"DIFRING"; "FAXF"; "XF"; "RETRACT"; "VSPACE"; "CHARZ"; "KONVERT"}*/
-/*"IPF" -> {"PI"; "NNI"; "INT"; "LIST"; "BOOLEAN"; "OAMONS"; "OCAMON"}*/
-/*"IPF" -> {"OAMON"; "OASGP"; "ORDSET"}*/
-"IPF" -> "TBAGG"
-/*"IPF" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"IPF" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "SINT"}*/
-/*"IPF" -> {"INS-"; "ILIST"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"IPF" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "VECTOR"; "IVECTOR"}*/
-/*"IPF" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
-/*"IPF" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"IPF" -> "BASTYPE-"*/
-
-"KAFILE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=KAFILE"]
-/*"KAFILE" -> {"FILECAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"KAFILE" -> "TBAGG"
-/*"KAFILE" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"KAFILE" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
-/*"KAFILE" -> {"ELTAB"; "FNCAT"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"KAFILE" -> {"LIST"; "INT"; "PRIMARR"; "A1AGG-"; "ISTRING"; "LSAGG"}*/
-/*"KAFILE" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"}*/
-/*"KAFILE" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "STRICAT"}*/
-/*"KAFILE" -> {"SRAGG"; "A1AGG"; "ORDFIN"; "FINITE"}*/
-
-"PATRES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PATRES"]
-/*"PATRES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "BOOLEAN"; "ALAGG"}*/
-"PATRES" -> "TBAGG"
-/*"PATRES" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PATRES" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
-/*"PATRES" -> {"ELTAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"PATRES" -> {"FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"}*/
-
-"PDEPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PDEPACK"]
-/*"PDEPACK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"}*/
-/*"PDEPACK" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "ILIST"}*/
-"PDEPACK" -> "TBAGG"
-/*"PDEPACK" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PDEPACK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"PDEPACK" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "NNI"; "SYMBOL"}*/
-/*"PDEPACK" -> {"REF"; "ALIST"; "FLAGG-"; "LNAGG-"; "INS-"; "PI"; "FPS"}*/
-/*"PDEPACK" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"PDEPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PDEPACK" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PDEPACK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"PDEPACK" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"PDEPACK" -> {"REAL"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"}*/
-/*"PDEPACK" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"PDEPACK" -> "ELEMFUN"*/
-
-"STBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STBL"]
-/*"STBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"}*/
-"STBL" -> "TBAGG"
-/*"STBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"STBL" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
-/*"STBL" -> {"ELTAB"; "ORDSET"}*/
-
-"STRTBL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=STRTBL"]
-"STRTBL" -> "TBAGG"
-/*"STRTBL" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"STRTBL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"STRTBL" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "STRICAT"; "SRAGG"}*/
-/*"STRTBL" -> {"A1AGG"; "FLAGG"; "LNAGG"; "ORDSET"; "OM"; "ORDFIN"; "FINITE"}*/
-
-"TABLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TABLE"]
-"TABLE" -> "TBAGG"
-/*"TABLE" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"TABLE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"TABLE" -> {"KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ALAGG"; "LSAGG"}*/
-/*"TABLE" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "FLAGG"; "ORDSET"}*/
-/*"TABLE" -> "ELAGG"*/
-
-"TBCMPPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TBCMPPK"]
-/*"TBCMPPK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"; "NNI"; "INT"}*/
-/*"TBCMPPK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
-/*"TBCMPPK" -> {"A1AGG-"; "ISTRING"}*/
-"TBCMPPK" -> "TBAGG"
-/*"TBCMPPK" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"TBCMPPK" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
-/*"TBCMPPK" -> "ELTAB"*/
-
-\end{chunk}
-\subsection{Layer16}
-Depends on: ALIST\\
-Used by next layer: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT 
-\begin{chunk}{layer16}
-
-LAYER16=\
-  ${OUT}/ACF.o      ${OUT}/ACF-.o     ${OUT}/ACPLOT.o   ${OUT}/ANTISYM.o  \
-  ${OUT}/ANY.o      ${OUT}/ASP12.o    ${OUT}/ASP27.o    ${OUT}/ASP28.o    \
-  ${OUT}/ASP30.o    ${OUT}/ASP33.o    ${OUT}/ASP49.o    ${OUT}/ASP55.o    \
-  ${OUT}/ASP7.o     ${OUT}/ASP78.o    ${OUT}/ASP8.o     ${OUT}/ASP9.o     \
-  ${OUT}/ATTRBUT.o  ${OUT}/BLUPPACK.o \
-  ${OUT}/BOP.o      ${OUT}/BOP1.o     ${OUT}/COMMONOP.o \
-  ${OUT}/COMPCAT.o  ${OUT}/COMPCAT-.o ${OUT}/DRAW.o     ${OUT}/DRAWCFUN.o \
-  ${OUT}/DROPT.o    ${OUT}/DROPT0.o   ${OUT}/D01ANFA.o  ${OUT}/D01ASFA.o  \
-  ${OUT}/D03AGNT.o  ${OUT}/EP.o       ${OUT}/E04AGNT.o  ${OUT}/FCPAK1.o   \
-  ${OUT}/FEXPR.o    ${OUT}/FFCAT.o    ${OUT}/FFCAT-.o   ${OUT}/FFCGP.o    \
-  ${OUT}/FFNBP.o    ${OUT}/FFP.o      ${OUT}/FLOAT.o    ${OUT}/FPARFRAC.o \
-  ${OUT}/FR.o       ${OUT}/FRNAALG.o  ${OUT}/FRNAALG-.o ${OUT}/FS.o       \
-  ${OUT}/FS-.o      ${OUT}/FST.o      ${OUT}/FUNCTION.o ${OUT}/GDMP.o     \
-  ${OUT}/GOPT.o     ${OUT}/GOPT0.o    ${OUT}/HACKPI.o   ${OUT}/IDEAL.o    \
-  ${OUT}/INFCLCT.o  \
-  ${OUT}/INFORM.o   ${OUT}/INFORM1.o  ${OUT}/IPRNTPK.o  ${OUT}/IR.o       \
-  ${OUT}/ISUPS.o    ${OUT}/KERNEL.o   ${OUT}/LIB.o      ${OUT}/LMDICT.o   \
-  ${OUT}/LODO.o     ${OUT}/LODOOPS.o  ${OUT}/MATRIX.o   ${OUT}/MKFLCFN.o  \
-  ${OUT}/MSET.o     ${OUT}/M3D.o      ${OUT}/NAGC02.o   ${OUT}/NAGC05.o   \
-  ${OUT}/NAGC06.o   ${OUT}/NAGD01.o   ${OUT}/NAGD02.o   ${OUT}/NAGD03.o   \
-  ${OUT}/NAGE01.o   ${OUT}/NAGE02.o   ${OUT}/NAGE04.o   ${OUT}/NAGF07.o   \
-  ${OUT}/NAGS.o     ${OUT}/NAGSP.o    ${OUT}/NREP.o     ${OUT}/NSDPS.o    \
-  ${OUT}/NUMFMT.o   \
-  ${OUT}/OC.o       ${OUT}/OC-.o      ${OUT}/ODEPACK.o  ${OUT}/ODERAT.o   \
-  ${OUT}/OMERR.o    ${OUT}/OMERRK.o   ${OUT}/OPTPACK.o  ${OUT}/OSI.o      \
-  ${OUT}/OVAR.o     ${OUT}/PACOFF.o   ${OUT}/PACRAT.o  \
-  ${OUT}/PATTERN.o  ${OUT}/PLCS.o     ${OUT}/PMKERNEL.o ${OUT}/PMSYM.o    \
-  ${OUT}/POLY.o     ${OUT}/PRIMELT.o  ${OUT}/QALGSET2.o ${OUT}/QEQUAT.o   \
-  ${OUT}/QUATCAT.o  ${OUT}/QUATCAT-.o ${OUT}/RECLOS.o   ${OUT}/REP1.o     \
-  ${OUT}/RESULT.o   ${OUT}/RFFACT.o   ${OUT}/RMATRIX.o  ${OUT}/ROMAN.o    \
-  ${OUT}/ROUTINE.o  ${OUT}/RPOLCAT.o  ${OUT}/RPOLCAT-.o ${OUT}/RULECOLD.o \
-  ${OUT}/SAOS.o     ${OUT}/SEGBIND.o  ${OUT}/SET.o      ${OUT}/SPECOUT.o  \
-  ${OUT}/SQMATRIX.o ${OUT}/SWITCH.o   ${OUT}/SYMS.o     ${OUT}/SYMTAB.o   \
-  ${OUT}/SYSSOLP.o  ${OUT}/UTSCAT.o   ${OUT}/UTSCAT-.o  ${OUT}/VARIABLE.o \
-  layer16done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 16 */
-/* depends on: ALIST */
-
-"ACF" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ACF"]
-/*"ACF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ACF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ACF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ACF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ACF" -> {"DIVRING"; "RADCAT"; "SYMBOL"; "INT"; "REF"}*/
-"ACF" -> "ALIST"
-/*"ACF" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ACF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"ACF" -> {"NNI"; "PI"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"ACF" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"ACF" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"ACF" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"; "STAGG"}*/
-/*"ACF" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"}*/
-/*"ACF" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"}*/
-/*"ACF" -> {"ELAGG-"; "URAGG-"; "BOOLEAN"}*/
-
-"ACF-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ACF"]
-/*"ACF-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "COMRING"}*/
-/*"ACF-" -> {"RING";  "RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
-/*"ACF-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP";  "MONOID"}*/
-/*"ACF-" -> {"LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
-/*"ACF-" -> {"ENTIRER";  "UFD";  "DIVRING";  "RADCAT";  "SYMBOL";  "INT"}*/
-/*"ACF-" -> "REF"*/
-"ACF-" -> "ALIST"
-/*"ACF-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
-/*"ACF-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-";  "ILIST"}*/
-/*"ACF-" -> {"NNI";  "PI";  "UPOLYC";  "POLYCAT";  "PDRING";  "FAMR"}*/
-/*"ACF-" -> {"AMR";  "CHARZ";  "CHARNZ";  "FRETRCT";  "RETRACT";  "EVALAB"}*/
-/*"ACF-" -> {"IEVALAB";  "FLINEXP";  "LINEXP";  "ORDSET";  "KONVERT"}*/
-/*"ACF-" -> {"PATMAB";  "PFECAT";  "ELTAB";  "DIFRING";  "DIFEXT"}*/
-/*"ACF-" -> {"STEP";  "LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "HOAGG"}*/
-/*"ACF-" -> {"AGG";  "TYPE";  "LNAGG";  "IXAGG";  "ELTAGG";  "CLAGG"}*/
-/*"ACF-" -> {"FLAGG";  "ELAGG";  "OM";  "LSAGG-";  "STAGG-";  "ELAGG-"}*/
-/*"ACF-" -> {"URAGG-";  "BOOLEAN"}*/
-
-"ACPLOT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ACPLOT"]
-/*"ACPLOT" -> {"PPCURVE"; "KOERCE"; "PI"; "NNI"; "INT"; "DFLOAT"; "FPS"}*/
-/*"ACPLOT" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ACPLOT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ACPLOT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ACPLOT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ACPLOT" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ACPLOT" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ACPLOT" -> {"CHARZ"; "BOOLEAN"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ACPLOT" -> {"CFCAT"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"ACPLOT" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"ACPLOT" -> {"TYPE"; "CHARNZ"; "PFECAT"; "FPS-"; "RNS-"; "LIST"; "ILIST"}*/
-/*"ACPLOT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "OM"}*/
-/*"ACPLOT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
-/*"ACPLOT" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "SYMBOL"; "REF"}*/
-"ACPLOT" -> "ALIST" 
-/*"ACPLOT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"ACPLOT" -> {"ISTRING"; "SRAGG-"; "LNAGG-"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"ACPLOT" -> {"FRETRCT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"ACPLOT" -> {"ELEMFUN"; "SPFCAT"; "RCAGG-"; "IXAGG-"; "PTCAT"; "VECTCAT"}*/
-/*"ACPLOT" -> "A1AGG"*/
-
-"ANTISYM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ANTISYM"]
-/*"ANTISYM" -> {"LALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ANTISYM" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ANTISYM" -> {"LMODULE"; "RETRACT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ANTISYM" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"ANTISYM" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"ANTISYM" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "BOOLEAN"}*/
-/*"ANTISYM" -> {"NNI"; "SINT"; "LSAGG-"; "STAGG-"; "PI"; "INS-"; "EUCDOM-"}*/
-/*"ANTISYM" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"ANTISYM" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "SYMBOL"; "REF"}*/
-"ANTISYM" -> "ALIST"
-/*"ANTISYM" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"ANTISYM" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"ANY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ANY"]
-/*"ANY" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
-"ANY" -> "ALIST"
-/*"ANY" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ANY" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"ANY" -> "LSAGG-"*/
-
-"ASP12" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP12"]
-/*"ASP12" -> {"FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"ASP12" -> "ALIST"
-/*"ASP12" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP12" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"ASP12" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"ASP12" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"ASP12" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ASP12" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"ASP12" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"ASP12" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"ASP12" -> {"CHARZ"; "STEP"; "OM"}*/
-
-"ASP27" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP27"]
-/*"ASP27" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
-/*"ASP27" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP27" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP27" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP27" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"ASP27" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ASP27" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"ASP27" -> {"SINT"; "PI"; "NNI"; "INT"; "SYMBOL"; "REF"}*/
-"ASP27" -> "ALIST"
-/*"ASP27" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"ASP27" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FMTC"}*/
-
-"ASP28" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP28"]
-/*"ASP28" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
-/*"ASP28" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP28" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP28" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP28" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"ASP28" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ASP28" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"ASP28" -> {"SINT"; "PI"; "NNI"; "INT"; "SYMBOL"; "REF"}*/
-"ASP28" -> "ALIST"
-/*"ASP28" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"ASP28" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FMTC"; "VECTOR"}*/
-
-"ASP30" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP30"]
-/*"ASP30" -> {"FMC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
-/*"ASP30" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP30" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP30" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP30" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"ASP30" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ASP30" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"ASP30" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-/*"ASP30" -> {"SYMBOL"; "INT"; "REF"}*/
-"ASP30" -> "ALIST"
-/*"ASP30" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP30" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "OM"}*/
-
-"ASP33" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP33"]
-/*"ASP33" -> {"FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"ASP33" -> "ALIST"
-/*"ASP33" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP33" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-
-"ASP49" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP49"]
-/*"ASP49" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
-/*"ASP49" -> {"INT"; "REF"}*/
-"ASP49" -> "ALIST"
-/*"ASP49" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP49" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"ASP49" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP49" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP49" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP49" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP49" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP49" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP49" -> {"CHARZ"; "ES"; "IEVALAB"; "EVALAB"; "VECTCAT"; "A1AGG"}*/
-/*"ASP49" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
-/*"ASP49" -> {"ELTAB"; "CLAGG"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ASP49" -> {"ELAGG"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP49" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP49" -> {"FRETRCT"; "FLINEXP"; "PFECAT"}*/
-
-"ASP55" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP55"]
-/*"ASP55" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
-/*"ASP55" -> {"INT"; "REF"}*/
-"ASP55" -> "ALIST"
-/*"ASP55" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP55" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"ASP55" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP55" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP55" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP55" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP55" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP55" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP55" -> {"CHARZ"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"}*/
-/*"ASP55" -> {"STEP"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "NNI"}*/
-/*"ASP55" -> {"VECTCAT-"; "IXAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ASP55" -> {"HOAGG"; "AGG"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"ASP55" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "LSAGG-"}*/
-/*"ASP55" -> {"ES"; "VECTCAT"; "A1AGG"; "FMTC"; "POLYCAT"; "PDRING"}*/
-/*"ASP55" -> {"FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"; "PFECAT"}*/
-
-"ASP7" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP7"]
-/*"ASP7" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"ASP7" -> "ALIST"
-/*"ASP7" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP7" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"ASP7" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP7" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP7" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP7" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP7" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP7" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP7" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP7" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP7" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
-
-"ASP78" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP78"]
-/*"ASP78" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"ASP78" -> "ALIST"
-/*"ASP78" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP78" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"ASP78" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP78" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP78" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP78" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP78" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP78" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP78" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP78" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP78" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
-
-"ASP8" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP8"]
-/*"ASP8" -> {"FVC"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"; "RNS"}*/
-/*"ASP8" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP8" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP8" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP8" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"ASP8" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ASP8" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"ASP8" -> {"SYMBOL"; "INT"; "REF"}*/
-"ASP8" -> "ALIST"
-/*"ASP8" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP8" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
-/*"ASP8" -> {"OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "VECTCAT"}*/
-/*"ASP8" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "EVALAB"}*/
-/*"ASP8" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"; "IVECTOR"}*/
-/*"ASP8" -> {"IARRAY1"; "FMTC"; "NNI"; "OM"; "ILIST"}*/
-
-"ASP9" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP9"]
-/*"ASP9" -> {"FORTFN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"ASP9" -> "ALIST"
-/*"ASP9" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ASP9" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"ASP9" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP9" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP9" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP9" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP9" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP9" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP9" -> {"CHARZ"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP9" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP9" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
-
-"ATTRBUT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ATTRBUT"]
-/*"ATTRBUT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"; "FIELD"}*/
-/*"ATTRBUT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"ATTRBUT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"ATTRBUT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ATTRBUT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"ATTRBUT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"ATTRBUT" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INT"}*/
-/*"ATTRBUT" -> {"LIST"; "ILIST"; "SYMBOL"; "REF"}*/
-"ATTRBUT" -> "ALIST"
-/*"ATTRBUT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"ATTRBUT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"BOOLEAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BOOLEAN",
-           shape=ellipse]
-/*"BOOLEAN" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"; "LOGIC"}*/
-/*"BOOLEAN" -> {"KONVERT"; "BOOLEAN"; "INT"; "INS-"; "PI"; "NNI"; "SYMBOL"}*/
-/*"BOOLEAN" -> "REF"*/
-"BOOLEAN" -> "ALIST"
-/*"BOOLEAN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"BOOLEAN" -> {"A1AGG"; "ISTRING"; "SRAGG"; "FLAGG"; "LNAGG"}*/
-
-"BLUPPACK" [color="#88FF44",href="bookvol10.4.pdf#nameddest=BLUPPACK"]
-"BLUPPACK" -> "RFP"
-"BLUPPACK" -> "NPOLYGON"
-/*"BLUPPACK" -> {"BLMETCT"; "PFORP"; "AFFPL"; "PACPERC"; "FIELD"; "EUCDOM"}*/
-/*"BLUPPACK" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"BLUPPACK" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"BLUPPACK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"BLUPPACK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"BLUPPACK" -> {"UFD"; "DIVRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"BLUPPACK" -> {"FRETRCT"; "RETRACT"; "DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"BLUPPACK" -> {"TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "DIFEXT"}*/
-/*"BLUPPACK" -> {"DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"}*/
-/*"BLUPPACK" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"BLUPPACK" -> {"OAMONS"; "VSPACE"; "INT"; "LIST"; "ILIST"; "POLYCAT"}*/
-/*"BLUPPACK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"BLUPPACK" -> {"RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"}*/
-/*"BLUPPACK" -> {"LSAGG-"; "STAGG-"; "SINT"; "PI"; "ELAGG-"; "FLAGG-"}*/
-/*"BLUPPACK" -> {"URAGG-"; "BOOLEAN"; "VECTOR"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"BLUPPACK" -> {"STRING"; "CHAR"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"BLUPPACK" -> {"STAGG-"; "LNAGG-"}*/
-
-"BOP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=BOP"]
-/*"BOP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"BOP" -> "ALIST"
-/*"BOP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"BOP" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "STRICAT"; "SRAGG"}*/
-/*"BOP" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"BOP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"BOP" -> {"OM"; "BOOLEAN"; "NNI"; "FSAGG"; "DIAGG"; "DIOPS"; "BGAGG"}*/
-/*"BOP" -> {"SETAGG"; "FINITE"; "ORDFIN"}*/
-
-"BOP1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BOP1"]
-/*"BOP1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "SYMBOL"; "INT"; "REF"}*/
-"BOP1" -> "ALIST"
-/*"BOP1" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"BOP1" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
-/*"BOP1" -> {"BOOLEAN"; "KONVERT"}*/
-
-"COMMONOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMMONOP"]
-/*"COMMONOP" -> {"BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
-"COMMONOP" -> "ALIST"
-/*"COMMONOP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"COMMONOP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
-/*"COMMONOP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "PI"}*/
-
-"COMPCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=COMPCAT"]
-/*"COMPCAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"COMPCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"COMPCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "MONOGEN"}*/
-/*"COMPCAT" -> {"FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"COMPCAT" -> {"KONVERT"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"COMPCAT" -> {"FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"COMPCAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"COMPCAT" -> {"FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"COMPCAT" -> {"IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"; "PATAB"}*/
-/*"COMPCAT" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"COMPCAT" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "NNI"; "INT"; "PI"; "INS"}*/
-/*"COMPCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"COMPCAT" -> {"CFCAT"; "REAL"; "BOOLEAN"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"COMPCAT" -> {"AMR"; "LIST"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"COMPCAT" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"COMPCAT" -> {"AGG"; "ELTAGG"; "CLAGG"; "SYMBOL"; "REF"}*/
-"COMPCAT" -> "ALIST"
-/*"COMPCAT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"COMPCAT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "RNS"; "FPS"}*/
-
-"COMPCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMPCAT"]
-/*"COMPCAT-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
-/*"COMPCAT-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
-/*"COMPCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
-/*"COMPCAT-" -> {"MONOGEN";  "FRAMALG";  "FINRALG";  "ALGEBRA";  "MODULE"}*/
-/*"COMPCAT-" -> {"CHARZ";  "CHARNZ";  "KONVERT";  "FRETRCT";  "RETRACT"}*/
-/*"COMPCAT-" -> {"FLINEXP";  "LINEXP";  "FINITE";  "FIELD";  "EUCDOM"}*/
-/*"COMPCAT-" -> {"PID";  "GCDDOM";  "INTDOM";  "ENTIRER";  "UFD";  "DIVRING"}*/
-/*"COMPCAT-" -> {"DIFEXT";  "DIFRING";  "PDRING";  "FFIELDC";  "FPC"}*/
-/*"COMPCAT-" -> {"STEP";  "FEVALAB";  "ELTAB";  "EVALAB";  "IEVALAB"}*/
-/*"COMPCAT-" -> {"FPATMAB";  "TYPE";  "PATMAB";  "PATAB";  "ORDSET"}*/
-/*"COMPCAT-" -> {"TRANFUN";  "TRIGCAT";  "ATRIG";  "HYPCAT";  "AHYP"}*/
-/*"COMPCAT-" -> {"ELEMFUN";  "RADCAT";  "PFECAT";  "NNI";  "INT";  "PI"}*/
-/*"COMPCAT-" -> {"INS";  "OINTDOM";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
-/*"COMPCAT-" -> {"OAMON";  "OASGP";  "CFCAT";  "REAL";  "BOOLEAN"}*/
-/*"COMPCAT-" -> {"UPOLYC";  "POLYCAT";  "FAMR";  "AMR";  "LIST";  "OM"}*/
-/*"COMPCAT-" -> {"VECTOR";  "IVECTOR";  "IARRAY1";  "VECTCAT";  "A1AGG"}*/
-/*"COMPCAT-" -> {"FLAGG";  "LNAGG";  "IXAGG";  "HOAGG";  "AGG";  "ELTAGG"}*/
-/*"COMPCAT-" -> {"CLAGG";  "SYMBOL";  "REF"}*/
-"COMPCAT-" -> "ALIST"
-/*"COMPCAT-" -> {"STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
-/*"COMPCAT-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-"}*/
-/*"COMPCAT-" -> {"RNS";  "FPS"}*/
-
-"DRAW" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAW"]
-/*"DRAW" -> {"KONVERT"; "SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
-/*"DRAW" -> "REF"*/
-"DRAW" -> "ALIST"
-/*"DRAW" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"DRAW" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"DRAW" -> {"NNI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"DRAW" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DRAW" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"DRAW" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"DRAW" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"DRAW" -> {"REAL"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"DRAWCFUN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWCFUN"]
-/*"DRAWCFUN" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"DRAWCFUN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DRAWCFUN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DRAWCFUN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DRAWCFUN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"DRAWCFUN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"DRAWCFUN" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"DRAWCFUN" -> {"SYMBOL"; "INT"; "REF"}*/
-"DRAWCFUN" -> "ALIST"
-/*"DRAWCFUN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"DRAWCFUN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"DRAWCFUN" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "DFLOAT"}*/
-/*"DRAWCFUN" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"DRAWCFUN" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "NNI"; "PI"; "PTCAT"}*/
-/*"DRAWCFUN" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"DRAWCFUN" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"}*/
-/*"DRAWCFUN" -> {"CLAGG"; "BOOLEAN"}*/
-
-"DROPT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DROPT"]
-/*"DROPT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"DROPT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"DROPT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"DROPT" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-/*"DROPT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"DROPT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"DROPT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"DROPT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"DROPT" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"DROPT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "SYMBOL"; "REF"}*/
-"DROPT" -> "ALIST"
-/*"DROPT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"DROPT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "FPS"}*/
-/*"DROPT" -> {"RNS"; "FIELD"; "DIVRING"; "RADCAT"; "BOOLEAN"}*/
-
-"DROPT0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DROPT0"]
-/*"DROPT0" -> {"SYMBOL"; "INT"; "REF"}*/
-"DROPT0" -> "ALIST"
-/*"DROPT0" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"DROPT0" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"DROPT0" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"DROPT0" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"DROPT0" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"DROPT0" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"DROPT0" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DROPT0" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"DROPT0" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"D01ANFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01ANFA"]
-/*"D01ANFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-/*"D01ANFA" -> {"SYMBOL"; "REF"}*/
-"D01ANFA" -> "ALIST"
-/*"D01ANFA" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"D01ANFA" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"D01ANFA" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"D01ANFA" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"D01ANFA" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"D01ANFA" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"D01ANFA" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"D01ANFA" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"D01ANFA" -> {"CHARZ"; "DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"D01ANFA" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "PI"; "INS-"}*/
-/*"D01ANFA" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"D01ANFA" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"D01ANFA" -> "ABELMON-"*/
-
-"D01ASFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01ASFA"]
-/*"D01ASFA" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "NNI"; "INT"}*/
-/*"D01ASFA" -> {"SYMBOL"; "REF"}*/
-"D01ASFA" -> "ALIST"
-/*"D01ASFA" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"D01ASFA" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"D01ASFA" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"D01ASFA" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"D01ASFA" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"D01ASFA" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"D01ASFA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"D01ASFA" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"D01ASFA" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"D01ASFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "PI"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"D01ASFA" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"D01ASFA" -> {"MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"; "DFLOAT"}*/
-/*"D01ASFA" -> {"FPS-"; "RNS-"; "FIELD-"; "DIVRING-"}*/
-
-"D03AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D03AGNT"]
-/*"D03AGNT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"D03AGNT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"D03AGNT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"D03AGNT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"D03AGNT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"D03AGNT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"D03AGNT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
-/*"D03AGNT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-/*"D03AGNT" -> {"NNI"; "INT"; "INS"; "OINTDOM"; "LINEXP"; "CFCAT"; "STEP"}*/
-/*"D03AGNT" -> {"SYMBOL"; "REF"}*/
-"D03AGNT" -> "ALIST"
-/*"D03AGNT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"D03AGNT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
-/*"D03AGNT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"D03AGNT" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"D03AGNT" -> {"FLAGG"; "ELAGG"; "ILIST"; "LSAGG-"; "STAGG-"; "DFLOAT"}*/
-/*"D03AGNT" -> {"PI"; "BOOLEAN"; "ELAGG-"; "URAGG-"; "FPS-"; "RNS-"}*/
-/*"D03AGNT" -> {"FIELD-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "DIVRING-"}*/
-/*"D03AGNT" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-
-"EP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EP"]
-/*"EP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"EP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"EP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"EP" -> {"MODULE"; "ENTIRER"; "ORDSET"; "KONVERT"; "OM"; "PATMAB"}*/
-/*"EP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"EP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "PFECAT"}*/
-/*"EP" -> {"UFD"; "QFCAT"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"}*/
-/*"EP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
-/*"EP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"EP" -> {"REAL"; "NNI"; "INT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"EP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"EP" -> {"FLAGG"; "ELAGG"; "LIST"; "ILIST"; "SINT"; "PI"; "SYMBOL"; "REF"}*/
-"EP" -> "ALIST"
-/*"EP" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"EP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "UPOLYC"; "VECTOR"; "IVECTOR"}*/
-/*"EP" -> "IARRAY1"*/
-
-/* Note that ES has a circular self reference */
-"ES" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ES",
-      shape=ellipse]
-/*"ES" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"ES" -> {"IEVALAB"; "EVALAB"; "CACHSET"; "SYMBOL"; "INT"; "REF"}*/
-"ES" -> "ALIST"
-/*"ES" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"ES" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "FSAGG"}*/
-/*"ES" -> {"DIAGG" ; "DIOPS" ; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "CLAGG"}*/
-/*"ES" -> {"KONVERT"; "SETAGG"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"ES" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"}*/
-/*"ES" -> {"OM"; "PATAB"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "NNI"}*/
-/*"ES" -> {"PATMAB"; "URAGG-"}*/
-
-"ES-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ES",
-       shape=ellipse]
-/*"ES-" -> {"ES";  "ORDSET";  "SETCAT";  "BASTYPE";  "KOERCE";  "RETRACT"}*/
-/*"ES-" -> {"IEVALAB";  "EVALAB";  "CACHSET";  "SYMBOL";  "INT";  "REF"}*/
-"ES-" -> "ALIST"
-/*"ES-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
-/*"ES-" -> {"A1AGG";  "ISTRING";  "SRAGG";  "FLAGG";  "LNAGG";  "BOOLEAN"}*/
-/*"ES-" -> {"FSAGG";  "DIAGG";  "DIOPS";  "BGAGG";  "HOAGG";  "AGG";  "TYPE"}*/
-/*"ES-" -> {"CLAGG";  "KONVERT";  "SETAGG";  "FINITE";  "LSAGG";  "STAGG"}*/
-/*"ES-" -> {"URAGG";  "RCAGG";  "LNAGG";  "IXAGG";  "ELTAGG";  "ELTAB"}*/
-/*"ES-" -> {"FLAGG";  "ELAGG";  "OM";  "PATAB";  "ILIST";  "LSAGG"}*/
-/*"ES-" -> {"STAGG";  "ELAGG";  "NNI";  "PATMAB";  "URAGG"}*/
-
-"E04AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=E04AGNT"]
-/*"E04AGNT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"E04AGNT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"E04AGNT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"E04AGNT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"E04AGNT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"E04AGNT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"E04AGNT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
-/*"E04AGNT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-/*"E04AGNT" -> {"DFLOAT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"E04AGNT" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"E04AGNT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "INT"; "LIST"}*/
-/*"E04AGNT" -> {"ILIST"; "SINT"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"E04AGNT" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "INS"}*/
-/*"E04AGNT" -> {"OINTDOM"; "LINEXP"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"}*/
-/*"E04AGNT" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"E04AGNT" -> {"CHARNZ"; "PFECAT"; "BOOLEAN"; "SYMBOL"; "REF"}*/
-"E04AGNT" -> "ALIST"
-/*"E04AGNT" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"E04AGNT" -> {"ISTRING"; "SRAGG-"; "PI"; "VECTOR"}*/
-
-"FCPAK1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FCPAK1"]
-/*"FCPAK1" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FCPAK1" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FCPAK1" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FCPAK1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FCPAK1" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FCPAK1" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"FCPAK1" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-/*"FCPAK1" -> {"SYMBOL"; "INT"; "REF"}*/
-"FCPAK1" -> "ALIST"
-/*"FCPAK1" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"FCPAK1" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"FEXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FEXPR"]
-/*"FEXPR" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"FEXPR" -> {"IEVALAB"; "EVALAB"; "ALGEBRA"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FEXPR" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FEXPR" -> {"MODULE"; "BMODULE"; "RMODULE"; "PDRING"; "FMTC"; "INTDOM"}*/
-/*"FEXPR" -> {"COMRING"; "ENTIRER"; "BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
-"FEXPR" -> "ALIST"
-/*"FEXPR" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"FEXPR" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
-/*"FEXPR" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"FEXPR" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"FEXPR" -> {"ELAGG"; "OM"; "ILIST"; "NNI"; "PATMAB"; "INS"; "UFD"}*/
-/*"FEXPR" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"FEXPR" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "LINEXP"; "CFCAT"}*/
-/*"FEXPR" -> {"REAL"; "CHARZ"; "STEP"; "POLYCAT"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"FEXPR" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "FPS"; "RNS"; "FIELD"}*/
-/*"FEXPR" -> {"DIVRING"; "RADCAT"}*/
-
-"FFCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FFCAT"]
-/*"FFCAT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FFCAT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FFCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"FFCAT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"FFCAT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"}*/
-/*"FFCAT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"FFCAT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
-/*"FFCAT" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-/*"FFCAT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
-/*"FFCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"FFCAT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"FFCAT" -> {"INT"; "BOOLEAN"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"FFCAT" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "SINT"; "VECTOR"}*/
-/*"FFCAT" -> {"IVECTOR"; "IARRAY1"; "SYMBOL"; "REF"}*/
-"FFCAT" -> "ALIST"
-/*"FFCAT" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"FFCAT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"}*/
-/*"FFCAT" -> {"STAGG-"; "INS"; "CFCAT"; "OM"; "VECTCAT-"; "PI"}*/
-
-"FFCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCAT"]
-/*"FFCAT-" -> {"UPOLYC";  "POLYCAT";  "PDRING";  "RING";  "RNG"}*/
-/*"FFCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
-/*"FFCAT-" -> {"BASTYPE";  "KOERCE";  "SGROUP";  "MONOID";  "LMODULE"}*/
-/*"FFCAT-" -> {"FAMR";  "AMR";  "BMODULE";  "RMODULE";  "COMRING"}*/
-/*"FFCAT-" -> {"ALGEBRA";  "MODULE";  "CHARZ";  "CHARNZ";  "INTDOM"}*/
-/*"FFCAT-" -> {"ENTIRER";  "FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB"}*/
-/*"FFCAT-" -> {"FLINEXP";  "LINEXP";  "ORDSET";  "KONVERT";  "PATMAB"}*/
-/*"FFCAT-" -> {"GCDDOM";  "PFECAT";  "UFD";  "ELTAB";  "DIFRING";  "DIFEXT"}*/
-/*"FFCAT-" -> {"STEP";  "EUCDOM";  "PID";  "FIELD";  "DIVRING";  "QFCAT"}*/
-/*"FFCAT-" -> {"FEVALAB";  "PATAB";  "FPATMAB";  "TYPE";  "OINTDOM"}*/
-/*"FFCAT-" -> {"ORDRING";  "OAGROUP";  "OCAMON";  "OAMON";  "OASGP"}*/
-/*"FFCAT-" -> {"REAL";  "MONOGEN";  "FRAMALG";  "FINRALG";  "FINITE"}*/
-/*"FFCAT-" -> {"FFIELDC";  "FPC";  "INT";  "BOOLEAN";  "NNI";  "VECTCAT"}*/
-/*"FFCAT-" -> {"A1AGG";  "FLAGG";  "LNAGG";  "IXAGG";  "HOAGG";  "AGG"}*/
-/*"FFCAT-" -> {"ELTAGG";  "CLAGG";  "SINT";  "VECTOR";  "IVECTOR"}*/
-/*"FFCAT-" -> {"IARRAY1";  "SYMBOL";  "REF"}*/
-"FFCAT-" -> "ALIST"
-/*"FFCAT-" -> {"LIST";  "STRING";  "CHAR";  "OUTFORM";  "PRIMARR";  "A1AGG-"}*/
-/*"FFCAT-" -> {"ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-";  "ILIST"}*/
-/*"FFCAT-" -> {"LSAGG-";  "STAGG-";  "INS";  "CFCAT";  "OM";  "VECTCAT-"}*/
-/*"FFCAT-" -> "PI"*/
-
-"FFCGP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFCGP"]
-/*"FFCGP" -> {"FAXF"; "XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFCGP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFCGP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFCGP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFCGP" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
-/*"FFCGP" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
-/*"FFCGP" -> {"NNI"; "INT"; "MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"}*/
-/*"FFCGP" -> {"PI"; "SINT"; "PRIMARR"; "SYMBOL"; "REF"}*/
-"FFCGP" -> "ALIST"
-/*"FFCGP" -> {"LIST"; "STRING"; "CHAR"; "OUTFORM"; "A1AGG-"; "ISTRING"}*/
-/*"FFCGP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "OAMONS"; "OCAMON"}*/
-/*"FFCGP" -> {"OAMON"; "OASGP"; "ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"FFCGP" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"FFCGP" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"FFCGP" -> {"ILIST"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "KONVERT"}*/
-/*"FFCGP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-
-"FFNBP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFNBP"]
-/*"FFNBP" -> {"FAXF"; "XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFNBP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFNBP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFNBP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FFNBP" -> {"ENTIRER"; "UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"}*/
-/*"FFNBP" -> {"FPC"; "CHARNZ"; "FINITE"; "FFIELDC"; "STEP"; "DIFRING"}*/
-/*"FFNBP" -> {"SYMBOL"; "INT"; "REF"}*/
-"FFNBP" -> "ALIST"
-/*"FFNBP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"FFNBP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"FFNBP" -> {"PI"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"}*/
-/*"FFNBP" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FFNBP" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"FFNBP" -> {"ORDSET"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "TBAGG"}*/
-/*"FFNBP" -> {"KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "VECTCAT-"; "UPOLYC"}*/
-/*"FFNBP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "FRETRCT"; "FLINEXP"}*/
-/*"FFNBP" -> {"LINEXP"; "PATMAB"; "PFECAT"; "DIFEXT"; "LSAGG"; "STAGG"}*/
-/*"FFNBP" -> {"URAGG"; "RCAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"; "MONOID-"}*/
-/*"FFNBP" -> {"ABELMON-"; "ORDSET-"; "SGROUP-"; "INS-"; "INS"; "OINTDOM"}*/
-/*"FFNBP" -> {"ORDRING"; "OAGROUP"; "CFCAT"; "REAL"; "IXAGG-"; "CLAGG-"}*/
-/*"FFNBP" -> {"HOAGG-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-
-"FFP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FFP"]
-/*"FFP" -> {"FAXF"; "XF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FFP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FFP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FFP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FFP" -> {"UFD"; "DIVRING"; "RETRACT"; "VSPACE"; "CHARZ"; "FPC"; "CHARNZ"}*/
-/*"FFP" -> {"FINITE"; "FFIELDC"; "STEP"; "DIFRING"; "SYMBOL"; "INT"; "REF"}*/
-"FFP" -> "ALIST"
-/*"FFP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"FFP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
-/*"FFP" -> {"MONOID-"; "ABELMON-"; "ORDSET-"; "SGROUP-"; "PI"; "BOOLEAN"}*/
-/*"FFP" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "TBAGG"; "KDAGG"}*/
-/*"FFP" -> {"DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"FFP" -> {"IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"FFP" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "IXAGG-"; "CLAGG-"}*/
-/*"FFP" -> {"HOAGG-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "ILIST"}*/
-/*"FFP" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "INS-"; "INS"; "OINTDOM"}*/
-/*"FFP" -> {"ORDRING"; "OAGROUP"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-
-"FLOAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FLOAT"]
-/*"FLOAT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FLOAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FLOAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FLOAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FLOAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FLOAT" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"FLOAT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"; "TRANFUN"}*/
-/*"FLOAT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "INS-"}*/
-/*"FLOAT" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"FLOAT" -> {"DIFRING-"; "ORDRING-"; "PI"; "NNI"; "MODULE-"; "RING-"}*/
-/*"FLOAT" -> {"ABELGRP-"; "ABELMON-"; "SINT"; "BOOLEAN"; "MONOID-"}*/
-/*"FLOAT" -> {"ABELSG-"; "SGROUP-"; "ORDSET-"; "INS"; "OINTDOM"; "LINEXP"}*/
-/*"FLOAT" -> {"CFCAT"; "STEP"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"}*/
-/*"FLOAT" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"FLOAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "STRING"; "CHAR"; "OUTFORM"}*/
-/*"FLOAT" -> {"LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"FLOAT" -> {"LNAGG-"; "SYMBOL"; "REF"}*/
-"FLOAT" -> "ALIST"
-/*"FLOAT" -> "DFLOAT"*/
-
-"FPARFRAC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FPARFRAC"]
-/*"FPARFRAC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "UPOLYC"}*/
-/*"FPARFRAC" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FPARFRAC" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FPARFRAC" -> {"FAMR"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"FPARFRAC" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"FPARFRAC" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"FPARFRAC" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "PATMAB"; "GCDDOM"}*/
-/*"FPARFRAC" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"FPARFRAC" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
-"FPARFRAC" -> "ALIST"
-/*"FPARFRAC" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"FPARFRAC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
-/*"FPARFRAC" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
-/*"FPARFRAC" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"FPARFRAC" -> {"PI"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "DPOLCAT"}*/
-/*"FPARFRAC" -> {"INS"; "CFCAT"}*/
-
-"FR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FR"]
-/*"FR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FR" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FR" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FR" -> {"ENTIRER"; "DIFEXT"; "DIFRING"; "PDRING"; "FEVALAB"; "ELTAB"}*/
-/*"FR" -> {"EVALAB"; "IEVALAB"; "FRETRCT"; "RETRACT"; "GCDDOM"; "REAL"}*/
-/*"FR" -> {"KONVERT"; "UFD"; "INT"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
-"FR" -> "ALIST"
-/*"FR" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"FR" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ORDSET"; "BOOLEAN"}*/
-/*"FR" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"FR" -> {"NNI"; "INS"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"FR" -> {"OCAMON"; "OAMON"; "OASGP"; "LINEXP"; "PATMAB"; "CFCAT"; "CHARZ"}*/
-/*"FR" -> {"STEP"; "DFLOAT"; "LSAGG-"; "STAGG-"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"FR" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"FR" -> {"MODULE-"; "RING-"; "ABELGRP-"; "PI"; "ELAGG-"; "URAGG-"}*/
-
-"FRNAALG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FRNAALG"]
-/*"FRNAALG" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
-/*"FRNAALG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FRNAALG" -> {"MONAD"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"}*/
-/*"FRNAALG" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "FIELD"}*/
-/*"FRNAALG" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "ENTIRER"}*/
-/*"FRNAALG" -> {"UFD"; "DIVRING"; "SINT"; "PI"; "NNI"; "INT"; "STRING"}*/
-/*"FRNAALG" -> {"CHAR"; "OUTFORM"; "LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"FRNAALG" -> {"SYMBOL"; "REF"}*/
-"FRNAALG" -> "ALIST"
-/*"FRNAALG" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"FRNAALG" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"FRNAALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"FRNAALG" -> {"PATMAB"; "PFECAT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"FRNAALG" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"FRNAALG" -> {"AGG"; "TYPE"; "ELTAGG"; "ELTAB"; "CLAGG"; "VECTCAT-"}*/
-/*"FRNAALG" -> {"ILIST"; "MONOID-"; "ABELSG-"; "SGROUP-"; "INS"; "OINTDOM"}*/
-/*"FRNAALG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"FRNAALG" -> {"CFCAT"; "REAL"; "STEP"; "OM"}*/
-
-"FRNAALG-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FRNAALG"]
-/*"FRNAALG-" -> {"FINAALG";  "NAALG";  "NARNG";  "ABELGRP";  "CABMON"}*/
-/*"FRNAALG-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
-/*"FRNAALG-" -> {"MONAD";  "MODULE";  "BMODULE";  "LMODULE";  "RMODULE"}*/
-/*"FRNAALG-" -> {"COMRING";  "RING";  "RNG";  "SGROUP";  "MONOID";  "FIELD"}*/
-/*"FRNAALG-" -> {"EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "ALGEBRA"}*/
-/*"FRNAALG-" -> {"ENTIRER";  "UFD";  "DIVRING";  "SINT";  "PI";  "NNI"}*/
-/*"FRNAALG-" -> {"INT";  "STRING";  "CHAR";  "OUTFORM";  "LIST";  "PRIMARR"}*/
-/*"FRNAALG-" -> {"A1AGG-";  "ISTRING";  "SYMBOL";  "REF"}*/
-"FRNAALG-" -> "ALIST"
-/*"FRNAALG-" -> {"SRAGG-";  "FLAGG-";  "LNAGG-";  "POLYCAT";  "PDRING"}*/
-/*"FRNAALG-" -> {"FAMR";  "AMR";  "CHARZ";  "CHARNZ";  "FRETRCT";  "RETRACT"}*/
-/*"FRNAALG-" -> {"EVALAB";  "IEVALAB";  "FLINEXP";  "LINEXP";  "ORDSET"}*/
-/*"FRNAALG-" -> {"KONVERT";  "PATMAB";  "PFECAT";  "VECTOR";  "IVECTOR"}*/
-/*"FRNAALG-" -> {"IARRAY1";  "VECTCAT";  "A1AGG";  "FLAGG";  "LNAGG"}*/
-/*"FRNAALG-" -> {"IXAGG";  "HOAGG";  "AGG";  "TYPE";  "ELTAGG";  "ELTAB"}*/
-/*"FRNAALG-" -> {"CLAGG";  "VECTCAT-";  "ILIST";  "MONOID-";  "ABELSG-"}*/
-/*"FRNAALG-" -> {"SGROUP-";  "INS";  "OINTDOM";  "ORDRING";  "OAGROUP"}*/
-/*"FRNAALG-" -> {"OCAMON";  "OAMON";  "OASGP";  "DIFRING";  "CFCAT"}*/
-/*"FRNAALG-" -> {"REAL";  "STEP";  "OM"}*/
-
-"FS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FS"]
-/*"FS" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"FS" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"FS" -> {"PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"; "ABELMON"}*/
-/*"FS" -> {"ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"; "LMODULE"}*/
-/*"FS" -> {"PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"}*/
-/*"FS" -> {"MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"FS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"FS" -> {"SYMBOL"; "INT"; "REF"}*/
-"FS" -> "ALIST"
-/*"FS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"FS" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "BOOLEAN"}*/
-/*"FS" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
-/*"FS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"FS" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "CACHSET"; "NNI"}*/
-/*"FS" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"FS" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"FS" -> {"PFECAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FS" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "PI"; "FPS"}*/
-/*"FS" -> {"RNS"; "RADCAT"; "UPOLYC"; "DIFEXT"; "QFCAT"; "FEVALAB"}*/
-
-"FS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FS"]
-/*"FS-" -> {"ES";  "ORDSET";  "SETCAT";  "BASTYPE";  "KOERCE";  "RETRACT"}*/
-/*"FS-" -> {"IEVALAB";  "EVALAB";  "PATAB";  "KONVERT";  "FPATMAB";  "TYPE"}*/
-/*"FS-" -> {"PATMAB";  "FRETRCT";  "MONOID";  "SGROUP";  "GROUP";  "ABELMON"}*/
-/*"FS-" -> {"ABELSG";  "ABELGRP";  "CABMON";  "RING";  "RNG";  "LMODULE"}*/
-/*"FS-" -> {"PDRING";  "FLINEXP";  "LINEXP";  "CHARZ";  "CHARNZ";  "ALGEBRA"}*/
-/*"FS-" -> {"MODULE";  "BMODULE";  "RMODULE";  "FIELD";  "EUCDOM";  "PID"}*/
-/*"FS-" -> {"GCDDOM";  "INTDOM";  "COMRING";  "ENTIRER";  "UFD";  "DIVRING"}*/
-/*"FS-" -> {"SYMBOL";  "INT";  "REF"}*/
-"FS-" -> "ALIST"
-/*"FS-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
-/*"FS-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-";  "ILIST"}*/
-/*"FS-" -> {"BOOLEAN";  "LSAGG-";  "STAGG-";  "ELAGG-";  "URAGG-";  "LSAGG"}*/
-/*"FS-" -> {"STAGG";  "URAGG";  "RCAGG";  "HOAGG";  "AGG";  "LNAGG"}*/
-/*"FS-" -> {"IXAGG";  "ELTAGG";  "ELTAB";  "CLAGG";  "FLAGG";  "ELAGG"}*/
-/*"FS-" -> {"OM";  "CACHSET";  "NNI";  "RCAGG-";  "IXAGG-";  "CLAGG-"}*/
-/*"FS-" -> {"HOAGG-";  "ORDSET-";  "AGG-";  "ELTAGG-";  "SETCAT-"}*/
-/*"FS-" -> {"BASTYPE-";  "POLYCAT";  "FAMR";  "AMR";  "PFECAT";  "INS"}*/
-/*"FS-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "OCAMON";  "OAMON"}*/
-/*"FS-" -> {"OASGP";  "DIFRING";  "CFCAT";  "REAL";  "STEP";  "PI";  "FPS"}*/
-/*"FS-" -> {"RNS";  "RADCAT";  "UPOLYC";  "DIFEXT";  "QFCAT";  "FEVALAB"}*/
-
-"FST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FST"]
-/*"FST" -> {"KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"FST" -> "ALIST"
-/*"FST" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"FST" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-
-"FUNCTION" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FUNCTION"]
-/*"FUNCTION" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"FUNCTION" -> "ALIST"
-/*"FUNCTION" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"FUNCTION" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"FUNCTION" -> "BOOLEAN"*/
-
-"GDMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GDMP"]
-/*"GDMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"GDMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"GDMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"GDMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"GDMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"GDMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
-/*"GDMP" -> {"UFD"; "DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"GDMP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
-/*"GDMP" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "FIELD"}*/
-/*"GDMP" -> {"EUCDOM"; "PID"; "DIVRING"; "ORDFIN"; "LSAGG"; "STAGG"}*/
-/*"GDMP" -> {"URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"GDMP" -> {"INT"; "LIST"; "ILIST"; "NNI"; "VECTCAT"; "A1AGG"; "VECTOR"}*/
-/*"GDMP" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "SINT"; "PI"}*/
-/*"GDMP" -> {"BOOLEAN"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"GDMP" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG-"}*/
-/*"GDMP" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "FPS"; "RNS"; "REAL"}*/
-/*"GDMP" -> {"RADCAT"; "SYMBOL"; "REF"}*/
-"GDMP" -> "ALIST"
-/*"GDMP" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
-/*"GDMP" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "UPOLYC"}*/
-
-"GOPT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GOPT"]
-/*"GOPT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"GOPT" -> "ALIST"
-/*"GOPT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"GOPT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"GOPT" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
-/*"GOPT" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"GOPT" -> {"SETCAT-"; "BASTYPE-"}*/
-
-"GOPT0" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GOPT0"]
-"GOPT0" -> "STRING"
-/*"GOPT0" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PI";"NNI"; "INT"; "BOOLEAN"}*/
-/*"GOPT0" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "PRIMARR"}*/
-/*"GOPT0" -> {"A1AGG-"; "ISTRING"; "MONOID-"; "ABELSG-"; "SGROUP-"; }*/
-/*"GOPT0" -> {"ORDSET-"; "SETCAT-"; "BASTYPE-"}*/
-
-"HACKPI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HACKPI"]
-/*"HACKPI" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"HACKPI" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"HACKPI" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"HACKPI" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"HACKPI" -> {"DIVRING"; "CHARZ"; "RETRACT"; "REAL"; "KONVERT"; "INS"}*/
-/*"HACKPI" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"HACKPI" -> {"ORDSET"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "STEP"}*/
-/*"HACKPI" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"HACKPI" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
-/*"HACKPI" -> {"ELTAB"; "DIFEXT"; "SYMBOL"; "INT"; "REF"}*/
-"HACKPI" -> "ALIST"
-/*"HACKPI" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"HACKPI" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
-/*"HACKPI" -> {"DFLOAT"; "OM"; "BOOLEAN"; "FPS"; "RNS"; "RADCAT"}*/
-
-"IDEAL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IDEAL"]
-/*"IDEAL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"IDEAL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"IDEAL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IDEAL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"IDEAL" -> {"DIVRING"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"IDEAL" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"IDEAL" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"IDEAL" -> {"LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "NNI"; "INT"; "LIST"}*/
-/*"IDEAL" -> {"ILIST"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"IDEAL" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"IDEAL" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"IDEAL" -> {"FLAGG-"; "SINT"; "SYMBOL"; "REF"}*/
-"IDEAL" -> "ALIST"
-/*"IDEAL" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"IDEAL" -> {"SRAGG-"; "LNAGG-"; "DIRPCAT"; "DIFEXT"; "DIFRING"; "FINITE"}*/
-/*"IDEAL" -> {"ORDRING"; "OAGROUP"; "VSPACE"; "ORDFIN"; "VECTOR"; "IVECTOR"}*/
-/*"IDEAL" -> {"IARRAY1"; "VECTCAT-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
-/*"IDEAL" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT"; "A1AGG"}*/
-
-"INFCLCT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=INFCLCT"]
-/*"INFCLCT" -> {"PRSPCT"; LOCPOWC"; PLACESC"; DIVCAT"; BLMETCT"; "AFFPL"}*/
-/*"INFCLCT" -> {SETCATD"; SETCAT"; BASTYPE"; KOERCE"; NNI"; INT"; "OUTFORM"}*/
-/*"INFCLCT" -> {LIST"; SYMBOL"; "REF"}*/
-"INFCLCT" -> "ALIST"
-/*"INFCLCT" -> {STRING"; CHAR"; SINT"; PRIMARR"; A1AGG-"; "ISTRING"}*/
-/*"INFCLCT" -> {SRAGG-"; FLAGG-"; LNAGG-"; ILIST"; LSAGG-"; "STAGG-"}*/
-/*"INFCLCT" -> {ELAGG-"; "URAGG-"}*?
-
-"INFORM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INFORM"]
-/*"INFORM" -> {"SEXCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "ORDSET"}*/
-/*"INFORM" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"INFORM" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"INFORM" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INFORM" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"INFORM" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"INFORM" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
-/*"INFORM" -> {"FIELD"; "DIVRING"; "RADCAT"; "INT"; "SYMBOL"; "REF"}*/
-"INFORM" -> "ALIST"
-/*"INFORM" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"INFORM" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "DFLOAT"}*/
-/*"INFORM" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"INFORM" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"INFORM" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"INFORM" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"INFORM" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "NNI"}*/
-/*"INFORM" -> {"STRICAT"; "SRAGG"; "A1AGG"}*/
-
-"INFORM1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFORM1"]
-/*"INFORM1" -> {"TYPE"; "SYMBOL"; "INT"; "REF"}*/
-"INFORM1" -> "ALIST"
-/*"INFORM1" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"INFORM1" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"IPRNTPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IPRNTPK"]
-/*"IPRNTPK" -> {"SYMBOL"; "INT"; "REF"}*/
-"IPRNTPK" -> "ALIST"
-/*"IPRNTPK" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"IPRNTPK" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"IR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IR"]
-/*"IR" -> {"MODULE"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"IR" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "RMODULE"; "RETRACT"}*/
-/*"IR" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"IR" -> {"SGROUP"; "MONOID"; "ALGEBRA"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"IR" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"IR" -> {"ORDSET"; "DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"IR" -> {"REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"; "DIVRING"}*/
-/*"IR" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"}*/
-/*"IR" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"}*/
-/*"IR" -> {"SYMBOL"; "INT"; "REF"}*/
-"IR" -> "ALIST"
-/*"IR" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"IR" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"IR" -> {"NNI"; "BOOLEAN"; "LFCAT"; "PRIMCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"IR" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "LSAGG-"; "STAGG-"}*/
-/*"IR" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "PI"; "LSAGG"; "STAGG"}*/
-/*"IR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"IR" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-
-"ISUPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ISUPS"]
-/*"ISUPS" -> {"UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ISUPS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ISUPS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"ISUPS" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"ISUPS" -> {"ELTAB"; "DIFRING"; "PDRING"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
-/*"ISUPS" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ISUPS" -> {"OASGP"; "ORDSET"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"ISUPS" -> {"CFCAT"; "REAL"; "STEP"; "BOOLEAN"; "INT"; "OM"; "SINT"}*/
-/*"ISUPS" -> {"NNI"; "PI"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"ISUPS" -> {"FLAGG-"; "URAGG-"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"ISUPS" -> {"AHYP"; "ELEMFUN"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
-/*"ISUPS" -> {"A1AGG-"; "ISTRING"; "SYMBOL"; "REF"}*/
-"ISUPS" -> "ALIST"
-/*"ISUPS" -> {"SRAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ISUPS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"ISUPS" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "FIELD"; "DIVRING"}*/
-
-"KERNEL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=KERNEL"]
-/*"KERNEL" -> {"CACHSET"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "PATAB"}*/
-/*"KERNEL" -> {"KONVERT"; "INT"; "NNI"; "LIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"KERNEL" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"KERNEL" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"KERNEL" -> {"ELAGG"; "OM"; "ILIST"; "SYMBOL"; "REF"}*/
-"KERNEL" -> "ALIST"
-/*"KERNEL" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"KERNEL" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "UFD"}*/
-/*"KERNEL" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"KERNEL" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"KERNEL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"KERNEL" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"KERNEL" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"KERNEL" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"; "RNS"}*/
-/*"KERNEL" -> {"FIELD"; "DIVRING"; "RADCAT"}*/
-
-"LIB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIB"]
-/*"LIB" -> {"TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"}*/
-/*"LIB" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"LIB" -> {"CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "SYMBOL"}*/
-/*"LIB" -> {"INT"; "REF"}*/
-"LIB" -> "ALIST"
-/*"LIB" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"LIB" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "STRICAT"}*/
-/*"LIB" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "ORDSET"; "OM"; "ORDFIN"}*/
-/*"LIB" -> "FINITE"*/
-
-"LIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIST",
-          shape=ellipse]
-/*"LIST" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"LIST" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"LIST" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"LIST" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "BOOLEAN"; "ILIST"}*/
-/*"LIST" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "SYMBOL"; "REF"}*/
-"LIST" -> "ALIST"
-/*"LIST" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"LIST" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "UFD"}*/
-/*"LIST" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"LIST" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LIST" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"LIST" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"LIST" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"LIST" -> {"REAL"; "CHARZ"; "STEP"}*/
-
-"LMDICT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LMDICT"]
-/*"LMDICT" -> {"MDAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"LMDICT" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"}*/
-/*"LMDICT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
-/*"LMDICT" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"}*/
-/*"LMDICT" -> {"LIST"; "ILIST"; "SYMBOL"; "REF"}*/
-"LMDICT" -> "ALIST"
-/*"LMDICT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"LMDICT" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"}*/
-/*"LMDICT" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "NNI"; "BOOLEAN"}*/
-
-"LODO" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LODO"]
-/*"LODO" -> {"LODOCAT"; "OREPCAT"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"LODO" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"LODO" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
-/*"LODO" -> {"ALGEBRA"; "MODULE"; "ELTAB"; "SYMBOL"; "INT"; "REF"}*/
-"LODO" -> "ALIST"
-/*"LODO" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"LODO" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FIELD"}*/
-/*"LODO" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
-/*"LODO" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"LODO" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"LODO" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"LODOOPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LODOOPS"]
-/*"LODOOPS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"LODOOPS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LODOOPS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LODOOPS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"LODOOPS" -> {"DIVRING"; "LODOCAT"; "OREPCAT"; "FRETRCT"; "RETRACT"}*/
-/*"LODOOPS" -> {"ELTAB"; "SYMBOL"; "INT"; "REF"}*/
-"LODOOPS" -> "ALIST"
-/*"LODOOPS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"LODOOPS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"LODOOPS" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"LODOOPS" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "CLAGG"}*/
-/*"LODOOPS" -> {"KONVERT"; "ORDSET"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"LODOOPS" -> {"VECTCAT-"; "NNI"; "PI"; "INS-"; "DPOLCAT"; "POLYCAT"}*/
-/*"LODOOPS" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FLINEXP"}*/
-/*"LODOOPS" -> {"LINEXP"; "PATMAB"; "PFECAT"; "DIFEXT"; "DIFRING"}*/
-/*"LODOOPS" -> {"ILIST"; "LSAGG-"; "BOOLEAN"}*/
-
-"MATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MATRIX"]
-/*"MATRIX" -> {"MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"MATRIX" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "KONVERT"}*/
-/*"MATRIX" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"MATRIX" -> {"ELTAB"; "CLAGG"; "ORDSET"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MATRIX" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"MATRIX" -> {"INT"; "PRIMARR"; "NNI"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"MATRIX" -> {"COMRING"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"MATRIX" -> {"ENTIRER"; "FIELD"; "UFD"; "DIVRING"; "INS-"; "VECTOR"}*/
-/*"MATRIX" -> {"IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"MATRIX" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"MATRIX" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "SYMBOL"}*/
-/*"MATRIX" -> "REF"*/
-"MATRIX" -> "ALIST"
-/*"MATRIX" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "A1AGG-"}*/
-/*"MATRIX" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"}*/
-/*"MATRIX" -> {"URAGG"; "RCAGG"; "ELAGG"}*/
-
-"MKFLCFN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MKFLCFN"]
-/*"MKFLCFN" -> {"KONVERT"; "SYMBOL"; "INT"; "REF"}*/
-"MKFLCFN" -> "ALIST"
-/*"MKFLCFN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"MKFLCFN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"MKFLCFN" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"MKFLCFN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"MKFLCFN" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ORDSET"}*/
-/*"MKFLCFN" -> {"ELAGG"; "OM"; "STRICAT"; "SRAGG"; "A1AGG"; "LSAGG-"}*/
-/*"MKFLCFN" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "DFLOAT"}*/
-
-"MSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MSET"]
-/*"MSET" -> {"MSETAGG"; "MDAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"MSET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"MSET" -> {"KONVERT"; "SETAGG"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"MSET" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"MSET" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"MSET" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"MSET" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"MSET" -> {"DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"MSET" -> {"CHARZ"; "STEP"; "INT"; "SYMBOL"; "REF"}*/
-"MSET" -> "ALIST"
-/*"MSET" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"MSET" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"MSET" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"MSET" -> {"ELTAB"; "FLAGG"; "ELAGG"; "OM"; "NNI"; "BOOLEAN"}*/
-
-"M3D" [color="#88FF44",href="bookvol10.3.pdf#nameddest=M3D"]
-/*"M3D" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"M3D" -> {"EVALAB"; "IEVALAB"; "SYMBOL"; "INT"; "REF"}*/
-"M3D" -> "ALIST"
-/*"M3D" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"M3D" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
-/*"M3D" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "PI"; "A1AGG"; "FLAGG"}*/
-/*"M3D" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"M3D" -> {"ORDSET"; "VECTCAT-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
-/*"M3D" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "VECTCAT"; "RING"}*/
-/*"M3D" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"M3D" -> {"MONOID"; "LMODULE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"M3D" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-
-"NAGC02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGC02"]
-/*"NAGC02" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGC02" -> "ALIST"
-/*"NAGC02" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGC02" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGC02" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGC02" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGC02" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGC02" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGC02" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NAGC02" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"NAGC02" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"NAGC05" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGC05"]
-/*"NAGC05" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGC05" -> "ALIST"
-/*"NAGC05" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGC05" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGC05" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGC05" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGC05" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"NAGC05" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"NAGC05" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"NAGC05" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"NAGC05" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"NAGC06" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGC06"]
-/*"NAGC06" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGC06" -> "ALIST"
-/*"NAGC06" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGC06" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGC06" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGC06" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGC06" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGC06" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGC06" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NAGC06" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"NAGC06" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"NAGD01" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGD01"]
-/*"NAGD01" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGD01" -> "ALIST"
-/*"NAGD01" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGD01" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGD01" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGD01" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGD01" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"NAGD01" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"NAGD01" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"NAGD01" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"NAGD01" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"NAGD02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGD02"]
-/*"NAGD02" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGD02" -> "ALIST"
-/*"NAGD02" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGD02" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGD02" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGD02" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGD02" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGD02" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGD02" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NAGD02" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"NAGD02" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"NAGD03" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGD03"]
-/*"NAGD03" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGD03" -> "ALIST"
-/*"NAGD03" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGD03" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGD03" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGD03" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGD03" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGD03" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGD03" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NAGD03" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"NAGD03" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-
-"NAGE01" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGE01"]
-/*"NAGE01" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGE01" -> "ALIST"
-/*"NAGE01" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGE01" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGE01" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGE01" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGE01" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGE01" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGE01" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NAGE01" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"NAGE01" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"NAGE01" -> {"LINEXP"; "CFCAT"; "STEP"}*/
-
-"NAGE02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGE02"]
-/*"NAGE02" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGE02" -> "ALIST"
-/*"NAGE02" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGE02" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGE02" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGE02" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGE02" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"NAGE02" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"NAGE02" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"NAGE02" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"NAGE02" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"}*/
-/*"NAGE02" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-
-"NAGE04" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGE04"]
-/*"NAGE04" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGE04" -> "ALIST"
-/*"NAGE04" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGE04" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGE04" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGE04" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGE04" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGE04" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGE04" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"NAGE04" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"NAGE04" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"}*/
-/*"NAGE04" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-
-"NAGF07" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF07"]
-/*"NAGF07" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGF07" -> "ALIST"
-/*"NAGF07" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGF07" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGF07" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGF07" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGF07" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGF07" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGF07" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NAGF07" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"NAGF07" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"NAGF07" -> {"LINEXP"; "CFCAT"; "STEP"}*/
-
-"NAGS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGS"]
-/*"NAGS" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGS" -> "ALIST"
-/*"NAGS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"NAGS" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"NAGS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"NAGS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"NAGS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"NAGS" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"NAGS" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"}*/
-/*"NAGS" -> {"PATMAB"; "CHARZ"}*/
-
-"NAGSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGSP"]
-/*"NAGSP" -> {"SYMBOL"; "INT"; "REF"}*/
-"NAGSP" -> "ALIST"
-/*"NAGSP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NAGSP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"NAGSP" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NAGSP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NAGSP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NAGSP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NAGSP" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NAGSP" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"NAGSP" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"NAGSP" -> {"LINEXP"; "CFCAT"; "STEP"}*/
-
-"NREP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NREP"]
-/*"NREP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"NREP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"NREP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"NREP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"NREP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"NREP" -> {"ORDSET"; "SYMBOL"; "INT"; "REF"}*/
-"NREP" -> "ALIST"
-/*"NREP" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"NREP" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
-/*"NREP" -> {"OINTDOM"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"NREP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
-/*"NREP" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
-/*"NREP" -> {"FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"; "UPOLYC"; "POLYCAT"}*/
-/*"NREP" -> {"FAMR"; "AMR"; "FRETRCT"}*/
-
-"NSDPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NSDPS"]
-/*"NSDPS" -> {"LOCPOWC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"NSDPS" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"NSDPS" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"NSDPS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NSDPS" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPSCAT"; "PSCAT"; "AMR"}*/
-/*"NSDPS" -> {"CHARZ"; "CHARNZ"; "ELTAB"; "DIFRING"; "PDRING"; "LZSTAGG"}*/
-/*"NSDPS" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"NSDPS" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
-/*"NSDPS" -> {"INT"; "BOOLEAN"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"NSDPS" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RETRACT"; "LINEXP"}*/
-/*"NSDPS" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"; "LIST"; "ILIST"; "SINT"}*/
-/*"NSDPS" -> {"NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "LSAGG"; "FLAGG"}*/
-/*"NSDPS" -> {"ELAGG"; "OM"; "SYMBOL"; "REF"}*/
-"NSDPS" -> "ALIST"
-/*"NSDPS" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"NSDPS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"NSDPS" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"NSDPS" -> {"BASTYPE-"}*/
-
-"NUMFMT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMFMT"]
-/*"NUMFMT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"}*/
-/*"NUMFMT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"NUMFMT" -> {"IXAGG-"; "STRICAT"; "SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"NUMFMT" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"NUMFMT" -> {"KOERCE"; "EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"NUMFMT" -> {"KONVERT"; "ORDSET"; "OM"; "BOOLEAN"; "SYMBOL"; "REF"}*/
-"NUMFMT" -> "ALIST"
-/*"NUMFMT" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"NUMFMT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"NUMFMT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"NUMFMT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"NUMFMT" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"NUMFMT" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "PI"; "NNI"}*/
-/*"NUMFMT" -> {"MONOID-"; "ABELSG-"; "SGROUP-"}*/
-
-"OC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=OC"]
-/*"OC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"OC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"OC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"OC" -> {"FRETRCT"; "RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
-/*"OC" -> {"FINITE"; "ORDSET"; "KONVERT"; "CHARZ"; "CHARNZ"; "BOOLEAN"}*/
-/*"OC" -> {"SYMBOL"; "INT"; "REF"}*/
-"OC" -> "ALIST"
-/*"OC" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"OC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FIELD"}*/
-/*"OC" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"OC" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"OC" -> {"REAL"; "RADCAT"; "PATMAB"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"OC" -> {"LINEXP"; "CFCAT"; "STEP"}*/
-
-"OC-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OC"]
-/*"OC-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON";  "ABELMON"}*/
-/*"OC-" -> {"ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP"}*/
-/*"OC-" -> {"MONOID";  "LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA"}*/
-/*"OC-" -> {"MODULE";  "FRETRCT";  "RETRACT";  "FEVALAB";  "ELTAB"}*/
-/*"OC-" -> {"EVALAB";  "IEVALAB";  "FINITE";  "ORDSET";  "KONVERT"}*/
-/*"OC-" -> {"CHARZ";  "CHARNZ";  "BOOLEAN";  "SYMBOL";  "INT";  "REF"}*/
-"OC-" -> "ALIST"
-/*"OC-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
-/*"OC-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-"}*/
-/*"OC-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "ENTIRER"}*/
-/*"OC-" -> {"UFD";  "DIVRING";  "RNS";  "ORDRING";  "OAGROUP";  "OCAMON"}*/
-/*"OC-" -> {"OAMON";  "OASGP";  "REAL";  "RADCAT";  "PATMAB";  "INS"}*/
-/*"OC-" -> {"OINTDOM";  "DIFRING";  "LINEXP";  "CFCAT";  "STEP"}*/
-
-"ODEPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPACK"]
-/*"ODEPACK" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ODEPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ODEPACK" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ODEPACK" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ODEPACK" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"ODEPACK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"ODEPACK" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "LSAGG"; "STAGG"}*/
-/*"ODEPACK" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"ODEPACK" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"ODEPACK" -> {"FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "INS-"}*/
-/*"ODEPACK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"ODEPACK" -> {"ISTRING"; "SRAGG-"; "TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"}*/
-/*"ODEPACK" -> {"BGAGG"; "NNI"; "SYMBOL"; "REF"}*/
-"ODEPACK" -> "ALIST"
-/*"ODEPACK" -> {"FLAGG-"; "LNAGG-"; "DFLOAT"; "DIFRING"; "TRANFUN"}*/
-/*"ODEPACK" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-/*"ODEPACK" -> {"PI"; "VECTCAT"; "A1AGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"ODEPACK" -> {"VECTCAT-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-
-"ODERAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODERAT"]
-/*"ODERAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODERAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODERAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ODERAT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ODERAT" -> {"UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"; "POLYCAT"}*/
-/*"ODERAT" -> {"PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"}*/
-/*"ODERAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"ODERAT" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
-/*"ODERAT" -> {"STEP"; "SYMBOL"; "INT"; "REF"}*/
-"ODERAT" -> "ALIST"
-/*"ODERAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ODERAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS-"}*/
-/*"ODERAT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
-/*"ODERAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"ODERAT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
-/*"ODERAT" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"}*/
-/*"ODERAT" -> {"NNI"; "LSAGG-"; "STAGG-"; "INS"; "CFCAT"; "VECTOR"}*/
-/*"ODERAT" -> {"IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"; "PI"}*/
-/*"ODERAT" -> {"VECTCAT-"; "BOOLEAN"}*/
-
-"OMERR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMERR"]
-/*"OMERR" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"OMERR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"OMERR" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"OMERR" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "NNI"}*/
-/*"OMERR" -> {"SYMBOL"; "REF"}*/
-"OMERR" -> "ALIST"
-/*"OMERR" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"OMERR" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"}*/
-/*"OMERR" -> {"STAGG-"; "PI"}*/
-
-"OMERRK" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OMERRK"]
-/*"OMERRK" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"OMERRK" -> "ALIST"
-/*"OMERRK" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"OMERRK" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"OPTPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OPTPACK"]
-/*"OPTPACK" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"OPTPACK" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"OPTPACK" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"OPTPACK" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"OPTPACK" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"OPTPACK" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"OPTPACK" -> {"RADCAT"; "PATMAB"; "CHARZ"; "STRING"; "CHAR"; "SINT"}*/
-/*"OPTPACK" -> {"OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"OPTPACK" -> {"SRAGG-"; "ILIST"; "TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"}*/
-/*"OPTPACK" -> {"BGAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"OPTPACK" -> {"CLAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "NNI"; "SYMBOL"; "REF"}*/
-"OPTPACK" -> "ALIST"
-/*"OPTPACK" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "INS-"}*/
-/*"OPTPACK" -> {"DFLOAT"; "PI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"OPTPACK" -> {"FLAGG"; "ELAGG"; "OM"; "DIFRING"; "TRANFUN"; "TRIGCAT"}*/
-/*"OPTPACK" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "EUCDOM-"}*/
-/*"OPTPACK" -> {"UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"OPTPACK" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "ABELMON-"}*/
-
-"OSI" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OSI"]
-/*"OSI" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INT"; "SYMBOL"; "REF"}*/
-"OSI" -> "ALIST"
-/*"OSI" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"OSI" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"OVAR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OVAR"]
-/*"OVAR" -> {"ORDFIN"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "FINITE"}*/
-/*"OVAR" -> {"KONVERT"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"OVAR" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"OVAR" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"OVAR" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"OVAR" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"OVAR" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS"; "OINTDOM"}*/
-/*"OVAR" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "LSAGG"; "STAGG"}*/
-/*"OVAR" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"OVAR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"OVAR" -> {"OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"OVAR" -> {"SYMBOL"; "REF"}*/
-"OVAR" -> "ALIST"
-/*"OVAR" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"OVAR" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "PI"}*/
-
-"PACOFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PACOFF"]
-/*"PACOFF" -> {"PACFFC"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"PACOFF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PACOFF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PACOFF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PACOFF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"}*/
-/*"PACOFF" -> {"FINITE"; "STEP"; "DIFRING"; "PACPERC"; "XF"; "RETRACT"}*/
-/*"PACOFF" -> {"VSPACE"; "CHARZ"; "ORDSET"; "NNI"; "INT"; "PI"; "VECTOR"}*/
-/*"PACOFF" -> {"IVECTOR"; "IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"}*/
-/*"PACOFF" -> {"LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"PACOFF" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "MONOID-"; "ABELMON-"}*/
-/*"PACOFF" -> {"SGROUP-"; "SINT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"PACOFF" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"PACOFF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"PACOFF" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"PACOFF" -> {"RCAGG-"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"PACOFF" -> {"FRETRCT"; "FLINEXP"; "LINEXP"; "PATMAB"; "PFECAT"; "DIFEXT"}*/
-/*"PACOFF" -> {"SYMBOL"; "REF"}*
-"PACOFF" -> "ALIST"
-/*"PACOFF" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
-/*"PACOFF" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PACOFF" -> {"OASGP"; "CFCAT"; "REAL"; "BOOLEAN"; "OAMONS"}*/
-
-"PACRAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PACRAT"]
-/*"PACRAT" -> {"PACRATC"; "PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PACRAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PACRAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE" "SGROUP"}*/
-/*"PACRAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PACRAT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"}*/
-/*"PACRAT" -> {"XF"; "VSPACE"; "FPC"; "CHARNZ"; "FINITE"; "INS"; "OINTDOM"}*/
-/*"PACRAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"PACRAT" -> {"DIFRING"; "KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"PACRAT" -> {"STEP"; "INT"; "NNI"; "PI"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"PACRAT" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"PACRAT" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"PACRAT" -> {"SETCAT-"; "BASTYPE-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"PACRAT" -> {"VECTCAT-"; "A1AGG-"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"PACRAT" -> {"AMR"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
-/*"PACRAT" -> {"ELTAB"; "DIFEXT"; "SYMBOL"; "REF"}*/
-"PACRAT" -> "ALIST"
-/*"PACRAT" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "ISTRING"}*/
-/*"PACRAT" -> {"SRAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"PACRAT" -> {"TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"PACRAT" -> {"OM"; "BOOLEAN"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
-
-"PATTERN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PATTERN"]
-/*"PATTERN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"; "SYMBOL"; "INT"}*/
-/*"PATTERN" -> "REF"*/
-"PATTERN" -> "ALIST"
-/*"PATTERN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"PATTERN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"PATTERN" -> {"NNI"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"PATTERN" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"PATTERN" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
-/*"PATTERN" -> {"ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"PATTERN" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"PATTERN" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "PATMAB"; "MONOID"}*/
-/*"PATTERN" -> {"SGROUP"; "ABELMON"; "ABELSG"; "PI"}*/
-
-"PLCS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLCS"]
-/*"PLCS" -> {"PLACESC"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
-/*"PLCS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"PLCS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"PLCS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PLCS" -> {"UFD"; "DIVRING"}*/
-"PLCS" -> "ALIST"
-/*"PLCS" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"; "DIFRING"}*/
-/*"PLCS" -> {"PDRING"; "SYMBOL"; "INT"; "REF"; "LOCPOWC"; "LIST"; "STRING"}*/
-/*"PLCS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"PLCS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PLCS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"PLCS" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"}*/
-/*"PLCS" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"PLCS" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"PLCS" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "PI"; "NNI"; "BOOLEAN"}*/
-
-"PMKERNEL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMKERNEL"]
-/*"PMKERNEL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "RETRACT"}*/
-/*"PMKERNEL" -> {"KONVERT"; "PATMAB"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"PMKERNEL" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"PMKERNEL" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"PMKERNEL" -> {"OM"; "INT"; "LIST"; "ILIST"; "NNI"; "SYMBOL"; "REF"}*/
-"PMKERNEL" -> "ALIST"
-/*"PMKERNEL" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"PMKERNEL" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "MONOID"; "SGROUP"}*/
-/*"PMKERNEL" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "ABELMON"; "ABELSG"}*/
-
-"PMSYM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMSYM"]
-/*"PMSYM" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ORDSET"; "SYMBOL"; "INT"}*/
-/*"PMSYM" -> "REF"*/
-"PMSYM" -> "ALIST"
-/*"PMSYM" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"PMSYM" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"POLY" [color="#88FF44",href="bookvol10.3.pdf#nameddest=POLY"]
-/*"POLY" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"POLY" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"POLY" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"POLY" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"POLY" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"POLY" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-/*"POLY" -> {"PFECAT"; "UFD"; "SYMBOL"; "INT"; "REF"}*/
-"POLY" -> "ALIST"
-/*"POLY" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"POLY" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"}*/
-/*"POLY" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"; "ORDRING"}*/
-/*"POLY" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RADCAT"}*/
-/*"POLY" -> {"INS"; "OINTDOM"; "DIFRING"; "CFCAT"; "STEP"; "UPOLYC"}*/
-/*"POLY" -> {"ELTAB"; "DIFEXT"}*/
-
-"PRIMELT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PRIMELT"]
-/*"PRIMELT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PRIMELT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PRIMELT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PRIMELT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PRIMELT" -> {"UFD"; "DIVRING"; "CHARZ"; "SINT"; "NNI"; "INT"; "INS-"}*/
-/*"PRIMELT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PRIMELT" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"PRIMELT" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
-/*"PRIMELT" -> {"PATMAB"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"PRIMELT" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"PRIMELT" -> {"CLAGG-"; "SYMBOL"; "REF"}*/
-"PRIMELT" -> "ALIST"
-/*"PRIMELT" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"PRIMELT" -> {"SRAGG-"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"PRIMELT" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PFECAT"}*/
-
-"QALGSET2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QALGSET2"]
-/*"QALGSET2" -> {"SYMBOL"; "INT"; "REF"}*/
-"QALGSET2" -> "ALIST"
-/*"QALGSET2" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"QALGSET2" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"QALGSET2" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"QALGSET2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"QALGSET2" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"QALGSET2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"QALGSET2" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"QALGSET2" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"QALGSET2" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"QALGSET2" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"QALGSET2" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
-/*"QALGSET2" -> {"FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"; "DIRPCAT"; "IXAGG"}*/
-/*"QALGSET2" -> {"HOAGG"; "AGG"; "ELTAGG"; "FRETRCT"; "FINITE"; "OAMONS"}*/
-/*"QALGSET2" -> {"VSPACE"; "ORDFIN"; "POLYCAT"; "FAMR"; "AMR"; "LSAGG"}*/
-/*"QALGSET2" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "CLAGG"; "FLAGG"}*/
-/*"QALGSET2" -> {"ELAGG"; "OM"; "BOOLEAN"}*/
-
-"QEQUAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QEQUAT"]
-/*"QEQUAT" -> {"KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"QEQUAT" -> "ALIST"
-/*"QEQUAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"QEQUAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"QUATCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=QUATCAT"]
-/*"QUATCAT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"QUATCAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"QUATCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"QUATCAT" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"QUATCAT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"QUATCAT" -> {"ENTIRER"; "ORDSET"; "DIVRING"; "KONVERT"; "CHARZ"; "CHARNZ"}*/
-/*"QUATCAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "UFD"}*/
-/*"QUATCAT" -> {"BOOLEAN"; "SYMBOL"; "INT"; "REF"}*/
-"QUATCAT" -> "ALIST"
-/*"QUATCAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"QUATCAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "RNS"}*/
-/*"QUATCAT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"QUATCAT" -> {"RADCAT"; "PATMAB"; "INS"; "OINTDOM"; "CFCAT"; "STEP"}*/
-
-"QUATCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QUATCAT"]
-/*"QUATCAT-" -> {"COMRING";  "RING";  "RNG";  "ABELGRP";  "CABMON"}*/
-/*"QUATCAT-" -> {"ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE";  "KOERCE"}*/
-/*"QUATCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "BMODULE";  "RMODULE"}*/
-/*"QUATCAT-" -> {"ALGEBRA";  "MODULE";  "FRETRCT";  "RETRACT";  "DIFEXT"}*/
-/*"QUATCAT-" -> {"DIFRING";  "PDRING";  "FEVALAB";  "ELTAB";  "EVALAB"}*/
-/*"QUATCAT-" -> {"IEVALAB";  "FLINEXP";  "LINEXP";  "ENTIRER";  "ORDSET"}*/
-/*"QUATCAT-" -> {"DIVRING";  "KONVERT";  "CHARZ";  "CHARNZ";  "FIELD"}*/
-/*"QUATCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "UFD";  "BOOLEAN"}*/
-/*"QUATCAT-" -> {"SYMBOL";  "INT";  "REF"}*/
-"QUATCAT-" -> "ALIST"
-/*"QUATCAT-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM";  "PRIMARR"}*/
-/*"QUATCAT-" -> {"A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-";  "LNAGG-"}*/
-/*"QUATCAT-" -> {"RNS";  "ORDRING";  "OAGROUP";  "OCAMON";  "OAMON"}*/
-/*"QUATCAT-" -> {"OASGP";  "REAL";  "RADCAT";  "PATMAB";  "INS";  "OINTDOM"}*/
-/*"QUATCAT-" -> {"CFCAT";  "STEP"}*/
-
-"RECLOS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RECLOS"]
-/*"RECLOS" -> {"RCFIELD"; "CHARZ"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"RECLOS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"RECLOS" -> {"MONOID"; "LMODULE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"RECLOS" -> {"OASGP"; "ORDSET"; "COMRING"; "BMODULE"; "RMODULE"; "FIELD"}*/
-/*"RECLOS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "MODULE"}*/
-/*"RECLOS" -> {"ENTIRER"; "UFD"; "DIVRING"; "FRETRCT"; "RETRACT"; "RADCAT"}*/
-/*"RECLOS" -> {"REAL"; "KONVERT"; "PI"; "NNI"; "INT"; "SYMBOL"; "REF"}*/
-"RECLOS" -> "ALIST"
-/*"RECLOS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"RECLOS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
-/*"RECLOS" -> {"OINTDOM"; "DIFRING"; "LINEXP"; "PATMAB"; "CFCAT"; "STEP"}*/
-/*"RECLOS" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
-/*"RECLOS" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"RECLOS" -> {"SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"RECLOS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"RECLOS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"RECLOS" -> {"OM"; "BOOLEAN"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PDRING"}*/
-/*"RECLOS" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "CHARNZ"; "PFECAT"}*/
-
-"REP1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REP1"]
-/*"REP1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"REP1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"REP1" -> {"INT"; "SINT"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"REP1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"REP1" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"REP1" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"REP1" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "LIST"}*/
-/*"REP1" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"REP1" -> {"LNAGG-"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"REP1" -> {"A1AGG-"; "IXAGG-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"REP1" -> {"IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "ELTAGG"}*/
-/*"REP1" -> {"ELTAB"; "CLAGG"; "PI"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"REP1" -> {"RCAGG"; "ELAGG"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"REP1" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "SYMBOL"; "REF"}*/
-"REP1" -> "ALIST"
-/*"REP1" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"}*/
-
-"RESULT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RESULT"]
-/*"RESULT" -> {"TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"}*/
-/*"RESULT" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"}*/
-/*"RESULT" -> {"CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"}*/
-/*"RESULT" -> {"SYMBOL"; "INT"; "REF"}*/
-"RESULT" -> "ALIST"
-/*"RESULT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"RESULT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-/*"RESULT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "FLAGG"}*/
-/*"RESULT" -> {"ELAGG"; "OM"; "ILIST"}*/
-
-"RFFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RFFACT"]
-/*"RFFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"RFFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RFFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"RFFACT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"RFFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"RFFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"RFFACT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
-/*"RFFACT" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-/*"RFFACT" -> {"SYMBOL"; "INT"; "REF"}*/
-"RFFACT" -> "ALIST"
-/*"RFFACT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"RFFACT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
-/*"RFFACT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"RFFACT" -> {"CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
-/*"RFFACT" -> "TYPE"*/
-
-"RMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RMATRIX"]
-/*"RMATRIX" -> {"RMATCAT"; "BMODULE"; "LMODULE"; "ABELGRP"; "CABMON"}*/
-/*"RMATRIX" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RMATRIX" -> {"RMODULE"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"RMATRIX" -> {"MODULE"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"RMATRIX" -> {"VSPACE"; "KONVERT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"RMATRIX" -> {"INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"; "NNI"}*/
-/*"RMATRIX" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"RMATRIX" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ORDSET"}*/
-/*"RMATRIX" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
-"RMATRIX" -> "ALIST"
-/*"RMATRIX" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"RMATRIX" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"ROMAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ROMAN"]
-/*"ROMAN" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"ROMAN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"ROMAN" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ROMAN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"ROMAN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ROMAN" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"ROMAN" -> {"REAL"; "CHARZ"; "STEP"; "SYMBOL"; "INT"; "REF"}*/
-"ROMAN" -> "ALIST"
-/*"ROMAN" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ROMAN" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"ROUTINE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ROUTINE"]
-/*"ROUTINE" -> {"TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"}*/
-/*"ROUTINE" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"ROUTINE" -> {"IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"ROUTINE" -> {"ORDSET"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
-/*"ROUTINE" -> {"INT"; "PRIMARR"; "A1AGG-"; "ISTRING"; "BOOLEAN"; "ILIST"}*/
-/*"ROUTINE" -> {"LSAGG-"; "STAGG-"; "PI"; "NNI"; "SYMBOL"; "REF"}*/
-"ROUTINE" -> "ALIST"
-/*"ROUTINE" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"ROUTINE" -> {"RCAGG"; "LNAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-
-"RPOLCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RPOLCAT"]
-/*"RPOLCAT" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"RPOLCAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RPOLCAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"RPOLCAT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"RPOLCAT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"RPOLCAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"RPOLCAT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "OAMONS"; "OCAMON"}*/
-/*"RPOLCAT" -> {"OAMON"; "OASGP"; "NNI"; "INT"; "LIST"; "BOOLEAN"; "ILIST"}*/
-/*"RPOLCAT" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "FINITE"; "SINT"}*/
-/*"RPOLCAT" -> {"OM"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "INS"}*/
-/*"RPOLCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "DIFRING"; "CFCAT"; "REAL"}*/
-/*"RPOLCAT" -> {"STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"}*/
-/*"RPOLCAT" -> {"FPATMAB"; "TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"RPOLCAT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"RPOLCAT" -> {"FLAGG"; "ELAGG"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
-/*"RPOLCAT" -> {"A1AGG-"; "ISTRING"; "SYMBOL"; "REF"}*/
-"RPOLCAT" -> "ALIST"
-/*"RPOLCAT" -> {"SRAGG-"; "LNAGG-"; "STRICAT"; "SRAGG"; "A1AGG"}*/
-/*"RPOLCAT" -> {"FPS"; "RNS"; "RADCAT"}*/
-
-"RPOLCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RPOLCAT"]
-/*"RPOLCAT-" -> {"POLYCAT";  "PDRING";  "RING";  "RNG";  "ABELGRP"}*/
-/*"RPOLCAT-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
-/*"RPOLCAT-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "FAMR"}*/
-/*"RPOLCAT-" -> {"AMR";  "BMODULE";  "RMODULE";  "COMRING";  "ALGEBRA"}*/
-/*"RPOLCAT-" -> {"MODULE";  "CHARZ";  "CHARNZ";  "INTDOM";  "ENTIRER"}*/
-/*"RPOLCAT-" -> {"FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP"}*/
-/*"RPOLCAT-" -> {"LINEXP";  "ORDSET";  "KONVERT";  "PATMAB";  "GCDDOM"}*/
-/*"RPOLCAT-" -> {"PFECAT";  "UFD";  "OAMONS";  "OCAMON";  "OAMON";  "OASGP"}*/
-/*"RPOLCAT-" -> {"NNI";  "INT";  "LIST";  "BOOLEAN";  "ILIST";  "EUCDOM"}*/
-/*"RPOLCAT-" -> {"PID";  "FIELD";  "DIVRING";  "FINITE";  "SINT";  "OM"}*/
-/*"RPOLCAT-" -> {"LSAGG-";  "STAGG-";  "ELAGG-";  "FLAGG-";  "INS"}*/
-/*"RPOLCAT-" -> {"OINTDOM";  "ORDRING";  "OAGROUP";  "DIFRING";  "CFCAT"}*/
-/*"RPOLCAT-" -> {"REAL";  "STEP";  "QFCAT";  "FEVALAB";  "ELTAB";  "DIFEXT"}*/
-/*"RPOLCAT-" -> {"PATAB";  "FPATMAB";  "TYPE";  "LSAGG";  "STAGG";  "URAGG"}*/
-/*"RPOLCAT-" -> {"RCAGG";  "HOAGG";  "AGG";  "LNAGG";  "IXAGG";  "ELTAGG"}*/
-/*"RPOLCAT-" -> {"CLAGG";  "FLAGG";  "ELAGG";  "STRING";  "CHAR";  "OUTFORM"}*/
-/*"RPOLCAT-" -> {"PRIMARR";  "A1AGG-";  "ISTRING";  "SYMBOL";  "REF"}*/
-"RPOLCAT-" -> "ALIST"
-/*"RPOLCAT-" -> {"SRAGG-";  "LNAGG-";  "STRICAT";  "SRAGG";  "A1AGG"}*/
-/*"RPOLCAT-" -> {"FPS";  "RNS";  "RADCAT"}*/
-
-"RULECOLD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RULECOLD"]
-/*"RULECOLD" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"RULECOLD" -> "ALIST"
-/*"RULECOLD" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"RULECOLD" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"RULECOLD" -> "BOOLEAN"*/
-
-"SAOS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SAOS"]
-/*"SAOS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
-/*"SAOS" -> {"INT"; "REF"}*/
-"SAOS" -> "ALIST"
-/*"SAOS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"SAOS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"SEGBIND" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEGBIND"]
-/*"SEGBIND" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
-/*"SEGBIND" -> "REF"*/
-"SEGBIND" -> "ALIST"
-/*"SEGBIND" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"SEGBIND" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"SEGBIND" -> "BOOLEAN"*/
-
-"SET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SET"]
-/*"SET" -> {"FSAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"SET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "CLAGG"}*/
-/*"SET" -> {"KONVERT"; "SETAGG"; "FINITE"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"SET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "ORDSET"; "ELAGG"; "INS"; "UFD"}*/
-/*"SET" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SET" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"SET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"}*/
-/*"SET" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"SET" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"SET" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "SYMBOL"; "INT"; "REF"}*/
-"SET" -> "ALIST"
-/*"SET" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"SET" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
-/*"SET" -> {"STAGG"; "URAGG"; "RCAGG"; "ILIST"; "NNI"; "BOOLEAN"}*/
-
-"SPECOUT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SPECOUT"]
-/*"SPECOUT" -> {"SYMBOL"; "INT"; "REF"}*/
-"SPECOUT" -> "ALIST"
-/*"SPECOUT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"SPECOUT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"SQMATRIX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SQMATRIX"]
-/*"SQMATRIX" -> {"SMATCAT"; "DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SQMATRIX" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SQMATRIX" -> {"SGROUP"; "MONOID"; "LMODULE"; "DIFRING"; "PDRING"}*/
-/*"SQMATRIX" -> {"BMODULE"; "RMODULE"; "RMATCAT"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"SQMATRIX" -> {"EVALAB"; "IEVALAB"; "MODULE"; "COMRING"; "FRETRCT"}*/
-/*"SQMATRIX" -> {"RETRACT"; "FLINEXP"; "LINEXP"; "ALGEBRA"; "KONVERT"}*/
-/*"SQMATRIX" -> {"NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"SQMATRIX" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"SQMATRIX" -> {"ORDSET"; "ELAGG"; "OM"; "LIST"; "ILIST"; "EUCDOM"}*/
-/*"SQMATRIX" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "FIELD"; "UFD"}*/
-/*"SQMATRIX" -> {"DIVRING"; "SYMBOL"; "REF"}*/
-"SQMATRIX" -> "ALIST"
-/*"SQMATRIX" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"SQMATRIX" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "OINTDOM"}*/
-/*"SQMATRIX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "PATMAB"}*/
-/*"SQMATRIX" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-
-"SWITCH" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SWITCH"]
-/*"SWITCH" -> {"KOERCE"; "INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"SWITCH" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"}*/
-/*"SWITCH" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"SWITCH" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INS"}*/
-/*"SWITCH" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"SWITCH" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"SWITCH" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"SWITCH" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"SWITCH" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "RETRACT"; "LINEXP"}*/
-/*"SWITCH" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "NNI"}*/
-/*"SWITCH" -> {"SYMBOL"; "REF"}*/
-"SWITCH" -> "ALIST"
-/*"SWITCH" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"SWITCH" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"SYMS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMS"]
-/*"SYMS" -> {"KOERCE"; "ORDSET"; "SETCAT"; "BASTYPE"; "SYMBOL"; "INT"; "REF"}*/
-"SYMS" -> "ALIST"
-/*"SYMS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"SYMS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-
-"SYMTAB" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SYMTAB"]
-/*"SYMTAB" -> {"KOERCE"; "ORDSET"; "SETCAT"; "BASTYPE"; "INS"; "UFD"}*/
-/*"SYMTAB" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SYMTAB" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"SYMTAB" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"SYMTAB" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"SYMTAB" -> {"OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"SYMTAB" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"; "LIST"}*/
-/*"SYMTAB" -> {"ILIST"; "OM"; "SYMBOL"; "REF"}*/
-"SYMTAB" -> "ALIST"
-/*"SYMTAB" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"SYMTAB" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"}*/
-/*"SYMTAB" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"SYMTAB" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-
-"SYSSOLP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SYSSOLP"]
-/*"SYSSOLP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SYSSOLP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SYSSOLP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SYSSOLP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "POLYCAT"; "PDRING"}*/
-/*"SYSSOLP" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"SYSSOLP" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"SYSSOLP" -> {"KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "QFCAT"}*/
-/*"SYSSOLP" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
-/*"SYSSOLP" -> {"DIFEXT"; "DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"}*/
-/*"SYSSOLP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"SYSSOLP" -> {"OASGP"; "REAL"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"SYSSOLP" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LSAGG"; "STAGG"}*/
-/*"SYSSOLP" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"SYSSOLP" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "NNI"; "SYMBOL"; "REF"}*/
-"SYSSOLP" -> "ALIST"
-/*"SYSSOLP" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"SYSSOLP" -> {"ISTRING"; "SRAGG-"; "LNAGG-"; "BOOLEAN"; "DIRPCAT"}*/
-/*"SYSSOLP" -> {"FINITE"; "OAMONS"; "VSPACE"; "ORDFIN"; "VECTOR"; "IVECTOR"}*/
-/*"SYSSOLP" -> {"IARRAY1"; "VECTCAT-"; "VECTCAT"; "A1AGG"}*/
-
-"UTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=UTSCAT"]
-/*"UTSCAT" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "SETCAT"}*/
-/*"UTSCAT" -> {"BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"UTSCAT" -> {"UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"UTSCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"UTSCAT" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"UTSCAT" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"UTSCAT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "BOOLEAN"; "INT"}*/
-/*"UTSCAT" -> {"SYMBOL"; "REF"}*/
-"UTSCAT" -> "ALIST"
-/*"UTSCAT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"UTSCAT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"UTSCAT" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"UTSCAT" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"UTSCAT" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"}*/
-/*"UTSCAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"UTSCAT" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "RETRACT"; "LINEXP"}*/
-/*"UTSCAT" -> {"PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-
-"UTSCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTSCAT"]
-/*"UTSCAT-" -> {"OAMONS";  "OCAMON";  "OAMON";  "OASGP";  "ORDSET"}*/
-/*"UTSCAT-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "ABELMON";  "ABELSG"}*/
-/*"UTSCAT-" -> {"CABMON";  "UPSCAT";  "PSCAT";  "AMR";  "RING";  "RNG"}*/
-/*"UTSCAT-" -> {"ABELGRP";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
-/*"UTSCAT-" -> {"RMODULE";  "COMRING";  "ALGEBRA";  "MODULE";  "CHARZ"}*/
-/*"UTSCAT-" -> {"CHARNZ";  "INTDOM";  "ENTIRER";  "ELTAB";  "DIFRING"}*/
-/*"UTSCAT-" -> {"PDRING";  "RADCAT";  "TRANFUN";  "TRIGCAT";  "ATRIG"}*/
-/*"UTSCAT-" -> {"HYPCAT";  "AHYP";  "ELEMFUN";  "BOOLEAN";  "INT"}*/
-/*"UTSCAT-" -> {"SYMBOL";  "REF"}*/
-"UTSCAT-" -> "ALIST"
-/*"UTSCAT-" -> {"LIST";  "STRING";  "CHAR";  "SINT";  "OUTFORM"}*/
-/*"UTSCAT-" -> {"PRIMARR";  "A1AGG-";  "ISTRING";  "SRAGG-";  "FLAGG-"}*/
-/*"UTSCAT-" -> {"LNAGG-";  "ILIST";  "NNI";  "LSAGG";  "STAGG";  "URAGG"}*/
-/*"UTSCAT-" -> {"RCAGG";  "HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB"}*/
-/*"UTSCAT-" -> {"LNAGG";  "IXAGG";  "ELTAGG";  "CLAGG";  "KONVERT";  "FLAGG"}*/
-/*"UTSCAT-" -> {"ELAGG";  "OM";  "LSAGG-";  "FIELD";  "EUCDOM";  "PID"}*/
-/*"UTSCAT-" -> {"GCDDOM";  "UFD";  "DIVRING";  "INS";  "OINTDOM";  "ORDRING"}*/
-/*"UTSCAT-" -> {"OAGROUP";  "RETRACT";  "LINEXP";  "PATMAB";  "CFCAT"}*/
-/*"UTSCAT-" -> {"REAL";  "STEP"}*/
-
-"VARIABLE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=VARIABLE"]
-/*"VARIABLE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"; "REF"}*/
-"VARIABLE" -> "ALIST"
-/*"VARIABLE" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"VARIABLE" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"VARIABLE" -> "BOOLEAN"*/
-
-\end{chunk}
-\subsection{Layer17}
-Depends on: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT NSDPS \\
-Used by next layer: ACFS EXPRSOL FDIVCAT UFPS ULSCCAT UTSSOL 
-
-The clique1.spad file is used because "MYEXPR" and "MYUP" are 
-mutually dependent. Rather than add one to the bootstrap we let the
-compiler resolve them in one step. This same technique might be useful
-for other cliques in bootstrap. This needs to be investigated.
-\begin{chunk}{layer17}
-
-LAYER17=\
-  ${OUT}/ACFS.o     ${OUT}/ACFS-.o    ${OUT}/AF.o       ${OUT}/AFFPLPS.o  \
-  ${OUT}/ALGFACT.o  \
-  ${OUT}/ALGFF.o    ${OUT}/ALGMANIP.o ${OUT}/ALGMFACT.o ${OUT}/ALGPKG.o   \
-  ${OUT}/ALGSC.o    ${OUT}/AN.o       ${OUT}/APPRULE.o  ${OUT}/ASP19.o    \
-  ${OUT}/ASP20.o    ${OUT}/ASP31.o    ${OUT}/ASP35.o    ${OUT}/ASP41.o    \
-  ${OUT}/ASP42.o    ${OUT}/ASP74.o    ${OUT}/ASP77.o    ${OUT}/ASP80.o    \
-  ${OUT}/CDFMAT.o   ${OUT}/CDFVEC.o   \
-  ${OUT}/CINTSLPE.o ${OUT}/COMBF.o    ${OUT}/COMPFACT.o ${OUT}/COMPLEX.o  \
-  ${OUT}/COMPLPAT.o ${OUT}/CMPLXRT.o  ${OUT}/CPMATCH.o  ${OUT}/CRFP.o     \
-  ${OUT}/CTRIGMNP.o ${OUT}/D01WGTS.o  ${OUT}/D02AGNT.o  ${OUT}/D03EEFA.o  \
-  ${OUT}/DBLRESP.o  ${OUT}/D01AGNT.o  ${OUT}/DERHAM.o   ${OUT}/DFSFUN.o   \
-  ${OUT}/DRAWCURV.o ${OUT}/DTP.o      \
-  ${OUT}/D01TRNS.o  ${OUT}/E04NAFA.o  ${OUT}/EF.o       \
-  ${OUT}/EFSTRUC.o  ${OUT}/ELFUTS.o   ${OUT}/ESTOOLS.o  ${OUT}/EXPEXPAN.o \
-  ${OUT}/EXPRODE.o  ${OUT}/EXPRTUBE.o ${OUT}/EXPR2.o    ${OUT}/FC.o       \
-  ${OUT}/FDIVCAT.o  ${OUT}/FDIVCAT-.o ${OUT}/FDIV2.o    ${OUT}/FFCAT2.o   \
-  ${OUT}/FLOATCP.o  ${OUT}/FORDER.o   ${OUT}/FORTRAN.o  ${OUT}/FRNAAF2.o  \
-  ${OUT}/FSPRMELT.o ${OUT}/FSRED.o    ${OUT}/FSUPFACT.o ${OUT}/FSPECF.o   \
-  ${OUT}/FS2.o      ${OUT}/FS2UPS.o   ${OUT}/GAUSSFAC.o ${OUT}/GCNAALG.o  \
-  ${OUT}/GDRAW.o    \
-  ${OUT}/GENUFACT.o ${OUT}/GENUPS.o   ${OUT}/GTSET.o    ${OUT}/GPOLSET.o  \
-  ${OUT}/IAN.o      ${OUT}/INEP.o     ${OUT}/INFPROD0.o ${OUT}/INFSP.o    \
-  ${OUT}/INPRODFF.o ${OUT}/INPRODPF.o ${OUT}/INTAF.o    ${OUT}/INTALG.o   \
-  ${OUT}/INTEF.o    ${OUT}/INTG0.o    ${OUT}/INTHERAL.o ${OUT}/INTPAF.o   \
-  ${OUT}/INTPM.o    ${OUT}/INTTOOLS.o ${OUT}/ITRIGMNP.o ${OUT}/JORDAN.o   \
-  ${OUT}/KOVACIC.o  ${OUT}/LF.o       ${OUT}/LIE.o      ${OUT}/LODOF.o    \
-  ${OUT}/LSQM.o     ${OUT}/MCMPLX.o   ${OUT}/MULTFACT.o \
-  ${MID}/clique1.spad \
-  ${OUT}/NAGF01.o   ${OUT}/NAGF02.o   ${OUT}/NAGF04.o   ${OUT}/NCEP.o     \
-  ${OUT}/NLINSOL.o  ${OUT}/NSMP.o     ${OUT}/NUMERIC.o  ${OUT}/OCT.o      \
-  ${OUT}/OCTCT2.o   ${OUT}/ODEPAL.o   ${OUT}/ODERTRIC.o ${OUT}/OMEXPR.o   \
-  ${OUT}/PACEXTC.o  ${OUT}/PADE.o     \
-  ${OUT}/PAN2EXPR.o ${OUT}/PFO.o      ${OUT}/PFOQ.o     ${OUT}/PICOERCE.o \
-  ${OUT}/PLACES.o   ${OUT}/PLACESPS.o \
-  ${OUT}/PMASSFS.o  ${OUT}/PMFS.o     ${OUT}/PMPREDFS.o ${OUT}/PROJPLPS.o \
-  ${OUT}/PSETPK.o   \
-  ${OUT}/QUAT.o     ${OUT}/QUATCT2.o  ${OUT}/RADFF.o    ${OUT}/RDEEF.o    \
-  ${OUT}/RDEEFS.o   ${OUT}/RDIV.o     ${OUT}/RSETCAT.o  ${OUT}/RSETCAT-.o \
-  ${OUT}/RSETGCD.o  ${OUT}/RULE.o     ${OUT}/RULESET.o  ${OUT}/SD.o       \
-  ${OUT}/SIGNEF.o   ${OUT}/SIMPAN.o   ${OUT}/SFORT.o    ${OUT}/SOLVESER.o \
-  ${OUT}/SOLVETRA.o ${OUT}/SUMFS.o    ${OUT}/SUTS.o     ${OUT}/TOOLSIGN.o \
-  ${OUT}/TRIGMNIP.o ${OUT}/TRMANIP.o  ${OUT}/UFPS.o     ${OUT}/ULSCCAT.o  \
-  ${OUT}/ULSCCAT-.o ${OUT}/UPXSSING.o ${OUT}/UTSODE.o   ${OUT}/UTSODETL.o \
-  ${OUT}/UTSSOL.o   ${OUT}/UTS2.o     ${OUT}/WUTSET.o  \
-  layer17done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 17 */
-/* depends on: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT */
-
-"ACFS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ACFS"]
-"ACFS" -> "ACF"
-/*"ACFS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ACFS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ACFS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ACFS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ACFS" -> {"UFD"; "DIVRING"; "RADCAT"}*/
-"ACFS" -> "FS"
-/*"ACFS" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
-/*"ACFS" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"}*/
-/*"ACFS" -> {"PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "INT"}*/
-/*"ACFS" -> {"LIST"; "ILIST"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"ACFS" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "NNI"}*/
-
-"ACFS-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ACFS"]
-"ACFS-" -> "ACF"
-/*"ACFS-" -> {"FIELD";  "EUCDOM";  "PID";  "GCDDOM";  "INTDOM";  "COMRING"}*/
-/*"ACFS-" -> {"RING";  "RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
-/*"ACFS-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "SGROUP";  "MONOID"}*/
-/*"ACFS-" -> {"LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE"}*/
-/*"ACFS-" -> {"ENTIRER";  "UFD";  "DIVRING";  "RADCAT"}*/
-"ACFS-" -> "FS"
-/*"ACFS-" -> {"ES";  "ORDSET";  "RETRACT";  "IEVALAB";  "EVALAB";  "PATAB"}*/
-/*"ACFS-" -> {"KONVERT";  "FPATMAB";  "TYPE";  "PATMAB";  "FRETRCT"}*/
-/*"ACFS-" -> {"GROUP";  "PDRING";  "FLINEXP";  "LINEXP";  "CHARZ";  "CHARNZ"}*/
-/*"ACFS-" -> {"INT";  "LIST";  "ILIST";  "UPOLYC";  "POLYCAT";  "FAMR"}*/
-/*"ACFS-" -> {"AMR";  "PFECAT";  "ELTAB";  "DIFRING";  "DIFEXT";  "STEP"}*/
-/*"ACFS-" -> "NNI"*/
-
-"AF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=AF"]
-/*"AF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
-/*"AF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"AF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"AF" -> {"MODULE"; "ENTIRER"}*/
-"AF" -> "FS"
-/*"AF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"AF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"AF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"AF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
-/*"AF" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"AF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-/*"AF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "UPOLYC"; "POLYCAT"}*/
-/*"AF" -> {"FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
-/*"AF" -> {"STEP"; "NNI"}*/
-"AF" -> "ACF"
-/*"AF" -> {"RADCAT"; "BOOLEAN"; "CACHSET"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"AF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "INS-"}*/
-
-"AFFPLPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AFFPLPS"]
-/*"AFFPLPS" -> {"AFSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"AFFPLPS" -> "PACFFC"
-/*"AFFPLPS" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"AFFPLPS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"AFFPLPS" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"AFFPLPS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"AFFPLPS" -> {"UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"}*/
-/*"AFFPLPS" -> {"PACPERC"; "PACOFF"; "AFFPL"}*/
-
-"ALGFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGFACT"]
-/*"ALGFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ALGFACT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ALGFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"ALGFACT" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"ALGFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"ALGFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"ALGFACT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
-/*"ALGFACT" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-/*"ALGFACT" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ES"; "LSAGG"}*/
-/*"ALGFACT" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "LNAGG"}*/
-/*"ALGFACT" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"ALGFACT" -> {"CACHSET"; "PATAB"; "ELAGG-"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"ALGFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"ALGFACT" -> {"QFCAT"; "FEVALAB"; "FPATMAB"}*/
-"ALGFACT" -> "ACF"
-/*"ALGFACT" -> {"RADCAT"; "NNI"; "BOOLEAN"; "MONOGEN"; "FRAMALG"; "FINRALG"}*/
-/*"ALGFACT" -> {"FINITE"; "FFIELDC"; "FPC"}*/
-
-"ALGFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALGFF"]
-/*"ALGFF" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ALGFF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ALGFF" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"ALGFF" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"ALGFF" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"ALGFF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"ALGFF" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "ELTAB"; "DIFRING"}*/
-/*"ALGFF" -> {"DIFEXT"; "STEP"; "EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-"ALGFF" -> "FFCAT"
-/*"ALGFF" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"ALGFF" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
-/*"ALGFF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"ALGFF" -> {"BOOLEAN"; "NNI"; "INT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"ALGFF" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "SINT"; "INS"}*/
-/*"ALGFF" -> {"CFCAT"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"ALGFF" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"ALGFF" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "OAMONS"}*/
-
-"ALGMANIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGMANIP"]
-/*"ALGMANIP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ALGMANIP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ALGMANIP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ALGMANIP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "FIELD"; "EUCDOM"}*/
-/*"ALGMANIP" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "ES"; "ORDSET"}*/
-/*"ALGMANIP" -> {"RETRACT"; "IEVALAB"; "EVALAB"; "SYMBOL"; "INT"; "REF"}*/
-/*"ALGMANIP" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"ALGMANIP" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"ALGMANIP" -> {"LNAGG-"; "ILIST"; "LSAGG-"; "CACHSET"; "UPOLYC"}*/
-/*"ALGMANIP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"ALGMANIP" -> {"FRETRCT"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"ALGMANIP" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "STAGG-"}*/
-/*"ALGMANIP" -> {"ELAGG-"; "URAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ALGMANIP" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"ALGMANIP" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "PATAB"; "BOOLEAN"}*/
-"ALGMANIP" -> "FS"
-/*"ALGMANIP" -> {"FPATMAB"; "GROUP"; "RADCAT"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"ALGMANIP" -> {"GCDDOM-"; "NNI"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"}*/
-/*"ALGMANIP" -> {"ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"; "INS"}*/
-/*"ALGMANIP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ALGMANIP" -> {"OASGP"; "CFCAT"; "REAL"}*/
-
-"ALGMFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGMFACT"]
-/*"ALGMFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"}*/
-/*"ALGMFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"ALGMFACT" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "SGROUP"}*/
-/*"ALGMFACT" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"ALGMFACT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"ALGMFACT" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"ALGMFACT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"ALGMFACT" -> {"GCDDOM"; "PFECAT"; "UFD"; "ES"}*/
-"ALGMFACT" -> "ACF"
-/*"ALGMFACT" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "RADCAT"; "UPOLYC"}*/
-/*"ALGMFACT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "REAL"}*/
-
-"ALGPKG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ALGPKG"]
-/*"ALGPKG" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ALGPKG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ALGPKG" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ALGPKG" -> {"MODULE"; "ENTIRER"}*/
-"ALGPKG" -> "FRNAALG"
-/*"ALGPKG" -> {"FINAALG"; "NAALG"; "NARNG"; "MONAD"; "PI"; "NNI"; "INT"}*/
-/*"ALGPKG" -> {"SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT"; "A1AGG"}*/
-/*"ALGPKG" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"ALGPKG" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"ALGPKG" -> {"VECTCAT-"; "A1AGG-"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
-/*"ALGPKG" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ALGPKG" -> {"OASGP"; "DIFRING"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"ALGPKG" -> {"REAL"; "CHARZ"; "STEP"; "OM"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
-/*"ALGPKG" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "BOOLEAN"; "LIST"}*/
-/*"ALGPKG" -> "ILIST"*/
-
-"ALGSC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALGSC"]
-"ALGSC" -> "FRNAALG"
-/*"ALGSC" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
-/*"ALGSC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"}*/
-/*"ALGSC" -> {"MODULE"; "BMODULE"; "LMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
-/*"ALGSC" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"}*/
-/*"ALGSC" -> {"MONOID"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"; "SMATCAT"}*/
-/*"ALGSC" -> {"DIFEXT"; "DIFRING"; "PDRING"; "RMATCAT"; "HOAGG"; "AGG"}*/
-/*"ALGSC" -> {"TYPE"; "EVALAB"; "IEVALAB"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
-/*"ALGSC" -> {"LINEXP"; "INT"; "VECTOR"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"ALGSC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"}*/
-/*"ALGSC" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"; "IVECTOR"}*/
-/*"ALGSC" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"}*/
-/*"ALGSC" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"ALGSC" -> {"BASTYPE-"; "SINT"; "PI"; "NNI"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"ALGSC" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "LIST"; "ILIST"}*/
-/*"ALGSC" -> {"LSAGG-"; "STAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"}*/
-/*"ALGSC" -> {"OUTFORM"; "PRIMARR"; "ISTRING"; "SRAGG-"; "LSAGG"; "STAGG"}*/
-/*"ALGSC" -> {"URAGG"; "RCAGG"; "ELAGG"; "BOOLEAN"; "POLYCAT"; "FAMR"}*/
-/*"ALGSC" -> {"AMR"; "CHARNZ"; "PFECAT"}*/
-
-"AN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=AN"]
-/*"AN" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"AN" -> {"IEVALAB"; "EVALAB"}*/
-"AN" -> "ACF"
-/*"AN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"AN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"AN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"AN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RADCAT"}*/
-/*"AN" -> {"LINEXP"; "REAL"; "KONVERT"; "CHARZ"; "DIFRING"; "INS"}*/
-/*"AN" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"AN" -> {"PATMAB"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
-/*"AN" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"AN" -> {"CHARNZ"; "PFECAT"; "FPS"; "RNS"; "CACHSET"}*/
-
-"APPRULE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=APPRULE"]
-/*"APPRULE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"; "ABELGRP"}*/
-/*"APPRULE" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"APPRULE" -> {"PATMAB"; "ORDSET"; "KONVERT"}*/
-"APPRULE" -> "FS"
-/*"APPRULE" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"}*/
-/*"APPRULE" -> {"TYPE"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"APPRULE" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"}*/
-/*"APPRULE" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"APPRULE" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "PI"}*/
-/*"APPRULE" -> {"NNI"; "SINT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"APPRULE" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"APPRULE" -> {"FLAGG"; "ELAGG"; "OM"; "INS-"}*/
-
-"ASP19" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP19"]
-/*"ASP19" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
-/*"ASP19" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"ASP19" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"ASP19" -> {"LNAGG-"; "ILIST"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"ASP19" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ASP19" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"ASP19" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ASP19" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"ASP19" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"ASP19" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-"ASP19" -> "FS"
-/*"ASP19" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
-/*"ASP19" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
-/*"ASP19" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
-/*"ASP19" -> {"ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"}*/
-/*"ASP19" -> {"STEP"; "FMTC"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"ASP19" -> {"VECTCAT-"; "IXAGG-"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"ASP19" -> {"RCAGG"; "ELAGG"; "LSAGG-"; "PI"; "POLYCAT"; "FAMR"}*/
-/*"ASP19" -> {"AMR"; "PFECAT"}*/
-
-"ASP20" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP20"]
-/*"ASP20" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "FPS"}*/
-/*"ASP20" -> {"RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ASP20" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ASP20" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP20" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"ASP20" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"ASP20" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"ASP20" -> {"CHARZ"; "ES"; "IEVALAB"; "EVALAB"; "SINT"; "PI"; "NNI"}*/
-/*"ASP20" -> {"INT"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"ASP20" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"ASP20" -> {"LNAGG-"; "FMTC"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP20" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP20" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
-/*"ASP20" -> {"DIFEXT"; "PATAB"; "FPATMAB"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"ASP20" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
-"ASP20" -> "FS"
-/*"ASP20" -> "GROUP"*/
-
-"ASP31" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP31"]
-/*"ASP31" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
-/*"ASP31" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"ASP31" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"ASP31" -> {"BOOLEAN"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"ASP31" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ASP31" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"}*/
-/*"ASP31" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ASP31" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ASP31" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"ASP31" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-"ASP31" -> "FS"
-/*"ASP31" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
-/*"ASP31" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
-/*"ASP31" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
-/*"ASP31" -> {"ELTAB"; "CLAGG"; "NNI"; "ILIST"; "VECTOR"; "IVECTOR"}*/
-/*"ASP31" -> {"IARRAY1"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"; "STEP"}*/
-/*"ASP31" -> {"OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "FMTC"}*/
-/*"ASP31" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
-
-"ASP35" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP35"]
-/*"ASP35" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SINT"}*/
-/*"ASP35" -> {"NNI"; "INT"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"ASP35" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"ASP35" -> {"FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"ASP35" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ASP35" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"}*/
-/*"ASP35" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ASP35" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"ASP35" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"ASP35" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-"ASP35" -> "FS"
-/*"ASP35" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
-/*"ASP35" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
-/*"ASP35" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
-/*"ASP35" -> {"ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"}*/
-/*"ASP35" -> {"STEP"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG"}*/
-/*"ASP35" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "FMTC"; "POLYCAT"}*/
-/*"ASP35" -> {"FAMR"; "AMR"; "PFECAT"}*/
-
-"ASP41" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP41"]
-/*"ASP41" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
-/*"ASP41" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"ASP41" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"ASP41" -> {"LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"ASP41" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ASP41" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"}*/
-/*"ASP41" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ASP41" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ASP41" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"ASP41" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-"ASP41" -> "FS"
-/*"ASP41" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
-/*"ASP41" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
-/*"ASP41" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"ASP41" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"ASP41" -> {"VECTCAT-"; "IXAGG-"; "NNI"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"ASP41" -> {"CFCAT"; "STEP"; "OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ASP41" -> {"ELAGG"; "FMTC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
-
-"ASP42" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP42"]
-/*"ASP42" -> {"FVFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "BOOLEAN"; "SYMBOL"}*/
-/*"ASP42" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"ASP42" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"ASP42" -> {"FLAGG-"; "LNAGG-"; "NNI"; "ILIST"; "FPS"; "RNS"; "FIELD"}*/
-/*"ASP42" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"ASP42" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"ASP42" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"ASP42" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"ASP42" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ASP42" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-"ASP42" -> "FS"
-/*"ASP42" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
-/*"ASP42" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
-/*"ASP42" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"}*/
-/*"ASP42" -> {"ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"; "CFCAT"}*/
-/*"ASP42" -> {"STEP"; "OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG"}*/
-/*"ASP42" -> {"STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "VECTCAT-"; "IXAGG-"}*/
-/*"ASP42" -> {"FMTC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
-
-"ASP74" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP74"]
-/*"ASP74" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"; "FIELD"}*/
-/*"ASP74" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"ASP74" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"ASP74" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ASP74" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"ASP74" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"ASP74" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "ES"}*/
-/*"ASP74" -> {"IEVALAB"; "EVALAB"; "NNI"; "INT"; "INS"; "OINTDOM"}*/
-/*"ASP74" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"; "OM"; "PI"; "FMTC"}*/
-/*"ASP74" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"ASP74" -> {"FLINEXP"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
-/*"ASP74" -> {"PATAB"; "FPATMAB"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"ASP74" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
-"ASP74" -> "FS"
-/*"ASP74" -> "GROUP"*/
-
-"ASP77" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP77"]
-/*"ASP77" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"ASP77" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ASP77" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ASP77" -> {"SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ASP77" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ASP77" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ASP77" -> {"OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"ASP77" -> {"RADCAT"; "PATMAB"; "CHARZ"}*/
-"ASP77" -> "FS"
-/*"ASP77" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
-/*"ASP77" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "VECTCAT"}*/
-/*"ASP77" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"ASP77" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"ASP77" -> {"CFCAT"; "STEP"; "BOOLEAN"; "FMTC"; "POLYCAT"; "FAMR"}*/
-/*"ASP77" -> {"AMR"; "PFECAT"; "QFCAT"; "FEVALAB"; "DIFEXT"}*/
-
-"ASP80" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ASP80"]
-/*"ASP80" -> {"FMFUN"; "FORTCAT"; "TYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
-/*"ASP80" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"ASP80" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"ASP80" -> {"BOOLEAN"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"ASP80" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ASP80" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "SGROUP"; "MONOID"}*/
-/*"ASP80" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ASP80" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ASP80" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"ASP80" -> {"RADCAT"; "PATMAB"; "CHARZ"; "FMTC"; "ES"; "IEVALAB"}*/
-/*"ASP80" -> {"EVALAB"; "PI"; "NNI"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ASP80" -> {"CFCAT"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"ASP80" -> {"FRETRCT"; "FLINEXP"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
-/*"ASP80" -> {"DIFEXT"; "PATAB"; "FPATMAB"; "VECTCAT"; "A1AGG"; "FLAGG"}*/
-/*"ASP80" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
-"ASP80" -> "FS"
-/*"ASP80" -> "GROUP"*/
-
-"CDFMAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CDFMAT"]
-"CDFMAT" -> "COMPCAT"
-/*"CDFMAT" -> {"MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "TYPE"; "SETCAT"}*/
-/*"CDFMAT" -> {"BASTYPE"; "KOERCE"; "EVALAB"; "IEVALAB"; "FPS"; "RNS"}*/
-/*"CDFMAT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"CDFMAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"CDFMAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"CDFMAT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"CDFMAT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"CDFMAT" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "MONOGEN"}*/
-/*"CDFMAT" -> {"FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
-/*"CDFMAT" -> {"LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"}*/
-/*"CDFMAT" -> {"FPC"; "STEP"; "FEVALAB"; "ELTAB"; "FPATMAB"; "PATAB"}*/
-/*"CDFMAT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"CDFMAT" -> {"PFECAT"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"CDFMAT" -> {"ELTAGG"; "CLAGG"; "INT"; "SINT"; "NNI"; "OM"; "SPFCAT"}*/
-
-"CDFVEC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CDFVEC"]
-"CDFVEC" -> "COMPCAT"
-/*"CDFVEC" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"CDFVEC" -> {"AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"*/
-/*"CDFVEC" -> {"IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"}*/
-/*"CDFVEC" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"CDFVEC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"CDFVEC" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"CDFVEC" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"CDFVEC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
-/*"CDFVEC" -> {"RADCAT"; "PATMAB"; "CHARZ"; "INT"; "SINT"; "NNI"; "MONOGEN"}*/
-/*"CDFVEC" -> {"FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"; "FLINEXP"}*/
-/*"CDFVEC" -> {"LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"}*/
-/*"CDFVEC" -> {"FPC"; "STEP"; "FEVALAB"; "FPATMAB"; "PATAB"; "TRANFUN"}*/
-/*"CDFVEC" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PFECAT"}*/
-/*"CDFVEC" -> {"OM"; "SPFCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
-
-"CINTSLPE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CINTSLPE"]
-/*"CINTSLPE" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"CINTSLPE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"CINTSLPE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CINTSLPE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"CINTSLPE" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"CINTSLPE" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"CINTSLPE" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"CINTSLPE" -> {"REAL"; "CHARZ"; "STEP"}*/
-"CINTSLPE" -> "COMPCAT"
-/*"CINTSLPE" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"CINTSLPE" -> {"FLINEXP"; "FINITE"; "FIELD"; "DIVRING"; "DIFEXT"}*/
-/*"CINTSLPE" -> {"PDRING"; "FFIELDC"; "FPC"; "FEVALAB"; "ELTAB"}*/
-/*"CINTSLPE" -> {"EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"}*/
-/*"CINTSLPE" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"CINTSLPE" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "INT"; "VECTOR"}*/
-/*"CINTSLPE" -> {"IVECTOR"; "IARRAY1"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"CINTSLPE" -> {"AMR"; "LIST"; "ILIST"; "NNI"; "BOOLEAN"}*/
-
-"COMBF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMBF"]
-/*"COMBF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"COMBF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"COMBF" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"COMBF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-"COMBF" -> "FS"
-/*"COMBF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"COMBF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"COMBF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"COMBF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
-/*"COMBF" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"COMBF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"COMBF" -> {"BOOLEAN"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"COMBF" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"COMBF" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"; "LSAGG-"; "STAGG-"}*/
-/*"COMBF" -> {"ELAGG-"; "URAGG-"; "CACHSET"; "RADCAT"; "INS"; "OINTDOM"}*/
-/*"COMBF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"COMBF" -> {"CFCAT"; "REAL"; "STEP"; "INS-"; "ELEMFUN"}*/
-
-"COMPFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMPFACT"]
-/*"COMPFACT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"COMPFACT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"COMPFACT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"COMPFACT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"COMPFACT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"COMPFACT" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"COMPFACT" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"COMPFACT" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"COMPFACT" -> {"FIELD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"COMPFACT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"COMPFACT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-"COMPFACT" -> "COMPCAT"
-/*"COMPFACT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
-/*"COMPFACT" -> {"FPC"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"COMPFACT" -> {"ELEMFUN"; "RADCAT"; "INT"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"COMPFACT" -> {"GCDDOM-"; "SINT"; "NNI"; "OM"; "LIST"}*/
-
-"COMPLEX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=COMPLEX"]
-"COMPLEX" -> "COMPCAT"
-/*"COMPLEX" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "RING"; "RNG"}*/
-/*"COMPLEX" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"COMPLEX" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"COMPLEX" -> {"MODULE"; "BMODULE"; "RMODULE"; "CHARZ"; "CHARNZ"}*/
-/*"COMPLEX" -> {"COMRING"; "KONVERT"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
-/*"COMPLEX" -> {"LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"COMPLEX" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"}*/
-/*"COMPLEX" -> {"DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"}*/
-/*"COMPLEX" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"}*/
-/*"COMPLEX" -> {"PATAB"; "ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"COMPLEX" -> {"AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"; "OM"; "BOOLEAN"}*/
-/*"COMPLEX" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "INS"; "OINTDOM"}*/
-/*"COMPLEX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"COMPLEX" -> {"CFCAT"; "REAL"; "RNS"; "FPS"; "OAMONS"}*/
-
-"COMPLPAT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=COMPLPAT"]
-/*"COMPLPAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "KONVERT"; "COMRING"}*/
-/*"COMPLPAT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"COMPLPAT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"COMPLPAT" -> "COMPCAT"
-/*"COMPLPAT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"}*/
-/*"COMPLPAT" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
-/*"COMPLPAT" -> {"LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"COMPLPAT" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"}*/
-/*"COMPLPAT" -> {"PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
-/*"COMPLPAT" -> {"EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"; "PATAB"}*/
-/*"COMPLPAT" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"COMPLPAT" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "SYMBOL"; "INT"; "REF"}*/
-/*"COMPLPAT" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"COMPLPAT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"COMPLPAT" -> {"LNAGG-"; "BOOLEAN"}*/
-
-"CMPLXRT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CMPLXRT"]
-/*"CMPLXRT" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"CMPLXRT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"CMPLXRT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"}*/
-/*"CMPLXRT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"CMPLXRT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"CMPLXRT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"CMPLXRT" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
-/*"CMPLXRT" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"; "PID"}*/
-/*"CMPLXRT" -> {"FIELD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"CMPLXRT" -> {"OAMON"; "OASGP"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
-/*"CMPLXRT" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"CMPLXRT" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"CMPLXRT" -> {"INS"; "OINTDOM"; "CFCAT"; "REAL"; "ILIST"}*/
-"CMPLXRT" -> "COMPCAT"
-/*"CMPLXRT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
-/*"CMPLXRT" -> {"FPC"; "FEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"}*/
-/*"CMPLXRT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"}*/
-/*"CMPLXRT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-
-"CPMATCH" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CPMATCH"]
-/*"CPMATCH" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "PATMAB"; "COMRING"; "RING"}*/
-/*"CPMATCH" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"CPMATCH" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"CPMATCH" -> "COMPCAT"
-/*"CPMATCH" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"}*/
-/*"CPMATCH" -> {"CHARZ"; "CHARNZ"; "KONVERT"; "FRETRCT"; "RETRACT"}*/
-/*"CPMATCH" -> {"FLINEXP"; "LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"CPMATCH" -> {"GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"}*/
-/*"CPMATCH" -> {"DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"}*/
-/*"CPMATCH" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"}*/
-/*"CPMATCH" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"CPMATCH" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "SYMBOL"; "INT"; "REF"}*/
-/*"CPMATCH" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"CPMATCH" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"CPMATCH" -> {"LNAGG-"; "NNI"; "POLYCAT"; "FAMR"; "AMR"}*/
-
-"CRFP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CRFP"]
-/*"CRFP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"CRFP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"CRFP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"CRFP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"CRFP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"CRFP" -> {"ORDSET"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"CRFP" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"CRFP" -> {"FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
-/*"CRFP" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
-"CRFP" -> "COMPCAT"
-/*"CRFP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"CRFP" -> {"FEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
-/*"CRFP" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "INT"; "NNI"}*/
-/*"CRFP" -> {"QFCAT"; "OINTDOM"; "REAL"; "PI"; "OM"; "BOOLEAN"; "LSAGG"}*/
-/*"CRFP" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"CRFP" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"CRFP" -> {"SINT"; "INS"; "CFCAT"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"CRFP" -> {"LNAGG-"; "MONOID-"; "ABELMON-"; "RNS"}*/
-
-"CTRIGMNP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CTRIGMNP"]
-/*"CTRIGMNP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"CTRIGMNP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"CTRIGMNP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"CTRIGMNP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
-"CTRIGMNP" -> "ACF"
-/*"CTRIGMNP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"CTRIGMNP" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"CTRIGMNP" -> {"AHYP"; "ELEMFUN"}*/
-"CTRIGMNP" -> "FS"
-/*"CTRIGMNP" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"CTRIGMNP" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"CTRIGMNP" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"CTRIGMNP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"CTRIGMNP" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"CTRIGMNP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"CTRIGMNP" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-"CTRIGMNP" -> "COMPCAT"
-/*"CTRIGMNP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"}*/
-/*"CTRIGMNP" -> {"DIFRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "PFECAT"}*/
-/*"CTRIGMNP" -> {"CACHSET"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"CTRIGMNP" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"CTRIGMNP" -> "SRAGG-"*/
-
-"D01WGTS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D01WGTS"]
-/*"D01WGTS" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"D01WGTS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"D01WGTS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"D01WGTS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"D01WGTS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"D01WGTS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"D01WGTS" -> {"ORDSET"; "REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"}*/
-/*"D01WGTS" -> "CHARZ"*/
-"D01WGTS" -> "FS"
-/*"D01WGTS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"D01WGTS" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"}*/
-/*"D01WGTS" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"D01WGTS" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"D01WGTS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"D01WGTS" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"D01WGTS" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "NNI"}*/
-/*"D01WGTS" -> {"LSAGG-"; "STAGG-"; "BOOLEAN"; "DIFRING"; "TRANFUN"}*/
-/*"D01WGTS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"}*/
-/*"D01WGTS" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "INS"}*/
-/*"D01WGTS" -> {"OINTDOM"; "CFCAT"; "STEP"; "DFLOAT"; "FPS-"; "RNS-"}*/
-
-"D02AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D02AGNT"]
-/*"D02AGNT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"D02AGNT" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "EVALAB"}*/
-/*"D02AGNT" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"D02AGNT" -> {"KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"; "INT"}*/
-/*"D02AGNT" -> {"LIST"; "ILIST"; "DFLOAT"; "NNI"; "PI"; "FPS"; "RNS"}*/
-/*"D02AGNT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"D02AGNT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"D02AGNT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"D02AGNT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"D02AGNT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "RETRACT"}*/
-/*"D02AGNT" -> {"RADCAT"; "PATMAB"; "CHARZ"; "VECTCAT"; "A1AGG"; "VECTOR"}*/
-/*"D02AGNT" -> {"IVECTOR"; "IARRAY1"; "DIFRING"; "TRANFUN"; "TRIGCAT"}*/
-/*"D02AGNT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "VECTCAT-"}*/
-/*"D02AGNT" -> {"A1AGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "BOOLEAN"}*/
-"D02AGNT" -> "FS"
-/*"D02AGNT" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"D02AGNT" -> {"FLINEXP"; "LINEXP"; "CHARNZ"; "MATCAT"; "ARR2CAT"}*/
-/*"D02AGNT" -> {"INS"; "OINTDOM"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"}*/
-/*"D02AGNT" -> {"DIFEXT"; "PFECAT"; "LNAGG-"; "IXAGG-"; "SINT"; "SYMBOL"}*/
-/*"D02AGNT" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
-/*"D02AGNT" -> {"PRIMARR"; "ISTRING"; "SRAGG-"}*/
-
-"D03EEFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D03EEFA"]
-/*"D03EEFA" -> {"PDECAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "LSAGG"}*/
-/*"D03EEFA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"D03EEFA" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"D03EEFA" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"}*/
-/*"D03EEFA" -> {"OM"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"; "STAGG-"}*/
-/*"D03EEFA" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "PI"; "MONOID-"; "ABELMON-"}*/
-/*"D03EEFA" -> {"DFLOAT"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"D03EEFA" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"D03EEFA" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"D03EEFA" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"D03EEFA" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"D03EEFA" -> {"OAMON"; "OASGP"; "REAL"; "RETRACT"; "RADCAT"}*/
-/*"D03EEFA" -> {"PATMAB"; "CHARZ"; "VECTOR"}*/
-"D03EEFA" -> "FS"
-/*"D03EEFA" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"D03EEFA" -> {"FLINEXP"; "LINEXP"; "CHARNZ"}*/
-
-"DBLRESP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DBLRESP"]
-/*"DBLRESP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"DBLRESP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"DBLRESP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"DBLRESP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"DBLRESP" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
-/*"DBLRESP" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"DBLRESP" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"DBLRESP" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
-/*"DBLRESP" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
-"DBLRESP" -> "FFCAT"
-/*"DBLRESP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
-/*"DBLRESP" -> {"FPC"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"DBLRESP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"DBLRESP" -> {"OASGP"; "REAL"; "NNI"; "INT"; "PI"}*/
-
-"D01AGNT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=D01AGNT"]
-/*"D01AGNT" -> {"INT"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"D01AGNT" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"D01AGNT" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"D01AGNT" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
-/*"D01AGNT" -> {"NNI"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"D01AGNT" -> {"A1AGG-"; "ISTRING"; "LSAGG-"; "STAGG-"; "FPS"; "RNS"}*/
-/*"D01AGNT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"D01AGNT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"D01AGNT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"D01AGNT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"D01AGNT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"D01AGNT" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"; "DIFRING"}*/
-/*"D01AGNT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"D01AGNT" -> {"ELEMFUN"; "SPFCAT"; "ELAGG-"; "FLAGG-"}*/
-"D01AGNT" -> "FS"
-/*"D01AGNT" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"D01AGNT" -> {"FLINEXP"; "LINEXP"; "CHARNZ"; "INS"; "OINTDOM"; "CFCAT"}*/
-/*"D01AGNT" -> {"STEP"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"; "BOOLEAN"}*/
-
-"DERHAM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=DERHAM"]
-/*"DERHAM" -> {"LALG"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"DERHAM" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"DERHAM" -> {"MONOID"; "LMODULE"; "RETRACT"}*/
-"DERHAM" -> "FS"
-/*"DERHAM" -> {"ES"; "ORDSET"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"DERHAM" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"DERHAM" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"}*/
-/*"DERHAM" -> {"BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"DERHAM" -> {"INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "LSAGG"}*/
-/*"DERHAM" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"DERHAM" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
-/*"DERHAM" -> {"LIST"; "ILIST"; "SINT"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"DERHAM" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"DERHAM" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"DERHAM" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
-/*"DERHAM" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-
-"DFSFUN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DFSFUN"]
-/*"DFSFUN" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"DFSFUN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DFSFUN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DFSFUN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DFSFUN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"DFSFUN" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"DFSFUN" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DFLOAT"}*/
-/*"DFSFUN" -> {"NNI"; "INT"; "PI"; "FPS-"; "RNS-"; "FIELD-"; "EUCDOM-"}*/
-/*"DFSFUN" -> {"UFD-"; "GCDDOM-"; "DIVRING-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"DFSFUN" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"DFSFUN" -> {"ABELMON-"; "MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
-/*"DFSFUN" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-/*"DFSFUN" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"DFSFUN" -> {"ELEMFUN"; "SPFCAT"}*/
-"DFSFUN" -> "COMPCAT"
-/*"DFSFUN" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"DFSFUN" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"}*/
-/*"DFSFUN" -> {"FPC"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"}*/
-/*"DFSFUN" -> {"TYPE"; "PATAB"; "PFECAT"; "FRAC"}*/
-
-"DRAWCURV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DRAWCURV"]
-/*"DRAWCURV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DRAWCURV" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"DRAWCURV" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"DRAWCURV" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
-"DRAWCURV" -> "FS"
-/*"DRAWCURV" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"DRAWCURV" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"DRAWCURV" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"DRAWCURV" -> {"GCDDOM"; "UFD"; "DIVRING"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"DRAWCURV" -> {"PFECAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"DRAWCURV" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"}*/
-/*"DRAWCURV" -> {"STEP"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"DRAWCURV" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"DRAWCURV" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"DRAWCURV" -> {"ELAGG-"; "URAGG-"; "OM"; "FPS"; "RNS"; "RADCAT"}*/
-
-"DTP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DTP"]
-"DTP" -> ""INFCLCT"
-/*"DTP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "DIVCAT"; "DSTRCAT"}*/
-/*"DTP" -> {"BLMETCT"; "PFORP"; "AFFPL"; "PARAMP"; "PLPKCRV"; "BLUPPACK"}*/
-/*"DTP" -> {"LPARSPT"; "DIV"; "PRJALGPK"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"DTP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"DTP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"DTP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"DTP" -> {"ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"DTP" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"DTP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"DTP" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"; "ELTAB"}*/
-/*"DTP" -> {"DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DTP" -> {"OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "UPSCAT"; "PSCAT"}*/
-/*"DTP" -> {"FAMONC"; "RCAGG"; "INT"; "PI"; "NNI"; "SINT"; "BOOLEAN"; "LIST"}*/
-/*"DTP" -> {"ILIST"; "LSAGG-"; "STAGG-"; "VECTOR"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"DTP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "SYMBOL"; "REF"}*/
-/*"DTP" -> {"ALIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"DTP" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"D01TRNS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=D01TRNS"]
-/*"D01TRNS" -> {"NUMINT"; "SETCAT"; "BASTYPE"; "KOERCE"; "STRING"; "CHAR"}*/
-/*"D01TRNS" -> {"SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"; "A1AGG-"}*/
-/*"D01TRNS" -> {"ISTRING"; "SRAGG-"; "SYMBOL"; "REF"; "ALIST"; "FLAGG-"}*/
-/*"D01TRNS" -> {"LNAGG-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"D01TRNS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"D01TRNS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"D01TRNS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"D01TRNS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"D01TRNS" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"}*/
-/*"D01TRNS" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"}*/
-/*"D01TRNS" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"D01TRNS" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"}*/
-/*"D01TRNS" -> {"FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"; "OM"; "FPS"}*/
-/*"D01TRNS" -> {"RNS"; "RADCAT"}*/
-"D01TRNS" -> "FS" 
-/*"D01TRNS" -> {"ES"; "FRETRCT"; "GROUP"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"D01TRNS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "DFLOAT"; "PI"}*/
-/*"D01TRNS" -> {"NNI"; "BOOLEAN"; "ILIST"}*/
-
-"E04NAFA" [color="#88FF44",href="bookvol10.3.pdf#nameddest=E04NAFA"]
-/*"E04NAFA" -> {"OPTCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "FPS"; "RNS"}*/
-/*"E04NAFA" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"E04NAFA" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"E04NAFA" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"E04NAFA" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"E04NAFA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"E04NAFA" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "STRING"}*/
-/*"E04NAFA" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"E04NAFA" -> {"A1AGG-"; "ISTRING"; "STRICAT"; "SRAGG"; "A1AGG"}*/
-/*"E04NAFA" -> {"FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"E04NAFA" -> {"EVALAB"; "IEVALAB"; "ELTAGG"; "ELTAB"; "CLAGG"; "OM"}*/
-/*"E04NAFA" -> {"NNI"; "DIFRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"E04NAFA" -> {"AHYP"; "ELEMFUN"; "SPFCAT"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"E04NAFA" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "ELAGG-"}*/
-/*"E04NAFA" -> {"FLAGG-"; "DFLOAT"; "PI"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"E04NAFA" -> {"AMR"; "CHARNZ"; "FRETRCT"; "FLINEXP"; "LINEXP"; "PFECAT"}*/
-/*"E04NAFA" -> "VECTCAT"*/
-"E04NAFA" -> "FS"
-/*"E04NAFA" -> {"ES"; "PATAB"; "FPATMAB"; "GROUP"; "INS-"; "INS"}*/
-/*"E04NAFA" -> {"OINTDOM"; "CFCAT"; "STEP"; "MONOID-"; "ABELMON-"; "BOOLEAN"}*/
-
-"EF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EF"]
-/*"EF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
-/*"EF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"EF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"EF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"}*/
-"EF" -> "FS"
-/*"EF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"EF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"EF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"EF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"; "SYMBOL"; "INT"}*/
-/*"EF" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"EF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"EF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"EF" -> {"ILIST"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"EF" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "OM"}*/
-/*"EF" -> {"INS-"; "LSAGG-"; "STAGG-"; "PI"; "NNI"; "BOOLEAN"; "CACHSET"}*/
-
-"EFSTRUC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EFSTRUC"]
-/*"EFSTRUC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"EFSTRUC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"EFSTRUC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"EFSTRUC" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"}*/
-"EFSTRUC" -> "ACF"
-/*"EFSTRUC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"EFSTRUC" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"EFSTRUC" -> {"AHYP"; "ELEMFUN"}*/
-"EFSTRUC" -> "FS"
-/*"EFSTRUC" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"EFSTRUC" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"EFSTRUC" -> {"CHARZ"; "CHARNZ"; "COMBOPC"; "CFCAT"; "CACHSET"; "BOOLEAN"}*/
-/*"EFSTRUC" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
-/*"EFSTRUC" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"EFSTRUC" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "INS"}*/
-/*"EFSTRUC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"EFSTRUC" -> {"DIFRING"; "REAL"; "STEP"; "PI"; "NNI"; "SINT"; "SYMBOL"}*/
-/*"EFSTRUC" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
-/*"EFSTRUC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "URAGG-"}*/
-/*"EFSTRUC" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"EFSTRUC" -> {"VECTCAT"; "A1AGG"; "VECTCAT-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"EFSTRUC" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-
-"ELFUTS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ELFUTS"]
-/*"ELFUTS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ELFUTS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ELFUTS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ELFUTS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ELFUTS" -> {"ENTIRER"; "UFD"; "DIVRING"}*/
-"ELFUTS" -> "UTSCAT"
-/*"ELFUTS" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
-/*"ELFUTS" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"ELFUTS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "LIST"}*/
-/*"ELFUTS" -> {"ILIST"; "LSAGG-"; "STAGG-"}*/
-
-"ESTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESTOOLS"]
-/*"ESTOOLS" -> {"INT"; "LIST"; "ILIST"; "NNI"; "FPS"; "RNS"; "FIELD"}*/
-/*"ESTOOLS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"ESTOOLS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"ESTOOLS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ESTOOLS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ESTOOLS" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ESTOOLS" -> {"OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"; "RETRACT"}*/
-/*"ESTOOLS" -> {"RADCAT"; "PATMAB"; "CHARZ"; "SINT"; "LSAGG-"; "DFLOAT"}*/
-/*"ESTOOLS" -> {"FPS-"; "RNS-"; "INS"; "OINTDOM"; "DIFRING"; "LINEXP"}*/
-/*"ESTOOLS" -> {"CFCAT"; "STEP"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"ESTOOLS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SPFCAT"; "QFCAT"; "FEVALAB"}*/
-/*"ESTOOLS" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "PDRING"}*/
-/*"ESTOOLS" -> {"FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"; "PFECAT"}*/
-/*"ESTOOLS" -> {"LZSTAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"ESTOOLS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "VECTOR"; "VECTCAT"}*/
-/*"ESTOOLS" -> {"A1AGG"; "FLAGG"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"ESTOOLS" -> {"A1AGG-"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"ESTOOLS" -> {"HOAGG-"; "BOOLEAN"; "LSAGG"; "ELAGG"; "STAGG-"}*/
-"ESTOOLS" -> "FS"
-/*"ESTOOLS" -> {"ES"; "FRETRCT"; "GROUP"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
-/*"ESTOOLS" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"ESTOOLS" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"ESTOOLS" -> {"ABELMON-"; "PI"; "TBAGG"; "KDAGG"; "DIAGG"; "DIOPS"}*/
-/*"ESTOOLS" -> {"BGAGG"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "ISTRING"}*/
-
-"EXPEXPAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXPEXPAN"]
-"EXPEXPAN" -> "ACF"
-/*"EXPEXPAN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"EXPEXPAN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"EXPEXPAN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"EXPEXPAN" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"EXPEXPAN" -> {"ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
-/*"EXPEXPAN" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"EXPEXPAN" -> "FS"
-/*"EXPEXPAN" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
-/*"EXPEXPAN" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
-/*"EXPEXPAN" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
-/*"EXPEXPAN" -> {"QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"; "DIFRING"; "STEP"}*/
-/*"EXPEXPAN" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"EXPEXPAN" -> {"OASGP"; "REAL"; "PFECAT"; "FAMR"; "AMR"; "PI"; "NNI"}*/
-/*"EXPEXPAN" -> {"INT"; "INS"; "CFCAT"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"EXPEXPAN" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"EXPEXPAN" -> {"CLAGG"; "FLAGG"; "ELAGG"; "LIST"; "ILIST"; "STRING"}*/
-/*"EXPEXPAN" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"EXPEXPAN" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "FPS"}*/
-/*"EXPEXPAN" -> {"RNS"; "UPOLYC"; "POLYCAT"}*/
-
-"EXPRODE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPRODE"]
-/*"EXPRODE" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"EXPRODE" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"EXPRODE" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"EXPRODE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "KONVERT"}*/
-"EXPRODE" -> "FS"
-/*"EXPRODE" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"}*/
-/*"EXPRODE" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"EXPRODE" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"EXPRODE" -> {"GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
-/*"EXPRODE" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"EXPRODE" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"}*/
-/*"EXPRODE" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"EXPRODE" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "CACHSET"; "UPOLYC"}*/
-/*"EXPRODE" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFEXT"}*/
-/*"EXPRODE" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"EXPRODE" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"EXPRODE" -> {"OM"; "ILIST"}*/
-
-"EXPRTUBE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPRTUBE"]
-/*"EXPRTUBE" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"EXPRTUBE" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"EXPRTUBE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"EXPRTUBE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"EXPRTUBE" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"EXPRTUBE" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"EXPRTUBE" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"EXPRTUBE" -> {"CHARZ"; "STEP"; "OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"EXPRTUBE" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"EXPRTUBE" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"EXPRTUBE" -> {"INT"; "LIST"; "ILIST"; "NNI"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"EXPRTUBE" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"EXPRTUBE" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"}*/
-"EXPRTUBE" -> "FS"
-/*"EXPRTUBE" -> {"ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"EXPRTUBE" -> {"FLINEXP"; "CHARNZ"; "FIELD"; "DIVRING"; "FPS"; "RNS"}*/
-/*"EXPRTUBE" -> "RADCAT"*/
-
-"EXPR2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPR2"]
-/*"EXPR2" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"; "RNG"}*/
-/*"EXPR2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"EXPR2" -> {"MONOID"; "LMODULE"}*/
-"EXPR2" -> "FS"
-/*"EXPR2" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"EXPR2" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"EXPR2" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"}*/
-/*"EXPR2" -> {"BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"EXPR2" -> {"INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"FC" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FC"]
-/*"FC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SINT"; "INS"; "UFD"; "GCDDOM"}*/
-/*"FC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FC" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"FC" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"FC" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"FC" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "INT"; "LIST"; "ILIST"}*/
-/*"FC" -> {"LSAGG-"; "STAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"FC" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"FC" -> {"FLAGG-"; "LNAGG-"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"FC" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"; "STRICAT"}*/
-/*"FC" -> {"SRAGG"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"FC" -> {"TYPE"; "ELTAGG"; "ELTAB"; "CLAGG"; "OM"; "NNI"; "DFLOAT"}*/
-/*"FC" -> {"BOOLEAN"; "FMTC"; "FPS"; "RNS"; "FIELD"; "DIVRING"; "RADCAT"}*/
-"FC" -> "COMPCAT"
-/*"FC" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"; "FFIELDC"}*/
-/*"FC" -> {"FPC"; "FEVALAB"; "FPATMAB"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
-/*"FC" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "VECTOR"; "IVECTOR"}*/
-/*"FC" -> {"IARRAY1"; "VECTCAT-"}*/
-"FC" -> "FS"
-/*"FC" -> {"ES"; "GROUP"}*/
-
-"FDIVCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FDIVCAT"]
-/*"FDIVCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FDIVCAT" -> {"BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FDIVCAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"FDIVCAT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FDIVCAT" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"FDIVCAT" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"FDIVCAT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"FDIVCAT" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"FDIVCAT" -> {"DIFEXT"; "STEP"}*/
-"FDIVCAT" -> "FFCAT"
-/*"FDIVCAT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-
-"FDIVCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FDIVCAT"]
-/*"FDIVCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
-/*"FDIVCAT-" -> {"BASTYPE";  "KOERCE";  "FIELD";  "EUCDOM";  "PID"}*/
-/*"FDIVCAT-" -> {"GCDDOM";  "INTDOM";  "COMRING";  "RING";  "RNG";  "SGROUP"}*/
-/*"FDIVCAT-" -> {"MONOID";  "LMODULE";  "BMODULE";  "RMODULE";  "ALGEBRA"}*/
-/*"FDIVCAT-" -> {"MODULE";  "ENTIRER";  "UFD";  "DIVRING";  "UPOLYC"}*/
-/*"FDIVCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ"}*/
-/*"FDIVCAT-" -> {"FRETRCT";  "RETRACT";  "EVALAB";  "IEVALAB";  "FLINEXP"}*/
-/*"FDIVCAT-" -> {"LINEXP";  "ORDSET";  "KONVERT";  "PATMAB";  "PFECAT"}*/
-/*"FDIVCAT-" -> {"ELTAB";  "DIFRING";  "DIFEXT";  "STEP"}*/
-"FDIVCAT-" -> "FFCAT"
-/*"FDIVCAT-" -> {"MONOGEN";  "FRAMALG";  "FINRALG";  "FINITE";  "FFIELDC"}*/
-/*"FDIVCAT-" -> "FPC"*/
-
-"FDIV2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FDIV2"]
-/*"FDIV2" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FDIV2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FDIV2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FDIV2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"FDIV2" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"FDIV2" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"FDIV2" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"FDIV2" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-"FDIV2" -> "FFCAT"
-/*"FDIV2" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-
-"FFCAT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FFCAT2"]
-/*"FFCAT2" -> {"UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FFCAT2" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FFCAT2" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FFCAT2" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FFCAT2" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"FFCAT2" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"FFCAT2" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"FFCAT2" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"FFCAT2" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-"FFCAT2" -> "FFCAT"
-/*"FFCAT2" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-
-"FLOATCP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FLOATCP"]
-/*"FLOATCP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"FLOATCP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FLOATCP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FLOATCP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FLOATCP" -> {"ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FLOATCP" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"FLOATCP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"FLOATCP" -> {"REAL"; "CHARZ"; "STEP"}*/
-"FLOATCP" -> "COMPCAT"
-/*"FLOATCP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"FLOATCP" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"}*/
-/*"FLOATCP" -> {"FPC"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"}*/
-/*"FLOATCP" -> {"TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"FLOATCP" -> {"AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"; "POLYCAT"; "FAMR"}*/
-/*"FLOATCP" -> {"AMR"; "BOOLEAN"; "OM"; "INT"; "LIST"; "ILIST"; "QFCAT"}*/
-
-"FORDER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FORDER"]
-/*"FORDER" -> {"FINITE"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"}*/
-/*"FORDER" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FORDER" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"FORDER" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FORDER" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
-/*"FORDER" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"FORDER" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"FORDER" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"}*/
-/*"FORDER" -> {"DIFRING"; "DIFEXT"; "STEP"}*/
-"FORDER" -> "FFCAT"
-/*"FORDER" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FFIELDC"}*/
-/*"FORDER" -> {"FPC"; "SINT"; "NNI"; "INT"}*/
-
-"FORTRAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FORTRAN"]
-/*"FORTRAN" -> {"FORTCAT"; "TYPE"; "KOERCE"; "SINT"; "SYMBOL"; "INT"}*/
-/*"FORTRAN" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "OUTFORM"}*/
-/*"FORTRAN" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"FORTRAN" -> {"LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"FORTRAN" -> {"RCAGG-"; "IXAGG-"; "ORDSET"; "SETCAT"; "BASTYPE"; "KONVERT"}*/
-/*"FORTRAN" -> {"OM"; "PATMAB"; "FMTC"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"FORTRAN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"FORTRAN" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FORTRAN" -> {"MODULE"; "ENTIRER"; "RETRACT"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"FORTRAN" -> {"RCAGG"; "HOAGG"; "AGG"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"FORTRAN" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"FORTRAN" -> {"NNI"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FORTRAN" -> {"UFD"; "DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FORTRAN" -> {"OASGP"; "REAL"; "RADCAT"; "CHARZ"; "INS"; "OINTDOM"}*/
-/*"FORTRAN" -> {"DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-"FORTRAN" -> "COMPCAT"
-/*"FORTRAN" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"FORTRAN" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"; "FPC"}*/
-/*"FORTRAN" -> {"FEVALAB"; "FPATMAB"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
-/*"FORTRAN" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PFECAT"}*/
-
-"FRNAAF2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FRNAAF2"]
-"FRNAAF2" -> "FRNAALG"
-/*"FRNAAF2" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
-/*"FRNAAF2" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FRNAAF2" -> {"MONAD"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"}*/
-/*"FRNAAF2" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "PI"}*/
-/*"FRNAAF2" -> {"NNI"; "INT"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-
-"FSPRMELT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSPRMELT"]
-/*"FSPRMELT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FSPRMELT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FSPRMELT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FSPRMELT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"FSPRMELT" -> "CHARZ"*/
-"FSPRMELT" -> "FS"
-/*"FSPRMELT" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"FSPRMELT" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"FSPRMELT" -> {"FLINEXP"; "LINEXP"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"FSPRMELT" -> {"GCDDOM"; "UFD"; "DIVRING"; "CACHSET"; "POLYCAT"; "FAMR"}*/
-/*"FSPRMELT" -> {"AMR"; "PFECAT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"FSPRMELT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"FSPRMELT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"}*/
-/*"FSPRMELT" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"FSPRMELT" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"FSPRMELT" -> {"FLAGG-"; "LNAGG-"; "NNI"; "ACF"; "RADCAT"; "BOOLEAN"}*/
-/*"FSPRMELT" -> {"UPOLYC"; "DIFRING"; "DIFEXT"; "STEP"; "PI"}*/
-
-"FSRED" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSRED"]
-/*"FSRED" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"FSRED" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FSRED" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FSRED" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
-"FSRED" -> "FS"
-/*"FSRED" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"FSRED" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"FSRED" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"FSRED" -> {"GCDDOM"; "UFD"; "DIVRING"; "CACHSET"; "INS"; "OINTDOM"}*/
-/*"FSRED" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"FSRED" -> {"CFCAT"; "REAL"; "STEP"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"FSRED" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "QFCAT"; "FEVALAB"; "OM"; "INT"}*/
-
-"FSUPFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSUPFACT"]
-/*"FSUPFACT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FSUPFACT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"FSUPFACT" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"FSUPFACT" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
-"FSUPFACT" -> "FS"
-/*"FSUPFACT" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"FSUPFACT" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"FSUPFACT" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"FSUPFACT" -> {"GCDDOM"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"FSUPFACT" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"FSUPFACT" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"FSUPFACT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"FSUPFACT" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-"FSUPFACT" -> "ACF"
-/*"FSUPFACT" -> {"RADCAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"FSUPFACT" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "QFCAT"}*/
-/*"FSUPFACT" -> {"FEVALAB"; "BOOLEAN"; "CACHSET"}*/
-
-"FSPECF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSPECF"]
-/*"FSPECF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"FSPECF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FSPECF" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FSPECF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-"FSPECF" -> "FS"
-/*"FSPECF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"FSPECF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"FSPECF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"FSPECF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "SYMBOL"; "INT"; "REF"}*/
-/*"FSPECF" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"FSPECF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"FSPECF" -> {"LNAGG-"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "SPFCAT"}*/
-/*"FSPECF" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "INS-"}*/
-/*"FSPECF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
-/*"FSPECF" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"FSPECF" -> {"OM"; "ELEMFUN"}*/
-
-"FS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FS2"]
-/*"FS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"FS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FS2" -> "ORDSET"*/
-"FS2" -> "FS"
-/*"FS2" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"FS2" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"FS2" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"}*/
-/*"FS2" -> {"BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FS2" -> {"INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "CACHSET"}*/
-
-"FS2UPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FS2UPS"]
-/*"FS2UPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"FS2UPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"FS2UPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"FS2UPS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"FS2UPS" -> {"RETRACT"; "LINEXP"}*/
-"FS2UPS" -> "ACF"
-/*"FS2UPS" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-/*"FS2UPS" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"FS2UPS" -> "FS"
-/*"FS2UPS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"FS2UPS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"FS2UPS" -> {"CHARZ"; "CHARNZ"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FS2UPS" -> {"OASGP"; "UPSCAT"; "PSCAT"; "AMR"; "ELTAB"; "DIFRING"}*/
-/*"FS2UPS" -> {"PTRANFN"; "NNI"; "INT"; "INS-"; "POLYCAT"; "FAMR"; "PFECAT"}*/
-/*"FS2UPS" -> {"BOOLEAN"; "LIST"; "ILIST"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"FS2UPS" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"FS2UPS" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"}*/
-/*"FS2UPS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"FS2UPS" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"FS2UPS" -> {"URAGG-"; "INS"; "OINTDOM"; "CFCAT"; "REAL"; "STEP"; "PI"}*/
-/*"FS2UPS" -> {"CACHSET"; "STRICAT"; "SRAGG"; "A1AGG"}*/
-
-"GAUSSFAC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GAUSSFAC"]
-/*"GAUSSFAC" -> {"INT"; "INS-"; "EUCDOM-"; "INS"; "UFD"; "GCDDOM"; "INTDOM"}*/
-/*"GAUSSFAC" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"GAUSSFAC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"GAUSSFAC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"GAUSSFAC" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"GAUSSFAC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"}*/
-/*"GAUSSFAC" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"GAUSSFAC" -> {"CHARZ"; "STEP"; "BOOLEAN"; "PI"; "NNI"; "UFD-"; "GCDDOM-"}*/
-/*"GAUSSFAC" -> {"INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"}*/
-/*"GAUSSFAC" -> {"RING-"; "ABELGRP-"; "ABELMON-"; "MONOID-"; "ORDSET-"}*/
-/*"GAUSSFAC" -> {"ABELSG-"; "SGROUP-"; "LIST"; "ILIST"; "OM"; "LSAGG-"}*/
-/*"GAUSSFAC" -> "STAGG-"*/
-"GAUSSFAC" -> "COMPCAT"
-/*"GAUSSFAC" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"GAUSSFAC" -> {"FLINEXP"; "FINITE"; "FIELD"; "DIVRING"; "DIFEXT"}*/
-/*"GAUSSFAC" -> {"PDRING"; "FFIELDC"; "FPC"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"GAUSSFAC" -> {"IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
-/*"GAUSSFAC" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"}*/
-
-"GCNAALG" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GCNAALG"]
-"GCNAALG" -> "FRNAALG"
-/*"GCNAALG" -> {"FINAALG"; "NAALG"; "NARNG"; "ABELGRP"; "CABMON"}*/
-/*"GCNAALG" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GCNAALG" -> {"MONAD"; "MODULE"; "BMODULE"; "LMODULE"; "RMODULE"}*/
-/*"GCNAALG" -> {"COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"; "POLYCAT"}*/
-/*"GCNAALG" -> {"PDRING"; "FAMR"; "AMR"; "ALGEBRA"; "CHARZ"; "CHARNZ"}*/
-/*"GCNAALG" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"GCNAALG" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"GCNAALG" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "QFCAT"; "FIELD"}*/
-/*"GCNAALG" -> {"EUCDOM"; "PID"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
-/*"GCNAALG" -> {"DIFRING"; "PATAB"; "FPATMAB"; "TYPE"; "STEP"; "OINTDOM"}*/
-/*"GCNAALG" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"GCNAALG" -> {"SMATCAT"; "RMATCAT"; "HOAGG"; "AGG"; "SINT"; "PI"; "NNI"}*/
-/*"GCNAALG" -> {"INT"; "STRING"; "CHAR"; "OUTFORM"; "LIST"; "PRIMARR"}*/
-/*"GCNAALG" -> {"A1AGG-"; "ISTRING"; "SYMBOL"; "REF"; "ALIST"; "SRAGG-"}*/
-/*"GCNAALG" -> {"FLAGG-"; "LNAGG-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"GCNAALG" -> {"VECTCAT-"; "IXAGG-"; "INS"; "CFCAT"; "OM"; "ILIST"}*/
-/*"GCNAALG" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"GCNAALG" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"GCNAALG" -> "BOOLEAN"*/
-
-"GDRAW" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GDRAW"]
-"GDRAW" -> "FS"
-/*"GDRAW" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"GDRAW" -> {"A1AGG-"; "ISTRING"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"GDRAW" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"GDRAW" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GDRAW" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"GDRAW" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"GDRAW" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"GDRAW" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "ES"}*/
-/*"GDRAW" -> {"IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "FRETRCT"}*/
-/*"GDRAW" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARNZ"; "PI"; "NNI"}*/
-/*"GDRAW" -> {"DIFRING"; "OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"GDRAW" -> {"AHYP"; "ELEMFUN"; "DFLOAT"}*/
-
-"GENUFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENUFACT"]
-/*"GENUFACT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"GENUFACT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"GENUFACT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"GENUFACT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"GENUFACT" -> {"INS"; "UFD"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"GENUFACT" -> {"OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"GENUFACT" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"GENUFACT" -> {"STEP"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"GENUFACT" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"GENUFACT" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"}*/
-/*"GENUFACT" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"GENUFACT" -> {"FFIELDC"; "FPC"; "FINITE"}*/
-"GENUFACT" -> "COMPCAT"
-/*"GENUFACT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "TRANFUN"; "TRIGCAT"}*/
-/*"GENUFACT" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "ES"}*/
-"GENUFACT" -> "ACF"
-/*"GENUFACT" -> "OM"*/
-
-"GENUPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GENUPS"]
-/*"GENUPS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"GENUPS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GENUPS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"GENUPS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"}*/
-"GENUPS" -> "ACF"
-/*"GENUPS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"GENUPS" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"GENUPS" -> {"AHYP"; "ELEMFUN"}*/
-"GENUPS" -> "FS"
-/*"GENUPS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"GENUPS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"GENUPS" -> {"CHARZ"; "CHARNZ"; "INT"; "NNI"; "INS"; "OINTDOM"}*/
-/*"GENUPS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"GENUPS" -> {"CFCAT"; "REAL"; "STEP"; "OM"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"GENUPS" -> "GCDDOM-"*/
-
-"GTSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GTSET"]
-/*"GTSET" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"GTSET" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"GTSET" -> {"KONVERT"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"GTSET" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"GTSET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
-/*"GTSET" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-"GTSET" -> "RPOLCAT"
-/*"GTSET" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"GTSET" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-/*"GTSET" -> {"GCDDOM"; "PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"GTSET" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"GTSET" -> {"IXAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"GTSET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"GTSET" -> {"BOOLEAN"; "FINITE"}*/
-
-"GPOLSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GPOLSET"]
-/*"GPOLSET" -> {"PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"}*/
-/*"GPOLSET" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "KONVERT"}*/
-/*"GPOLSET" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"GPOLSET" -> {"SGROUP"; "MONOID"; "LMODULE"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"GPOLSET" -> {"OASGP"; "ORDSET"}*/
-"GPOLSET" -> "RPOLCAT"
-/*"GPOLSET" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"GPOLSET" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"GPOLSET" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"GPOLSET" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "LSAGG"; "STAGG"}*/
-/*"GPOLSET" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"GPOLSET" -> {"FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"GPOLSET" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"GPOLSET" -> "IXAGG-"*/
-
-"IAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=IAN"]
-/*"IAN" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"IAN" -> {"IEVALAB"; "EVALAB"}*/
-"IAN" -> "ACF"
-/*"IAN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"IAN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"IAN" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"IAN" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "LINEXP"}*/
-/*"IAN" -> {"REAL"; "KONVERT"; "CHARZ"; "DIFRING"; "INS"; "OINTDOM"}*/
-/*"IAN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "PATMAB"}*/
-/*"IAN" -> {"CFCAT"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
-/*"IAN" -> {"PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"; "CHARNZ"}*/
-/*"IAN" -> {"PFECAT"; "FPS"; "RNS"}*/
-"IAN" -> "FS"
-/*"IAN" -> {"FRETRCT"; "GROUP"; "OM"; "BOOLEAN"; "CACHSET"; "POLYCAT"}*/
-/*"IAN" -> {"FAMR"; "AMR"; "INT"; "LIST"; "ILIST"; "NNI"; "UPOLYC"}*/
-"IAN" -> "COMPCAT"
-/*"IAN" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"IAN" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-
-"INEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INEP"]
-/*"INEP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INEP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INEP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INEP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"INEP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"INEP" -> {"ORDSET"; "INS"; "OINTDOM"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"INEP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
-/*"INEP" -> {"FPS"; "RNS"; "RADCAT"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"INEP" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"INEP" -> {"TYPE"; "CHARNZ"; "PFECAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"INEP" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"INEP" -> {"AMR"; "FRETRCT"; "NNI"; "INT"; "SINT"; "VECTOR"; "IVECTOR"}*/
-/*"INEP" -> {"IARRAY1"; "LIST"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-"INEP" -> "COMPCAT"
-/*"INEP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
-/*"INEP" -> {"FPC"; "PI"}*/
-
-"INFPROD0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFPROD0"]
-/*"INFPROD0" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"INFPROD0" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INFPROD0" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INFPROD0" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
-"INFPROD0" -> "UTSCAT"
-/*"INFPROD0" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARNZ"; "ELTAB"; "DIFRING"}*/
-/*"INFPROD0" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"INFPROD0" -> {"HYPCAT"; "AHYP"; "ELEMFUN"}*/
-
-"INFSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INFSP"]
-/*"INFSP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INFSP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INFSP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"INFSP" -> {"MODULE"; "ENTIRER"; "FIELD"; "EUCDOM"; "PID"; "UFD"}*/
-/*"INFSP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"INFSP" -> {"ORDSET"; "INS"; "OINTDOM"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"INFSP" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FPS"}*/
-/*"INFSP" -> {"RNS"; "RADCAT"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"INFSP" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"INFSP" -> {"TYPE"; "CHARNZ"; "PFECAT"; "OM"; "NNI"; "INT"; "POLYCAT"}*/
-/*"INFSP" -> {"FAMR"; "AMR"; "FRETRCT"}*/
-"INFSP" -> "COMPCAT"
-/*"INFSP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"INFSP" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"INFSP" -> {"UPOLYC"; "LIST"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"INFSP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"INFSP" -> {"FLAGG"; "ELAGG"; "LSAGG-"; "STAGG-"; "PRIMARR"; "PI"}*/
-/*"INFSP" -> {"DIRPCAT"; "OAMONS"; "VSPACE"; "ORDFIN"; "BOOLEAN"; "ELAGG-"}*/
-/*"INFSP" -> "FLAGG-"*/
-
-"INPRODFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INPRODFF"]
-/*"INPRODFF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INPRODFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INPRODFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INPRODFF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INPRODFF" -> {"ENTIRER"; "UFD"; "DIVRING"; "FINITE"; "KONVERT"; "UPOLYC"}*/
-/*"INPRODFF" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"INPRODFF" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"INPRODFF" -> {"LINEXP"; "ORDSET"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"INPRODFF" -> {"DIFEXT"; "STEP"; "MONOGEN"; "FRAMALG"; "FINRALG"}*/
-/*"INPRODFF" -> {"FFIELDC"; "FPC"}*/
-"INPRODFF" -> "UTSCAT"
-/*"INPRODFF" -> {"UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"INPRODFF" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"INPRODFF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"INPRODFF" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "BOOLEAN"}*/
-
-"INPRODPF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INPRODPF"]
-/*"INPRODPF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INPRODPF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INPRODPF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INPRODPF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INPRODPF" -> {"ENTIRER"; "UFD"; "DIVRING"; "FINITE"; "KONVERT"}*/
-"INPRODPF" -> "UTSCAT"
-/*"INPRODPF" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
-/*"INPRODPF" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"INPRODPF" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INS"; "OINTDOM"}*/
-/*"INPRODPF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"INPRODPF" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-
-"INTAF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTAF"]
-/*"INTAF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
-/*"INTAF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INTAF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INTAF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"}*/
-"INTAF" -> "ACF"
-/*"INTAF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"}*/
-"INTAF" -> "FS"
-/*"INTAF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"INTAF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"INTAF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "CACHSET"; "UPOLYC"}*/
-/*"INTAF" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"INTAF" -> {"DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "OINTDOM"; "ORDRING"}*/
-/*"INTAF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "NNI"; "INT"}*/
-/*"INTAF" -> {"SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"INTAF" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"INTAF" -> {"FLAGG-"; "LNAGG-"}*/
-
-"INTALG" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTALG"]
-/*"INTALG" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"INTALG" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"INTALG" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"INTALG" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
-"INTALG" -> "ACF"
-/*"INTALG" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"INTALG" -> "RADCAT"*/
-"INTALG" -> "FS"
-/*"INTALG" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"INTALG" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"INTALG" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"INTALG" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-"INTALG" -> "FFCAT"
-/*"INTALG" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"INTALG" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"INTALG" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"INTALG" -> {"FLAGG-"; "LNAGG-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"INTALG" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "VECTOR"}*/
-/*"INTALG" -> {"IVECTOR"; "IARRAY1"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"INTALG" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "ILIST"}*/
-/*"INTALG" -> {"QFCAT"; "FEVALAB"; "LSAGG-"; "STAGG-"; "ELAGG-"; "NNI"}*/
-/*"INTALG" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "ELAGG"; "INS-"}*/
-/*"INTALG" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "BOOLEAN"; "PI"; "CACHSET"}*/
-
-"INTEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTEF"]
-/*"INTEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INTEF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INTEF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "CHARZ"}*/
-/*"INTEF" -> {"RETRACT"; "LINEXP"}*/
-"INTEF" -> "ACF"
-/*"INTEF" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-/*"INTEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"INTEF" -> "FS"
-/*"INTEF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"INTEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"INTEF" -> {"CHARNZ"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"INTEF" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"INTEF" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "ILIST"; "UPOLYC"}*/
-/*"INTEF" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"INTEF" -> {"DIFEXT"; "STEP"; "CACHSET"; "QFCAT"; "FEVALAB"; "OINTDOM"}*/
-/*"INTEF" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"INTEF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"INTEF" -> {"LFCAT"; "PRIMCAT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"INTEF" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"INTEF" -> {"FLAGG"; "ELAGG"; "OM"}*/
-
-"INTG0" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTG0"]
-/*"INTG0" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTG0" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"INTG0" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"INTG0" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
-/*"INTG0" -> {"ORDSET"; "CHARZ"; "LINEXP"}*/
-"INTG0" -> "FS"
-/*"INTG0" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"INTG0" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"INTG0" -> {"CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
-"INTG0" -> "ACF"
-/*"INTG0" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"INTG0" -> {"ELEMFUN"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"INTG0" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"INTG0" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "CACHSET"; "ILIST"; "UPOLYC"}*/
-/*"INTG0" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"INTG0" -> {"DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "OINTDOM"; "ORDRING"}*/
-/*"INTG0" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "NNI"}*/
-/*"INTG0" -> {"LODOCAT"; "OREPCAT"}*/
-
-"INTHERAL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTHERAL"]
-/*"INTHERAL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"INTHERAL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"INTHERAL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"INTHERAL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INTHERAL" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"INTHERAL" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"INTHERAL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"INTHERAL" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"INTHERAL" -> {"DIFEXT"; "STEP"}*/
-"INTHERAL" -> "FFCAT"
-/*"INTHERAL" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
-/*"INTHERAL" -> {"FPC"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"INTHERAL" -> {"PI"; "NNI"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"INTHERAL" -> {"OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"}*/
-/*"INTHERAL" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"}*/
-/*"INTHERAL" -> {"AGG"; "TYPE"; "ELTAGG"; "CLAGG"; "QFCAT"; "FEVALAB"}*/
-/*"INTHERAL" -> {"PATAB"; "FPATMAB"}*/
-
-"INTPAF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTPAF"]
-/*"INTPAF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTPAF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INTPAF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INTPAF" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "ORDSET"}*/
-/*"INTPAF" -> {"CHARZ"; "LINEXP"}*/
-"INTPAF" -> "FS"
-/*"INTPAF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"INTPAF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"INTPAF" -> {"CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
-"INTPAF" -> "ACF"
-/*"INTPAF" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"INTPAF" -> {"ELEMFUN"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"INTPAF" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"INTPAF" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"INTPAF" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"INTPAF" -> {"QFCAT"; "FEVALAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"INTPAF" -> {"OAMON"; "OASGP"; "REAL"; "OM"; "BOOLEAN"; "NNI"; "CACHSET"}*/
-/*"INTPAF" -> {"PI"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"INTPAF" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"INTPAF" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "LODOCAT"; "OREPCAT"}*/
-
-"INTPM" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTPM"]
-/*"INTPM" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"INTPM" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INTPM" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INTPM" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LINEXP"}*/
-"INTPM" -> "ACF"
-/*"INTPM" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-/*"INTPM" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"INTPM" -> "FS"
-/*"INTPM" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"INTPM" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"INTPM" -> {"CHARZ"; "CHARNZ"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"}*/
-/*"INTPM" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"INTPM" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "OINTDOM"}*/
-/*"INTPM" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"INTPM" -> {"CFCAT"; "REAL"; "STEP"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"INTPM" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"INTPM" -> {"FLAGG"; "ELAGG"; "OM"; "ILIST"; "PI"; "NNI"; "LFCAT"}*/
-/*"INTPM" -> {"PRIMCAT"; "CACHSET"; "BOOLEAN"; "LSAGG-"; "POLYCAT"; "FAMR"}*/
-/*"INTPM" -> {"AMR"; "PFECAT"; "UPOLYC"; "DIFEXT"; "STAGG-"; "ELAGG-"}*/
-/*"INTPM" -> {"URAGG-"; "SPFCAT"}*/
-
-"INTTOOLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTTOOLS"]
-/*"INTTOOLS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"INTTOOLS" -> "FS"
-/*"INTTOOLS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"INTTOOLS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
-/*"INTTOOLS" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"}*/
-/*"INTTOOLS" -> {"RING"; "RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"INTTOOLS" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
-/*"INTTOOLS" -> {"RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"INTTOOLS" -> {"COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "CACHSET"; "INT"}*/
-/*"INTTOOLS" -> {"LIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"INTTOOLS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"INTTOOLS" -> {"ELAGG"; "OM"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"INTTOOLS" -> {"NNI"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"INTTOOLS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"INTTOOLS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ELEMFUN"; "POLYCAT"}*/
-/*"INTTOOLS" -> {"FAMR"; "AMR"; "PFECAT"; "UPOLYC"; "DIFRING"; "DIFEXT"}*/
-/*"INTTOOLS" -> {"STEP"; "LFCAT"; "PRIMCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"INTTOOLS" -> {"ATRIG"; "HYPCAT"; "AHYP"}*/
-
-"ITRIGMNP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ITRIGMNP"]
-/*"ITRIGMNP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"ITRIGMNP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"ITRIGMNP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"ITRIGMNP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-"ITRIGMNP" -> "FS"
-/*"ITRIGMNP" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"ITRIGMNP" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"ITRIGMNP" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"ITRIGMNP" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
-/*"ITRIGMNP" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "BOOLEAN"}*/
-"ITRIGMNP" -> "COMPCAT"
-/*"ITRIGMNP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"}*/
-/*"ITRIGMNP" -> {"DIFRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
-/*"ITRIGMNP" -> {"PFECAT"; "OM"; "CACHSET"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"ITRIGMNP" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"ITRIGMNP" -> {"CLAGG"; "FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"}*/
-/*"ITRIGMNP" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"ITRIGMNP" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"ITRIGMNP" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"ITRIGMNP" -> {"URAGG-"; "POLYCAT"; "FAMR"; "AMR"}*/
-
-"JORDAN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=JORDAN"]
-/*"JORDAN" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"JORDAN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"; "MODULE"}*/
-/*"JORDAN" -> {"BMODULE"; "LMODULE"; "RMODULE"}*/
-"JORDAN" -> "FRNAALG"
-/*"JORDAN" -> {"FINAALG"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"JORDAN" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"}*/
-/*"JORDAN" -> {"ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"JORDAN" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"JORDAN" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"JORDAN" -> {"PATMAB"; "PFECAT"}*/
-
-"KOVACIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=KOVACIC"]
-/*"KOVACIC" -> {"CHARZ"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"KOVACIC" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"KOVACIC" -> {"MONOID"; "LMODULE"}*/
-"KOVACIC" -> "ACF"
-/*"KOVACIC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"KOVACIC" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"KOVACIC" -> {"UFD"; "DIVRING"; "RADCAT"; "RETRACT"; "UPOLYC"}*/
-/*"KOVACIC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"KOVACIC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"KOVACIC" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"KOVACIC" -> {"DIFEXT"; "STEP"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"}*/
-/*"KOVACIC" -> {"TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"KOVACIC" -> {"OASGP"; "REAL"; "PI"; "NNI"; "INT"; "LIST"; "ILIST"}*/
-/*"KOVACIC" -> "BOOLEAN"*/
-
-"LF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LF"]
-/*"LF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
-/*"LF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LF" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"LF" -> {"MODULE"; "ENTIRER"}*/
-"LF" -> "FS"
-/*"LF" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"LF" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"LF" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"LF" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
-/*"LF" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SYMBOL"}*/
-/*"LF" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"LF" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"LF" -> {"LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"LF" -> {"PI"; "NNI"; "BOOLEAN"}*/
-
-"LIE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LIE"]
-/*"LIE" -> {"NAALG"; "NARNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LIE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "MONAD"; "MODULE"; "BMODULE"}*/
-/*"LIE" -> {"LMODULE"; "RMODULE"}*/
-"LIE" -> "FRNAALG"
-/*"LIE" -> {"FINAALG"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"LIE" -> {"PI"; "NNI"; "INT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"LIE" -> {"INTDOM"; "ALGEBRA"; "ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"}*/
-/*"LIE" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"LIE" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"LIE" -> {"ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-
-"LODOF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LODOF"]
-/*"LODOF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"LODOF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"LODOF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"LODOF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"LODOF" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
-/*"LODOF" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"LODOF" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"LODOF" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
-/*"LODOF" -> {"STEP"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"LODOF" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"LODOF" -> {"OASGP"; "REAL"; "BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"LODOF" -> {"STAGG-"; "SINT"; "NNI"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"LODOF" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"LODOF" -> {"FLAGG"; "ELAGG"; "PI"; "ELAGG-"; "MONOID-"; "ABELMON-"}*/
-"LODOF" -> "ACF"
-/*"LODOF" -> {"RADCAT"; "ES"}*/
-
-"LSQM" [color="#88FF44",href="bookvol10.3.pdf#nameddest=LSQM"]
-/*"LSQM" -> {"SMATCAT"; "DIFEXT"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"LSQM" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"LSQM" -> {"MONOID"; "LMODULE"; "DIFRING"; "PDRING"; "BMODULE"; "RMODULE"}*/
-/*"LSQM" -> {"RMATCAT"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"LSQM" -> {"MODULE"; "COMRING"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"LSQM" -> "ALGEBRA"*/
-"LSQM" -> "FRNAALG"
-/*"LSQM" -> {"FINAALG"; "NAALG"; "NARNG"; "MONAD"; "INTDOM"; "ENTIRER"}*/
-/*"LSQM" -> {"PI"; "NNI"; "INT"; "SINT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"LSQM" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"LSQM" -> {"ELTAB"; "CLAGG"; "KONVERT"; "ORDSET"; "VECTCAT-"; "A1AGG-"}*/
-/*"LSQM" -> {"FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"}*/
-/*"LSQM" -> {"AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "EUCDOM"; "PID"}*/
-/*"LSQM" -> {"GCDDOM"; "FIELD"; "UFD"; "DIVRING"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"LSQM" -> {"CHARZ"; "CHARNZ"; "PATMAB"; "PFECAT"; "INS"; "OINTDOM"}*/
-/*"LSQM" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"}*/
-/*"LSQM" -> {"REAL"; "STEP"}*/
-
-"OMEXPR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OMEXPR"]
-/*"OMEXPR" -> {"OM"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RING"}*/
-/*"OMEXPR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"OMEXPR" -> {"MONOID"; "LMODULE"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"OMEXPR" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"OMEXPR" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"OMEXPR" -> {"FLAGG"; "ELAGG"; "INT"; "LIST"; "ILIST"; "NNI"; "LSAGG-"}*/
-/*"OMEXPR" -> {"STAGG-"; "PI"; "SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"}*/
-/*"OMEXPR" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"OMEXPR" -> {"FLAGG-"; "LNAGG-"}*/
-"OMEXPR" -> "FS"
-/*"OMEXPR" -> {"ES"; "RETRACT"; "PATAB"; "FPATMAB"; "PATMAB"; "FRETRCT"}*/
-/*"OMEXPR" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
-/*"OMEXPR" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
-/*"OMEXPR" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
-/*"OMEXPR" -> "DIVRING"*/
-
-"MCMPLX" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MCMPLX"]
-/*"MCMPLX" -> {"FMTC"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MCMPLX" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MCMPLX" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"MCMPLX" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"}*/
-"MCMPLX" -> "COMPCAT"
-/*"MCMPLX" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARZ"; "CHARNZ"}*/
-/*"MCMPLX" -> {"KONVERT"; "FRETRCT"; "FLINEXP"; "LINEXP"; "FINITE"}*/
-/*"MCMPLX" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"MCMPLX" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"}*/
-/*"MCMPLX" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"}*/
-/*"MCMPLX" -> {"PATMAB"; "PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"MCMPLX" -> {"AHYP"; "ELEMFUN"; "RADCAT"; "PFECAT"; "FPS"; "RNS"}*/
-/*"MCMPLX" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"MCMPLX" -> {"INS"; "OINTDOM"; "CFCAT"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"MCMPLX" -> {"AMR"; "OAMONS"}*/
-
-"MULTFACT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=MULTFACT"]
-/*"MULTFACT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "OAMONS"; "OCAMON"}*/
-/*"MULTFACT" -> {"OAMON"; "OASGP"; "ABELMON"; "ABELSG"; "CABMON"; "EUCDOM"}*/
-/*"MULTFACT" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"MULTFACT" -> {"ABELGRP"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"MULTFACT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
-/*"MULTFACT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"MULTFACT" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"MULTFACT" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "INS"; "OINTDOM"}*/
-/*"MULTFACT" -> {"ORDRING"; "OAGROUP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
-"MULTFACT" -> "COMPCAT"
-/*"MULTFACT" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FIELD"}*/
-/*"MULTFACT" -> {"DIVRING"; "DIFEXT"; "FFIELDC"; "FPC"; "FEVALAB"; "ELTAB"}*/
-/*"MULTFACT" -> {"FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"MULTFACT" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "RADCAT"; "UPOLYC"}*/
-
-/* MYEXPR and MYUP are mutually dependent */
-/* We remove them and create a new node */
-"MYEXPR/MYUP" [color="blue",href="bookvol10.3.pdf#nameddest=MYEXPR"]
-"MYEXPR/MYUP" -> "FS"
-
-/*"MYEXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MYEXPR"]*/
-/*"MYEXPR" -> "MYUP"*/ /* clique1.spad */
-/*"MYEXPR" -> {"FS"; "ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MYEXPR" -> {"RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"MYEXPR" -> {"TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"}*/
-/*"MYEXPR" -> {"ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"}*/
-/*"MYEXPR" -> {"LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
-/*"MYEXPR" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
-/*"MYEXPR" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
-/*"MYEXPR" -> {"DIVRING"; "COMBOPC"; "CFCAT"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"MYEXPR" -> {"PFECAT"; "UPOLYC"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"MYEXPR" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"MYEXPR" -> {"OASGP"; "REAL"; "FPS"; "RNS"; "RADCAT"; "QFCAT"}*/
-/*"MYEXPR" -> {"FEVALAB"; "CACHSET"}*/
-
-/*"MYUP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=MYUP"]*/
-/*"MYUP" -> "MYEXPR"*/ /* clique1.spad */
-/*"MYUP" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"MYUP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"MYUP" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"MYUP" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"MYUP" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"MYUP" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-/*"MYUP" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"MYUP" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"; "NNI"; "INT"; "FPS"}*/
-/*"MYUP" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"MYUP" -> {"REAL"; "RADCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
-
-"NAGF01" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF01"]
-/*"NAGF01" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"NAGF01" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"NAGF01" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"}*/
-/*"NAGF01" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"NAGF01" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"NAGF01" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"NAGF01" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"NAGF01" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"NAGF01" -> {"REAL"; "KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-/*"NAGF01" -> {"INS"; "OINTDOM"; "DIFRING"; "LINEXP"; "CFCAT"; "STEP"}*/
-"NAGF01" -> "COMPCAT"
-/*"NAGF01" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"NAGF01" -> {"FLINEXP"; "FINITE"; "DIFEXT"; "PDRING"; "FFIELDC"; "FPC"}*/
-/*"NAGF01" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"}*/
-/*"NAGF01" -> {"PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"NAGF01" -> {"ELEMFUN"; "PFECAT"}*/
-
-"NAGF02" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF02"]
-/*"NAGF02" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"NAGF02" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"NAGF02" -> {"FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"NAGF02" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NAGF02" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"NAGF02" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"NAGF02" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"NAGF02" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"NAGF02" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "INS-"}*/
-/*"NAGF02" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"NAGF02" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"NAGF02" -> {"ABELMON-"; "MONOID-"; "ORDSET-"; "ABELSG-"; "SGROUP-"}*/
-/*"NAGF02" -> {"DFLOAT"; "PI"; "NNI"}*/
-"NAGF02" -> "COMPCAT"
-/*"NAGF02" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"NAGF02" -> {"FLINEXP"; "LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"}*/
-/*"NAGF02" -> {"PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"}*/
-/*"NAGF02" -> {"ELTAB"; "EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"}*/
-/*"NAGF02" -> {"PATAB"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"NAGF02" -> {"AHYP"; "ELEMFUN"; "PFECAT"}*/
-
-"NAGF04" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NAGF04"]
-/*"NAGF04" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"NAGF04" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"NAGF04" -> {"FLAGG-"; "LNAGG-"; "FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"NAGF04" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NAGF04" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"NAGF04" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"NAGF04" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"}*/
-/*"NAGF04" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"}*/
-/*"NAGF04" -> {"KONVERT"; "RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"}*/
-"NAGF04" -> "COMPCAT"
-/*"NAGF04" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "CHARNZ"; "FRETRCT"}*/
-/*"NAGF04" -> {"FLINEXP"; "LINEXP"; "FINITE"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"NAGF04" -> {"FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"NAGF04" -> {"IEVALAB"; "FPATMAB"; "TYPE"; "PATAB"; "TRANFUN"; "TRIGCAT"}*/
-/*"NAGF04" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PFECAT"; "INS"}*/
-/*"NAGF04" -> {"OINTDOM"; "CFCAT"; "DFLOAT"}*/
-
-"NCEP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NCEP"]
-/*"NCEP" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"NCEP" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"NCEP" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"NCEP" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"NCEP" -> {"DIVRING"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"NCEP" -> {"ORDSET"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"NCEP" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"NCEP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "INS"; "OINTDOM"; "DIFRING"}*/
-/*"NCEP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"NCEP" -> {"CHARZ"; "STEP"; "QFCAT"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"NCEP" -> {"IEVALAB"; "DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"NCEP" -> {"TYPE"; "CHARNZ"; "PFECAT"}*/
-"NCEP" -> "COMPCAT"
-/*"NCEP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FRETRCT"; "FINITE"; "FFIELDC"}*/
-/*"NCEP" -> {"FPC"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"NCEP" -> {"ELEMFUN"; "RADCAT"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
-
-"NLINSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NLINSOL"]
-/*"NLINSOL" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"NLINSOL" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"NLINSOL" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"NLINSOL" -> {"MODULE"; "ENTIRER"; "ORDSET"; "KONVERT"; "OM"; "PATMAB"}*/
-/*"NLINSOL" -> {"INT"; "LIST"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"NLINSOL" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"NLINSOL" -> {"FLINEXP"; "LINEXP"; "GCDDOM"; "PFECAT"; "UFD"}*/
-"NLINSOL" -> "ACF"
-/*"NLINSOL" -> {"FIELD"; "EUCDOM"; "PID"; "DIVRING"; "RADCAT"; "ILIST"}*/
-/*"NLINSOL" -> {"LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"NLINSOL" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"NLINSOL" -> {"CLAGG"; "FLAGG"; "ELAGG"; "NNI"; "INS"; "OINTDOM"}*/
-/*"NLINSOL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"NLINSOL" -> {"CFCAT"; "REAL"; "STEP"; "QFCAT"; "FEVALAB"; "DIFEXT"}*/
-/*"NLINSOL" -> {"PATAB"; "FPATMAB"}*/
-
-"NSMP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NSMP"]
-"NSMP" -> "RPOLCAT"
-/*"NSMP" -> {"POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"NSMP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"NSMP" -> {"MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"NSMP" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"NSMP" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"NSMP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
-/*"NSMP" -> {"UFD"; "NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"NSMP" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"NSMP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"NSMP" -> {"BASTYPE-"; "BOOLEAN"; "MONOID-"; "ABELMON-"; "PI"; "EUCDOM"}*/
-/*"NSMP" -> {"PID"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"NSMP" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"}*/
-/*"NSMP" -> {"FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"; "PATAB"}*/
-/*"NSMP" -> {"FPATMAB"; "TYPE"; "FPS"; "RNS"; "RADCAT"; "UPOLYC"}*/
-
-"NUMERIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NUMERIC"]
-/*"NUMERIC" -> {"KONVERT"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"NUMERIC" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"NUMERIC" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-"NUMERIC" -> "COMPCAT"
-/*"NUMERIC" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "MODULE"}*/
-/*"NUMERIC" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"}*/
-/*"NUMERIC" -> {"LINEXP"; "FINITE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"NUMERIC" -> {"INTDOM"; "ENTIRER"; "UFD"; "DIVRING"; "DIFEXT"; "DIFRING"}*/
-/*"NUMERIC" -> {"PDRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
-/*"NUMERIC" -> {"EVALAB"; "IEVALAB"; "FPATMAB"; "TYPE"; "PATMAB"; "PATAB"}*/
-/*"NUMERIC" -> {"ORDSET"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"NUMERIC" -> {"ELEMFUN"; "RADCAT"; "PFECAT"; "FPS"; "RNS"; "ORDRING"}*/
-/*"NUMERIC" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "OM"}*/
-/*"NUMERIC" -> {"POLYCAT"; "FAMR"; "AMR"}*/
-
-"OCT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=OCT"]
-"OCT" -> "OC"
-/*"OCT" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"OCT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"OCT" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
-/*"OCT" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FINITE"; "ORDSET"}*/
-/*"OCT" -> {"KONVERT"; "CHARZ"; "CHARNZ"; "COMRING"}*/
-"OCT" -> "QUATCAT"
-/*"OCT" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "ENTIRER"}*/
-/*"OCT" -> {"DIVRING"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"OCT" -> {"UFD"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"OCT" -> {"OASGP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "RNS"; "RADCAT"}*/
-
-"OCTCT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=OCTCT2"]
-"OCTCT2" -> "OC"
-/*"OCTCT2" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"OCTCT2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"OCTCT2" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FRETRCT"}*/
-/*"OCTCT2" -> {"RETRACT"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FINITE"}*/
-/*"OCTCT2" -> {"ORDSET"; "KONVERT"; "CHARZ"; "CHARNZ"; "COMRING"}*/
-
-"ODEPAL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEPAL"]
-/*"ODEPAL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODEPAL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODEPAL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ODEPAL" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ODEPAL" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
-/*"ODEPAL" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"ODEPAL" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"ODEPAL" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-"ODEPAL" -> "FFCAT"
-/*"ODEPAL" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"ODEPAL" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
-/*"ODEPAL" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"ODEPAL" -> {"LODOCAT"; "OREPCAT"}*/
-
-"ODERTRIC" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODERTRIC"]
-/*"ODERTRIC" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"ODERTRIC" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ODERTRIC" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"ODERTRIC" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ODERTRIC" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"; "UPOLYC"}*/
-/*"ODERTRIC" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"; "FRETRCT"}*/
-/*"ODERTRIC" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"ODERTRIC" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"ODERTRIC" -> {"DIFEXT"; "STEP"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
-/*"ODERTRIC" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"ODERTRIC" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"ODERTRIC" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
-/*"ODERTRIC" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"ODERTRIC" -> {"ILIST"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ODERTRIC" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"ODERTRIC" -> {"FLAGG"; "ELAGG"; "OM"; "BOOLEAN"}*/
-"ODERTRIC" -> "UTSCAT"
-/*"ODERTRIC" -> {"UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"ODERTRIC" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"ODERTRIC" -> "ACF"
-/*"ODERTRIC" -> {"LSAGG-"; "STAGG-"}*/
-
-"PACEXTC" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PACEXTC"]
-"PACEXTC" -> "PACRAT"
-/*"PACEXTC" -> {"PACRATC"; "PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PACEXTC" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PACEXTC" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"PACEXTC" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PACEXTC" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"PACEXTC" -> {"DIVRING"; "CHARZ"; "RETRACT"; "XF"; "VSPACE";}*/
-/*"PACEXTC" -> {"FPC"; "CHARNZ"; "FINITE"}*/
-
-"PADE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PADE"]
-/*"PADE" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PADE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PADE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PADE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"PADE" -> "DIVRING"*/
-"PADE" -> "UTSCAT"
-/*"PADE" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
-/*"PADE" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"PADE" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "UPOLYC"; "POLYCAT"}*/
-/*"PADE" -> {"FAMR"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"PADE" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"; "DIFEXT"}*/
-/*"PADE" -> {"STEP"; "NNI"; "INT"; "SINT"; "LIST"; "ILIST"; "PI"}*/
-
-"PAN2EXPR" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PAN2EXPR"]
-/*"PAN2EXPR" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PAN2EXPR" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"PAN2EXPR" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PAN2EXPR" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"PAN2EXPR" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PAN2EXPR" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"PAN2EXPR" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-/*"PAN2EXPR" -> {"STEP"; "ES"; "IEVALAB"; "EVALAB"}*/
-"PAN2EXPR" -> "ACF"
-/*"PAN2EXPR" -> {"FIELD"; "DIVRING"; "RADCAT"}*/
-"PAN2EXPR" -> "FS"
-/*"PAN2EXPR" -> {"PATAB"; "FPATMAB"; "TYPE"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"PAN2EXPR" -> {"FLINEXP"; "CHARNZ"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"PAN2EXPR" -> {"PFECAT"; "OM"}*/
-
-"PFO" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFO"]
-/*"PFO" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"}*/
-/*"PFO" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PFO" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PFO" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"}*/
-"PFO" -> "FS"
-/*"PFO" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"PFO" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"PFO" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"PFO" -> {"GCDDOM"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"PFO" -> {"AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-"PFO" -> "FFCAT"
-/*"PFO" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"PFO" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PFO" -> {"OASGP"; "CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "CACHSET"}*/
-/*"PFO" -> {"INT"; "LIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"PFO" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"PFO" -> {"OM"; "ILIST"; "NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"}*/
-/*"PFO" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG-"; "PI"; "INTDOM-"}*/
-/*"PFO" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"PFO" -> {"ABELGRP-"; "ABELMON-"; "VECTCAT"; "A1AGG"; "BOOLEAN"}*/
-
-"PFOQ" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PFOQ"]
-/*"PFOQ" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PFOQ" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PFOQ" -> {"SGROUP"; "MONOID"; "LMODULE"; "FAMR"; "AMR"; "BMODULE"}*/
-/*"PFOQ" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"PFOQ" -> {"INTDOM"; "ENTIRER"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PFOQ" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"}*/
-/*"PFOQ" -> {"PFECAT"; "UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"PFOQ" -> {"EUCDOM"; "PID"; "FIELD"; "DIVRING"}*/
-"PFOQ" -> "FFCAT"
-/*"PFOQ" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"PFOQ" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PFOQ" -> {"OASGP"; "CFCAT"; "REAL"; "QFCAT"; "FEVALAB"; "PATAB"}*/
-/*"PFOQ" -> {"FPATMAB"; "TYPE"; "OM"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"PFOQ" -> {"NNI"; "INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "PI"; "INTDOM-"}*/
-/*"PFOQ" -> {"ALGEBRA-"; "DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"}*/
-/*"PFOQ" -> {"ABELGRP-"; "ABELMON-"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"PFOQ" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
-
-"PLACES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLACES"]
-/*"PLACES" -> {"PLACESC"; "SETCATD"; "LOCPOWC"; "DIV"}*/
-"PLACES" -> "NSDPS"
-"PLACES" -> "PLCS"
-/*"PLACES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"}*/
-/*"PLACES" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PLACES" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PLACES" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"PLACES" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-
-"PLACESPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PLACESPS"]
-/*"PLACESPS" -> {"PLCS"; "PLACESC"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"PLACESPS" -> "PACOFF"
-/*"PLACESPS" -> {"PACFFC"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"PLACESPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"PLACESPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"PLACESPS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PLACESPS" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
-/*"PLACESPS" -> {"DIFRING"; "PACPERC"}*/
-
-"PICOERCE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PICOERCE"]
-/*"PICOERCE" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"PICOERCE" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"PICOERCE" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"PICOERCE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "INS"; "UFD"}*/
-/*"PICOERCE" -> {"GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"PICOERCE" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "RETRACT"}*/
-/*"PICOERCE" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-/*"PICOERCE" -> {"UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"PICOERCE" -> {"FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
-/*"PICOERCE" -> {"ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"}*/
-"PICOERCE" -> "FS"
-/*"PICOERCE" -> {"ES"; "PATAB"; "FPATMAB"; "TYPE"; "GROUP"}*/
-
-"PMASSFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMASSFS"]
-/*"PMASSFS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"PMASSFS" -> "FS"
-/*"PMASSFS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"PMASSFS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
-/*"PMASSFS" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"}*/
-/*"PMASSFS" -> {"RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"}*/
-/*"PMASSFS" -> {"CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"}*/
-/*"PMASSFS" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
-/*"PMASSFS" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"}*/
-
-"PMFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMFS"]
-/*"PMFS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"; "COMRING"; "RING"}*/
-/*"PMFS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"PMFS" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"PMFS" -> {"ENTIRER"; "ORDSET"; "PATMAB"}*/
-"PMFS" -> "FS"
-/*"PMFS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"PMFS" -> {"FPATMAB"; "TYPE"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"PMFS" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"PMFS" -> {"GCDDOM"; "UFD"; "DIVRING"; "CACHSET"; "INT"; "LIST"; "ILIST"}*/
-/*"PMFS" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-
-"PMPREDFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PMPREDFS"]
-/*"PMPREDFS" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-"PMPREDFS" -> "FS"
-/*"PMPREDFS" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"PMPREDFS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
-/*"PMPREDFS" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"}*/
-/*"PMPREDFS" -> {"RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"}*/
-/*"PMPREDFS" -> {"CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"}*/
-/*"PMPREDFS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PMPREDFS" -> {"ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"}*/
-/*"PMPREDFS" -> {"LSAGG-"; "STAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"PMPREDFS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"PMPREDFS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"PSETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PSETCAT",
-          shape=ellipse]
-/*"PSETCAT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "CLAGG"; "HOAGG"; "AGG"}*/
-/*"PSETCAT" -> {"TYPE"; "EVALAB"; "IEVALAB"; "KONVERT"; "RING"; "RNG"}*/
-/*"PSETCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"PSETCAT" -> {"MONOID"; "LMODULE"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"PSETCAT" -> {"OASGP"; "ORDSET"}*/
-"PSETCAT" -> "RPOLCAT"
-/*"PSETCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"PSETCAT" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"PSETCAT" -> {"ENTIRER"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"PSETCAT" -> {"PATMAB"; "GCDDOM"; "PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"}*/
-/*"PSETCAT" -> {"LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"PSETCAT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"}*/
-/*"PSETCAT" -> {"OM"; "ELAGG-"; "FLAGG-"; "BOOLEAN"; "URAGG-"; "LNAGG-"}*/
-/*"PSETCAT" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "EUCDOM"; "PID"}*/
-
-"PSETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PSETCAT",
-          shape=ellipse]
-/*"PSETCAT-" -> {"SETCAT";  "BASTYPE";  "KOERCE";  "CLAGG";  "HOAGG"}*/
-/*"PSETCAT-" -> {"AGG";  "TYPE";  "EVALAB";  "IEVALAB";  "KONVERT";  "RING"}*/
-/*"PSETCAT-" -> {"RNG";  "ABELGRP";  "CABMON";  "ABELMON";  "ABELSG"}*/
-/*"PSETCAT-" -> {"SGROUP";  "MONOID";  "LMODULE";  "OAMONS";  "OCAMON"}*/
-/*"PSETCAT-" -> {"OAMON";  "OASGP";  "ORDSET"}*/
-"PSETCAT-" -> "RPOLCAT"
-/*"PSETCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "BMODULE"}*/
-/*"PSETCAT-" -> {"RMODULE";  "COMRING";  "ALGEBRA";  "MODULE";  "CHARZ"}*/
-/*"PSETCAT-" -> {"CHARNZ";  "INTDOM";  "ENTIRER";  "FRETRCT";  "RETRACT"}*/
-/*"PSETCAT-" -> {"FLINEXP";  "LINEXP";  "PATMAB";  "GCDDOM";  "PFECAT"}*/
-/*"PSETCAT-" -> {"UFD";  "INT";  "LIST";  "ILIST";  "LSAGG-";  "STAGG-"}*/
-/*"PSETCAT-" -> {"LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "LNAGG";  "IXAGG"}*/
-/*"PSETCAT-" -> {"ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG";  "OM";  "ELAGG-"}*/
-/*"PSETCAT-" -> {"FLAGG-";  "BOOLEAN";  "URAGG-";  "LNAGG-";  "RCAGG-"}*/
-/*"PSETCAT-" -> {"IXAGG-";  "CLAGG-";  "EUCDOM";  "PID"}*/
-
-"PROJPLPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PROJPLPS"]
-/*"PROJPLPS" -> {"PRSPCAT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"PROJPLPS" -> {"PACFFC"}*/
-"PROJPLPS" -> "PACOFF"
-/*"PROJPLPS" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"PROJPLPS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PROJPLPS" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PROJPLPS" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"PROJPLPS" -> {"DIVRING"; "CHARNZ"; "FINITE"; "STEP"; "DIFRING"; "PACPERC"}*/
-
-"PSETPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=PSETPK"]
-/*"PSETPK" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"PSETPK" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"PSETPK" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"PSETPK" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"PSETPK" -> {"OASGP"; "ORDSET"}*/
-"PSETPK" -> "RPOLCAT"
-/*"PSETPK" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"PSETPK" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"PSETPK" -> {"LINEXP"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"; "UFD"}*/
-/*"PSETPK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PSETPK" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"PSETPK" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"PSETPK" -> {"ELAGG-"; "BOOLEAN"; "FLAGG-"; "NNI"; "TSETCAT"; "PSETCAT"}*/
-/*"PSETPK" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "EUCDOM"}*/
-/*"PSETPK" -> "PID"*/
-
-"QUAT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=QUAT"]
-"QUAT" -> "QUATCAT"
-/*"QUAT" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"QUAT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"QUAT" -> {"LMODULE"; "MODULE"; "BMODULE"; "RMODULE"; "FRETRCT"; "RETRACT"}*/
-/*"QUAT" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FEVALAB"; "ELTAB"; "EVALAB"}*/
-/*"QUAT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ENTIRER"; "ORDSET"; "DIVRING"}*/
-/*"QUAT" -> {"KONVERT"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"QUAT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "UFD"; "INS"; "OINTDOM"}*/
-/*"QUAT" -> "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "PATMAB"}*/
-/*"QUAT" -> "CFCAT"; "REAL"; "STEP"; "RNS"; "RADCAT"}*/
-
-"QUATCT2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QUATCT2"]
-"QUATCT2" -> "QUATCAT"
-/*"QUATCT2" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"QUATCT2" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"QUATCT2" -> {"MONOID"; "LMODULE"; "MODULE"; "BMODULE"; "RMODULE"}*/
-/*"QUATCT2" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "DIFRING"; "PDRING"}*/
-/*"QUATCT2" -> {"FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"QUATCT2" -> {"LINEXP"; "ENTIRER"; "ORDSET"; "DIVRING"; "KONVERT"}*/
-/*"QUATCT2" -> {"CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"QUATCT2" -> {"INTDOM"; "COMRING"; "UFD"}*/
-
-"RADFF" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RADFF"]
-"RADFF" -> "FFCAT"
-/*"RADFF" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "ALGEBRA"; "RING"; "RNG"}*/
-/*"RADFF" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RADFF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "MODULE"; "BMODULE"}*/
-/*"RADFF" -> {"RMODULE"; "CHARZ"; "CHARNZ"; "COMRING"; "KONVERT"; "FRETRCT"}*/
-/*"RADFF" -> {"RETRACT"; "FLINEXP"; "LINEXP"; "FINITE"; "FIELD"; "EUCDOM"}*/
-/*"RADFF" -> {"PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"RADFF" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FFIELDC"; "FPC"; "STEP"}*/
-/*"RADFF" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "EVALAB"; "IEVALAB"}*/
-/*"RADFF" -> {"ORDSET"; "PATMAB"; "PFECAT"; "ELTAB"; "QFCAT"; "FEVALAB"}*/
-/*"RADFF" -> {"PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"RADFF" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "NNI"; "INT"; "BOOLEAN"}*/
-/*"RADFF" -> {"VECTOR"; "IVECTOR"; "IARRAY1"; "INS"; "CFCAT"; "OM"; "SINT"}*/
-/*"RADFF" -> {"VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"}*/
-/*"RADFF" -> {"ELTAGG"; "CLAGG"; "PRIMARR"; "A1AGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"RADFF" -> {"LIST"; "ILIST"; "LSAGG-"; "PI"; "OAMONS"}*/
-
-"RDEEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDEEF"]
-/*"RDEEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"RDEEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RDEEF" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RDEEF" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"RDEEF" -> {"CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"; "TRIGCAT"}*/
-/*"RDEEF" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"RDEEF" -> "ACF"
-/*"RDEEF" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-"RDEEF" -> "FS"
-/*"RDEEF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"RDEEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"RDEEF" -> {"CHARNZ"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"RDEEF" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"RDEEF" -> {"ELAGG"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
-/*"RDEEF" -> {"DIFRING"; "DIFEXT"; "STEP"; "SYMBOL"; "INT"; "REF"; "ALIST"}*/
-/*"RDEEF" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"RDEEF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "OM"}*/
-/*"RDEEF" -> {"CACHSET"; "ILIST"; "BOOLEAN"; "NNI"; "INS"; "OINTDOM"}*/
-/*"RDEEF" -> "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"RDEEF" -> "CFCAT"; "REAL"; "PI"}*/
-
-"RDEEFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDEEFS"]
-/*"RDEEFS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"RDEEFS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RDEEFS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"RDEEFS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "CHARZ"; "RETRACT"}*/
-/*"RDEEFS" -> {"LINEXP"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"RDEEFS" -> {"AHYP"; "ELEMFUN"}*/
-"RDEEFS" -> "ACF"
-/*"RDEEFS" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-"RDEEFS" -> "FS"
-/*"RDEEFS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"RDEEFS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"RDEEFS" -> {"CHARNZ"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
-/*"RDEEFS" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "INT"; "LIST"; "ILIST"}*/
-/*"RDEEFS" -> {"CACHSET"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-
-"RDIV" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RDIV"]
-/*"RDIV" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"RDIV" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"RDIV" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RDIV" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"RDIV" -> {"DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"RDIV" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"RDIV" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"RDIV" -> {"ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-"RDIV" -> "FFCAT"
-/*"RDIV" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"; "FPC"}*/
-/*"RDIV" -> {"QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "OINTDOM"}*/
-/*"RDIV" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-
-"RSETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=RSETCAT"]
-/*"RSETCAT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"RSETCAT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RSETCAT" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RSETCAT" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "TSETCAT"}*/
-/*"RSETCAT" -> {"PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"RSETCAT" -> {"IEVALAB"; "KONVERT"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"RSETCAT" -> {"OASGP"; "ORDSET"}*/
-"RSETCAT" -> "RPOLCAT"
-/*"RSETCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"RSETCAT" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-/*"RSETCAT" -> {"PFECAT"; "UFD"; "BOOLEAN"; "INT"; "LIST"; "ILIST"}*/
-/*"RSETCAT" -> {"FINITE"; "NNI"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"RSETCAT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
-/*"RSETCAT" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "URAGG-"}*/
-/*"RSETCAT" -> {"LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-
-"RSETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RSETCAT"]
-/*"RSETCAT-" -> {"GCDDOM";  "INTDOM";  "COMRING";  "RING";  "RNG"}*/
-/*"RSETCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
-/*"RSETCAT-" -> {"BASTYPE";  "KOERCE";  "SGROUP";  "MONOID";  "LMODULE"}*/
-/*"RSETCAT-" -> {"BMODULE";  "RMODULE";  "ALGEBRA";  "MODULE";  "ENTIRER"}*/
-/*"RSETCAT-" -> {"TSETCAT";  "PSETCAT";  "CLAGG";  "HOAGG";  "AGG";  "TYPE"}*/
-/*"RSETCAT-" -> {"EVALAB";  "IEVALAB";  "KONVERT";  "OAMONS";  "OCAMON"}*/
-/*"RSETCAT-" -> {"OAMON";  "OASGP";  "ORDSET"}*/
-"RSETCAT-" -> "RPOLCAT"
-/*"RSETCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ"}*/
-/*"RSETCAT-" -> {"FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP";  "PATMAB"}*/
-/*"RSETCAT-" -> {"PFECAT";  "UFD";  "BOOLEAN";  "INT";  "LIST";  "ILIST"}*/
-/*"RSETCAT-" -> {"FINITE";  "NNI";  "LSAGG-";  "STAGG-";  "ELAGG-"}*/
-/*"RSETCAT-" -> {"FLAGG-";  "LSAGG";  "STAGG";  "URAGG";  "RCAGG"}*/
-/*"RSETCAT-" -> {"LNAGG";  "IXAGG";  "ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG"}*/
-/*"RSETCAT-" -> "OM";  "URAGG-";  "LNAGG-";  "RCAGG-";  "IXAGG-";  "CLAGG-"}*/
-
-"RSETGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RSETGCD"]
-/*"RSETGCD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"RSETGCD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RSETGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"RSETGCD" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"}*/
-/*"RSETGCD" -> {"OAMON"; "OASGP"; "ORDSET"}*/
-"RSETGCD" -> "RPOLCAT"
-/*"RSETGCD" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"RSETGCD" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"RSETGCD" -> {"LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "RSETCAT"}*/
-/*"RSETGCD" -> {"TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"RSETGCD" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
-/*"RSETGCD" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "BOOLEAN"; "INT"}*/
-/*"RSETGCD" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"RSETGCD" -> {"OM"; "NNI"; "INS-"}*/
-
-"RULE" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RULE"]
-/*"RULE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ELTAB"; "RETRACT"}*/
-"RULE" -> "FS"
-/*"RULE" -> {"ES"; "ORDSET"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"RULE" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"}*/
-/*"RULE" -> {"GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"}*/
-/*"RULE" -> {"RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"}*/
-/*"RULE" -> {"CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"}*/
-/*"RULE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"}*/
-/*"RULE" -> {"UFD"; "DIVRING"; "INT"; "LIST"; "ILIST"; "OM"; "BOOLEAN"}*/
-/*"RULE" -> {"LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"RULE" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"RULE" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"RULE" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-
-"RULESET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RULESET"]
-/*"RULESET" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ELTAB"}*/
-"RULESET" -> "FS"
-/*"RULESET" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
-/*"RULESET" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "MONOID"}*/
-/*"RULESET" -> {"SGROUP"; "GROUP"; "ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"}*/
-/*"RULESET" -> {"RING"; "RNG"; "LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"RULESET" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "MODULE"; "BMODULE"}*/
-/*"RULESET" -> {"RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"RULESET" -> {"COMRING"; "ENTIRER"; "UFD"; "DIVRING"; "INT"; "LIST"}*/
-/*"RULESET" -> {"ILIST"; "FSAGG"; "DIAGG"; "DIOPS"; "BGAGG"; "HOAGG"}*/
-/*"RULESET" -> {"AGG"; "CLAGG"; "SETAGG"; "FINITE"}*/
-
-"SD" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SD",
-        shape=ellipse]
-/*"SD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"SD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MODULE"; "BMODULE"; "LMODULE"}*/
-/*"SD" -> {"RMODULE"; "RETRACT"; "ES"; "ORDSET"; "IEVALAB"; "EVALAB"}*/
-/*"SD" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
-/*"SD" -> {"MONOID"; "GROUP"; "RING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"SD" -> {"CHARZ"; "CHARNZ"; "ALGEBRA"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"SD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"SD" -> {"NNI"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"SD" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"SD" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"SD" -> {"BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"SD" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"SD" -> {"FLAGG"; "ELAGG"; "OM"; "PI"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"SD" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"SD" -> {" ISTRING"; "SRAGG";-" BOOLEAN"; "BSD"}*/
-"SD" -> "FS"
-
-"SIGNEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SIGNEF"]
-/*"SIGNEF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SIGNEF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"SIGNEF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"SIGNEF" -> {"MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"; "GCDDOM"}*/
-/*"SIGNEF" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-/*"SIGNEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"SIGNEF" -> "FS"
-/*"SIGNEF" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"SIGNEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"SIGNEF" -> {"CHARZ"; "CHARNZ"; "NNI"; "INT"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"SIGNEF" -> {"PFECAT"; "CACHSET"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
-/*"SIGNEF" -> {"ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"SIGNEF" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"}*/
-/*"SIGNEF" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"SIGNEF" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "FPS"}*/
-/*"SIGNEF" -> {"RNS"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SIGNEF" -> {"REAL"; "DIFRING"; "INTCAT"; "QFCAT"; "FEVALAB"; "DIFEXT"}*/
-/*"SIGNEF" -> {"STEP"; "OINTDOM"; "PI"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"SIGNEF" -> {"URAGG-"; "INS-"}*/
-
-"SIMPAN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SIMPAN"]
-/*"SIMPAN" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"SIMPAN" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SIMPAN" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SIMPAN" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"SIMPAN" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"SIMPAN" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"SIMPAN" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"}*/
-"SIMPAN" -> "FS"
-/*"SIMPAN" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"SIMPAN" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"SIMPAN" -> {"FIELD"; "DIVRING"}*/
-
-"SFORT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SFORT"]
-/*"SFORT" -> {"FORTCAT"; "TYPE"; "KOERCE"; "ORDSET"; "SETCAT"; "BASTYPE"}*/
-"SFORT" -> "FS"
-/*"SFORT" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"SFORT" -> {"FPATMAB"; "PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"}*/
-/*"SFORT" -> {"ABELMON"; "ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"}*/
-/*"SFORT" -> {"LMODULE"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
-/*"SFORT" -> {"ALGEBRA"; "MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"}*/
-/*"SFORT" -> {"PID"; "GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"}*/
-/*"SFORT" -> {"DIVRING"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"SFORT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"SFORT" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"}*/
-
-"SOLVESER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVESER"]
-/*"SOLVESER" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SOLVESER" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SOLVESER" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SOLVESER" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "SYMBOL"}*/
-/*"SOLVESER" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"SOLVESER" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"SOLVESER" -> {"FLAGG-"; "LNAGG-"}*/
-"SOLVESER" -> "FS"
-/*"SOLVESER" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"SOLVESER" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"SOLVESER" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"SOLVESER" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"}*/
-/*"SOLVESER" -> {"FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"}*/
-/*"SOLVESER" -> {"STEP"; "NNI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "ILIST"}*/
-/*"SOLVESER" -> {"PI"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
-/*"SOLVESER" -> {"HOAGG"; "AGG"; "ELTAGG"; "CLAGG"}*/
-
-"SOLVETRA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVETRA"]
-/*"SOLVETRA" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
-/*"SOLVETRA" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SOLVETRA" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"SOLVETRA" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"SOLVETRA" -> {"ENTIRER"; "RETRACT"; "LINEXP"; "CHARZ"; "INT"; "LIST"}*/
-/*"SOLVETRA" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"SOLVETRA" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"}*/
-/*"SOLVETRA" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"}*/
-/*"SOLVETRA" -> {"OM"; "NNI"; "QFCAT"; "FIELD"; "UFD"; "DIVRING"; "FEVALAB"}*/
-/*"SOLVETRA" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "PATAB"}*/
-/*"SOLVETRA" -> {"FPATMAB"; "PATMAB"; "STEP"; "OINTDOM"; "ORDRING"}*/
-/*"SOLVETRA" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "CHARNZ"}*/
-/*"SOLVETRA" -> {"PFECAT"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"SOLVETRA" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"SOLVETRA" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"SOLVETRA" -> {"AMR"; "FRETRCT"}*/
-"SOLVETRA" -> "FS"
-/*"SOLVETRA" -> {"ES"; "GROUP"; "LSAGG-"; "STAGG-"; "CACHSET"; "PI"; "ACFS"}*/
-/*"SOLVETRA" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"SOLVETRA" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
-/*"SOLVETRA" -> {"SPFCAT"; "ELAGG-"; "URAGG-"; "FPS"; "RNS"; "INTCAT"}*/
-/*"SOLVETRA" -> {"COMPCAT"; "MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"}*/
-/*"SOLVETRA" -> {"FFIELDC"; "FPC"}*/
-
-"SUMFS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SUMFS"]
-/*"SUMFS" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"SUMFS" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SUMFS" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SUMFS" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"; "RETRACT"; "LINEXP"}*/
-"SUMFS" -> "FS"
-/*"SUMFS" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"SUMFS" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"SUMFS" -> {"CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"SUMFS" -> {"UFD"; "DIVRING"; "COMBOPC"; "CFCAT"}*/
-"SUMFS" -> "ACF"
-/*"SUMFS" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"SUMFS" -> {"ELEMFUN"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"SUMFS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"SUMFS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"SUMFS" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"SUMFS" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "CACHSET"; "ILIST"; "BOOLEAN"}*/
-
-"SUTS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUTS"]
-/*"SUTS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SUTS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-"SUTS" -> "UTSCAT"
-/*"SUTS" -> {"UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"SUTS" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"SUTS" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"SUTS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INT"; "BOOLEAN"}*/
-/*"SUTS" -> {"NNI"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"SUTS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"SUTS" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"SUTS" -> {"STEP"; "OM"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
-/*"SUTS" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "FIELD"; "DIVRING"; "OAMONS"}*/
-
-"TOOLSIGN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TOOLSIGN"]
-/*"TOOLSIGN" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"TOOLSIGN" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"TOOLSIGN" -> {"LMODULE"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"TOOLSIGN" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"TOOLSIGN" -> {"EUCDOM"; "PID"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"TOOLSIGN" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"; "KONVERT"}*/
-/*"TOOLSIGN" -> {"RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"TOOLSIGN" -> {"CHARZ"; "STEP"}*/
-"TOOLSIGN" -> "FS"
-/*"TOOLSIGN" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"TOOLSIGN" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"; "FIELD"}*/
-/*"TOOLSIGN" -> {"DIVRING"; "OM"; "INT"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"TOOLSIGN" -> {"GCDDOM-"; "INTDOM-"; "ALGEBRA-"; "DIFRING-"; "ORDRING-"}*/
-/*"TOOLSIGN" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
-/*"TOOLSIGN" -> {"PRIMARR"; "A1AGG-"; "ISTRING"}*/
-
-"TRIGMNIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TRIGMNIP"]
-/*"TRIGMNIP" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"TRIGMNIP" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"TRIGMNIP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"TRIGMNIP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"TRIGMNIP" -> {"RETRACT"; "LINEXP"}*/
-"TRIGMNIP" -> "ACF"
-/*"TRIGMNIP" -> {"FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-/*"TRIGMNIP" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"TRIGMNIP" -> "FS"
-/*"TRIGMNIP" -> {"ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"TRIGMNIP" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"TRIGMNIP" -> {"CHARZ"; "CHARNZ"; "INT"; "LIST"; "ILIST"}*/
-"TRIGMNIP" -> "COMPCAT"
-/*"TRIGMNIP" -> {"MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"}*/
-/*"TRIGMNIP" -> {"DIFRING"; "FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"}*/
-/*"TRIGMNIP" -> {"PFECAT"; "OM"; "SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"}*/
-/*"TRIGMNIP" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"TRIGMNIP" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"TRIGMNIP" -> {"INS-"; "NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"TRIGMNIP" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
-/*"TRIGMNIP" -> {"ELAGG"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "BOOLEAN"}*/
-
-"TRMANIP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=TRMANIP"]
-/*"TRMANIP" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "GCDDOM"; "INTDOM"}*/
-/*"TRMANIP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"TRMANIP" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"TRMANIP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-"TRMANIP" -> "FS"
-/*"TRMANIP" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"TRMANIP" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"TRMANIP" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"TRMANIP" -> {"PID"; "UFD"; "DIVRING"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"TRMANIP" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "SYMBOL"; "INT"; "REF"}*/
-/*"TRMANIP" -> {"ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"TRMANIP" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"TRMANIP" -> {"LNAGG-"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"TRMANIP" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"TRMANIP" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"; "LSAGG-"; "STAGG-"}*/
-/*"TRMANIP" -> {"BOOLEAN"; "ELAGG-"; "URAGG-"; "CACHSET"; "POLYCAT"}*/
-/*"TRMANIP" -> {"FAMR"; "AMR"; "PFECAT"}*/
-
-"TSETCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TSETCAT",
-          shape=ellipse]
-/*"TSETCAT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"TSETCAT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"TSETCAT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"TSETCAT" -> {"MODULE"; "ENTIRER"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"}*/
-/*"TSETCAT" -> {"TYPE"; "EVALAB"; "IEVALAB"; "KONVERT"; "OAMONS"; "OCAMON"}*/
-/*"TSETCAT" -> {"OAMON"; "OASGP"; "ORDSET"}*/
-"TSETCAT" -> "RPOLCAT"
-/*"TSETCAT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"TSETCAT" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-/*"TSETCAT" -> {"GCDDOM"; "PFECAT"; "UFD"; "BOOLEAN"; "INT"; "LIST"}*/
-/*"TSETCAT" -> {"ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"TSETCAT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"TSETCAT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"TSETCAT" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "NNI"; "INS-"; "FINITE"}*/
-
-"TSETCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=TSETCAT",
-          shape=ellipse]
-/*"TSETCAT-" -> {"INTDOM";  "COMRING";  "RING";  "RNG";  "ABELGRP"}*/
-/*"TSETCAT-" -> {"CABMON";  "ABELMON";  "ABELSG";  "SETCAT";  "BASTYPE"}*/
-/*"TSETCAT-" -> {"KOERCE";  "SGROUP";  "MONOID";  "LMODULE";  "BMODULE"}*/
-/*"TSETCAT-" -> {"RMODULE";  "ALGEBRA";  "MODULE";  "ENTIRER";  "PSETCAT"}*/
-/*"TSETCAT-" -> {"CLAGG";  "HOAGG";  "AGG";  "TYPE";  "EVALAB";  "IEVALAB"}*/
-/*"TSETCAT-" -> {"KONVERT";  "OAMONS";  "OCAMON";  "OAMON";  "OASGP"}*/
-/*"TSETCAT-" -> "ORDSET"*/
-"TSETCAT-" -> "RPOLCAT"
-/*"TSETCAT-" -> {"POLYCAT";  "PDRING";  "FAMR";  "AMR";  "CHARZ";  "CHARNZ"}*/
-/*"TSETCAT-" -> {"FRETRCT";  "RETRACT";  "FLINEXP";  "LINEXP";  "PATMAB"}*/
-/*"TSETCAT-" -> {"GCDDOM";  "PFECAT";  "UFD";  "BOOLEAN";  "INT";  "LIST"}*/
-/*"TSETCAT-" -> {"ILIST";  "LSAGG";  "STAGG";  "URAGG";  "RCAGG";  "LNAGG"}*/
-/*"TSETCAT-" -> {"IXAGG";  "ELTAGG";  "ELTAB";  "FLAGG";  "ELAGG";  "OM"}*/
-/*"TSETCAT-" -> {"LSAGG-";  "STAGG-";  "ELAGG-";  "FLAGG-";  "URAGG-"}*/
-/*"TSETCAT-" -> {"LNAGG-";  "RCAGG-";  "IXAGG-";  "CLAGG-";  "NNI"}*/
-/*"TSETCAT-" -> {"INS-";  "FINITE"}*/
-
-"UFPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UFPS"]
-/*"UFPS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UFPS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-"UFPS" -> "UTSCAT"
-/*"UFPS" -> {"UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"UFPS" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"UFPS" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"UFPS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "OAMONS"; "OCAMON"}*/
-/*"UFPS" -> {"OAMON"; "OASGP"; "ORDSET"; "INS"; "UFD"; "GCDDOM"; "EUCDOM"}*/
-/*"UFPS" -> {"PID"; "OINTDOM"; "ORDRING"; "OAGROUP"; "KONVERT"; "RETRACT"}*/
-/*"UFPS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "FIELD"; "DIVRING"}*/
-
-"ULSCCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ULSCCAT"]
-/*"ULSCCAT" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"}*/
-/*"ULSCCAT" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"ULSCCAT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ULSCCAT" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"ULSCCAT" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
-/*"ULSCCAT" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"ULSCCAT" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"ULSCCAT" -> {"UFD"; "DIVRING"; "RETRACT"; "QFCAT"; "FEVALAB"; "EVALAB"}*/
-/*"ULSCCAT" -> {"IEVALAB"; "DIFEXT"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"ULSCCAT" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
-/*"ULSCCAT" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ULSCCAT" -> {"OASGP"; "REAL"; "PFECAT"}*/
-"ULSCCAT" -> "UTSCAT"
-/*"ULSCCAT" -> {"INS"; "CFCAT"}*/
-
-"ULSCCAT-" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ULSCCAT"]
-/*"ULSCCAT-" -> {"ULSCAT";  "UPSCAT";  "PSCAT";  "AMR";  "RING";  "RNG"}*/
-/*"ULSCCAT-" -> {"ABELGRP";  "CABMON";  "ABELMON";  "ABELSG";  "SETCAT"}*/
-/*"ULSCCAT-" -> {"BASTYPE";  "KOERCE";  "SGROUP";  "MONOID";  "LMODULE"}*/
-/*"ULSCCAT-" -> {"BMODULE";  "RMODULE";  "COMRING";  "ALGEBRA";  "MODULE"}*/
-/*"ULSCCAT-" -> {"CHARZ";  "CHARNZ";  "INTDOM";  "ENTIRER";  "ELTAB"}*/
-/*"ULSCCAT-" -> {"DIFRING";  "PDRING";  "RADCAT";  "TRANFUN";  "TRIGCAT"}*/
-/*"ULSCCAT-" -> {"ATRIG";  "HYPCAT";  "AHYP";  "ELEMFUN";  "FIELD"}*/
-/*"ULSCCAT-" -> {"EUCDOM";  "PID";  "GCDDOM";  "UFD";  "DIVRING";  "RETRACT"}*/
-/*"ULSCCAT-" -> {"QFCAT";  "FEVALAB";  "EVALAB";  "IEVALAB";  "DIFEXT"}*/
-/*"ULSCCAT-" -> {"FLINEXP";  "LINEXP";  "PATAB";  "KONVERT";  "FPATMAB"}*/
-/*"ULSCCAT-" -> {"TYPE";  "PATMAB";  "STEP";  "ORDSET";  "OINTDOM"}*/
-/*"ULSCCAT-" -> {"ORDRING";  "OAGROUP";  "OCAMON";  "OAMON";  "OASGP"}*/
-/*"ULSCCAT-" -> {"REAL";  "PFECAT"}*/
-"ULSCCAT-" -> "UTSCAT"
-/*"ULSCCAT-" -> {"INS";  "CFCAT"}*/
-
-"UPXSSING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXSSING"]
-"UPXSSING" -> "ACF"
-/*"UPXSSING" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"UPXSSING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UPXSSING" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"UPXSSING" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"UPXSSING" -> {"ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"}*/
-/*"UPXSSING" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"UPXSSING" -> "FS"
-/*"UPXSSING" -> {"ES"; "ORDSET"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
-/*"UPXSSING" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
-/*"UPXSSING" -> {"GROUP"; "PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"}*/
-/*"UPXSSING" -> {"FAMR"; "AMR"; "UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"}*/
-/*"UPXSSING" -> {"ELTAB"; "DIFRING"; "NNI"; "INT"; "LIST"; "ILIST"; "INS"}*/
-/*"UPXSSING" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"UPXSSING" -> {"OASGP"; "CFCAT"; "REAL"; "STEP"; "BOOLEAN"; "OM"}*/
-/*"UPXSSING" -> {"LSAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"UPXSSING" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
-/*"UPXSSING" -> {"ELAGG"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"UPXSSING" -> {"A1AGG-"; "ISTRING"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"}*/
-
-"UTSODE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTSODE"]
-/*"UTSODE" -> {"ALGEBRA"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"UTSODE" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"UTSODE" -> {"MONOID"; "LMODULE"; "MODULE"; "BMODULE"; "RMODULE"}*/
-"UTSODE" -> "UTSCAT"
-/*"UTSODE" -> {"UPSCAT"; "PSCAT"; "AMR"; "COMRING"; "CHARZ"; "CHARNZ"}*/
-/*"UTSODE" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"}*/
-/*"UTSODE" -> {"RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"UTSODE" -> {"ELEMFUN"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"UTSODE" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"UTSODE" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"UTSODE" -> {"KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
-
-"UTSODETL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTSODETL"]
-/*"UTSODETL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UTSODETL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"UTSODETL" -> {"LMODULE"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"UTSODETL" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"UTSODETL" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "FRETRCT"}*/
-/*"UTSODETL" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"UTSODETL" -> {"ORDSET"; "KONVERT"; "PATMAB"; "GCDDOM"; "PFECAT"}*/
-/*"UTSODETL" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
-/*"UTSODETL" -> {"PID"; "FIELD"; "DIVRING"; "LODOCAT"; "OREPCAT"}*/
-"UTSODETL" -> "UTSCAT"
-/*"UTSODETL" -> {"UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"UTSODETL" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"; "SINT"}*/
-/*"UTSODETL" -> {"VECTOR"; "IVECTOR"; "IARRAY1"}*/
-
-"UTSSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTSSOL"]
-/*"UTSSOL" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"UTSSOL" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UTSSOL" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UTSSOL" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"UTSSOL" -> {"UFD"; "DIVRING"}*/
-"UTSSOL" -> "UTSCAT"
-/*"UTSSOL" -> {"UPSCAT"; "PSCAT"; "AMR"; "CHARZ"; "CHARNZ"; "ELTAB"}*/
-/*"UTSSOL" -> {"DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"UTSSOL" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"; "LSAGG"}*/
-/*"UTSSOL" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"UTSSOL" -> {"IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"}*/
-/*"UTSSOL" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "UPOLYC"; "POLYCAT"}*/
-/*"UTSSOL" -> {"FAMR"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-/*"UTSSOL" -> {"PFECAT"; "DIFEXT"; "STEP"; "LZSTAGG"}*/
-
-"UTS2" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UTS2"]
-/*"UTS2" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UTS2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-"UTS2" -> "UTSCAT"
-/*"UTS2" -> {"UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"; "COMRING"}*/
-/*"UTS2" -> {"ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"}*/
-/*"UTS2" -> {"ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"UTS2" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-
-"WUTSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=WUTSET"]
-/*"WUTSET" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"WUTSET" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"WUTSET" -> {"KONVERT"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"WUTSET" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"WUTSET" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"WUTSET" -> {"OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-"WUTSET" -> "RPOLCAT"
-/*"WUTSET" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"WUTSET" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-/*"WUTSET" -> {"GCDDOM"; "PFECAT"; "UFD"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"WUTSET" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"}*/
-/*"WUTSET" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"WUTSET" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"WUTSET" -> {"CLAGG-"; "BOOLEAN"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"WUTSET" -> {"SETCAT-"; "BASTYPE-"; "FINITE"}*/
-
-\end{chunk}
-\subsection{Layer18}
-Depends on: ACFS EXPRSOL FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL 
-Used in next layer: EXPRSOL SFRTCAT
-\begin{chunk}{layer18}
-
-LAYER18=\
-  ${OUT}/DEFINTEF.o ${OUT}/DEFINTRF.o ${OUT}/DFINTTLS.o ${OUT}/EFULS.o    \
-  ${OUT}/ESCONT.o   ${OUT}/EXPR.o     ${OUT}/EXPRSOL.o  ${OUT}/EXPR2UPS.o \
-  ${OUT}/FACTEXT.o  \
-  ${OUT}/FDIV.o     ${OUT}/FSCINT.o   ${OUT}/FSINT.o    ${OUT}/FS2EXPXP.o \
-  ${OUT}/GSERIES.o  ${OUT}/HELLFDIV.o ${OUT}/INTDIVP.o  \
-  ${OUT}/INVLAPLA.o ${OUT}/IR2F.o     \
-  ${OUT}/IRRF2F.o   ${OUT}/LAPLACE.o  ${OUT}/LIMITPS.o  ${OUT}/LODEEF.o   \
-  ${OUT}/NODE1.o    ${OUT}/NOTTING.o \
-  ${OUT}/NTSCAT.o   ${OUT}/ODECONST.o ${OUT}/ODEEF.o    \
-  ${OUT}/ODEINT.o   ${OUT}/QCMPACK.o  ${OUT}/REGSET.o   ${OUT}/REP.o      \
-  ${OUT}/RGCHAIN.o  ${OUT}/RSDCMPK.o  ${OUT}/SFRTCAT.o  ${OUT}/SOLVERAD.o \
-  ${OUT}/SULS.o     ${OUT}/SUPXS.o    ${OUT}/UFPS1.o    ${OUT}/ULS.o      \
-  ${OUT}/ULSCONS.o  ${OUT}/UPXS.o     ${OUT}/UPXSCONS.o ${OUT}/UTS.o      \
-  ${OUT}/UTSZ.o \
-  layer18done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 18 */
-/* depends on: ACFS FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL */
-
-"DEFINTEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DEFINTEF"]
-/*"DEFINTEF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DEFINTEF" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"DEFINTEF" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DEFINTEF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"DEFINTEF" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
-/*"DEFINTEF" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PRIMCAT"}*/
-"DEFINTEF" -> "ACFS"
-/*"DEFINTEF" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"DEFINTEF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"DEFINTEF" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"DEFINTEF" -> {"CHARNZ"; "SPFCAT"; "BOOLEAN"; "CACHSET"; "SYMBOL"; "INT"}*/
-/*"DEFINTEF" -> {"REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"DEFINTEF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"DEFINTEF" -> {"LNAGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DEFINTEF" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
-/*"DEFINTEF" -> {"OM"; "ILIST"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"}*/
-/*"DEFINTEF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
-/*"DEFINTEF" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-
-"DEFINTRF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DEFINTRF"]
-/*"DEFINTRF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"DEFINTRF" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"DEFINTRF" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"DEFINTRF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"DEFINTRF" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "FS"; "ES"}*/
-/*"DEFINTRF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"DEFINTRF" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"DEFINTRF" -> {"FIELD"; "UFD"; "DIVRING"; "BOOLEAN"; "POLYCAT"; "FAMR"}*/
-/*"DEFINTRF" -> {"AMR"; "PFECAT"; "INT"; "LIST"; "ILIST"; "QFCAT"; "FEVALAB"}*/
-/*"DEFINTRF" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "STEP"; "OINTDOM"; "ORDRING"}*/
-/*"DEFINTRF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-"DEFINTRF" -> "ACFS"
-/*"DEFINTRF" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"DEFINTRF" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
-/*"DEFINTRF" -> "SPFCAT"*/
-
-"DFINTTLS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DFINTTLS"]
-/*"DFINTTLS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"DFINTTLS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"DFINTTLS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"DFINTTLS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"DFINTTLS" -> {"RETRACT"; "LINEXP"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"DFINTTLS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"DFINTTLS" -> "ACFS"
-/*"DFINTTLS" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"}*/
-/*"DFINTTLS" -> {"RADCAT"; "FS"; "ES"; "IEVALAB"; "EVALAB"; "PATAB"}*/
-/*"DFINTTLS" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
-/*"DFINTTLS" -> {"GROUP"; "PDRING"; "FLINEXP"; "CHARZ"; "CHARNZ"; "NNI"}*/
-/*"DFINTTLS" -> {"INT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"DFINTTLS" -> {"OAMON"; "OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
-/*"DFINTTLS" -> {"OM"; "BOOLEAN"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"DFINTTLS" -> {"LIST"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SYMBOL"; "REF"}*/
-/*"DFINTTLS" -> {"ALIST"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "POLYCAT"}*/
-/*"DFINTTLS" -> {"FAMR"; "AMR"; "PFECAT"; "QFCAT"; "FEVALAB"; "ELTAB"}*/
-/*"DFINTTLS" -> {"DIFEXT"; "LSAGG-"; "INS-"}*/
-
-"EFULS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EFULS"]
-/*"EFULS" -> "PTRANFN"*/
-"EFULS" -> "ULSCCAT"
-/*"EFULS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"}*/
-/*"EFULS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"EFULS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"EFULS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"EFULS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
-/*"EFULS" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"EFULS" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"EFULS" -> {"UFD"; "DIVRING"; "RETRACT"; "QFCAT"; "FEVALAB"; "EVALAB"}*/
-/*"EFULS" -> {"IEVALAB"; "DIFEXT"; "FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"}*/
-/*"EFULS" -> {"FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"; "OINTDOM"}*/
-/*"EFULS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"}*/
-/*"EFULS" -> {"PFECAT"; "UTSCAT"; "NNI"; "INT"; "INS"; "CFCAT"; "PI"}*/
-/*"EFULS" -> {"OM"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"}*/
-/*"EFULS" -> {"PRIMARR"; "A1AGG-"; "ISTRING"}*/
-
-"ESCONT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ESCONT"]
-/*"ESCONT" -> {"FPS"; "RNS"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"ESCONT" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"ESCONT" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"ESCONT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"ESCONT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "ORDRING"; "OAGROUP"}*/
-/*"ESCONT" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "REAL"; "KONVERT"}*/
-/*"ESCONT" -> {"RETRACT"; "RADCAT"; "PATMAB"; "CHARZ"; "DIFRING"; "OM"}*/
-/*"ESCONT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"ESCONT" -> {"SPFCAT"; "DFLOAT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"ESCONT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"ESCONT" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "INT"}*/
-/*"ESCONT" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"ESCONT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "STRING"; "CHAR"}*/
-/*"ESCONT" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "INS"}*/
-/*"ESCONT" -> {"OINTDOM"; "LINEXP"; "CFCAT"; "STEP"; "QFCAT"; "FEVALAB"}*/
-/*"ESCONT" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "CHARNZ"}*/
-/*"ESCONT" -> {"PFECAT"; "FS"; "ES"; "FRETRCT"; "GROUP"; "NNI"; "SYMBOL"}*/
-/*"ESCONT" -> {"REF"; "ALIST"; "SRAGG-"; "PI"; "VECTCAT"; "A1AGG"}*/
-"ESCONT" -> "ACFS"
-/*"ESCONT" -> {"ACF"; "COMBOPC"; "LFCAT"; "PRIMCAT"; "VECTOR"; "IVECTOR"}*/
-/*"ESCONT" -> {"IARRAY1"; "VECTCAT-"}*/
-
-"EXPR" [color="#88FF44",href="bookvol10.3.pdf#nameddest=EXPR"]
-/*"EXPR" -> {"FS"; "ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"EXPR" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"EXPR" -> {"PATMAB"; "FRETRCT"; "MONOID"; "SGROUP"; "GROUP"; "ABELMON"}*/
-/*"EXPR" -> {"ABELSG"; "ABELGRP"; "CABMON"; "RING"; "RNG"; "LMODULE"}*/
-/*"EXPR" -> {"PDRING"; "FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "ALGEBRA"}*/
-/*"EXPR" -> {"MODULE"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"EXPR" -> {"GCDDOM"; "INTDOM"; "COMRING"; "ENTIRER"; "UFD"; "DIVRING"}*/
-"EXPR" -> "ACFS"
-/*"EXPR" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"EXPR" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
-/*"EXPR" -> {"SPFCAT"; "BOOLEAN"; "CACHSET"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"EXPR" -> {"PFECAT"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"EXPR" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"EXPR" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"EXPR" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"}*/
-/*"EXPR" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"}*/
-/*"EXPR" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"EXPR" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "NNI"}*/
-/*"EXPR" -> {"PI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "QFCAT"}*/
-/*"EXPR" -> {"FEVALAB"; "DIFEXT"; "DIFRING"; "STEP"; "OINTDOM"; "ORDRING"}*/
-/*"EXPR" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "UPOLYC"}*/
-/*"EXPR" -> {"INS"; "FPS"; "RNS"; "LF"}*/
-
-"EXPRSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPRSOL"]
-"EXPRSOL" -> "UTSSOL" /* by loadlib */
-/*"EXPRSOL" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "INTDOM"}*/
-/*"EXPRSOL" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"EXPRSOL" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"EXPRSOL" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "KONVERT"}*/
-/*"EXPRSOL" -> {"FS"; "ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"}*/
-/*"EXPRSOL" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"EXPRSOL" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"}*/
-/*"EXPRSOL" -> {"PID"; "GCDDOM"; "UFD"; "DIVRING"; "UTSCAT"; "UPSCAT"}*/
-/*"EXPRSOL" -> {"PSCAT"; "AMR"; "ELTAB"; "DIFRING"; "RADCAT"; "TRANFUN"}*/
-/*"EXPRSOL" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "SYMBOL"}*/
-/*"EXPRSOL" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"EXPRSOL" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"EXPRSOL" -> {"FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-
-"EXPR2UPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPR2UPS"]
-/*"EXPR2UPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"EXPR2UPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"EXPR2UPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"EXPR2UPS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"EXPR2UPS" -> {"RETRACT"; "LINEXP"; "ACF"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"EXPR2UPS" -> {"UFD"; "DIVRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"EXPR2UPS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FS"; "ES"; "IEVALAB"}*/
-/*"EXPR2UPS" -> {"EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
-/*"EXPR2UPS" -> {"FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARZ"; "CHARNZ"}*/
-/*"EXPR2UPS" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"EXPR2UPS" -> {"OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"}*/
-"EXPR2UPS" -> "ULSCCAT"
-/*"EXPR2UPS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "ELTAB"; "QFCAT"}*/
-/*"EXPR2UPS" -> {"FEVALAB"; "DIFEXT"; "PFECAT"; "BOOLEAN"; "STRING"}*/
-/*"EXPR2UPS" -> {"CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"EXPR2UPS" -> {"A1AGG-"; "ISTRING"; "NNI"; "ILIST"; "UPXSCCA"; "UPXSCAT"}*/
-
-"FACTEXT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FACTEXT"]
-"FACTEXT" -> "PACEXTC"
-/*"FACTEXT" -> {"PACRATC"; "PACPERC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FACTEXT" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"FACTEXT" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"FACTEXT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"FACTEXT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARZ"; "RETRACT"}*/
-/*"FACTEXT" -> {"XF"; "VSPACE"; "FPC"; "CHARNZ"; "FINITE"; "UPOLYC"}*/
-/*"FACTEXT" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "FRETRCT"; "EVALAB"}*/
-/*"FACTEXT" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"FACTEXT" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"FACTEXT" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FACTEXT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"FACTEXT" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "NNI"}*/
-
-"FDIV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=FDIV"]
-"FDIV" -> "FDIVCAT"
-/*"FDIV" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FDIV" -> {"BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"FDIV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"FDIV" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FDIV" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"FDIV" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"FDIV" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"}*/
-/*"FDIV" -> {"PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"FDIV" -> {"FFCAT"; "MONOGEN"; "FRAMALG"; "FINRALG"; "FINITE"; "FFIELDC"}*/
-/*"FDIV" -> {"FPC"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"}*/
-/*"FDIV" -> {"A1AGG-"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"FDIV" -> {"OAMON"; "OASGP"; "CFCAT"; "REAL"; "OM"; "NNI"; "PI"; "VECTCAT"}*/
-/*"FDIV" -> {"A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"FDIV" -> {"ELTAGG"; "CLAGG"; "FLAGG-"; "LNAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"FDIV" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "QFCAT"; "FEVALAB"; "PATAB"}*/
-/*"FDIV" -> "FPATMAB"*/
-
-"FSCINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSCINT"]
-/*"FSCINT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"FSCINT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FSCINT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FSCINT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FSCINT" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
-/*"FSCINT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-"FSCINT" -> "ACFS"
-/*"FSCINT" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"FSCINT" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"FSCINT" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"FSCINT" -> {"INT"; "LIST"; "ILIST"; "COMPCAT"; "MONOGEN"; "FRAMALG"}*/
-/*"FSCINT" -> {"FINRALG"; "FINITE"; "DIFEXT"; "DIFRING"; "FFIELDC"; "FPC"}*/
-/*"FSCINT" -> {"STEP"; "FEVALAB"; "ELTAB"; "PFECAT"; "OM"; "LFCAT"}*/
-/*"FSCINT" -> {"PRIMCAT"; "BOOLEAN"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"FSCINT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"FSCINT" -> {"FLAGG"; "ELAGG"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"FSCINT" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "SYMBOL"}*/
-/*"FSCINT" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"FSCINT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-
-"FSINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FSINT"]
-/*"FSINT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"FSINT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"FSINT" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"FSINT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"FSINT" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
-/*"FSINT" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PRIMCAT"}*/
-"FSINT" -> "ACFS"
-/*"FSINT" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"FSINT" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"FSINT" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"FSINT" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"FSINT" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"FSINT" -> {"FLAGG-"; "LNAGG-"; "NNI"; "ILIST"; "COMPCAT"; "MONOGEN"}*/
-/*"FSINT" -> {"FRAMALG"; "FINRALG"; "FINITE"; "DIFEXT"; "DIFRING"}*/
-/*"FSINT" -> {"FFIELDC"; "FPC"; "STEP"; "FEVALAB"; "ELTAB"; "PFECAT"}*/
-/*"FSINT" -> {"OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"FSINT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"FSINT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"}*/
-/*"FSINT" -> {"IXAGG-"; "CLAGG-"; "CACHSET"; "BOOLEAN"}*/
-
-"FS2EXPXP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=FS2EXPXP"]
-/*"FS2EXPXP" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"FS2EXPXP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"FS2EXPXP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"FS2EXPXP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"FS2EXPXP" -> {"ENTIRER"; "UFD"; "DIVRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"FS2EXPXP" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FS"; "ES"; "ORDSET"}*/
-/*"FS2EXPXP" -> {"RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"}*/
-/*"FS2EXPXP" -> {"FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"}*/
-/*"FS2EXPXP" -> {"FLINEXP"; "LINEXP"; "CHARZ"; "CHARNZ"; "PI"; "NNI"; "INT"}*/
-/*"FS2EXPXP" -> {"INS"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"FS2EXPXP" -> {"OASGP"; "DIFRING"; "CFCAT"; "REAL"; "STEP"; "CACHSET"}*/
-/*"FS2EXPXP" -> {"LIST"; "ILIST"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"FS2EXPXP" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"FS2EXPXP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"; "QFCAT"; "FEVALAB"}*/
-/*"FS2EXPXP" -> {"ELTAB"; "DIFEXT"; "PFECAT"; "UPXSCCA"; "UPXSCAT"}*/
-/*"FS2EXPXP" -> {"UPSCAT"; "PSCAT"; "AMR"}*/
-"FS2EXPXP" -> "ULSCCAT"
-/*"FS2EXPXP" -> {"ULSCAT"; "INS-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"FS2EXPXP" -> {"OM"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"FS2EXPXP" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
-/*"FS2EXPXP" -> {"ELAGG"; "STRICAT"; "SRAGG"; "A1AGG"}*/
-
-"GSERIES" [color="#88FF44",href="bookvol10.3.pdf#nameddest=GSERIES"]
-/*"GSERIES" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"GSERIES" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"GSERIES" -> {"LMODULE"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"}*/
-/*"GSERIES" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"GSERIES" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"}*/
-/*"GSERIES" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"GSERIES" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"GSERIES" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"}*/
-/*"GSERIES" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"GSERIES" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"GSERIES" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"GSERIES" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"GSERIES" -> {"ORDSET"; "ELAGG"; "OM"; "PATMAB"; "ILIST"; "LSAGG-"}*/
-/*"GSERIES" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
-"GSERIES" -> "ACFS"
-/*"GSERIES" -> {"ACF"; "FS"; "ES"; "RETRACT"; "PATAB"; "FPATMAB"; "FRETRCT"}*/
-/*"GSERIES" -> {"GROUP"; "FLINEXP"; "LINEXP"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"GSERIES" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"GSERIES" -> {"STEP"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"}*/
-
-"HELLFDIV" [color="#88FF44",href="bookvol10.3.pdf#nameddest=HELLFDIV"]
-"HELLFDIV" -> "FDIVCAT"
-/*"HELLFDIV" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"HELLFDIV" -> {"BASTYPE"; "KOERCE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"HELLFDIV" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "SGROUP"; "MONOID"}*/
-/*"HELLFDIV" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"HELLFDIV" -> {"ENTIRER"; "UFD"; "DIVRING"; "UPOLYC"; "POLYCAT"; "PDRING"}*/
-/*"HELLFDIV" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"HELLFDIV" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"HELLFDIV" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"}*/
-/*"HELLFDIV" -> {"DIFEXT"; "STEP"; "FFCAT"; "MONOGEN"; "FRAMALG"; "FINRALG"}*/
-/*"HELLFDIV" -> {"FINITE"; "FFIELDC"; "FPC"; "INT"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"HELLFDIV" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"HELLFDIV" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"HELLFDIV" -> {"BOOLEAN"; "NNI"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"HELLFDIV" -> {"URAGG-"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"HELLFDIV" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"HELLFDIV" -> {"REAL"; "OM"; "VECTCAT"; "A1AGG"; "FLAGG"; "LNAGG"}*/
-/*"HELLFDIV" -> {"IXAGG"; "HOAGG"; "AGG"; "ELTAGG"; "CLAGG"; "VECTOR"}*/
-/*"HELLFDIV" -> {"IVECTOR"; "IARRAY1"; "INS"; "CFCAT"; "PI"}*/
-
-"INTDIVP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INTDIVP"]
-"INTDIVP" -> "DTP"
-/*"INTDIVP" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "DIVCAT"}*/
-/*"INTDIVP" -> {"INFCLCT"; "DSTRCAT"; "BLMETCT"; "PFORP"; "PARAMP"}*/
-/*"INTDIVP" -> {"PRJALGPK"; "LPARSPT"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"INTDIVP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"INTDIVP" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INTDIVP" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"INTDIVP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"; "DIVRING"}*/
-/*"INTDIVP" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"INTDIVP" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"INTDIVP" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"INTDIVP" -> {"DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
-/*"INTDIVP" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"}*/
-/*"INTDIVP" -> {"OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"; "UPSCAT"}*/
-/*"INTDIVP" -> {"PSCAT"; "FAMONC"; "RCAGG"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"INTDIVP" -> {"LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"INTDIVP" -> {"ILIST"; "LSAGG-"; "BOOLEAN"; "NNI"; "OUTFORM"}*/
-
-"INVLAPLA" [color="#FF4488",href="bookvol10.4.pdf#nameddest=INVLAPLA"]
-/*"INVLAPLA" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"INVLAPLA" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"INVLAPLA" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"INVLAPLA" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"INVLAPLA" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"}*/
-/*"INVLAPLA" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"INVLAPLA" -> {"PRIMCAT"; "SPFCAT"}*/
-"INVLAPLA" -> "ACFS"
-/*"INVLAPLA" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"INVLAPLA" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"INVLAPLA" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"INVLAPLA" -> {"CHARNZ"; "BOOLEAN"; "UPOLYC"; "POLYCAT"; "FAMR"; "AMR"}*/
-/*"INVLAPLA" -> {"PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "LSAGG"}*/
-/*"INVLAPLA" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"}*/
-/*"INVLAPLA" -> {"IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
-/*"INVLAPLA" -> {"LIST"; "ILIST"; "NNI"; "CACHSET"; "PI"; "INS"; "OINTDOM"}*/
-/*"INVLAPLA" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"INVLAPLA" -> {"CFCAT"; "REAL"}*/
-
-"IR2F" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IR2F"]
-/*"IR2F" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"IR2F" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"IR2F" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"IR2F" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "ORDSET"; "LINEXP"}*/
-"IR2F" -> "ACFS"
-/*"IR2F" -> {"ACF"; "FIELD"; "EUCDOM"; "PID"; "UFD"; "DIVRING"; "RADCAT"}*/
-/*"IR2F" -> {"FS"; "ES"; "IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"IR2F" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"IR2F" -> {"CHARZ"; "CHARNZ"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"IR2F" -> {"AHYP"; "ELEMFUN"; "INT"; "LIST"; "ILIST"; "SYMBOL"; "REF"}*/
-/*"IR2F" -> {"ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"IR2F" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"}*/
-/*"IR2F" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "INS-"; "BOOLEAN"; "INS"}*/
-/*"IR2F" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"IR2F" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "NNI"; "PI"; "CACHSET"}*/
-/*"IR2F" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "ELTAB"; "DIFEXT"}*/
-/*"IR2F" -> {"OM"; "VECTOR"; "IVECTOR"; "IARRAY1"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"IR2F" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"IR2F" -> {"FLAGG"; "ELAGG"}*/
-
-"IRRF2F" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRRF2F"]
-/*"IRRF2F" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"IRRF2F" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"IRRF2F" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"IRRF2F" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "RETRACT"; "ORDSET"}*/
-/*"IRRF2F" -> {"LINEXP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"IRRF2F" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"IRRF2F" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "FS"; "ES"; "PATAB"}*/
-/*"IRRF2F" -> {"FPATMAB"; "TYPE"; "GROUP"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"IRRF2F" -> {"DIVRING"; "QFCAT"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
-/*"IRRF2F" -> {"DIFRING"; "STEP"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"IRRF2F" -> {"OAMON"; "OASGP"; "REAL"}*/
-"IRRF2F" -> "ACFS"
-/*"IRRF2F" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"IRRF2F" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
-/*"IRRF2F" -> {"SPFCAT"; "INT"; "LIST"; "ILIST"}*/
-
-"LAPLACE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LAPLACE"]
-/*"LAPLACE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"LAPLACE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"LAPLACE" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LAPLACE" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LAPLACE" -> {"ORDSET"; "CHARZ"; "RETRACT"; "LINEXP"; "TRANFUN"; "TRIGCAT"}*/
-/*"LAPLACE" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PRIMCAT"}*/
-"LAPLACE" -> "ACFS"
-/*"LAPLACE" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"LAPLACE" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"LAPLACE" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"LAPLACE" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"LAPLACE" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"LAPLACE" -> {"FLAGG-"; "LNAGG-"; "NNI"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"LAPLACE" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"LAPLACE" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"}*/
-/*"LAPLACE" -> {"BOOLEAN"; "STAGG-"; "ELAGG-"; "URAGG-"; "UPOLYC"; "POLYCAT"}*/
-/*"LAPLACE" -> {"FAMR"; "AMR"; "PFECAT"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"LAPLACE" -> {"CACHSET"; "PI"}*/
-
-"LIMITPS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LIMITPS"]
-/*"LIMITPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"LIMITPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"LIMITPS" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"LIMITPS" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDSET"}*/
-/*"LIMITPS" -> {"RETRACT"; "LINEXP"; "ACF"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"LIMITPS" -> {"UFD"; "DIVRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"}*/
-/*"LIMITPS" -> {"HYPCAT"; "AHYP"; "ELEMFUN"; "FS"; "ES"; "IEVALAB"; "EVALAB"}*/
-/*"LIMITPS" -> {"PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "FRETRCT"}*/
-/*"LIMITPS" -> {"GROUP"; "PDRING"; "FLINEXP"; "CHARZ"; "CHARNZ"; "LSAGG"}*/
-/*"LIMITPS" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"LIMITPS" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
-/*"LIMITPS" -> {"LIST"; "ILIST"; "BOOLEAN"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"LIMITPS" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"LIMITPS" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"; "PI"; "INS"}*/
-/*"LIMITPS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"LIMITPS" -> {"DIFRING"; "CFCAT"; "REAL"; "STEP"; "QFCAT"; "FEVALAB"}*/
-/*"LIMITPS" -> {"DIFEXT"; "PFECAT"; "UPXSCCA"; "UPXSCAT"; "UPSCAT"}*/
-/*"LIMITPS" -> {"PSCAT"; "AMR"}*/
-"LIMITPS" -> "ULSCCAT"
-/*"LIMITPS" -> {"ULSCAT"; "INS-"}*/
-
-"LODEEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LODEEF"]
-/*"LODEEF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
-/*"LODEEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"LODEEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"LODEEF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"LODEEF" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
-"LODEEF" -> "ACFS"
-/*"LODEEF" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"LODEEF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"LODEEF" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"LODEEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"LODEEF" -> {"PRIMCAT"; "LODOCAT"; "OREPCAT"; "ELTAB"; "CACHSET"}*/
-/*"LODEEF" -> {"POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "NNI"; "INT"; "LSAGG"}*/
-/*"LODEEF" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"LODEEF" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"}*/
-/*"LODEEF" -> {"BOOLEAN"; "UPOLYC"; "DIFRING"; "DIFEXT"; "STEP"; "QFCAT"}*/
-/*"LODEEF" -> {"FEVALAB"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"LODEEF" -> {"OAMON"; "OASGP"; "REAL"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"LODEEF" -> {"FLAGG-"; "URAGG-"; "VECTOR"; "IVECTOR"; "IARRAY1"}*/
-/*"LODEEF" -> {"INS"; "CFCAT"; "VECTCAT"; "A1AGG"}*/
-
-"NODE1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NODE1"]
-/*"NODE1" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
-/*"NODE1" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NODE1" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"NODE1" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"NODE1" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
-"NODE1" -> "ACFS"
-/*"NODE1" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"NODE1" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"NODE1" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"NODE1" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"NODE1" -> {"PRIMCAT"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"NODE1" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"NODE1" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "CACHSET"; "ILIST"; "LSAGG"}*/
-/*"NODE1" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"NODE1" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "POLYCAT"}*/
-/*"NODE1" -> {"FAMR"; "AMR"; "PFECAT"; "NNI"; "PI"; "LSAGG-"; "STAGG-"}*/
-
-"NOTTING" [color="#88FF44",href="bookvol10.3.pdf#nameddest=NOTTING"]
-/*"NOTTING" -> {"GROUP"; "MONOID"; "SGROUP"; "SETCAT"; "BASTYPE"} */
-/*"NOTTING" -> {"KOERCE"; "FFIELDC"; "FPC"} */
-/* "NOTTING" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"} */
-/* "NOTTING" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"} */
-/* "NOTTING" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"} */
-/* "NOTTING" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"} */
-/* "NOTTING" -> {"DIFRING"; "NNI"; "INT"} */
-"NOTTING" -> "UFPS"
-
-"NTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=NTSCAT"]
-"NTSCAT" -> "RSETCAT"
-/*"NTSCAT" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"NTSCAT" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"NTSCAT" -> "KONVERT"*/
-
-"ODECONST" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODECONST"]
-/*"ODECONST" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
-/*"ODECONST" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ODECONST" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"ODECONST" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"ODECONST" -> {"ENTIRER"; "RETRACT"; "LINEXP"; "CHARZ"}*/
-"ODECONST" -> "ACFS"
-/*"ODECONST" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"ODECONST" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"ODECONST" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"ODECONST" -> {"CHARNZ"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
-/*"ODECONST" -> {"ELEMFUN"; "PRIMCAT"; "LODOCAT"; "OREPCAT"; "ELTAB"}*/
-/*"ODECONST" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "UPOLYC"; "POLYCAT"}*/
-/*"ODECONST" -> {"FAMR"; "AMR"; "PFECAT"; "DIFRING"; "DIFEXT"; "STEP"}*/
-/*"ODECONST" -> {"SINT"; "NNI"}*/
-
-"ODEEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEEF"]
-/*"ODEEF" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
-/*"ODEEF" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ODEEF" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ODEEF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ODEEF" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
-"ODEEF" -> "ACFS"
-/*"ODEEF" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"ODEEF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"ODEEF" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"ODEEF" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"ODEEF" -> {"PRIMCAT"; "INT"; "VECTOR"; "IVECTOR"; "IARRAY1"; "SINT"}*/
-/*"ODEEF" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"}*/
-/*"ODEEF" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"ODEEF" -> {"ELAGG"; "OM"; "LIST"; "ILIST"; "BOOLEAN"; "VECTCAT"; "A1AGG"}*/
-/*"ODEEF" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
-/*"ODEEF" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-/*"ODEEF" -> {"CACHSET"; "LSAGG-"; "STAGG-"; "ELAGG-"; "PI"; "POLYCAT"}*/
-/*"ODEEF" -> {"FAMR"; "AMR"; "PFECAT"}*/
-
-"ODEINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ODEINT"]
-/*"ODEINT" -> {"ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "EUCDOM"; "PID"}*/
-/*"ODEINT" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"ODEINT" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ODEINT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ODEINT" -> {"RETRACT"; "LINEXP"; "CHARZ"}*/
-"ODEINT" -> "ACFS"
-/*"ODEINT" -> {"ACF"; "FIELD"; "UFD"; "DIVRING"; "RADCAT"; "FS"; "ES"}*/
-/*"ODEINT" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"ODEINT" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "CHARNZ"}*/
-/*"ODEINT" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"ODEINT" -> {"PRIMCAT"; "INT"; "LIST"; "ILIST"; "INS"; "OINTDOM"}*/
-/*"ODEINT" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "DIFRING"}*/
-/*"ODEINT" -> {"CFCAT"; "REAL"; "STEP"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"ODEINT" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
-/*"ODEINT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LSAGG-"; "STAGG-"}*/
-/*"ODEINT" -> {"ELAGG-"; "CACHSET"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"ODEINT" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"ODEINT" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "NNI"}*/
-
-"QCMPACK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=QCMPACK"]
-/*"QCMPACK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"QCMPACK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"QCMPACK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"QCMPACK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
-/*"QCMPACK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
-/*"QCMPACK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"QCMPACK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"QCMPACK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
-"QCMPACK" -> "RSETCAT"
-/*"QCMPACK" -> {"TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"QCMPACK" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"}*/
-/*"QCMPACK" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"QCMPACK" -> {"ELTAB"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "FLAGG-"}*/
-/*"QCMPACK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"QCMPACK" -> {"ISTRING"; "NNI"; "BOOLEAN"; "URAGG-"; "LNAGG-"}*/
-/*"QCMPACK" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-
-"REGSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=REGSET"]
-"REGSET" -> "RSETCAT"
-/*"REGSET" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"REGSET" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"REGSET" -> {"KONVERT"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"REGSET" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"REGSET" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"REGSET" -> {"ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"REGSET" -> {"RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"REGSET" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-/*"REGSET" -> {"PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"REGSET" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"REGSET" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
-/*"REGSET" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "BOOLEAN"; "INS-"}*/
-/*"REGSET" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
-/*"REGSET" -> {"BASTYPE-"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
-/*"REGSET" -> {"A1AGG-"; "ISTRING"; "NNI"; "FINITE"}*/
-
-"REP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=REP"]
-/*"REP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"REP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"REP" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"REP" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"}*/
-/*"REP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"REP" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"}*/
-/*"REP" -> {"REAL"; "CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"REP" -> {"CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "PFECAT"}*/
-/*"REP" -> {"QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"; "DIFEXT"}*/
-/*"REP" -> {"PATAB"; "FPATMAB"; "TYPE"; "FS"; "ES"; "GROUP"; "OM"; "NNI"}*/
-/*"REP" -> {"INT"; "SINT"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"REP" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"REP" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"}*/
-"REP" -> "ACFS"
-/*"REP" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"REP" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "LFCAT"; "PRIMCAT"; "SPFCAT"}*/
-/*"REP" -> {"ILIST"; "MATCAT"; "ARR2CAT"; "HOAGG"; "AGG"; "PI"; "LSAGG"}*/
-/*"REP" -> {"STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"REP" -> {"FLAGG"; "ELAGG"}*/
-
-"RGCHAIN" [color="#88FF44",href="bookvol10.3.pdf#nameddest=RGCHAIN"]
-"RGCHAIN" -> "RSETCAT"
-/*"RGCHAIN" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RGCHAIN" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"RGCHAIN" -> {"KONVERT"; "ORDFIN"; "ORDSET"; "FINITE"; "GCDDOM"; "INTDOM"}*/
-/*"RGCHAIN" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"RGCHAIN" -> {"ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RGCHAIN" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "RPOLCAT"}*/
-/*"RGCHAIN" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
-/*"RGCHAIN" -> {"FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"; "PATMAB"}*/
-/*"RGCHAIN" -> {"PFECAT"; "UFD"}*/
-
-"RSDCMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RSDCMPK"]
-/*"RSDCMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"RSDCMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"RSDCMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RSDCMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
-/*"RSDCMPK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
-/*"RSDCMPK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"RSDCMPK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"RSDCMPK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
-"RSDCMPK" -> "RSETCAT"
-/*"RSDCMPK" -> {"TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"RSDCMPK" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"; "IXAGG"}*/
-/*"RSDCMPK" -> {"ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"RSDCMPK" -> {"ILIST"; "LSAGG-"; "NNI"; "STAGG-"; "ELAGG-"; "BOOLEAN"}*/
-/*"RSDCMPK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"RSDCMPK" -> {"ISTRING"; "FLAGG-"}*/
-
-"SFRTCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SFRTCAT"]
-"SFRTCAT" -> "RSETCAT"
-/*"SFRTCAT" -> {"TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SFRTCAT" -> {"CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"SFRTCAT" -> "KONVERT"*/
-
-"SOLVERAD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SOLVERAD"]
-/*"SOLVERAD" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"SOLVERAD" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"SOLVERAD" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"SOLVERAD" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"SOLVERAD" -> {"ORDSET"; "CHARZ"; "BOOLEAN"; "FS"; "ES"; "RETRACT"}*/
-/*"SOLVERAD" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"}*/
-/*"SOLVERAD" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"SOLVERAD" -> {"LINEXP"; "CHARNZ"; "FIELD"; "UFD"; "DIVRING"}*/
-"SOLVERAD" -> "ACFS"
-/*"SOLVERAD" -> {"ACF"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"SOLVERAD" -> {"AHYP"; "ELEMFUN"; "COMBOPC"; "CFCAT"; "LFCAT"; "PRIMCAT"}*/
-/*"SOLVERAD" -> {"SPFCAT"; "SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"}*/
-/*"SOLVERAD" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"SOLVERAD" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "POLYCAT"}*/
-/*"SOLVERAD" -> {"FAMR"; "AMR"; "PFECAT"; "NNI"; "ILIST"; "LSAGG-"}*/
-/*"SOLVERAD" -> {"STAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"SOLVERAD" -> {"AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"}*/
-/*"SOLVERAD" -> {"FLAGG"; "ELAGG"; "OM"; "ELAGG-"; "PI"}*/
-
-"SULS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SULS"]
-/*"SULS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SULS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-"SULS" -> "ULSCCAT"
-/*"SULS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"SULS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"SULS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
-/*"SULS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"}*/
-/*"SULS" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"SULS" -> {"QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"}*/
-/*"SULS" -> {"LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
-/*"SULS" -> {"STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"SULS" -> {"OAMON"; "OASGP"; "REAL"; "PFECAT"; "INT"; "NNI"; "BOOLEAN"}*/
-/*"SULS" -> {"POLYCAT"; "FAMR"; "FRETRCT"; "INS"; "CFCAT"; "UTSCAT"}*/
-/*"SULS" -> {"OAMONS"; "FPS"; "RNS"; "UPOLYC"; "OM"}*/
-
-"SUPXS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SUPXS"]
-/*"SUPXS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"SUPXS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"SUPXS" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"}*/
-/*"SUPXS" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"SUPXS" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"}*/
-/*"SUPXS" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"SUPXS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"}*/
-/*"SUPXS" -> "RETRACT"*/
-"SUPXS" -> "ULSCCAT"
-/*"SUPXS" -> {"ULSCAT"; "QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"SUPXS" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"SUPXS" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"SUPXS" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "PFECAT"; "INS"; "CFCAT"}*/
-/*"SUPXS" -> {"INT"; "NNI"; "OM"}*/
-
-"UFPS1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=UFPS1"]
-"UFPS1" -> "UFPS" /* imported by macro */
-/*"UFPS1" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UFPS1" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"UFPS1" -> "LMODULE"*/
-
-"ULS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ULS"]
-/*"ULS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"ULS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-"ULS" -> "ULSCCAT"
-/*"ULS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"ULS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"ULS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
-/*"ULS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "FIELD"}*/
-/*"ULS" -> {"EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
-/*"ULS" -> {"QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"}*/
-/*"ULS" -> {"LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"}*/
-/*"ULS" -> {"STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"}*/
-/*"ULS" -> {"OAMON"; "OASGP"; "REAL"; "PFECAT"; "INT"; "UTSCAT"; "OAMONS"}*/
-/*"ULS" -> {"FPS"; "RNS"; "INS"; "CFCAT"; "UPOLYC"; "POLYCAT"; "FAMR"}*/
-/*"ULS" -> {"FRETRCT"; "OM"}*/
-
-"ULSCONS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ULSCONS"]
-"ULSCONS" -> "ULSCCAT"
-/*"ULSCONS" -> {"ULSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"}*/
-/*"ULSCONS" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"ULSCONS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ULSCONS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"ULSCONS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
-/*"ULSCONS" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"ULSCONS" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"ULSCONS" -> {"UFD"; "DIVRING"; "RETRACT"; "QFCAT"; "FEVALAB"; "EVALAB"}*/
-/*"ULSCONS" -> {"IEVALAB"; "DIFEXT"; "FLINEXP"; "LINEXP"; "PATAB"}*/
-/*"ULSCONS" -> {"KONVERT"; "FPATMAB"; "TYPE"; "PATMAB"; "STEP"; "ORDSET"}*/
-/*"ULSCONS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"ULSCONS" -> {"OASGP"; "REAL"; "PFECAT"; "UTSCAT"; "INT"; "NNI"; "BOOLEAN"}*/
-/*"ULSCONS" -> {"INS-"; "EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"ULSCONS" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"ULSCONS" -> {"OAMONS"; "POLYCAT"; "FAMR"; "FRETRCT"; "ABELMON-"}*/
-/*"ULSCONS" -> {"SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"ULSCONS" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"ULSCONS" -> {"FLAGG-"; "LNAGG-"; "INS"; "CFCAT"; "LSAGG"; "STAGG"}*/
-/*"ULSCONS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"ULSCONS" -> {"ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ILIST"; "LSAGG-"}*/
-/*"ULSCONS" -> {"STAGG-"; "ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
-"ULSCONS" -> "ACFS"
-/*"ULSCONS" -> {"ACF"; "FS"; "ES"; "GROUP"; "FPS"; "RNS"; "UPOLYC"}*/
-
-"UPXS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXS"]
-/*"UPXS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UPXS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UPXS" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"}*/
-/*"UPXS" -> {"RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"}*/
-/*"UPXS" -> {"INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"}*/
-/*"UPXS" -> {"TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"}*/
-/*"UPXS" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "UFD"; "DIVRING"; "RETRACT"}*/
-"UPXS" -> "ULSCCAT"
-/*"UPXS" -> {"ULSCAT"; "QFCAT"; "FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"}*/
-/*"UPXS" -> {"FLINEXP"; "LINEXP"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"UPXS" -> {"PATMAB"; "STEP"; "ORDSET"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"UPXS" -> {"OCAMON"; "OAMON"; "OASGP"; "REAL"; "PFECAT"; "INS"; "CFCAT"}*/
-/*"UPXS" -> {"INT"; "INS-"; "NNI"; "PI"}*/
-/*"UPXS" -> "BOOLEAN"*/
-/*"UPXS" -> {"LIST"; "ILIST"; "SINT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"UPXS" -> {"HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"}*/
-/*"UPXS" -> {"ELAGG"; "OM"; "LSAGG-"; "SYMBOL"; "REF"; "ALIST"; "STRING"}*/
-/*"UPXS" -> {"CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"UPXS" -> {"FLAGG-"; "LNAGG-"}*/
-
-"UPXSCONS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UPXSCONS"]
-/*"UPXSCONS" -> {"UPXSCCA"; "UPXSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"}*/
-/*"UPXSCONS" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"UPXSCONS" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UPXSCONS" -> {"BMODULE"; "RMODULE"; "COMRING"; "ALGEBRA"; "MODULE"}*/
-/*"UPXSCONS" -> {"CHARZ"; "CHARNZ"; "INTDOM"; "ENTIRER"; "ELTAB"; "DIFRING"}*/
-/*"UPXSCONS" -> {"PDRING"; "RADCAT"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"}*/
-/*"UPXSCONS" -> {"AHYP"; "ELEMFUN"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"UPXSCONS" -> {"UFD"; "DIVRING"; "RETRACT"; "ULSCAT"; "INS"; "OINTDOM"}*/
-/*"UPXSCONS" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"UPXSCONS" -> {"KONVERT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"}*/
-/*"UPXSCONS" -> {"OM"; "INT"; "NNI"; "PI"; "INS-"; "EUCDOM-"; "UFD-"}*/
-/*"UPXSCONS" -> {"GCDDOM-"; "SYMBOL"; "REF"; "ALIST"; "LIST"; "STRING"}*/
-/*"UPXSCONS" -> {"CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"UPXSCONS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"UPXSCONS" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"UPXSCONS" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"UPXSCONS" -> {"ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-/*"UPXSCONS" -> {"RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
-"UPXSCONS" -> "ACFS"
-/*"UPXSCONS" -> {"ACF"; "FS"; "ES"; "PATAB"; "FPATMAB"; "FRETRCT"; "GROUP"}*/
-/*"UPXSCONS" -> {"FLINEXP"; "QFCAT"; "FEVALAB"; "DIFEXT"; "PFECAT"}*/
-
-"UTS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTS"]
-/*"UTS" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"UTS" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"UTS" -> {"UTSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "BMODULE"; "RMODULE"}*/
-/*"UTS" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"UTS" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
-/*"UTS" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"}*/
-/*"UTS" -> {"BOOLEAN"; "SINT"; "PI"; "SYMBOL"; "REF"; "ALIST"; "LIST"}*/
-/*"UTS" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"UTS" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"UTS" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"UTS" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "RETRACT"}*/
-/*"UTS" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "QFCAT"}*/
-/*"UTS" -> {"FEVALAB"; "EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"; "PATAB"}*/
-/*"UTS" -> {"FPATMAB"; "TYPE"; "PFECAT"; "OM"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"UTS" -> {"RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
-/*"UTS" -> {"FLAGG"; "ELAGG"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"UTS" -> {"URAGG-"; "RCAGG-"; "IXAGG-"; "PRIMCAT"}*/
-"UTS" -> "ACFS"
-/*"UTS" -> {"ACF"; "FS"; "ES"; "FRETRCT"; "GROUP"; "OAMONS"}*/
-
-"UTSZ" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTSZ"]
-/*"UTSZ" -> {"UTSCAT"; "UPSCAT"; "PSCAT"; "AMR"; "RING"; "RNG"; "ABELGRP"}*/
-/*"UTSZ" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"UTSZ" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"UTSZ" -> {"COMRING"; "ALGEBRA"; "MODULE"; "CHARZ"; "CHARNZ"; "INTDOM"}*/
-/*"UTSZ" -> {"ENTIRER"; "ELTAB"; "DIFRING"; "PDRING"; "RADCAT"; "TRANFUN"}*/
-/*"UTSZ" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "NNI"; "INT"}*/
-/*"UTSZ" -> {"BOOLEAN"; "SINT"; "PI"; "SYMBOL"; "REF"; "ALIST"; "LIST"}*/
-/*"UTSZ" -> {"STRING"; "CHAR"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"}*/
-/*"UTSZ" -> {"SRAGG"; "FLAGG-"; "LNAGG-"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"UTSZ" -> {"UFD"; "DIVRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"UTSZ" -> {"OCAMON.o"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "RETRACT"}*/
-/*"UTSZ" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "STEP"; "QFCAT"; "FEVALAB"}*/
-/*"UTSZ" -> {"EVALAB"; "IEVALAB"; "DIFEXT"; "FLINEXP"; "PATAB"; "FPATMAB"}*/
-/*"UTSZ" -> {"TYPE"; "PFECAT"; "OM"; "PRIMCAT"}*/
-"UTSZ" -> "ACFS"
-/*"UTSZ" -> {"ACF"; "FS"; "ES"; "FRETRCT"; "GROUP"; "ILIST"; "OAMONS"}*/
-
-\end{chunk}
-\subsection{Layer19}
-Depends on: EXPRSOL SFRTCAT FACTEXT INTDIVP DTP\\
-Next layer depends on: RECOP
-\begin{chunk}{layer19}
-
-LAYER19=\
-  ${OUT}/GPAFF.o    \
-  ${OUT}/IRURPK.o   ${OUT}/LAZM3PK.o  ${OUT}/LEXTRIPK.o ${OUT}/NORMPK.o  \
-  ${OUT}/PACEXT.o   \
-  ${OUT}/RECOP.o    ${OUT}/RURPK.o    ${OUT}/SFRGCD.o   ${OUT}/SFQCMPK.o \
-  ${OUT}/SNTSCAT.o  ${OUT}/SRDCMPK.o  ${OUT}/SREGSET.o  ${OUT}/ZDSOLVE.o \
-  layer19done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 19 */
-/* EXPRSOL SFRTCAT */
-
-"GPAFF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GPAFF"]
-"GPAFF" -> "INTDIVP"
-"GPAFF" -> "DTP"
-/*"GPAFF" -> {"PRSPCAT"; "SETCATD"; "LOCPOWC"; "PLACESC"; "DIVCAT"}*/
-/*"GPAFF" -> {"INFCLCT"; "DSTRCAT"; "BLMETCT"; "PACFFC"; "PACPERC"}*/
-/*"GPAFF" -> {"PFORP"; "PLPKCRV"; "INTFRSP"; "PRJALGPK"; "PARAMP"; "LPARSPT"}*/
-/*"GPAFF" -> {"UTSZ"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"GPAFF" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"GPAFF" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"GPAFF" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"GPAFF" -> {"ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"GPAFF" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"GPAFF" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
-/*"GPAFF" -> {"PFECAT"; "DIRPCAT"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"GPAFF" -> {"ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"; "FINITE"; "ORDRING"}*/
-/*"GPAFF" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"; "VSPACE"}*/
-/*"GPAFF" -> {"UPSCAT"; "PSCAT"; "FAMONC"; "RCAGG"; "BOOLEAN"; "INT"}*/
-/*"GPAFF" -> {"LIST"; "ILIST"; "INS"; "OINTDOM"; "CFCAT"; "REAL"; "STEP"}*/
-/*"GPAFF" -> {"LSAGG"; "STAGG"; "URAGG"; "LNAGG"; "CLAGG"; "FLAGG"; "ELAGG"}*/
-/*"GPAFF" -> {"OM"; "NNI"; "LSAGG-"; "STAGG-"; "ORDFIN"; "LOGIC"; "ELAGG-"}*/
-/*"GPAFF" -> {"FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-/*"GPAFF" -> {"HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"GPAFF" -> {"PI"; "FFIELDC"; "FPC"; "MONOID-"; "ABELMON-"; "SGROUP-"}*/
-/*"GPAFF" -> {"ABELSG-"; "SINT"; "OUTFORM"}*/
-
-"IRURPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=IRURPK"]
-/*"IRURPK" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"IRURPK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"IRURPK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"IRURPK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"IRURPK" -> {"CHARZ"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"IRURPK" -> {"RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ"}*/
-/*"IRURPK" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"IRURPK" -> {"LINEXP"; "KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
-"IRURPK" -> "SFRTCAT"
-/*"IRURPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"}*/
-/*"IRURPK" -> {"TYPE"; "NNI"; "INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"IRURPK" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"IRURPK" -> {"LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"}*/
-/*"IRURPK" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "BOOLEAN"}*/
-
-"LAZM3PK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LAZM3PK"]
-/*"LAZM3PK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"LAZM3PK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"LAZM3PK" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"LAZM3PK" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"LAZM3PK" -> {"OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"LAZM3PK" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"LAZM3PK" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"LAZM3PK" -> {"PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"}*/
-/*"LAZM3PK" -> {"HOAGG"; "AGG"; "TYPE"}*/
-"LAZM3PK" -> "SFRTCAT"
-/*"LAZM3PK" -> {"INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"LAZM3PK" -> {"FLAGG-"; "BOOLEAN"}*/
-
-"LEXTRIPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=LEXTRIPK"]
-/*"LEXTRIPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"LEXTRIPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"LEXTRIPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"LEXTRIPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "ORDFIN"}*/
-/*"LEXTRIPK" -> {"ORDSET"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"LEXTRIPK" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"LEXTRIPK" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"LEXTRIPK" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"LEXTRIPK" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"LEXTRIPK" -> "IXAGG-"; "CLAGG-"; "BOOLEAN"}*/
-"LEXTRIPK" -> "SFRTCAT"
-/*"LEXTRIPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"}*/
-
-"NORMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=NORMPK"]
-/*"NORMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"NORMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"NORMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"NORMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"}*/
-/*"NORMPK" -> {"OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"}*/
-/*"NORMPK" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"NORMPK" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"NORMPK" -> {"PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"}*/
-/*"NORMPK" -> {"HOAGG"; "AGG"; "TYPE"}*/
-"NORMPK" -> "SFRTCAT"
-/*"NORMPK" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "LIST"; "INT"; "PRIMARR"}*/
-/*"NORMPK" -> {"A1AGG-"; "ISTRING"; "NNI"; "BOOLEAN"; "ILIST"}*/
-/*"NORMPK" -> {"LSAGG-"; "STAGG-"}*/
-
-"PACEXT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=PACEXT"]
-/*"PACEXT" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PACEXT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PACEXT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PACEXT" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"PACEXT" -> {"DIVRING"; "CHARZ"; "RETRACT"; "XF"; "VSPACE"; "FPC"}*/
-/*"PACEXT" -> {"CHARNZ"; "FINITE"; "PI"; "NNI"; "INT"; "LIST"; "ILIST"}*/
-/*"PACEXT" -> {"LSAGG-"; "STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"}*/
-/*"PACEXT" -> {"RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"}*/
-/*"PACEXT" -> {"ELTAGG-"; "SETCAT-"; "BASTYPE-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"PACEXT" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"PACEXT" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"PACEXT" -> {"FLAGG"; "ORDSET"; "ELAGG"; "OM"; "VECTOR"; "IVECTOR"}*/
-/*"PACEXT" -> {"IARRAY1"; "VECTCAT-"; "A1AGG-"; "UPOLYC"; "POLYCAT"}*/
-/*"PACEXT" -> {"PDRING"; "FAMR"; "AMR"; "FRETRCT"; "FLINEXP"; "LINEXP"}*/
-/*"PACEXT" -> {"PATMAB"; "PFECAT"; "DIFRING"; "DIFEXT"; "STEP"; "SYMBOL"}*/
-/*"PACEXT" -> {"REF"; "ALIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"PACEXT" -> {"PRIMARR"; "ISTRING"; "SRAGG-"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"PACEXT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "CFCAT"; "REAL"}*/
-/*"PACEXT" -> {"BOOLEAN"; "QFCAT"; "FEVALAB"; "PATAB"; "FPATMAB"; "PACPERC"}*/
-/*"PACEXT" -> {"PACRATC"; "PACRAT"}*/
-"PACEXT" -> "FACTEXT"
-
-"RECOP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RECOP"]
-"RECOP" -> "EXPRSOL"     /* by loadlib */
-/*"RECOP" -> {"UFPS"; "UTSSOL"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"RECOP" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"RECOP" -> {"ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"RECOP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "KONVERT"; "FS"}*/
-/*"RECOP" -> {"ES"; "RETRACT"; "IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"}*/
-/*"RECOP" -> {"TYPE"; "PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"RECOP" -> {"LINEXP"; "CHARZ"; "CHARNZ"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"RECOP" -> {"GCDDOM"; "UFD"; "DIVRING"; "COMBOPC"; "CFCAT"; "SYMBOL"}*/
-/*"RECOP" -> {"INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"RECOP" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"}*/
-/*"RECOP" -> {"LNAGG-"; "PI"; "NNI"; "ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"}*/
-/*"RECOP" -> {"STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"}*/
-/*"RECOP" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "ELAGG-"}*/
-/*"RECOP" -> {"URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "MONOID-"; "ABELMON-"}*/
-/*"RECOP" -> {"ORDSET-"; "SGROUP-"; "ABELSG-"; "SETCAT-"; "BASTYPE-"}*/
-/*"RECOP" -> {"UPOLYC"; "POLYCAT"; "FAMR"; "AMR"; "PFECAT"; "DIFRING"}*/
-/*"RECOP" -> {"DIFEXT"; "STEP"; "BOOLEAN"; "CACHSET"; "INS-"}*/
-
-"RURPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=RURPK"]
-/*"RURPK" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"RURPK" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"RURPK" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"RURPK" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"}*/
-/*"RURPK" -> {"SYMBOL"; "INT"; "REF"; "ALIST"; "LIST"; "STRING"; "CHAR"}*/
-/*"RURPK" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"RURPK" -> {"FLAGG-"; "LNAGG-"; "ILIST"; "LSAGG-"; "STAGG-"; "ELAGG-"}*/
-/*"RURPK" -> {"ORDFIN"; "ORDSET"; "FINITE"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"RURPK" -> {"RCAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-/*"RURPK" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"}*/
-/*"RURPK" -> {"FLAGG"; "ELAGG"; "OM"; "URAGG-"; "RCAGG-"; "IXAGG-"}*/
-/*"RURPK" -> {"CLAGG-"; "BOOLEAN"}*/
-"RURPK" -> "SFRTCAT"
-/*"RURPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"}*/
-
-"SFRGCD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SFRGCD"]
-/*"SFRGCD" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SFRGCD" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"SFRGCD" -> {"SGROUP"; "MONOID"; "LMODULE"; "BMODULE"; "RMODULE"}*/
-/*"SFRGCD" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"}*/
-/*"SFRGCD" -> {"OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"SFRGCD" -> {"AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"}*/
-/*"SFRGCD" -> {"IEVALAB"; "FLINEXP"; "LINEXP"; "KONVERT"; "PATMAB"}*/
-/*"SFRGCD" -> {"PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"}*/
-/*"SFRGCD" -> {"HOAGG"; "AGG"; "TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"SFRGCD" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"}*/
-/*"SFRGCD" -> {"BOOLEAN"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"SFRGCD" -> {"INS-"; "NNI"; "ELAGG-"; "FLAGG-"; "OM"}*/
-"SFRGCD" -> "SFRTCAT"
-
-"SFQCMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SFQCMPK"]
-/*"SFQCMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SFQCMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SFQCMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"SFQCMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
-/*"SFQCMPK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
-/*"SFQCMPK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"SFQCMPK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"SFQCMPK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"; "RSETCAT"; "TSETCAT"}*/
-/*"SFQCMPK" -> {"PSETCAT"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "INT"; "LIST"}*/
-/*"SFQCMPK" -> {"ILIST"; "LSAGG-"; "STAGG-"; "LSAGG"; "STAGG"; "URAGG"}*/
-/*"SFQCMPK" -> {"RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"}*/
-/*"SFQCMPK" -> {"ELAGG"; "OM"; "ELAGG-"; "FLAGG-"; "STRING"; "CHAR"; "SINT"}*/
-/*"SFQCMPK" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "NNI"; "BOOLEAN"}*/
-"SFQCMPK" -> "SFRTCAT"
-/*"SFQCMPK" -> {"URAGG-"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"}*/
-
-"SNTSCAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SNTSCAT"]
-"SNTSCAT" -> "SFRTCAT"
-/*"SNTSCAT" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"}*/
-/*"SNTSCAT" -> {"KOERCE"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"SNTSCAT" -> {"IEVALAB"; "KONVERT"; "NTSCAT"}*/
-
-"SRDCMPK" [color="#FF4488",href="bookvol10.4.pdf#nameddest=SRDCMPK"]
-/*"SRDCMPK" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"SRDCMPK" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"}*/
-/*"SRDCMPK" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"SRDCMPK" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "OAMONS"}*/
-/*"SRDCMPK" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RPOLCAT"; "POLYCAT"}*/
-/*"SRDCMPK" -> {"PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"}*/
-/*"SRDCMPK" -> {"RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"}*/
-/*"SRDCMPK" -> {"KONVERT"; "PATMAB"; "PFECAT"; "UFD"}*/
-"SRDCMPK" -> "SFRTCAT"
-/*"SRDCMPK" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"; "AGG"}*/
-/*"SRDCMPK" -> {"TYPE"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"SRDCMPK" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"; "INT"}*/
-/*"SRDCMPK" -> {"LIST"; "ILIST"; "LSAGG-"; "NNI"; "STAGG-"; "ELAGG-"}*/
-/*"SRDCMPK" -> {"BOOLEAN"; "STRING"; "CHAR"; "SINT"; "OUTFORM"}*/
-/*"SRDCMPK" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "FLAGG-"}*/
-
-"SREGSET" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SREGSET"]
-"SREGSET" -> "SFRTCAT"
-/*"SREGSET" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "SETCAT"; "BASTYPE"}*/
-/*"SREGSET" -> {"KOERCE"; "CLAGG"; "HOAGG"; "AGG"; "TYPE"; "EVALAB"}*/
-/*"SREGSET" -> {"IEVALAB"; "KONVERT"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"SREGSET" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"SREGSET" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"SREGSET" -> {"MODULE"; "ENTIRER"; "OAMONS"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"SREGSET" -> {"ORDSET"; "RPOLCAT"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"}*/
-/*"SREGSET" -> {"CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"; "FLINEXP"; "LINEXP"}*/
-/*"SREGSET" -> {"PATMAB"; "PFECAT"; "UFD"; "INT"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"SREGSET" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"SREGSET" -> {"IXAGG-"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"SREGSET" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "FLAGG"; "ELAGG"; "OM"}*/
-/*"SREGSET" -> {"BOOLEAN"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"SREGSET" -> {"SETCAT-"; "BASTYPE-"; "NNI"; "MONOID-"; "ABELMON-"}*/
-/*"SREGSET" -> "SGROUP-"; "ABELSG-"; "INS-"; "STRING"; "CHAR"; "SINT"}*/
-/*"SREGSET" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "FINITE"}*/
-
-"ZDSOLVE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=ZDSOLVE"]
-/*"ZDSOLVE" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"ZDSOLVE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "ABELMON"; "ABELSG"; "CABMON"}*/
-/*"ZDSOLVE" -> {"ABELGRP"; "RING"; "RNG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"ZDSOLVE" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "BMODULE"}*/
-/*"ZDSOLVE" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "CHARZ"; "REAL"}*/
-/*"ZDSOLVE" -> {"KONVERT"; "INT"; "LIST"; "ILIST"; "LSAGG-"; "STAGG-"}*/
-/*"ZDSOLVE" -> {"ELAGG-"; "FLAGG-"; "URAGG-"; "ORDFIN"; "FINITE"; "BOOLEAN"}*/
-/*"ZDSOLVE" -> {"RSETCAT"; "TSETCAT"; "PSETCAT"; "CLAGG"; "HOAGG"}*/
-/*"ZDSOLVE" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"}*/
-"ZDSOLVE" -> "SFRTCAT"
-/*"ZDSOLVE" -> {"QFCAT"; "FIELD"; "UFD"; "DIVRING"; "RETRACT"; "FEVALAB"}*/
-/*"ZDSOLVE" -> {"ELTAB"; "DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"ZDSOLVE" -> {"PATAB"; "FPATMAB"; "PATMAB"; "STEP"; "OINTDOM"; "CHARNZ"}*/
-/*"ZDSOLVE" -> {"PFECAT"; "RCFIELD"; "FRETRCT"; "RADCAT"; "LSAGG"; "STAGG"}*/
-/*"ZDSOLVE" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "FLAGG"}*/
-/*"ZDSOLVE" -> {"ELAGG"; "OM"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"*/
-
-\end{chunk}
-\subsection{Layer20}
-Depends on: RECOP
-Next layer depends on: GUESS
-\begin{chunk}{layer20}
-
-LAYER20=\
-  ${OUT}/GUESS.o ${OUT}/INFCLSPT.o \
-  layer20done
-    
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 20 */
-
-"GUESS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESS"]
-/*"GUESS" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/ 
-/*"GUESS" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"}*/ 
-"GUESS" -> "RECOP"  /* by loadlib */
-/*"GUESS" -> {"UFPS1"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"}*/
-/*"GUESS" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"}*/
-/*"GUESS" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"GUESS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"GUESS" -> {"ENTIRER"; "UFD"; "DIVRING"; "FS"; "ES"; "ORDSET"; "RETRACT"}*/
-/*"GUESS" -> {"IEVALAB"; "EVALAB"; "PATAB"; "KONVERT"; "FPATMAB"; "TYPE"}*/
-/*"GUESS" -> {"PATMAB"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"; "LINEXP"}*/
-/*"GUESS" -> {"CHARZ"; "CHARNZ"; "COMBOPC"; "CFCAT"; "LSAGG"; "STAGG"}*/
-/*"GUESS" -> {"URAGG"; "RCAGG"; "HOAGG"; "AGG"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"GUESS" -> {"ELTAB"; "CLAGG"; "FLAGG"; "ELAGG"; "OM"; "INT"; "LIST"}*/
-/*"GUESS" -> {"ILIST"; "PI"; "NNI"; "LSAGG-"; "STAGG-"; "SINT"; "INS-"}*/
-/*"GUESS" -> {"EUCDOM-"; "UFD-"; "GCDDOM-"; "INTDOM-"; "ALGEBRA-"}*/
-/*"GUESS" -> {"DIFRING-"; "ORDRING-"; "MODULE-"; "RING-"; "ABELGRP-"}*/
-/*"GUESS" -> {"ABELMON-"; "QFCAT"; "FEVALAB"; "DIFEXT"; "DIFRING"; "STEP"}*/
-/*"GUESS" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"GUESS" -> {"REAL"; "PFECAT"; "ORDFIN"; "FINITE"; "POLYCAT"; "FAMR"}*/
-/*"GUESS" -> {"AMR"; "UPOLYC"; "STRING"; "CHAR"; "OUTFORM"; "PRIMARR"}*/
-/*"GUESS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"}*/
-/*"GUESS" -> {"UTSCAT"; "UPSCAT"; "PSCAT"; "RADCAT"; "TRANFUN"; "TRIGCAT"}*/
-/*"GUESS" -> {"ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "INS"; "VECTOR"}*/
-/*"GUESS" -> {"BOOLEAN"; "SYMBOL"; "REF"; "ALIST"; "LNAGG-"; "MONOID-"}*/
-/*"GUESS" -> {"ORDSET-"; "ABELSG-"; "SGROUP-"; "SETCAT-"; "RETRACT-"}*/
-/*"GUESS" -> {"BASTYPE-"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "IXAGG-"}*/
-/*"GUESS" -> {"RCAGG-"; "CLAGG-"}*/
-
-"INFCLSPT" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INFCLSPT"]
-"INFCLSPT" -> "INFCLCT"
-/*"INFCLSPT" -> {"SETCATD"; "AFFPL"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
-/*"INFCLSPT" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"INFCLSPT" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"}*/
-/*"INFCLSPT" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"INFCLSPT" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "POLYCAT"; "PDRING"}*/
-/*"INFCLSPT" -> {"FAMR"; "AMR"; "CHARZ"; "CHARNZ"; "FRETRCT"; "RETRACT"}*/
-/*"INFCLSPT" -> {"EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"; "ORDSET"}*/
-/*"INFCLSPT" -> {"KONVERT"; "PATMAB"; "PFECAT"; "DIRPCAT"; "IXAGG"; "HOAGG"}*/
-/*"INFCLSPT" -> {"AGG"; "TYPE"; "ELTAGG"; "ELTAB"; "DIFEXT"; "DIFRING"}*/
-/*"INFCLSPT" -> {"FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"INFCLSPT" -> {"OAMONS"; "VSPACE"; "PRSPCAT"; "LOCPOWC"; "UPSCAT"; "PSCAT"}*/
-/*"INFCLSPT" -> {"PLACESC"; "DIVCAT"; "FAMONC"; "BLMETCT"; "SINT"; "NNI"}*/
-/*"INFCLSPT" -> {"INT"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "LNAGG"}*/
-/*"INFCLSPT" -> {"CLAGG"; "FLAGG"; "ELAGG"; "OM"; "LIST"; "ILIST"; "LSAGG-"}*/
-/*"INFCLSPT" -> {"STAGG-"; "ELAGG-"; "FLAGG-"; "URAGG-"; "LNAGG-"; "RCAGG-"}*/
-/*"INFCLSPT" -> {"IXAGG-"; "CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
-/*"INFCLSPT" -> {"SETCAT-"; "BASTYPE-"; "BOOLEAN"; "VECTOR"; "PACPERC"; "PI"}*/
-/*"INFCLSPT" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
-/*"INFCLSPT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-
-\end{chunk}
-\subsection{Layer21}
-Depends on: GUESS
-Next layer depends on: GUESSF1 INFCLSPT 
-\begin{chunk}{layer21}
-
-LAYER21=\
-  ${OUT}/GUESSAN.o  ${OUT}/GUESSINT.o ${OUT}/GUESSF1.o  ${OUT}/GUESSP.o \
-  ${OUT}/GUESSUP.o  ${OUT}/ICP.o      \
-  layer21done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 21 */
-/* GUESS */
-
-"GUESSAN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSAN"]
-/*"GUESSAN" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/
-/*"GUESSAN" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
-"GUESSAN" -> "GUESS" /* by loadlib */
-/*"GUESSAN" -> {"ES"; "ORDSET"; "SETCAT"; "BASTYPE"; "KOERCE"; "RETRACT"}*/
-/*"GUESSAN" -> {"IEVALAB"; "EVALAB"; "ACF"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"GUESSAN" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"GUESSAN" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"GUESSAN" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"GUESSAN" -> {"DIVRING"; "RADCAT"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"}*/
-/*"GUESSAN" -> {"OCAMON"; "OAMON"; "OASGP"; "DIFRING"; "KONVERT"; "LINEXP"}*/
-/*"GUESSAN" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "FS"; "PATAB"}*/
-/*"GUESSAN" -> {"FPATMAB"; "TYPE"; "FRETRCT"; "GROUP"; "PDRING"; "FLINEXP"}*/
-/*"GUESSAN" -> {"CHARNZ"; "OM"}*/
-
-"GUESSINT" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSINT"]
-/*"GUESSINT" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/ 
-/*"GUESSINT" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
-"GUESSINT" -> "GUESS" /* by loadlib */
-/*"GUESSINT" -> {"INS"; "INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"GUESSINT" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"GUESSINT" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
-/*"GUESSINT" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"GUESSINT" -> {"ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"}*/
-/*"GUESSINT" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"}*/
-/*"GUESSINT" -> {"DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"GUESSINT" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "QFCAT"; "FIELD"}*/
-/*"GUESSINT" -> {"DIVRING"; "FEVALAB"; "ELTAB"; "EVALAB"; "IEVALAB"}*/
-/*"GUESSINT" -> {"DIFEXT"; "PDRING"; "FLINEXP"; "PATAB"; "FPATMAB"; "TYPE"}*/
-/*"GUESSINT" -> {"CHARNZ"; "PFECAT"; "FS"; "ES"; "FRETRCT"; "GROUP"; "OM"}*/
-
-"GUESSF1" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSF1"]
-/*"GUESSF1" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"}*/ 
-/*"GUESSF1" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
-"GUESSF1" -> "GUESS" /* by loadlib */
-/*"GUESSF1" -> {"FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"}*/
-/*"GUESSF1" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
-/*"GUESSF1" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
-/*"GUESSF1" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"}*/
-/*"GUESSF1" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"}*/
-/*"GUESSF1" -> {"STEP"; "DIFRING"; "KONVERT"; "INS"; "OINTDOM"; "ORDRING"}*/
-/*"GUESSF1" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "RETRACT"}*/
-/*"GUESSF1" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"}*/
-
-"GUESSP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSP"]
-/*"GUESSP" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"} */ 
-/*"GUESSP" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"}*/
-"GUESSP" -> "GUESS" /* by loadlib */
-/*"GUESSP" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
-/*"GUESSP" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
-/*"GUESSP" -> {"BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"}*/
-/*"GUESSP" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "EUCDOM"; "PID"}*/
-/*"GUESSP" -> {"OINTDOM"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"}*/
-/*"GUESSP" -> {"ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"}*/
-/*"GUESSP" -> {"CFCAT"; "REAL"; "CHARZ"; "STEP"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"GUESSP" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"GUESSP" -> {"PFECAT"; "QFCAT"; "FIELD"; "DIVRING"; "FEVALAB"; "ELTAB"}*/
-/*"GUESSP" -> {"DIFEXT"; "PATAB"; "FPATMAB"; "TYPE"; "FS"; "ES"}*/
-/*"GUESSP" -> {"GROUP"; "OM"}*/
-
-"GUESSUP" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSUP"]
-/*"GUESSUP" -> {"NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR"; "UTSSOL"} */  
-/*"GUESSUP" -> {"EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1"} */ 
-"GUESSUP" -> "GUESS" 
-/*"GUESSUP" -> {"MYEXPR"; "MYUP"; "INS"; "UFD"; "GCDDOM"; "INTDOM"} */
-/*"GUESSUP" -> {"COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"} */
-/*"GUESSUP" -> {"ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"} */
-/*"GUESSUP" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"} */
-/*"GUESSUP" -> {"MODULE"; "ENTIRER"; "EUCDOM"; "PID"; "OINTDOM"; "ORDRING"} */
-/*"GUESSUP" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "DIFRING"} */
-/*"GUESSUP" -> {"KONVERT"; "RETRACT"; "LINEXP"; "PATMAB"; "CFCAT"; "REAL"}*/
-/*"GUESSUP" -> {"CHARZ"; "STEP"; "UPOLYC"; "POLYCAT"; "PDRING"; "FAMR"}*/
-/*"GUESSUP" -> {"AMR"; "CHARNZ"; "FRETRCT"; "EVALAB"; "IEVALAB"; "FLINEXP"}*/
-/*"GUESSUP" -> {"PFECAT"; "ELTAB"; "DIFEXT"; "FIELD"; "DIVRING"; "QFCAT"}*/
-/*"GUESSUP" -> {"FEVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "FS"; "ES"}*/
-/*"GUESSUP" -> {"GROUP"; "COMBOPC"}*/
-
-"ICP" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ICP"]
-/*"ICP" -> {"DIVCAT"; "PROJPL"; "NSDPS"; "DIV"}*/
-"ICP" -> "PLACES"
-"ICP" -> "INFCLSPT"
-/*"ICP" -> {"INFCLCT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"; "FIELD"}*/
-/*"ICP" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"}*/
-/*"ICP" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"ICP" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"}*/
-/*"ICP" -> {"UFD"; "DIVRING"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
-/*"ICP" -> {"AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"}*/
-/*"ICP" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ORDSET"; "ELAGG"; "OM"}*/
-/*"ICP" -> {"INT"; "LIST"; "ILIST"; "DIRPCAT"; "FRETRCT"; "RETRACT"}*/
-/*"ICP" -> {"DIFEXT"; "DIFRING"; "PDRING"; "FLINEXP"; "LINEXP"; "FINITE"}*/
-/*"ICP" -> {"ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "OAMONS"}*/
-/*"ICP" -> {"VSPACE"; "PLACESC"; "BLMETCT"; "SYMBOL"; "REF"; "ALIST"}*/
-/*"ICP" -> {"STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"}*/
-/*"ICP" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"}*/
-/*"ICP" -> {"ELAGG-"; "URAGG-"}*/
-
-\end{chunk}
-\subsection{Layer22}
-Depends on: GUESSF1
-\begin{chunk}{layer22}
-
-LAYER22=\
-  ${OUT}/GUESSF.o ${OUT}/INFCLSPS.o  \
-  layer22done
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 22 */
-/* GUESSF */
-
-"GUESSF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESSF"]
-/*"GUESSF" -> { "NEWTON"; "FAMR2"; "FFFG"; "FFFGF"; "SUPEXPR" ; "UTSSOL" } */
-/*"GUESSF" -> { "EXPRSOL"; "GOPT"; "GOPT0"; "UFPS"; "RECOP"; "UFPS1" } */
-/*"GUESSF" -> "GUESS"*/ /* by loadlib */
-"GUESSF" -> "GUESSF1" /* by loadlib */
-/*"GUESSF" -> { "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM" } */
-/*"GUESSF" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"} */
-/*"GUESSF" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"} */
-/*"GUESSF" -> {"MONOID"; "LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"} */
-/*"GUESSF" -> {"MODULE"; "ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"} */
-/*"GUESSF" -> {"STEP"; "DIFRING"; "INS"; "OINTDOM"; "ORDRING"; "OAGROUP"} */
-/*"GUESSF" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "KONVERT"; "RETRACT"} */
-/*"GUESSF" -> {"LINEXP"; "PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "FS"; "ES" } */
-/*"GUESSF" -> {"IEVALAB"; "EVALAB"; "PATAB"; "FPATMAB"; "TYPE"; "FRETRCT"} */
-/*"GUESSF" -> {"GROUP"; "PDRING"; "FLINEXP"} */
-
-"INFCLSPS" [color="#88FF44",href="bookvol10.3.pdf#nameddest=INFCLSPS"]
-"INFCLSPS" -> "PROJPLPS"
-/*"INFCLSPS" -> {"PACOFF"; "NSDPS"; "PLACESPS"; "DIV"; "DIVCAT"; "INFCLCT"}*/
-/*"INFCLSPS" -> {"INFCLSPT"; "SETCATD"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
-/*"INFCLSPS" -> {"PACFFC"; "FFIELDC"; "FPC"; "FIELD"; "EUCDOM"; "PID"}*/
-/*"INFCLSPS" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"}*/
-/*"INFCLSPS" -> {"CABMON"; "ABELMON"; "ABELSG"; "SGROUP"; "MONOID"}*/
-/*"INFCLSPS" -> {"LMODULE"; "BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"}*/
-/*"INFCLSPS" -> {"ENTIRER"; "UFD"; "DIVRING"; "CHARNZ"; "FINITE"; "STEP"}*/
-/*"INFCLSPS" -> {"DIFRING"; "PACPERC"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
-/*"INFCLSPS" -> {"HOAGG"; "AGG"; "TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"}*/
-/*"INFCLSPS" -> {"IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"}*/
-/*"INFCLSPS" -> {"ORDSET"; "ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "DIRPCAT"}*/
-/*"INFCLSPS" -> {"FRETRCT"; "RETRACT"; "DIFEXT"; "PDRING"; "FLINEXP"}*/
-/*"INFCLSPS" -> {"LINEXP"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"INFCLSPS" -> {"OASGP"; "OAMONS"; "VSPACE"; "PLACESC"; "BLMETCT"}*/
-/*"INFCLSPS" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "SINT"}*/
-/*"INFCLSPS" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
-/*"INFCLSPS" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
-
-\end{chunk}
-\subsection{Layer23}
-Depends on: INFCLSPS
-
-Note that PAFF and PAFFFF form clique2.spad. Each one depends on the other.
-\begin{chunk}{layer23}
-
-LAYER23=\
-  ${MID}/clique2.spad \
-  layer23done
-
-\end{chunk}
-\begin{chunk}{layerpic}
-/* layer 23 */
-
-"PAFF" -> "PAFFFF"
-"PAFF" -> "INFCLSPS"
-/*"PAFF" -> {"BLMETCT"; "GPAFF"; "PFORP"; "PACOFF"; "PROJPLPS"; "PLACESPS"}*/
-/*"PAFF" -> {"NSDPS"; "LOCPOWC"; "DIV"; "SETCATD"; "PLACESC"; "DIVCAT"}*/
-/*"PAFF" -> {"INFCLCT"; "DSTREE"; "DSTRCAT"; "PRSPCAT"; "UTSZ"; "PACFFC"}*/
-/*"PAFF" -> {"PACPERC"; "PROJPL"; "PLACES"; "INFCLSPT"; "PROJPL"; "ICP"}*/
-/*"PAFF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PAFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PAFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PAFF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"PAFF" -> {"DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"PAFF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PAFF" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"PAFF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PAFF" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"PAFF" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "DIRPCAT"; "DIFEXT"}*/
-/*"PAFF" -> {"DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PAFF" -> {"OASGP"; "OAMONS"; "VSPACE"; "INS"; "OINTDOM"; "CFCAT"; "REAL"}*/
-/*"PAFF" -> {"STEP"; "PI"; "NNI"; "BOOLEAN"}*/
-
-"PAFFFF" -> "PAFF"
-"PAFF" -> "INFCLSPS"
-/*"PAFF" -> {"BLMETCT"; "GPAFF"; "PFORP"; "PACOFF"; "PROJPLPS"; "PLACESPS"}*/
-/*"PAFF" -> {"NSDPS"; "LOCPOWC"; "DIV"; "SETCATD"; "PLACESC"; "DIVCAT"}*/
-/*"PAFF" -> {"INFCLCT"; "DSTREE"; "DSTRCAT"; "PRSPCAT"; "UTSZ"; "PACFFC"}*/
-/*"PAFF" -> {"PACPERC"; "PROJPL"; "PLACES"; "INFCLSPT"; "PROJPL"; "ICP"}*/
-/*"PAFF" -> {"FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"}*/
-/*"PAFF" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
-/*"PAFF" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"; "LMODULE"}*/
-/*"PAFF" -> {"BMODULE"; "RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "UFD"}*/
-/*"PAFF" -> {"DIVRING"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"}*/
-/*"PAFF" -> {"CHARNZ"; "FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"}*/
-/*"PAFF" -> {"FLINEXP"; "LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"; "PFECAT"}*/
-/*"PAFF" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG"; "TYPE"}*/
-/*"PAFF" -> {"LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"; "CLAGG"; "FLAGG"}*/
-/*"PAFF" -> {"ELAGG"; "OM"; "INT"; "LIST"; "ILIST"; "DIRPCAT"; "DIFEXT"}*/
-/*"PAFF" -> {"DIFRING"; "FINITE"; "ORDRING"; "OAGROUP"; "OCAMON"; "OAMON"}*/
-/*"PAFF" -> {"OASGP"; "OAMONS"; "VSPACE"; "INS"; "OINTDOM"; "CFCAT"; "REAL"}*/
-/*"PAFF" -> {"STEP"; "PI"; "NNI"; "BOOLEAN"}*/
-
-\end{chunk}
-\subsection{Order}
-The final order of the layers is determined here. The GUESS package
-is broken so we remove the layers involved until this can be resolved.
-\begin{chunk}{order}
-ORDER=\
-  ${LAYER0BOOTSTRAP}     ${LAYER0}  ${LAYER1}  ${LAYER2}  ${LAYER3}  \
-  ${LAYER4}   ${LAYER5}  ${LAYER6}  ${LAYER7}  ${LAYER8}  ${LAYER9}  \
-  ${LAYER10}  ${LAYER11} ${LAYER12} ${LAYER13} ${LAYER14} ${LAYER15} \
-  ${LAYER16}  ${LAYER17} ${LAYER18} ${LAYER19} ${LAYER20} ${LAYER21} \
-  ${LAYER22}  ${LAYER23} ${LAYER0COPY}
-\end{chunk}
-
-\begin{verbatim}
-ORDER=\
-  ${LAYER0BOOTSTRAP}     ${LAYER0}  ${LAYER1}  ${LAYER2}  ${LAYER3}  \
-  ${LAYER4}   ${LAYER5}  ${LAYER6}  ${LAYER7}  ${LAYER8}  ${LAYER9}  \
-  ${LAYER10}  ${LAYER11} ${LAYER12} ${LAYER13} ${LAYER14} ${LAYER15} \
-  ${LAYER16}  ${LAYER17} ${LAYER18} ${LAYER19} ${LAYER0COPY}
-
-\end{verbatim}
-\section{Cliques}
-The algebra code sometimes have circular references. The compiler can
-resolve these references directly if all of the required sources
-are in the same source file.
-
-So the idea to remove the BOOTSTRAP code is to cluster the spad
-sources into "cliqueN.spad" files and feed them all to the compiler
-at once.
-\begin{chunk}{newcode}
-CLIQUE1FILES = ${OUT}/MYUP.o  ${OUT}/MYEXPR.o
-
-${MID}/clique1.spad: ${CLIQUE1FILES}
-	@echo sa01 making ${OUT}/MYUP.o from ${MID}/clique1.spad
-	@echo sa02 making ${OUT}/MYEXPR.o from ${MID}/clique1.spad
-	@ (cd ${MID} ; \
-	   cat ${IN}/MYUP.spad >clique1.spad ; \
-	   cat ${IN}/MYEXPR.spad >>clique1.spad ; \
-	   if [ -z "${NOISE}" ] ; then \
-	    echo ")co clique1.spad" | ${INTERPSYS}  ; \
-           else \
-	    echo ")co clique1.spad" | ${INTERPSYS} >${TMP}/trace ; \
-	   fi )
-	@ cp ${MID}/MYUP.nrlib/code.o ${OUT}/MYUP.o
-	@ cp ${MID}/MYEXPR.nrlib/code.o ${OUT}/MYEXPR.o
-	
-\end{chunk}
-Here we have the general case where two files are co-dependent, that is,
-PAFF and PAFFFF both have to be compiled together. They also have a set
-of prerequired files that must be loaded since they are not yet in the
-new database.
-\begin{chunk}{newcode}
-CLIQUE2FILES = ${OUT}/PAFF.o ${OUT}/PAFFFF.o
-CLIQUE2DEPS  = BLMETCT GPAFF PFORP PACOFF PROJPLPS PLACESPS NSDPS LOCPOWC \
-               DIV SETCATD PLACESC DIVCAT INFCLSPS INFCLCT DSTREE DSTRCAT \
-               PRSPCAT UTSZ PACFFC PACPERC PROJPL PLACES INFCLSPT PROJPL ICP
-
-${MID}/clique2.spad: ${CLIQUE2FILES}
-	@echo sa03 making ${OUT}/PAFF.o from ${MID}/clique2.spad
-	@echo sa04 making ${OUT}/PAFFFF.o from ${MID}/clique2.spad
-	@ (cd ${MID} ; \
-	   cat ${IN}/PAFF.spad >clique2.spad ; \
-	   cat ${IN}/PAFFFF.spad >>clique2.spad ; \
-	   if [ -z "${NOISE}" ] ; then \
-	    echo -e ")lib ${CLIQUE2DEPS} \n )co clique2.spad" \
-              | ${INTERPSYS} ; \
-           else \
-	    echo -e ")lib ${CLIQUE2DEPS} \n )co clique2.spad" \
-	      | ${INTERPSYS} >${TMP}/trace ; \
-	    echo ")co clique2.spad" | ${INTERPSYS} >${TMP}/trace ; \
-	   fi )
-	@ cp ${MID}/PAFF.nrlib/code.o ${OUT}/PAFF.o
-	@ cp ${MID}/PAFFFF.nrlib/code.o ${OUT}/PAFFFF.o
-	
-\end{chunk}
-\begin{chunk}{ignore}
-EXPRDEPS  = LF
-
-${MID}/EXPR.nrlib/code.o: ${MID}/EXPR.spad
-	@echo sa05 newcode EXPR.o depends on LF.o
-	@ ( cd ${MID} ; \
-            echo -e ")lib ${EXPRDEPS} \n )co EXPR.spad" | ${INTERPSYS} )
-	@ cp ${MID}/EXPR.nrlib/code.o ${OUT}/EXPR.o
-	
-\end{chunk}
-\section{Broken Files}
-These files are Aldor files
-\begin{verbatim}
-axtimer.as Timer
-iviews.as  InventorRenderPackage IVREND
-ffrac.as   FormalFraction FORMAL
-iviews.as  InventorViewPort IVVIEW
-iviews.as  InventorDataSink IVDATA
-herm.as    PackedHermitianSequence PACKED
-nsfip.as   NagSpecialFunctionsInterfacePackage NAGSPE
-nrc.as     NagResultChecks NAGRES
-nqip.as    NagQuadratureInterfacePackage NAGQUA
-noptip.as  NagOptimizationInterfacePackage NAGOPT
-nepip.as   NagEigenInterfacePackage NAGEIG
-ndftip.as  NagDiscreteFourierTransformInterfacePackage NAGDIS
-\end{verbatim}
-
-These domains are referenced but don't exist
-\begin{verbatim}
-OBJECT
-\end{verbatim}
-
-\section{The Environment}
-\subsection{The working directories}
-We define 5 directories for this build. The{\bf IN} directory
-contains the pamphlet files for the algebra. These are expanded
-into the{\bf MID} directory as either .spad or .as files. The
-.spad files are compiled by the native spad internal compiler.
-The .as files are compiled using the Aldor compiler. The output
-of the compilation has two purposes. Part of the information is
-used to build various database files (daase files). The other
-part is executable code which is placed in the {\bf OUT}
-directory. When invoked as ``make document'' we construct
-the .dvi files in the{\bf DOC} directory.
-
-The \verb|OUTSRC=${MNT}/${SYS}/src/algebra| subdirectory contains the 
-algebra source files extracted from the pamphlet files. These sources 
-allow the end user to change the algebra if needed.
-
-\begin{chunk}{environment}
-
-IN=${SRC}/algebra
-MID=${INT}/algebra
-OUT=${MNT}/${SYS}/algebra
-DOC=${MNT}/${SYS}/doc/src/algebra
-OUTSRC=${MNT}/${SYS}/src/algebra
-INPUT=${INT}/input
-LISP=${OBJ}/${SYS}/bin/lisp
-LISPTANGLE=${OBJ}/${SYS}/bin/lisp
-BOOKSRC=${SPD}/books/bookvol5.pamphlet
-
-\end{chunk}
-\subsection{The depsys variable}
-The {\bf depsys} image is the compile-time environment for boot and lisp
-files.
-
-\begin{chunk}{environment}
-
-DEPSYS=${OBJ}/${SYS}/bin/depsys
-
-\end{chunk}
-\subsection{The interpsys variable}
-The {\bf interpsys} image is the compile-time environment for algebra
-files.
-
-\begin{chunk}{environment}
-
-INTERPSYS=${OBJ}/${SYS}/bin/interpsys
-
-\end{chunk}
-\subsection{The shell variable}
-We use the ``-e'' flag to echo which is not supported by the ``sh''
-shell but is supported by ``bash''. The ``-e'' flag to echo causes
-it to interpret special characters, in our case newlines.
-
-\begin{chunk}{environment}
-
-SHELL=bash
-
-\end{chunk}
-\section{The Makefile Stanzas}
-A spad pamphlet can contain many Axiom categories, domains, and
-packages. 
-
-For the purpose of explanation we assume that the pamphlet file is 
-named foo.spad.pamphlet. It contains the domains BAR, BAX,
-and BAZ. Thus there will be a subsection named foo.spad.
-
-Since pamphlet files (e.g. foo.spad.pamphlet contain a spad file
-e.g. foo.spad, it follows that every subsection contains a Makefile
-stanza that extract the foo.spad file using notangle.
-
-Since pamphlet files are intended as documents it follows that each
-subsection contains a Makefile stanza that extracts a dvi file
-using noweave.
-
-We could have a category, domain, or package that is in
-the ``bootstrap'' list. Bootstrap spad files contain their generated
-lisp code in special sections. The way bootstrapping works is that
-we extract the lisp code and compile it rather than extracting the
-spad code. We do this because we need the domain to exist before we
-can compile the domain. Some domains depend on themselves directly.
-Some domains depend on themselves thru a long chain of other domains.
-In either case we can't compile the domain until it exists so we
-cache the generated lisp code and, when we need to bootstrap the
-domain, we compile the raw lisp rather than the spad.
-
-This will only happen when the system is built from scratch. Once
-the system has been built the bootstrap code is no longer executed
-and these algebra files will appear as normal algebra files. That
-means that once the system has been built once only the last three
-rules will ever be executed. The first two rules happen when the
-system is built from scratch.
-
-A 5 stanza group for this case performs the following functions:
-\begin{enumerate}
-\item extract the lisp BAR.lsp from the pamphlet foo.spad.pamphlet
-\item compile and copy the bootstrap lisp to the final algebra directory
-\item extract the bootstrap BAR.lsp from the spad file foo.spad
-\item compile the extracted BAR domain
-\item copy the compiled BAR to the final algebra directory
-\end{enumerate}
-
-The subtle point here occurs in the first item. The bootstrap code
-group (in the layer0 bootstrap code chunk above) asks for the
-compiled ``.o'' files in the \verb|\${MID}| directory. Essentially this
-code group calls for intermediate compiled files. This triggers the
-bootstrap stanzas (items 1 and 2 above). All of the other layer 
-chunks ask for compiled code in the \verb|\${OUT}| directory which is
-the final algebra directory. 
-
-The bootstrap process works because first we ask for the compiled
-lisp code stanzas (the \verb|\${MID}/BAR.o| files), THEN we ask for
-the final algebra code stanzas (the \verb|\${OUT}/BAR.o| files). This
-is a very subtle point so think it through carefully. The layer0
-bootstrap list is the only file list that calls for \verb|\${MID}| files.
-All other layers ask for \verb|\${OUT}| files. Make sure you
-understand this before you change things. If you break it the
-world will no longer compile.
-
-So we have a 3 stanza group for normal files, a 3+2 (5) stanza
-group for normal files with default code, and a 3+2 (5) stanza
-group for normal files that need to be bootstrapped. There is
-another combination that occurs, namely bootstrap code that
-also contains default code which gives a 3+2+2+2 (9) stanza case.
-(see TSETCAT for an example. Be sure to read the items in reverse order).
-
-A 9 stanza group for this case performs the following functions:
-\begin{enumerate}
-\item extract the bootstrap BAR.lsp from the foo.spad.pamphlet
-\item compile the bootstrap BAR.lsp and copy to the intermediate directory
-\item extract the bootstrap BAR-.lsp from the foo.spad.pamphlet
-\item compile the bootstrap BAR-.lsp and copy to intermediate directory
-\item extract the spad BAR.spad from the pamphlet foo.spad.pamphlet
-\item compile the extracted BAR.spad domain (to get BAR.o)
-\item copy the BAR.o to the final algebra directory
-\item compile the extracted BAR.spad domain (to get BAR-.o)
-\item copy the BAR-.o to the final algebra directory
-\end{enumerate}
-
-As you can see this is just the combination of the two possible 5
-stanza case. We just have to deal with the BAR- both in regular
-and bootstrap files. The first four stanzas will only happen when
-the system is built from scratch. Once the system is built these
-four rules no longer apply and these stanzas effectively act like
-the 5 stanza rules above.
-
-I'm sure all of this seems confusing but it is very stylized code.
-Basically you need to figure out which kind of stanza group you need,
-copy an existing stanza group, and do a correct renaming of the parts.
-The decision tree looks something like:
-\begin{verbatim}
-IF (you have a regular spad domain)
- THEN use a 3 stanza form (see YSTREAM)
-IF (you have a default spad domain (it generates ``-'' files)) AND
-   (it does not require bootstrapping)
- THEN use the first 5 stanza form explained above (see LIECAT)
-IF (you have a normal spad domain) AND
-   (it requires bootstrapping)
- THEN use the second 5 stanza form explained above (see VECTOR)
-IF (you have a default spad domain (it generates ``-'' files)) AND
-   (it requires bootstrapping)
- THEN use the 9 stanza form explained above (see TSETCAT)
-\end{verbatim}
-
-\section{Generic Make Rules}
-The idea is to use generic rules to try to cut down the size of this file.
-
-This Makefile works very hard to cache
-intermediate results in order to minimize the re-build time. The cached
-files are kept in the int or obj directories. If one of these
-files disappears but the original pamphlet file is unchanged we only
-need to rebuild the intermediate file. These rule will attempt to do
-that and they succeed however these are intermediate files created by
-implicit rules so they would normally be deleted. To prevent the removal
-the nrlib directory and its contents, the files are marked as .PRECIOUS.
-
-The output of the compile step is saved in a file of the same name
-and extension .out in the \${MID} directory. These files are useful for
-deriving the dependencies by scanning the ``Loading ...'' messages.
-
-\begin{chunk}{genericDotOfiles}
-
-${OUT}/%.o: ${MID}/%.nrlib/code.o
-	@ echo sa06 copying $*.nrlib to $*.o
-	@ cp ${MID}/$*.nrlib/code.o ${OUT}/$*.o
-
-\end{chunk}
-\begin{chunk}{genericnrlibfiles}
-
-.PRECIOUS: ${MID}/%.nrlib/code.o
-${MID}/%.nrlib/code.o: ${MID}/%.spad
-	@ echo sa07 compiling $*.spad to $*.nrlib
-	@ if [ -z "${NOISE}" ] ; then \
-	   (cd ${MID} ; \
-	    echo ")co $*.spad" | ${INTERPSYS} ) ; \
-           else \
-	   (cd ${MID} ; \
-	     echo ")co $*.spad" | ${INTERPSYS} ) 1>/dev/null 2>/dev/null ; \
-	   fi 
-
-\end{chunk}
-\begin{chunk}{genericBOOTSTRAPfiles}
-
-${MID}/%.o: ${MID}/%.lsp
-	@ echo sa08 compiling $*.lsp to $*.o
-	@ (cd ${MID} ; \
-	  if [ -z "${NOISE}" ] ; then \
-	   echo '(progn (in-package (quote boot)) (compile-file "$*.lsp" :output-file "$*.o"))'\
-            | ${DEPSYS} ; \
-	  else \
-	   echo '(progn (in-package (quote boot)) (compile-file "$*.lsp" :output-file "$*.o"))'\
-           | ${DEPSYS} 1>/dev/null 2>/dev/null ; \
-	  fi )
-	@ cp ${MID}/$*.o ${OUT}/$*.o
-
-\end{chunk}
-\begin{chunk}{genericSPADfiles}
-
-${OUTSRC}/%.spad: ${IN}/%.pamphlet
-	@ echo sa09tangling $*.pamphlet to $*.spad
-	@(cd ${OUTSRC} ; \
-	 ${TANGLE} ${IN}/$*.pamphlet >$*.spad )
-
-\end{chunk}
-\begin{chunk}{genericDOCfiles}
-
-${DOC}/%.dvi: ${IN}/%.pamphlet ${DOC}/ps
-	@ echo sa10 latexing $*.pamphlet to ${DOC}/$*.dvi
-	@ (cd ${DOC} ; \
-	cp ${IN}/$*.pamphlet ${DOC} ; \
-	${DOCUMENT} ${NOISE} $* ; \
-	rm -f ${DOC}/$*.pamphlet ; \
-	rm -f ${DOC}/$*.tex ; \
-	rm -f ${DOC}/$* )
-
-\end{chunk}
-\begin{chunk}{genericRules}
-
-\getchunk{genericDotOfiles}
-\getchunk{genericnrlibfiles}
-\getchunk{genericBOOTSTRAPfiles}
-\getchunk{genericSPADfiles}
-\getchunk{genericDOCfiles}
-
-\end{chunk}
-
-\begin{chunk}{libdb.text (OUT from IN)}
-${OUT}/libdb.text: ${IN}/libdb.text
-	@ echo sa11 copying ${IN}/libdb.text to ${OUT}/libdb.text
-	@ cp ${IN}/libdb.text ${OUT}/libdb.text
-
-\end{chunk}
-\begin{chunk}{ps (DOC from SRC)}
-${DOC}/ps: ${SRC}/doc/ps
-	@echo sa12 making ${DOC}/ps from ${SRC}/doc/ps
-	@cp -pr ${SRC}/doc/ps ${DOC}
-
-\end{chunk}
-
-\section{Pamphlet file structure}
-Because the individual .spad files are grouped into higher-level
-algebra pamphlet files, the rules for extracting them are coded
-below as simple ``awk'' scripts that are called when the Makefile
-is constructed.
-
-\begin{chunk}{findAlgebraFiles}
-
-\getchunk{findSpadFiles}
-\getchunk{findBootstrapFiles}
-\end{chunk}
-
-There are, at present, 2 kinds of algebra files to be handled.
-
-There are the bootstrap files. These files live within
-their respective pamphlet files and are "captured" lisp code.
-These are necessary to create the algebra. See the 
-src/algebra/Makefile.pamphlet for details.
-
-Second, there are 3 ``types'' of algebra which are all treated 
-the same at compile time, namely the ``domain'', ``category'', and
-``package'' algebra.
-
-\subsection{Finding the algebra code}
-Step 1 is to scan all of the algebra pamphlet files for the
-chunk names which contain the string "domain", "package", or
-"category". This is done using grep -E (same as egrep, which
-means that the pattern is an extended regular expression) because
-extended regular expressions allows the use of alternatives
-written as (domain|package|category). Thus the command
-\begin{verbatim}
-  grep -E '\\begin{chunk}{(domain|package|category)\ .*}' *.pamphlet
-\end{verbatim}
-will scan the algebra files looking for special chunknames.
-Axiom's chunk names are written in a stylized form so that each
-algebra chunk name begins with one of those three symbols. Thus 
-in bookvol10.3.pamphlet the LexTriangularPackage chunkname is:
-\begin{verbatim}
-  begin{chunk}{package LEXTRIPK LexTriangularPackage}
-\end{verbatim}
-so this grep will generate an output line, prefixed by the filename
-that looks like:
-\begin{verbatim}
-bookvol10.3.pamphlet:begin{chunk}{package LEXTRIPK LexTriangularPackage}
-\end{verbatim}
-There can be many lines of output per pamphlet file, one for
-each domain, package and category cod chunk contained in the file.
-The results are sorted and made unique.
-
-Step 2 is an awk command line.
-
-\subsection{Write the Makefile stanzas for the algebra files}
-
-\begin{chunk}{findSpadFiles}
-
-grep -E 'begin{chunk}{category\ .*}' ${BOOKS}/bookvol10.2.pamphlet | sort | uniq | awk -F: '{
-  chunk=substr($1,15,length($1)-15);
-  split(chunk,part," ");
-  spadfile="${MID}/"part[2]".spad";
-  print spadfile": ${BOOKS}/bookvol10.2.pamphlet";
-  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.2.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
-  print "";
-}'
-
-grep -E 'begin{chunk}{domain\ .*}' ${BOOKS}/bookvol10.3.pamphlet | sort | uniq | awk -F: '{
-  chunk=substr($1,15,length($1)-15);
-  split(chunk,part," ");
-  spadfile="${MID}/"part[2]".spad";
-  print spadfile": ${BOOKS}/bookvol10.3.pamphlet";
-  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.3.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
-  print "";
-}'
-
-grep -E 'begin{chunk}{package\ .*}' ${BOOKS}/bookvol10.4.pamphlet | sort | uniq | awk -F: '{
-  chunk=substr($1,15,length($1)-15);
-  split(chunk,part," ");
-  spadfile="${MID}/"part[2]".spad";
-  print spadfile": ${BOOKS}/bookvol10.4.pamphlet";
-  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.4.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
-  print "";
-}'
-
-grep -E 'begin{chunk}{package\ .*}' ${BOOKS}/bookvol10.5.pamphlet | sort | uniq | awk -F: '{
-  chunk=substr($1,15,length($1)-15);
-  split(chunk,part," ");
-  spadfile="${MID}/"part[2]".spad";
-  print spadfile": ${BOOKS}/bookvol10.5.pamphlet";
-  print "	   @echo \x27(tangle \"${BOOKS}/bookvol10.5.pamphlet\" \""chunk"\" \""part[2]".spad\")\x27 | ${LISPTANGLE} ";
-  print "";
-}'
-
-\end{chunk}
-awk processes each line of the grep output. 
-
-The awk script uses ``-F:'' which is a flag that says that a ``:'' is
-the field separator. As a result the \$1 and \$2 in the awk script
-refer to the parts of the grep output that come before and after the
-``:'' respectively.
-
-The variable ``chunk'' is assigned the actual chunk name minus
-the '\verb|\begin{chunk}{|' and '\verb|}|' delimiters. 
-In the example given above this will become
-\begin{verbatim}
-package LEXTRIPK LexTriangularPackage
-\end{verbatim}
-The call to ``split'' splits the chunk into parts separated
-by spaces. Thus
-\begin{verbatim}
-  part[1]=package
-  part[2]=LEXTRIPK
-  part[3]=LexTriangularPackage
-\end{verbatim}
-The variable ``spadfile'' in the above example is set to
-\begin{verbatim}
-${MID}/LEXTRIPK.spad
-\end{verbatim}
-Finally, in the domain example given above we print two lines.
-The first line is the Makefile stanza header which depends on the
-original ``zerodim.spad.pamphlet'' file.
-
-The second line is the body of the makefile stanza which calls 
-notangle to extract the algebra from the original pamphlet using
-the chunk name and writes it to the intermediate subdirectory. In
-the case above this would resolve to \verb|\${MID}/LEXTRIPK.spad|.
-
-For the line given above it outputs the following:
-\begin{verbatim}
-${MID}/LEXTRIPK.spad: ${IN}/bookvol10.3.pamphlet
-    echo '(tangle "bookvol10.4.pamphlet" "package LEXTRIPK LexTrianglularPackage" "LEXTRIPK.spad")' | ${LISPTANGLE}
-\end{verbatim}
-
-\subsection{Find the algebra bootstrap code}
-Step 3 works like step 1 above except that we are looking for
-chunk names that have the "BOOTSTRAP" string. The output will look like:
-\begin{verbatim}
-bookvol10.3.pamphlet:begin{chunk}{VECTOR.lsp BOOTSTRAP}
-\end{verbatim}
-This output, which can consist of many lines per input file is piped
-into ``awk''.
-
-\subsection{Write the Makefile stanzas for the bootstrap files}
-For each of the above output lines we run an ``grep'' command:
-
-\begin{chunk}{findBootstrapFiles}
-
-grep 'begin{chunk}{.*BOOTSTRAP}' ${BOOKS}/bookvol10.2.pamphlet | sort | uniq | \
-awk -F: '{
-  chunk=substr($1,15,length($1)-15);
-  split(chunk,part," ");
-  lspfile="${MID}/"part[1];
-  print lspfile": ${BOOKS}/bookvol10.2.pamphlet";
-  print "	  @echo \x27(tangle \"${BOOKS}/bookvol10.2.pamphlet\" \""chunk"\" \""lspfile"\")\x27 | ${LISPTANGLE} ";
-  print "";
-}'
-
-grep 'begin{chunk}{.*BOOTSTRAP}' ${BOOKS}/bookvol10.3.pamphlet | sort | uniq | \
-awk -F: '{
-  chunk=substr($1,15,length($1)-15);
-  split(chunk,part," ");
-  lspfile="${MID}/"part[1];
-  print lspfile": ${BOOKS}/bookvol10.3.pamphlet";
-  print "	  @echo \x27(tangle \"${BOOKS}/bookvol10.3.pamphlet\" \""chunk"\" \""lspfile"\")\x27 | ${LISPTANGLE} ";
-  print "";
-}'
-
-\end{chunk}
-
-The process is the same way as described above except that
-there are only two parts to the chunk names
-\begin{verbatim}
-  part[1]=VECTOR.lsp
-  part[2]=BOOTSTRAP
-\end{verbatim}
-The lspfile variable is assigned
-\begin{verbatim}
-${MID}/VECTOR.lsp
-\end{verbatim}
-Finally we output two lines:
-\begin{verbatim}
-${MID}/vector.spad.pamphlet: ${IN}/bookvol10.3.pamphlet
- @echo '(tangle "${IN}/bookvol10.4.pamphlet" "VECTOR.lsp BOOTSTRAP" "VECTOR.lsp")' | ${LISPTANGLE} 
-\end{verbatim}
-
-The first line is the stanza head and creates a dependence between
-the intermediate file, in this case int/algebra/VECTOR.lsp and
-the input file src/algebra/vector.spad.pamphlet
-
-The second line calls the lisp ``tangle'' to extract the required chunk
-from the source file.
-
-\section{Stage markers}
-We output these as each stage completes.
-\begin{chunk}{stages}
-
-layer0bootstrap:
-	@ echo =====================================
-	@ echo === algebra bootstrap complete ======
-	@ echo =====================================
-
-layer0copy:
-	@ echo ==================================
-	@ echo === layer  0 copy complete  ======
-	@ echo ==================================
-
-layer0done:
-	@ echo ==================================
-	@ echo === layer  0 of 24 complete ======
-	@ echo ==================================
-
-layer1done:
-	@ echo ==================================
-	@ echo === layer  1 of 24 complete ======
-	@ echo ==================================
-
-layer2done:
-	@ echo ==================================
-	@ echo === layer  2 of 24 complete ======
-	@ echo ==================================
-
-layer3done:
-	@ echo ==================================
-	@ echo === layer  3 of 24 complete ======
-	@ echo ==================================
-
-layer4done:
-	@ echo ==================================
-	@ echo === layer  4 of 24 complete ======
-	@ echo ==================================
-
-layer5done:
-	@ echo ==================================
-	@ echo === layer  5 of 24 complete ======
-	@ echo ==================================
-
-layer6done:
-	@ echo ==================================
-	@ echo === layer  6 of 24 complete ======
-	@ echo ==================================
-
-layer7done:
-	@ echo ==================================
-	@ echo === layer  7 of 24 complete ======
-	@ echo ==================================
-
-layer8done:
-	@ echo ==================================
-	@ echo === layer  8 of 24 complete ======
-	@ echo ==================================
-
-layer9done:
-	@ echo ==================================
-	@ echo === layer 9 of 24 complete ======
-	@ echo ==================================
-
-layer10done:
-	@ echo ==================================
-	@ echo === layer 10 of 24 complete ======
-	@ echo ==================================
-
-layer11done:
-	@ echo ==================================
-	@ echo === layer 11 of 24 complete ======
-	@ echo ==================================
-
-layer12done:
-	@ echo ==================================
-	@ echo === layer 12 of 24 complete ======
-	@ echo ==================================
-
-layer13done:
-	@ echo ==================================
-	@ echo === layer 13 of 24 complete ======
-	@ echo ==================================
-
-layer14done:
-	@ echo ==================================
-	@ echo === layer 14 of 24 complete ======
-	@ echo ==================================
-
-layer15done:
-	@ echo ==================================
-	@ echo === layer 15 of 24 complete ======
-	@ echo ==================================
-
-layer16done:
-	@ echo ==================================
-	@ echo === layer 16 of 24 complete ======
-	@ echo ==================================
-
-layer17done:
-	@ echo ==================================
-	@ echo === layer 17 of 24 complete ======
-	@ echo ==================================
-
-layer18done:
-	@ echo ==================================
-	@ echo === layer 18 of 24 complete ======
-	@ echo ==================================
-
-layer19done:
-	@ echo ==================================
-	@ echo === layer 19 of 24 complete ======
-	@ echo ==================================
-
-layer20done:
-	@ echo ==================================
-	@ echo === layer 20 of 24 complete ======
-	@ echo ==================================
-
-layer21done:
-	@ echo ==================================
-	@ echo === layer 21 of 24 complete ======
-	@ echo ==================================
-
-layer22done:
-	@ echo ==================================
-	@ echo === layer 22 of 24 complete ======
-	@ echo ==================================
-
-layer23done:
-	@ echo ==================================
-	@ echo === layer 23 of 24 complete ======
-	@ echo ==================================
-
-layer24done:
-	@ echo ==================================
-	@ echo === layer 24 of 24 complete ======
-	@ echo ==================================
-
-\end{chunk}
-\subsection{Regression testing}
-
-There is a Makefile variable called REGRESS in the algebra Makefile:
-\begin{verbatim}
-REGRESS=\
- AssociationList.regress  BalancedBinaryTree.regress \
-\end{verbatim}
-
-This is part of a Makefile that structure within the algebra Makefile.
-This Makefile gets extracted by the Makefile in the input subdirectory.
-Thus there is a connection between the two Makefiles (algebra and input).
-This algebra regression Makefile goes by the chunk name 
-{\bf algebra.regress}. It contains a list of regression files and a 
-single stanza:
-\begin{verbatim}
-%.regress: %.input
-	@ echo sa13 algebra regression testing $*
-	@ (cd ${MID} ; \
-	  rm -f $*.output ; \
-	  if [ -z "${NOISE}" ] ; then \
-           echo ')read $*.input' | ${TESTSYS} ; \
-	  else \
-           echo ')read $*.input' | ${TESTSYS} >${TMP}/trace ; \
-	  fi ; \
-	  if [ -z "${NOISE}" ] ; then \
-           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
-                | egrep -v '(Timestamp|Version)' | tee $*.regress ; \
-	  else \
-           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
-                | egrep -v '(Timestamp|Version)' > $*.regress ; \
-	  fi ; \
-	  fgrep "regression result" $*.regress )
-
-\end{verbatim}
-The input Makefile extracts {\bf algebra.regress} and then calls 
-make to process this file.
-
-This keeps the regression test list in the algebra Makefile.
-
-The algebra files contain input chunks in regress format.
-This stanza is extracted by the src/input/Makefile after
-all of the other regression tests are complete. This stanza
-is put into a int/Makefile.algebra and then executed by make.
-\begin{chunk}{algebra.regress}
-TESTSYS=  ${OBJ}/${SYS}/bin/interpsys
-
-REGRESS= \
- AbelianGroup.regress \
- AbelianMonoid.regress \
- AbelianMonoidRing.regress \
- AbelianSemiGroup.regress \
- AdditiveValuationAttribute.regress \
- AffineAlgebraicSetComputeWithGroebnerBasis.regress \
- AffineAlgebraicSetComputeWithResultant.regress \
- AffinePlane.regress \
- AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.regress \
- AffineSpace.regress \
- AffineSpaceCategory.regress \
- Aggregate.regress \
- Algebra.regress \
- AlgebraGivenByStructuralConstants.regress \
- AlgebraicallyClosedField.regress \
- AlgebraicallyClosedFunctionSpace.regress \
- AlgebraicFunctionField.regress \
- AlgebraicFunction.regress \
- AlgebraicHermiteIntegration.regress \
- AlgebraicIntegrate.regress \
- AlgebraicIntegration.regress \
- AlgebraicManipulations.regress \
- AlgebraicMultFact.regress \
- AlgebraicNumber.regress \
- AlgebraPackage.regress \
- AlgFactor.regress \
- AnnaNumericalIntegrationPackage.regress \
- AnnaNumericalOptimizationPackage.regress \
- AnnaOrdinaryDifferentialEquationPackage.regress \
- AnnaPartialDifferentialEquationPackage.regress \
- AnonymousFunction.regress \
- AntiSymm.regress \
- Any.regress \
- AnyFunctions1.regress \
- ApplicationProgramInterface.regress \
- ApplyRules.regress \
- ApplyUnivariateSkewPolynomial.regress \
- ApproximateAttribute.regress \
- ArbitraryExponentAttribute.regress \
- ArbitraryPrecisionAttribute.regress \
- ArcHyperbolicFunctionCategory.regress \
- ArcTrigonometricFunctionCategory.regress \
- ArrayStack.regress \
- Asp1.regress \
- Asp10.regress \
- Asp12.regress \
- Asp19.regress \
- Asp20.regress \
- Asp24.regress \
- Asp27.regress \
- Asp28.regress \
- Asp29.regress \
- Asp30.regress \
- Asp31.regress \
- Asp33.regress \
- Asp34.regress \
- Asp35.regress \
- Asp4.regress \
- Asp41.regress \
- Asp42.regress \
- Asp49.regress \
- Asp50.regress \
- Asp55.regress \
- Asp6.regress \
- Asp7.regress \
- Asp73.regress \
- Asp74.regress \
- Asp77.regress \
- Asp78.regress \
- Asp8.regress \
- Asp80.regress \
- Asp9.regress \
- AssociatedEquations.regress \
- AssociatedJordanAlgebra.regress \
- AssociatedLieAlgebra.regress \
- AssociationList.regress \
- AssociationListAggregate.regress \
- AttachPredicates.regress \
- AttributeButtons.regress \
- Automorphism.regress \
- AxiomServer.regress \
- BalancedBinaryTree.regress \
- BalancedFactorisation.regress \
- BalancedPAdicInteger.regress \
- BalancedPAdicRational.regress \
- BagAggregate.regress \
- BasicFunctions.regress \
- BasicOperator.regress \
- BasicOperatorFunctions1.regress \
- BasicStochasticDifferential.regress \
- BasicType.regress \
- Bezier.regress \
- BezoutMatrix.regress \
- BiModule.regress \
- BinaryExpansion.regress \
- BinaryFile.regress \
- BinaryRecursiveAggregate.regress \
- BinarySearchTree.regress \
- BinaryTournament.regress \
- BinaryTree.regress \
- BinaryTreeCategory.regress \
- BitAggregate.regress \
- Bits.regress \
- BlasLevelOne.regress \
- BlowUpMethodCategory.regress \
- BlowUpPackage.regress \
- BlowUpWithHamburgerNoether.regress \
- BlowUpWithQuadTrans.regress \
- Boolean.regress \
- BoundIntegerRoots.regress \
- BrillhartTests.regress \
- CachableSet.regress \
- CancellationAbelianMonoid.regress \
- CanonicalAttribute.regress \
- CanonicalClosedAttribute.regress \
- CanonicalUnitNormalAttribute.regress \
- CardinalNumber.regress \
- CartesianTensor.regress \
- CartesianTensorFunctions2.regress \
- CentralAttribute.regress \
- ChangeOfVariable.regress \
- Character.regress \
- CharacterClass.regress \
- CharacteristicNonZero.regress \
- CharacteristicPolynomialInMonogenicalAlgebra.regress \
- CharacteristicPolynomialPackage.regress \
- CharacteristicZero.regress \
- ChineseRemainderToolsForIntegralBases.regress \
- CliffordAlgebra.regress \
- CoercibleTo.regress \
- CoerceVectorMatrixPackage.regress \
- Collection.regress \
- Color.regress \
- CombinatorialFunction.regress \
- CombinatorialFunctionCategory.regress \
- CombinatorialOpsCategory.regress \
- CommonDenominator.regress \
- CommonOperators.regress \
- CommutativeRing.regress \
- CommutativeStarAttribute.regress \
- Commutator.regress \
- CommuteUnivariatePolynomialCategory.regress \
- Comparable.regress \
- Complex.regress \
- ComplexCategory.regress \
- ComplexDoubleFloatMatrix.regress \
- ComplexDoubleFloatVector.regress \
- ComplexFactorization.regress \
- ComplexIntegerSolveLinearPolynomialEquation.regress \
- ComplexFunctions2.regress \
- ComplexPattern.regress \
- ComplexPatternMatch.regress \
- ComplexRootFindingPackage.regress \
- ComplexRootPackage.regress \
- ComplexTrigonometricManipulations.regress \
- ConstantLODE.regress \
- ContinuedFraction.regress \
- ConvertibleTo.regress \
- CoordinateSystems.regress \
- CRApackage.regress \
- CycleIndicators.regress \
- CyclicStreamTools.regress \
- CyclotomicPolynomialPackage.regress \
- dasum.regress \
- daxpy.regress \
- dcabs1.regress \
- dcopy.regress \
- Database.regress \
- DataList.regress \
- DecimalExpansion.regress \
- DefiniteIntegrationTools.regress \
- DegreeReductionPackage.regress \
- Dequeue.regress \
- DequeueAggregate.regress \
- DeRhamComplex.regress \
- DesingTree.regress \
- DesingTreeCategory.regress \
- DesingTreePackage.regress \
- Dictionary.regress \
- DictionaryOperations.regress \
- DifferentialExtension.regress \
- DifferentialPolynomialCategory.regress \
- DifferentialRing.regress \
- DifferentialSparseMultivariatePolynomial.regress \
- DifferentialVariableCategory.regress \
- DiophantineSolutionPackage.regress \
- DirectProduct.regress \
- DirectProductCategory.regress \
- DirectProductFunctions2.regress \
- DirectProductMatrixModule.regress \
- DirectProductModule.regress \
- DirichletRing.regress \
- DiscreteLogarithmPackage.regress \
- DisplayPackage.regress \
- DistributedMultivariatePolynomial.regress \
- DistinctDegreeFactorize.regress \
- DivisionRing.regress \
- Divisor.regress \
- DivisorCategory.regress \
- DoubleFloat.regress \
- DoubleFloatMatrix.regress \
- DoubleFloatSpecialFunctions.regress \
- DoubleFloatVector.regress \
- DoubleResultantPackage.regress \
- DoublyLinkedAggregate.regress \
- DrawComplex.regress \
- DrawNumericHack.regress \
- DrawOption.regress \
- DrawOptionFunctions0.regress \
- DrawOptionFunctions1.regress \
- d01AgentsPackage.regress \
- d01ajfAnnaType.regress \
- d01akfAnnaType.regress \
- d01alfAnnaType.regress \
- d01amfAnnaType.regress \
- d01anfAnnaType.regress \
- d01apfAnnaType.regress \
- d01aqfAnnaType.regress \
- d01asfAnnaType.regress \
- d01fcfAnnaType.regress \
- d01gbfAnnaType.regress \
- d01TransformFunctionType.regress \
- d01WeightsPackage.regress \
- d02AgentsPackage.regress \
- d02bbfAnnaType.regress \
- d02bhfAnnaType.regress \
- d02cjfAnnaType.regress \
- d02ejfAnnaType.regress \
- d03AgentsPackage.regress \
- d03eefAnnaType.regress \
- d03fafAnnaType.regress \
- EigenPackage.regress \
- ElementaryFunction.regress \
- ElementaryFunctionCategory.regress \
- ElementaryFunctionDefiniteIntegration.regress \
- ElementaryFunctionLODESolver.regress \
- ElementaryFunctionODESolver.regress \
- ElementaryFunctionSign.regress \
- ElementaryFunctionStructurePackage.regress \
- ElementaryFunctionsUnivariateLaurentSeries.regress \
- ElementaryFunctionsUnivariatePuiseuxSeries.regress \
- ElementaryIntegration.regress \
- ElementaryRischDE.regress \
- ElementaryRischDESystem.regress \
- EllipticFunctionsUnivariateTaylorSeries.regress \
- Eltable.regress \
- EltableAggregate.regress \
- EntireRing.regress \
- EqTable.regress \
- Equation.regress \
- EquationFunctions2.regress \
- ErrorFunctions.regress \
- EuclideanDomain.regress \
- EuclideanGroebnerBasisPackage.regress \
- EuclideanModularRing.regress \
- Evalable.regress \
- EvaluateCycleIndicators.regress \
- ExpertSystemContinuityPackage.regress \
- ExpertSystemContinuityPackage1.regress \
- ExpertSystemToolsPackage.regress \
- ExpertSystemToolsPackage1.regress \
- ExpertSystemToolsPackage2.regress \
- ExponentialExpansion.regress \
- ExponentialOfUnivariatePuiseuxSeries.regress \
- Export3D.regress \
- Expression.regress \
- ExpressionFunctions2.regress \
- ExpressionSpace.regress \
- ExpressionSolve.regress \
- ExpressionSpaceFunctions1.regress \
- ExpressionSpaceFunctions2.regress \
- ExpressionSpaceODESolver.regress \
- ExpressionToOpenMath.regress \
- ExpressionToUnivariatePowerSeries.regress \
- ExpressionTubePlot.regress \
- ExtAlgBasis.regress \
- ExtensibleLinearAggregate.regress \
- ExtensionField.regress \
- e04AgentsPackage.regress \
- e04dgfAnnaType.regress \
- e04fdfAnnaType.regress \
- e04gcfAnnaType.regress \
- e04jafAnnaType.regress \
- e04mbfAnnaType.regress \
- e04nafAnnaType.regress \
- e04ucfAnnaType.regress \
- Factored.regress \
- FactoredFunctions.regress \
- FactoredFunctions2.regress \
- FactoredFunctionUtilities.regress \
- FactoringUtilities.regress \
- FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.regress \
- FactorisationOverPseudoAlgebraicClosureOfRationalNumber.regress \
- FGLMIfCanPackage.regress \
- Field.regress \
- FieldOfPrimeCharacteristic.regress \
- File.regress \
- FileCategory.regress \
- FileName.regress \
- FileNameCategory.regress \
- FindOrderFinite.regress \
- Finite.regress \
- FiniteAbelianMonoidRing.regress \
- FiniteAbelianMonoidRingFunctions2.regress \
- FiniteAggregateAttribute.regress \
- FiniteAlgebraicExtensionField.regress \
- FiniteDivisor.regress \
- FiniteDivisorCategory.regress \
- FiniteDivisorFunctions2.regress \
- FiniteField.regress \
- FiniteFieldCategory.regress \
- FiniteFieldCyclicGroup.regress \
- FiniteFieldCyclicGroupExtension.regress \
- FiniteFieldCyclicGroupExtensionByPolynomial.regress \
- FiniteFieldExtension.regress \
- FiniteFieldExtensionByPolynomial.regress \
- FiniteFieldFactorization.regress \
- FiniteFieldFactorizationWithSizeParseBySideEffect.regress \
- FiniteFieldFunctions.regress \
- FiniteFieldHomomorphisms.regress \
- FiniteFieldNormalBasis.regress \
- FiniteFieldNormalBasisExtension.regress \
- FiniteFieldNormalBasisExtensionByPolynomial.regress \
- FiniteFieldPolynomialPackage.regress \
- FiniteFieldSolveLinearPolynomialEquation.regress \
- FiniteFieldPolynomialPackage2.regress \
- FiniteFieldSolveLinearPolynomialEquation.regress \
- FiniteFieldSquareFreeDecomposition.regress \
- FiniteLinearAggregate.regress \
- FiniteLinearAggregateFunctions2.regress \
- FiniteLinearAggregateSort.regress \
- FiniteRankAlgebra.regress \
- FiniteRankNonAssociativeAlgebra.regress \
- FiniteSetAggregate.regress \
- FiniteSetAggregateFunctions2.regress \
- FlexibleArray.regress \
- Float.regress \
- FloatingComplexPackage.regress \
- FloatingPointSystem.regress \
- FloatingRealPackage.regress \
- FortranCode.regress \
- FortranCodePackage1.regress \
- FortranExpression.regress \
- FortranFunctionCategory.regress \
- FortranMachineTypeCategory.regress \
- FortranMatrixCategory.regress \
- FortranMatrixFunctionCategory.regress \
- FortranOutputStackPackage.regress \
- FortranPackage.regress \
- FortranProgram.regress \
- FortranProgramCategory.regress \
- FortranScalarType.regress \
- FortranTemplate.regress \
- FortranType.regress \
- FortranVectorCategory.regress \
- FortranVectorFunctionCategory.regress \
- FourierComponent.regress \
- FourierSeries.regress \
- Fraction.regress \
- FractionalIdeal.regress \
- FractionalIdealFunctions2.regress \
- FractionFreeFastGaussian.regress \
- FractionFreeFastGaussianFractions.regress \
- FractionFunctions2.regress \
- FramedAlgebra.regress \
- FramedModule.regress \
- FramedNonAssociativeAlgebra.regress \
- FramedNonAssociativeAlgebraFunctions2.regress \
- FreeAbelianGroup.regress \
- FreeAbelianMonoid.regress \
- FreeAbelianMonoidCategory.regress \
- FreeGroup.regress \
- FreeLieAlgebra.regress \
- FreeModuleCat.regress \
- FreeModule.regress \
- FreeModule1.regress \
- FreeMonoid.regress \
- FreeNilpotentLie.regress \
- FullPartialFractionExpansion.regress \
- FullyEvalableOver.regress \
- FullyLinearlyExplicitRingOver.regress \
- FullyPatternMatchable.regress \
- FullyRetractableTo.regress \
- FunctionalSpecialFunction.regress \
- FunctionCalled.regress \
- FunctionFieldCategory.regress \
- FunctionFieldCategoryFunctions2.regress \
- FunctionFieldIntegralBasis.regress \
- FunctionSpace.regress \
- FunctionSpaceAssertions.regress \
- FunctionSpaceAttachPredicates.regress \
- FunctionSpaceComplexIntegration.regress \
- FunctionSpaceFunctions2.regress \
- FunctionSpaceIntegration.regress \
- FunctionSpacePrimitiveElement.regress \
- FunctionSpaceReduce.regress \
- FunctionSpaceSum.regress \
- FunctionSpaceToExponentialExpansion.regress \
- FunctionSpaceToUnivariatePowerSeries.regress \
- FunctionSpaceUnivariatePolynomialFactor.regress \
- GaloisGroupFactorizer.regress \
- GaloisGroupFactorizationUtilities.regress \
- GaloisGroupPolynomialUtilities.regress \
- GaloisGroupUtilities.regress \
- GaussianFactorizationPackage.regress \
- GcdDomain.regress \
- GeneralDistributedMultivariatePolynomial.regress \
- GeneralHenselPackage.regress \
- GeneralizedMultivariateFactorize.regress \
- GeneralModulePolynomial.regress \
- GeneralPackageForAlgebraicFunctionField.regress \
- GeneralPolynomialGcdPackage.regress \
- GeneralSparseTable.regress \
- GenericNonAssociativeAlgebra.regress \
- GeneralPolynomialSet.regress \
- GeneralTriangularSet.regress \
- GeneralUnivariatePowerSeries.regress \
- GenerateUnivariatePowerSeries.regress \
- GenExEuclid.regress \
- GenUFactorize.regress \
- GenusZeroIntegration.regress \
- GnuDraw.regress \
- GosperSummationMethod.regress \
- GradedAlgebra.regress \
- GradedModule.regress \
- GraphicsDefaults.regress \
- GraphImage.regress \
- GrayCode.regress \
- GroebnerFactorizationPackage.regress \
- GroebnerInternalPackage.regress \
- GroebnerPackage.regress \
- GroebnerSolve.regress \
- Group.regress \
- Guess.regress \
- GuessAlgebraicNumber.regress \
- GuessFinite.regress \
- GuessFiniteFunctions.regress \
- GuessInteger.regress \
- GuessOption.regress \
- GuessOptionFunctions0.regress \
- GuessPolynomial.regress \
- GuessUnivariatePolynomial.regress \
- HallBasis.regress \
- HashTable.regress \
- Heap.regress \
- HeuGcd.regress \
- HexadecimalExpansion.regress \
- HTMLFormat.regress \
- HomogeneousAggregate.regress \
- HomogeneousDirectProduct.regress \
- HomogeneousDistributedMultivariatePolynomial.regress \
- HyperbolicFunctionCategory.regress \
- HyperellipticFiniteDivisor.regress \
- IdealDecompositionPackage.regress \
- IncrementingMaps.regress \
- IndexCard.regress \
- IndexedAggregate.regress \
- IndexedBits.regress \
- IndexedDirectProductAbelianGroup.regress \
- IndexedDirectProductAbelianMonoid.regress \
- IndexedDirectProductCategory.regress \
- IndexedDirectProductObject.regress \
- IndexedDirectProductOrderedAbelianMonoid.regress \
- IndexedDirectProductOrderedAbelianMonoidSup.regress \
- IndexedExponents.regress \
- IndexedFlexibleArray.regress \
- IndexedList.regress \
- IndexedMatrix.regress \
- IndexedOneDimensionalArray.regress \
- IndexedString.regress \
- IndexedTwoDimensionalArray.regress \
- IndexedVector.regress \
- InfClsPt.regress \
- InfiniteProductCharacteristicZero.regress \
- InfiniteProductFiniteField.regress \
- InfiniteProductPrimeField.regress \
- InfiniteTuple.regress \
- InfiniteTupleFunctions2.regress \
- InfiniteTupleFunctions3.regress \
- InfinitlyClosePoint.regress \
- InfinitlyClosePointCategory.regress \
- InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.regress \
- Infinity.regress \
- InnerAlgebraicNumber.regress \
- InnerAlgFactor.regress \
- InnerCommonDenominator.regress \
- InnerEvalable.regress \
- InnerFiniteField.regress \
- InnerFreeAbelianMonoid.regress \
- InnerIndexedTwoDimensionalArray.regress \
- InnerMatrixLinearAlgebraFunctions.regress \
- InnerMatrixQuotientFieldFunctions.regress \
- InnerModularGcd.regress \
- InnerMultFact.regress \
- InnerNormalBasisFieldFunctions.regress \
- InnerNumericEigenPackage.regress \
- InnerNumericFloatSolvePackage.regress \
- InnerPAdicInteger.regress \
- InnerPolySign.regress \
- InnerPolySum.regress \
- InnerPrimeField.regress \
- InnerSparseUnivariatePowerSeries.regress \
- InnerTable.regress \
- InnerTaylorSeries.regress \
- InnerTrigonometricManipulations.regress \
- InputForm.regress \
- InputFormFunctions1.regress \
- Integer.regress \
- IntegerCombinatoricFunctions.regress \
- IntegerBits.regress \
- IntegerFactorizationPackage.regress \
- IntegerLinearDependence.regress \
- IntegerMod.regress \
- IntegerNumberSystem.regress \
- IntegerNumberTheoryFunctions.regress \
- IntegerPrimesPackage.regress \
- IntegerRetractions.regress \
- IntegerRoots.regress \
- IntegerSolveLinearPolynomialEquation.regress \
- IntegralBasisTools.regress \
- IntegralBasisPolynomialTools.regress \
- IntegralDomain.regress \
- IntegrationFunctionsTable.regress \
- IntegrationResult.regress \
- IntegrationResultFunctions2.regress \
- IntegrationResultRFToFunction.regress \
- IntegrationResultToFunction.regress \
- IntegrationTools.regress \
- InterfaceGroebnerPackage.regress \
- InternalPrintPackage.regress \
- InternalRationalUnivariateRepresentationPackage.regress \
- InterpolateFormsPackage.regress \
- IntersectionDivisorPackage.regress \
- Interval.regress \
- IntervalCategory.regress \
- InverseLaplaceTransform.regress \
- IrredPolyOverFiniteField.regress \
- IrrRepSymNatPackage.regress \
- JacobiIdentityAttribute.regress \
- Kernel.regress \
- KernelFunctions2.regress \
- KeyedAccessFile.regress \
- KeyedDictionary.regress \
- Kovacic.regress \
- LaplaceTransform.regress \
- LaurentPolynomial.regress \
- LazyRepresentationAttribute.regress \
- LazyStreamAggregate.regress \
- LazardSetSolvingPackage.regress \
- LeadingCoefDetermination.regress \
- LeftAlgebra.regress \
- LeftModule.regress \
- LeftUnitaryAttribute.regress \
- LexTriangularPackage.regress \
- Library.regress \
- LieAlgebra.regress \
- LieExponentials.regress \
- LiePolynomial.regress \
- LieSquareMatrix.regress \
- LinearDependence.regress \
- LinearlyExplicitRingOver.regress \
- LinearAggregate.regress \
- LinearOrdinaryDifferentialOperator.regress \
- LinearOrdinaryDifferentialOperator1.regress \
- LinearOrdinaryDifferentialOperator2.regress \
- LinearOrdinaryDifferentialOperatorCategory.regress \
- LinearOrdinaryDifferentialOperatorFactorizer.regress \
- LinearOrdinaryDifferentialOperatorsOps.regress \
- LinearPolynomialEquationByFractions.regress \
- LinearSystemFromPowerSeriesPackage.regress \
- LinearSystemMatrixPackage.regress \
- LinearSystemMatrixPackage1.regress \
- LinearSystemPolynomialPackage.regress \
- LinesOpPack.regress \
- LinGroebnerPackage.regress \
- LiouvillianFunction.regress \
- LiouvillianFunctionCategory.regress \
- List.regress \
- ListAggregate.regress \
- ListFunctions2.regress \
- ListFunctions3.regress \
- ListMonoidOps.regress \
- ListMultiDictionary.regress \
- ListToMap.regress \
- LocalAlgebra.regress \
- Localize.regress \
- LocalParametrizationOfSimplePointPackage.regress \
- LocalPowerSeriesCategory.regress \
- Logic.regress \
- LyndonWord.regress \
- MachineComplex.regress \
- MachineFloat.regress \
- MachineInteger.regress \
- Magma.regress \
- MakeBinaryCompiledFunction.regress \
- MakeFloatCompiledFunction.regress \
- MakeRecord.regress \
- MakeUnaryCompiledFunction.regress \
- MathMLFormat.regress \
- MakeCachableSet.regress \
- MakeFunction.regress \
- MappingPackage1.regress \
- MappingPackage2.regress \
- MappingPackage3.regress \
- MappingPackageInternalHacks1.regress \
- MappingPackageInternalHacks2.regress \
- MappingPackageInternalHacks3.regress \
- Matrix.regress \
- MatrixCategory.regress \
- MatrixCategoryFunctions2.regress \
- MatrixCommonDenominator.regress \
- MatrixLinearAlgebraFunctions.regress \
- MatrixManipulation.regress \
- MergeThing.regress \
- MeshCreationRoutinesForThreeDimensions.regress \
- ModMonic.regress \
- ModularDistinctDegreeFactorizer.regress \
- ModularField.regress \
- ModularHermitianRowReduction.regress \
- ModularRing.regress \
- Module.regress \
- ModuleMonomial.regress \
- ModuleOperator.regress \
- MoebiusTransform.regress \
- Monad.regress \
- MonadWithUnit.regress \
- MonogenicAlgebra.regress \
- MonogenicLinearOperator.regress \
- Monoid.regress \
- MonoidRing.regress \
- MonoidRingFunctions2.regress \
- MonomialExtensionTools.regress \
- MoreSystemCommands.regress \
- MPolyCatFunctions2.regress \
- MPolyCatFunctions3.regress \
- MPolyCatPolyFactorizer.regress \
- MPolyCatRationalFunctionFactorizer.regress \
- MRationalFactorize.regress \
- MultFiniteFactorize.regress \
- MultiDictionary.regress \
- MultipleMap.regress \
- MultiplicativeValuationAttribute.regress \
- Multiset.regress \
- MultisetAggregate.regress \
- MultiVariableCalculusFunctions.regress \
- MultivariateFactorize.regress \
- MultivariatePolynomial.regress \
- MultivariateSquareFree.regress \
- MultivariateTaylorSeriesCategory.regress \
- MyExpression.regress \
- MyUnivariatePolynomial.regress \
- NAGLinkSupportPackage.regress \
- NeitherSparseOrDensePowerSeries.regress \
- NewSparseMultivariatePolynomial.regress \
- NewSparseUnivariatePolynomial.regress \
- NewSparseUnivariatePolynomialFunctions2.regress \
- NewtonInterpolation.regress \
- NewtonPolygon.regress \
- NonAssociativeAlgebra.regress \
- NonAssociativeRing.regress \
- NonAssociativeRng.regress \
- NonCommutativeOperatorDivision.regress \
- None.regress \
- NoneFunctions1.regress \
- NonLinearFirstOrderODESolver.regress \
- NonLinearSolvePackage.regress \
- NonNegativeInteger.regress \
- NormalizationPackage.regress \
- NormalizedTriangularSetCategory.regress \
- NormInMonogenicAlgebra.regress \
- NormRetractPackage.regress \
- NotherianAttribute.regress \
- NottinghamGroup.regress \
- NoZeroDivisorsAttribute.regress \
- NPCoef.regress \
- NullSquareAttribute.regress \
- NumberFieldIntegralBasis.regress \
- NumberFormats.regress \
- NumberTheoreticPolynomialFunctions.regress \
- Numeric.regress \
- NumericalIntegrationCategory.regress \
- NumericalIntegrationProblem.regress \
- NumericalODEProblem.regress \
- NumericalOptimizationCategory.regress \
- NumericalOptimizationProblem.regress \
- NumericalOrdinaryDifferentialEquations.regress \
- NumericalPDEProblem.regress \
- NumericalQuadrature.regress \
- NumericComplexEigenPackage.regress \
- NumericContinuedFraction.regress \
- NumericRealEigenPackage.regress \
- NumericTubePlot.regress \
- Octonion.regress \
- OctonionCategory.regress \
- OctonionCategoryFunctions2.regress \
- ODEIntegration.regress \
- ODEIntensityFunctionsTable.regress \
- ODETools.regress \
- OneDimensionalArray.regress \
- OneDimensionalArrayAggregate.regress \
- OneDimensionalArrayFunctions2.regress \
- OnePointCompletion.regress \
- OnePointCompletionFunctions2.regress \
- OpenMath.regress \
- OpenMathConnection.regress \
- OpenMathDevice.regress \
- OpenMathEncoding.regress \
- OpenMathError.regress \
- OpenMathErrorKind.regress \
- OpenMathPackage.regress \
- OpenMathServerPackage.regress \
- OperationsQuery.regress \
- Operator.regress \
- OppositeMonogenicLinearOperator.regress \
- OrderedAbelianGroup.regress \
- OrderedAbelianMonoid.regress \
- OrderedAbelianMonoidSup.regress \
- OrderedAbelianSemiGroup.regress \
- OrderedCancellationAbelianMonoid.regress \
- OrderedCompletion.regress \
- OrderedCompletionFunctions2.regress \
- OrderedDirectProduct.regress \
- OrderedFinite.regress \
- OrderedFreeMonoid.regress \
- OrderedIntegralDomain.regress \
- OrderedMonoid.regress \
- OrderedMultisetAggregate.regress \
- OrderedRing.regress \
- OrderedSet.regress \
- OrderedVariableList.regress \
- OrderingFunctions.regress \
- OrderlyDifferentialPolynomial.regress \
- OrderlyDifferentialVariable.regress \
- OrdinaryDifferentialEquationsSolverCategory.regress \
- OrdinaryDifferentialRing.regress \
- OrdinaryWeightedPolynomials.regress \
- OrdSetInts.regress \
- OrthogonalPolynomialFunctions.regress \
- OutputForm.regress \
- OutputPackage.regress \
- PackageForAlgebraicFunctionField.regress \
- PackageForAlgebraicFunctionFieldOverFiniteField.regress \
- PackageForPoly.regress \
- PadeApproximantPackage.regress \
- PadeApproximants.regress \
- PAdicInteger.regress \
- PAdicIntegerCategory.regress \
- PAdicRational.regress \
- PAdicRationalConstructor.regress \
- PAdicWildFunctionFieldIntegralBasis.regress \
- Palette.regress \
- ParadoxicalCombinatorsForStreams.regress \
- ParametricLinearEquations.regress \
- ParametricPlaneCurve.regress \
- ParametricPlaneCurveFunctions2.regress \
- ParametricSpaceCurve.regress \
- ParametricSpaceCurveFunctions2.regress \
- ParametricSurface.regress \
- ParametricSurfaceFunctions2.regress \
- ParametrizationPackage.regress \
- PartialDifferentialEquationsSolverCategory.regress \
- PartialDifferentialRing.regress \
- PartialFraction.regress \
- PartialFractionPackage.regress \
- PartiallyOrderedSetAttribute.regress \
- PartialTranscendentalFunctions.regress \
- Partition.regress \
- PartitionsAndPermutations.regress \
- Pattern.regress \
- Patternable.regress \
- PatternFunctions1.regress \
- PatternFunctions2.regress \
- PatternMatch.regress \
- PatternMatchable.regress \
- PatternMatchAssertions.regress \
- PatternMatchFunctionSpace.regress \
- PatternMatchIntegerNumberSystem.regress \
- PatternMatchIntegration.regress \
- PatternMatchKernel.regress \
- PatternMatchListAggregate.regress \
- PatternMatchListResult.regress \
- PatternMatchPolynomialCategory.regress \
- PatternMatchPushDown.regress \
- PatternMatchQuotientFieldCategory.regress \
- PatternMatchResult.regress \
- PatternMatchResultFunctions2.regress \
- PatternMatchSymbol.regress \
- PatternMatchTools.regress \
- PermutationGroupExamples.regress \
- PendantTree.regress \
- Permanent.regress \
- Permutation.regress \
- PermutationCategory.regress \
- PermutationGroup.regress \
- Pi.regress \
- PiCoercions.regress \
- Places.regress \
- PlacesCategory.regress \
- PlacesOverPseudoAlgebraicClosureOfFiniteField.regress \
- PlaneAlgebraicCurvePlot.regress \
- Plcs.regress \
- Plot.regress \
- Plot3D.regress \
- PlotFunctions1.regress \
- PointFunctions2.regress \
- PlottablePlaneCurveCategory.regress \
- PlottableSpaceCurveCategory.regress \
- PlotTools.regress \
- PoincareBirkhoffWittLyndonBasis.regress \
- Point.regress \
- PointCategory.regress \
- PointPackage.regress \
- PointsOfFiniteOrder.regress \
- PointsOfFiniteOrderRational.regress \
- PointsOfFiniteOrderTools.regress \
- PolToPol.regress \
- PolyGroebner.regress \
- Polynomial.regress \
- PolynomialAN2Expression.regress \
- PolynomialCategory.regress \
- PolynomialCategoryLifting.regress \
- PolynomialCategoryQuotientFunctions.regress \
- PolynomialComposition.regress \
- PolynomialDecomposition.regress \
- PolynomialFactorizationByRecursion.regress \
- PolynomialFactorizationByRecursionUnivariate.regress \
- PolynomialFactorizationExplicit.regress \
- PolynomialFunctions2.regress \
- PolynomialGcdPackage.regress \
- PolynomialIdeals.regress \
- PolynomialInterpolation.regress \
- PolynomialInterpolationAlgorithms.regress \
- PolynomialNumberTheoryFunctions.regress \
- PolynomialPackageForCurve.regress \
- PolynomialRing.regress \
- PolynomialRoots.regress \
- PolynomialSetCategory.regress \
- PolynomialSetUtilitiesPackage.regress \
- PolynomialSolveByFormulas.regress \
- PolynomialSquareFree.regress \
- PolynomialToUnivariatePolynomial.regress \
- PositiveInteger.regress \
- PowerSeriesCategory.regress \
- PowerSeriesLimitPackage.regress \
- PrecomputedAssociatedEquations.regress \
- PrimeField.regress \
- PrimitiveArray.regress \
- PrimitiveArrayFunctions2.regress \
- PrimitiveElement.regress \
- PrimitiveFunctionCategory.regress \
- PrimitiveRatDE.regress \
- PrimitiveRatRicDE.regress \
- PrincipalIdealDomain.regress \
- PrintPackage.regress \
- PriorityQueueAggregate.regress \
- Product.regress \
- ProjectiveAlgebraicSetPackage.regress \
- ProjectivePlane.regress \
- ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.regress \
- ProjectiveSpace.regress \
- ProjectiveSpaceCategory.regress \
- PseudoAlgebraicClosureOfAlgExtOfRationalNumber.regress \
- PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.regress \
- PseudoAlgebraicClosureOfFiniteField.regress \
- PseudoAlgebraicClosureOfFiniteFieldCategory.regress \
- PseudoAlgebraicClosureOfPerfectFieldCategory.regress \
- PseudoAlgebraicClosureOfRationalNumber.regress \
- PseudoAlgebraicClosureOfRationalNumberCategory.regress \
- PseudoLinearNormalForm.regress \
- PseudoRemainderSequence.regress \
- PureAlgebraicIntegration.regress \
- PureAlgebraicLODE.regress \
- PushVariables.regress \
- QuadraticForm.regress \
- QuasiAlgebraicSet.regress \
- QuasiAlgebraicSet2.regress \
- QuasiComponentPackage.regress \
- Quaternion.regress \
- QuaternionCategory.regress \
- QuaternionCategoryFunctions2.regress \
- QueryEquation.regress \
- Queue.regress \
- QueueAggregate.regress \
- QuotientFieldCategory.regress \
- QuotientFieldCategoryFunctions2.regress \
- RadicalCategory.regress \
- RadicalEigenPackage.regress \
- RadicalFunctionField.regress \
- RadicalSolvePackage.regress \
- RadixExpansion.regress \
- RadixUtilities.regress \
- RandomDistributions.regress \
- RandomFloatDistributions.regress \
- RandomIntegerDistributions.regress \
- RandomNumberSource.regress \
- RationalFactorize.regress \
- RationalFunction.regress \
- RationalFunctionDefiniteIntegration.regress \
- RationalFunctionFactor.regress \
- RationalFunctionFactorizer.regress \
- RationalFunctionIntegration.regress \
- RationalFunctionLimitPackage.regress \
- RationalFunctionSign.regress \
- RationalFunctionSum.regress \
- RationalIntegration.regress \
- RationalInterpolation.regress \
- RationalLODE.regress \
- RationalRetractions.regress \
- RationalRicDE.regress \
- RationalUnivariateRepresentationPackage.regress \
- RealClosedField.regress \
- RealClosure.regress \
- RealConstant.regress \
- RealNumberSystem.regress \
- RealPolynomialUtilitiesPackage.regress \
- RealRootCharacterizationCategory.regress \
- RealSolvePackage.regress \
- RealZeroPackage.regress \
- RealZeroPackageQ.regress \
- RectangularMatrix.regress \
- RectangularMatrixCategory.regress \
- RectangularMatrixCategoryFunctions2.regress \
- RecurrenceOperator.regress \
- RecursiveAggregate.regress \
- RecursivePolynomialCategory.regress \
- ReducedDivisor.regress \
- ReduceLODE.regress \
- ReductionOfOrder.regress \
- Reference.regress \
- RegularChain.regress \
- RegularSetDecompositionPackage.regress \
- RegularTriangularSet.regress \
- RegularTriangularSetCategory.regress \
- RegularTriangularSetGcdPackage.regress \
- RepeatedDoubling.regress \
- RepeatedSquaring.regress \
- RepresentationPackage1.regress \
- RepresentationPackage2.regress \
- ResidueRing.regress \
- ResolveLatticeCompletion.regress \
- Result.regress \
- RetractableTo.regress \
- RetractSolvePackage.regress \
- RewriteRule.regress \
- RightModule.regress \
- RightOpenIntervalRootCharacterization.regress \
- RightUnitaryAttribute.regress \
- Ring.regress \
- Rng.regress \
- RomanNumeral.regress \
- RootsFindingPackage.regress \
- RoutinesTable.regress \
- RuleCalled.regress \
- Ruleset.regress \
- SAERationalFunctionAlgFactor.regress \
- ScriptFormulaFormat.regress \
- ScriptFormulaFormat1.regress \
- Segment.regress \
- SegmentBindingFunctions2.regress \
- SegmentCategory.regress \
- SegmentExpansionCategory.regress \
- SegmentFunctions2.regress \
- SemiGroup.regress \
- Set.regress \
- SetAggregate.regress \
- SetCategory.regress \
- SetCategoryWithDegree.regress \
- SetOfMIntegersInOneToN.regress \
- SequentialDifferentialPolynomial.regress \
- SequentialDifferentialVariable.regress \
- SExpression.regress \
- SExpressionCategory.regress \
- SExpressionOf.regress \
- ShallowlyMutableAttribute.regress \
- SimpleAlgebraicExtension.regress \
- SimpleAlgebraicExtensionAlgFactor.regress \
- SimpleFortranProgram.regress \
- SingleInteger.regress \
- SingletonAsOrderedSet.regress \
- SimplifyAlgebraicNumberConvertPackage.regress \
- SmithNormalForm.regress \
- SortedCache.regress \
- SortPackage.regress \
- SparseTable.regress \
- SparseMultivariatePolynomial.regress \
- SparseMultivariateTaylorSeries.regress \
- SparseUnivariateLaurentSeries.regress \
- SparseUnivariatePolynomial.regress \
- SparseUnivariatePolynomialExpressions.regress \
- SparseUnivariatePolynomialFunctions2.regress \
- SparseUnivariatePuiseuxSeries.regress \
- SparseUnivariateSkewPolynomial.regress \
- SparseUnivariateTaylorSeries.regress \
- SpecialFunctionCategory.regress \
- SpecialOutputPackage.regress \
- SplitHomogeneousDirectProduct.regress \
- SplittingNode.regress \
- SplittingTree.regress \
- SquareMatrix.regress \
- SquareFreeNormalizedTriangularSetCategory.regress \
- SquareFreeQuasiComponentPackage.regress \
- SquareFreeRegularSetDecompositionPackage.regress \
- SquareFreeRegularTriangularSet.regress \
- SquareFreeRegularTriangularSetCategory.regress \
- SquareFreeRegularTriangularSetGcdPackage.regress \
- SquareMatrixCategory.regress \
- Stack.regress \
- StackAggregate.regress \
- StepThrough.regress \
- StochasticDifferential.regress \
- StorageEfficientMatrixOperations.regress \
- Stream.regress \
- StreamAggregate.regress \
- StreamFunctions1.regress \
- StreamFunctions2.regress \
- StreamFunctions3.regress \
- StreamInfiniteProduct.regress \
- StreamTaylorSeriesOperations.regress \
- StreamTensor.regress \
- StreamTranscendentalFunctions.regress \
- StreamTranscendentalFunctionsNonCommutative.regress \
- String.regress \
- StringAggregate.regress \
- StringCategory.regress \
- StringTable.regress \
- StructuralConstantsPackage.regress \
- SturmHabichtPackage.regress \
- SubResultantPackage.regress \
- SubSpace.regress \
- SubSpaceComponentProperty.regress \
- SuchThat.regress \
- SupFractionFactorizer.regress \
- Switch.regress \
- Symbol.regress \
- SymbolTable.regress \
- SymmetricFunctions.regress \
- SymmetricGroupCombinatoricFunctions.regress \
- SymmetricPolynomial.regress \
- SystemODESolver.regress \
- SystemSolvePackage.regress \
- Table.regress \
- TableAggregate.regress \
- Tableau.regress \
- TableauxBumpers.regress \
- TabulatedComputationPackage.regress \
- TangentExpansions.regress \
- TaylorSeries.regress \
- TaylorSolve.regress \
- TemplateUtilities.regress \
- TexFormat.regress \
- TexFormat1.regress \
- TextFile.regress \
- TheSymbolTable.regress \
- ThreeDimensionalMatrix.regress \
- ThreeDimensionalViewport.regress \
- ThreeSpace.regress \
- ThreeSpaceCategory.regress \
- ToolsForSign.regress \
- TopLevelDrawFunctions.regress \
- TopLevelDrawFunctionsForAlgebraicCurves.regress \
- TopLevelDrawFunctionsForCompiledFunctions.regress \
- TopLevelDrawFunctionsForPoints.regress \
- TopLevelThreeSpace.regress \
- TranscendentalFunctionCategory.regress \
- TranscendentalHermiteIntegration.regress \
- TranscendentalIntegration.regress \
- TranscendentalManipulations.regress \
- TranscendentalRischDE.regress \
- TranscendentalRischDESystem.regress \
- TransSolvePackage.regress \
- TransSolvePackageService.regress \
- Tree.regress \
- TriangularSetCategory.regress \
- TriangularMatrixOperations.regress \
- TrigonometricFunctionCategory.regress \
- TrigonometricManipulations.regress \
- TubePlot.regress \
- TubePlotTools.regress \
- Tuple.regress \
- TwoDimensionalArray.regress \
- TwoDimensionalArrayCategory.regress \
- TwoDimensionalPlotClipping.regress \
- TwoFactorize.regress \
- UnaryRecursiveAggregate.regress \
- UniqueFactorizationDomain.regress \
- UnitsKnownAttribute.regress \
- UnivariateFactorize.regress \
- UnivariateFormalPowerSeries.regress \
- UnivariateFormalPowerSeriesFunctions.regress \
- UnivariateLaurentSeries.regress \
- UnivariateLaurentSeriesCategory.regress \
- UnivariateLaurentSeriesConstructor.regress \
- UnivariateLaurentSeriesConstructorCategory.regress \
- UnivariateLaurentSeriesFunctions2.regress \
- UnivariatePolynomial.regress \
- UnivariatePolynomialCategory.regress \
- UnivariatePolynomialCategoryFunctions2.regress \
- UnivariatePolynomialCommonDenominator.regress \
- UnivariatePolynomialDecompositionPackage.regress \
- UnivariatePolynomialDivisionPackage.regress \
- UnivariatePolynomialFunctions2.regress \
- UnivariatePolynomialMultiplicationPackage.regress \
- UnivariatePolynomialSquareFree.regress \
- UnivariatePowerSeriesCategory.regress \
- UnivariatePuiseuxSeries.regress \
- UnivariatePuiseuxSeriesCategory.regress \
- UnivariatePuiseuxSeriesConstructor.regress \
- UnivariatePuiseuxSeriesConstructorCategory.regress \
- UnivariatePuiseuxSeriesFunctions2.regress \
- UnivariatePuiseuxSeriesWithExponentialSingularity.regress \
- UnivariateSkewPolynomial.regress \
- UnivariateSkewPolynomialCategory.regress \
- UnivariateSkewPolynomialCategoryOps.regress \
- UnivariateTaylorSeries.regress \
- UnivariateTaylorSeriesCZero.regress \
- UnivariateTaylorSeriesCategory.regress \
- UnivariateTaylorSeriesFunctions2.regress \
- UnivariateTaylorSeriesODESolver.regress \
- UniversalSegment.regress \
- UniversalSegmentFunctions2.regress \
- UserDefinedPartialOrdering.regress \
- UserDefinedVariableOrdering.regress \
- UTSodetools.regress \
- U8Matrix.regress \
- U16Matrix.regress \
- U32Matrix.regress \
- U32VectorPolynomialOperations.regress \
- U8Vector.regress \
- U16Vector.regress \
- U32Vector.regress \
- Variable.regress \
- Vector.regress \
- VectorCategory.regress \
- VectorFunctions2.regress \
- VectorSpace.regress \
- ViewDefaultsPackage.regress \
- ViewportPackage.regress \
- Void.regress \
- WeightedPolynomials.regress \
- WeierstrassPreparation.regress \
- WildFunctionFieldIntegralBasis.regress \
- WuWenTsunTriangularSet.regress \
- XAlgebra.regress \
- XDistributedPolynomial.regress \
- XExponentialPackage.regress \
- XFreeAlgebra.regress \
- XPBWPolynomial.regress \
- XPolynomial.regress \
- XPolynomialRing.regress \
- XPolynomialsCat.regress \
- XRecursivePolynomial.regress \
- ZeroDimensionalSolvePackage.regress 
-# these requires graphics
-# TwoDimensionalViewport
-
-%.regress: %.input
-	@ echo sa14 algebra regression testing $*
-	@ rm -f $*.output 
-	@ if [ -z "${NOISE}" ] ; then \
-           echo ')read $*.input' | ${TESTSYS} ; \
-	  else \
-           echo ')read $*.input' | ${TESTSYS} >${TMP}/trace ; \
-	  fi 
-	@ rm $*.input 
-	@ if [ -z "${NOISE}" ] ; then \
-           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
-                | egrep -v '(Timestamp|Version)' | tee $*.regress ; \
-	  else \
-           echo ')lisp (regress "$*.output")' | ${TESTSYS} \
-                | egrep -v '(Timestamp|Version)' > $*.regress ; \
-	  fi 
-	@ fgrep "regression result" $*.regress 
-
-all: announce ${REGRESS}
-	@echo sa15 algebra test cases complete.
-
-announce:
-	@ echo ======================================
-	@ echo src/algebra RUNNING REGRESSION TESTING
-	@ echo ======================================
-
-\end{chunk}
-\section{The Makefile}
-
-\begin{chunk}{*}
-
-\getchunk{environment}
-
-\getchunk{layer0 bootstrap}
-\getchunk{layer0 copy}
-\getchunk{layer0}
-\getchunk{layer1}
-\getchunk{layer2}
-\getchunk{layer3}
-\getchunk{layer4}
-\getchunk{layer5}
-\getchunk{layer6}
-\getchunk{layer7}
-\getchunk{layer8}
-\getchunk{layer9}
-\getchunk{layer10}
-\getchunk{layer11}
-\getchunk{layer12}
-\getchunk{layer13}
-\getchunk{layer14}
-\getchunk{layer15}
-\getchunk{layer16}
-\getchunk{layer17}
-\getchunk{layer18}
-\getchunk{layer19}
-\getchunk{layer20}
-\getchunk{layer21}
-\getchunk{layer22}
-\getchunk{layer23}
-\getchunk{order}
-
-all: fasthelp fastinput fastxhtml src ${OUT}/libdb.text \
-     ${SPADBIN}/index.html gloss
-	@ echo sa16 finished ${IN}
-
-fasthelp:
-	@ echo ======================================
-	@ echo src/algebra BUILDING HELP FILES
-	@ echo ======================================
-	@echo sa17 making .help files with lisp
-	@ echo "(makeHelpFiles)" | ${LISP}
-
-fastinput:
-	@ echo ======================================
-	@ echo src/algebra BUILDING INPUT FILES
-	@ echo ======================================
-	@echo sa18 making .input files with lisp
-	@ echo "(makeInputFiles)" | ${LISP}
-
-fastxhtml:
-	@ echo ======================================
-	@ echo src/algebra BUILDING XHTML FILES
-	@ echo ======================================
-	@echo sa19 making .xhtml files with lisp
-	@ mkdir -p ${MNT}/doc
-	@ echo "(makeXHTMLFiles)" | ${LISP}
-
-\getchunk{newcode}
-
-${SPADBIN}/index.html:
-	@ echo sa20 making ${SPADBIN}/index.html
-	@ echo "<html><head>Axiom Algebra</head><body>" >${SPADBIN}/index.html
-	@- (for i in ${IN}/*.pamphlet ; do \
-	   ${TANGLE} -R'algebra html' $$i 2>/dev/null | \
-             sed -e 's?DOC?${DOC}?g' >>${SPADBIN}/index.html ; \
-	   done)
-	@ echo "</body></html>" >>${SPADBIN}/index.html
-
-#all:	${SUBPART}
-
-gloss:
-	@ echo sa21 copying glossary files
-	@ cp ${SRC}/share/algebra/gloss.text ${MNT}/${SYS}/algebra
-	@ cp ${SRC}/share/algebra/glossdef.text ${MNT}/${SYS}/algebra
-	@ cp ${SRC}/share/algebra/glosskey.text ${MNT}/${SYS}/algebra
-
-everything: lib db cmd gloss
-	@ echo sa22 invoking make in `pwd` with parms:
-	@ echo SYS= ${SYS} LSP= ${LSP} PART= ${PART} SUBPART= ${SUBPART}
-	@ echo SPAD= ${SPAD} SRC= ${SRC} INT= ${INT}
-	@ echo OBJ= ${OBJ} MNT= ${MNT} O=${O} LISP=${LISP} BYE=${BYE}
-
-src:	announce ${ORDER}
-	@ echo sa23 Finished uilding nrlibS from spad sources
-
-announce:
-	@ echo ======================================
-	@ echo src/algebra BUILDING ALGEBRA FILES
-	@ echo ======================================
-
-\getchunk{genericRules}
-\getchunk{ps (DOC from SRC)}
-\getchunk{libdb.text (OUT from IN)}
-\getchunk{stages}
-
-clean:
-	@echo sa24 src/algebra cleaned
-
-\end{chunk}
-\eject
-\begin{thebibliography}{99}
-\bibitem{1} nothing
-\end{thebibliography}
-\end{document}
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 6e150b4..a519aab 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4546,6 +4546,8 @@ zips/gcl-2.6.10.tgz add the latest gcl and all of its patches
 books/bookvol5 GCL 2.6.10 assoc sematics change requires GETL fix
 <a href="patches/20140712.01.tpd.patch">20140712.01.tpd.patch</a>
 books/bookvol5  remove compression
+<a href="patches/20140713.01.tpd.patch">20140713.01.tpd.patch</a>
+books/bookvol10 absorb src/algebra/Makefile
  </body>
 </html>
 
